@@ -17,8 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <assert.h>
 #include <string.h>
 
 /* libxml includes */
@@ -117,7 +115,7 @@ static void pause_board (gboolean pause)
   if(gcomprisBoard==NULL)
     return;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
   if(gamewon == TRUE && pause == FALSE) /* the game is won */
     game_won();
 
@@ -135,8 +133,8 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
     gcomprisBoard->sublevel = 1;
     gcomprisBoard->number_of_sublevel = 8;
 
-    gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
-    gcompris_score_start(SCORESTYLE_NOTE,
+    gc_bar_set(GC_BAR_LEVEL);
+    gc_score_start(SCORESTYLE_NOTE,
 			 gcomprisBoard->width - 220,
 			 gcomprisBoard->height - 50,
 			 gcomprisBoard->number_of_sublevel);
@@ -159,7 +157,7 @@ static void end_board () {
 
   if(gcomprisBoard!=NULL){
     pause_board(TRUE);
-    gcompris_score_end();
+    gc_score_end();
     colors_destroy_all_items();
     // free list
     while (g_list_length(listColors) > 0)
@@ -205,8 +203,8 @@ static void colors_next_level() {
   colors_destroy_all_items();
   gamewon = FALSE;
 
-  gcompris_score_set(gcomprisBoard->sublevel);
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_score_set(gcomprisBoard->sublevel);
+  gc_bar_set_level(gcomprisBoard);
 
   /* initialize board only once*/
   if (gcomprisBoard->sublevel == 1) {
@@ -227,7 +225,7 @@ static void colors_next_level() {
     /* set background */
     str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir, backgroundFile);
     g_warning("background = %s\n", str);
-    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), str);
+    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), str);
     g_free(str);
   }
 
@@ -237,7 +235,7 @@ static void colors_next_level() {
   color_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", colors[GPOINTER_TO_INT(g_list_nth_data(listColors,0))],
-				      "font", gcompris_skin_font_board_title_bold,
+				      "font", gc_skin_font_board_title_bold,
 				      "x", (double) (color_x1+color_x2)/2,
 				      "y", (double) (color_y1+color_y2)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
@@ -272,7 +270,7 @@ static GnomeCanvasItem *colors_create_item(GnomeCanvasGroup *parent) {
 							    NULL));
 
   str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir, "advanced_colors_highlight.png");
-  highlight_pixmap = gcompris_load_pixmap(str);
+  highlight_pixmap = gc_pixmap_load(str);
 
   highlight_image_item = gnome_canvas_item_new (boardRootItem,
 						gnome_canvas_pixbuf_get_type (),
@@ -296,7 +294,7 @@ static GnomeCanvasItem *colors_create_item(GnomeCanvasGroup *parent) {
 
   /* setup the clock */
   str = g_strdup_printf("%s%d.png", "gcompris/timers/clock",errors);
-  clock_pixmap = gcompris_load_pixmap(str);
+  clock_pixmap = gc_pixmap_load(str);
 
   clock_image_item = gnome_canvas_item_new (boardRootItem,
 					    gnome_canvas_pixbuf_get_type (),
@@ -324,7 +322,7 @@ static void game_won() {
     gcomprisBoard->level++;
     gcomprisBoard->sublevel = 1;
     if (gcomprisBoard->level > gcomprisBoard->maxlevel) {
-      board_finished(BOARD_FINISHED_TUXLOCO);
+      gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
       return;
     }
 
@@ -340,7 +338,7 @@ static void game_won() {
  * =====================================================================*/
 static gboolean ok_timeout() {
   g_warning("+++ ok_timeout errors = %d\n", errors);
-  gcompris_display_bonus(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, BONUS_SMILEY);
   if (!gamewon)
     errors--;
   if (errors <1)
@@ -348,14 +346,14 @@ static gboolean ok_timeout() {
   update_clock();
 
   if (errors <= 1) {
-    board_finished(BOARD_FINISHED_TOOMANYERRORS);
+    gc_bonus_end_display(BOARD_FINISHED_TOOMANYERRORS);
   }
 
   return FALSE;
 }
 
 static void ok() {
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
   // leave time to display the right answer
   g_timeout_add(TIME_CLICK_TO_BONUS, ok_timeout, NULL);
 }
@@ -407,7 +405,7 @@ static void update_clock() {
 
   gtk_object_destroy (GTK_OBJECT(clock_image_item));
 
-  clock_pixmap = gcompris_load_pixmap(str);
+  clock_pixmap = gc_pixmap_load(str);
 
   clock_image_item = gnome_canvas_item_new (boardRootItem,
 					    gnome_canvas_pixbuf_get_type (),
@@ -429,7 +427,7 @@ static void update_clock() {
 static void highlight_selected(int c) {
   int x, y;
 
-  assert(c>=0 && c<8);
+  g_assert(c>=0 && c<8);
 
   x = (X[c*2] + X[c*2+1]) /2;
   y = (Y[(int)(c/4)*2] + Y[(int)(c/4)*2+1]) /2;
@@ -437,7 +435,7 @@ static void highlight_selected(int c) {
   x -= highlight_width/2;
   y -= highlight_height;
   gnome_canvas_item_show(highlight_image_item);
-  item_absolute_move(highlight_image_item, x, y);
+  gc_item_absolute_move(highlight_image_item, x, y);
 }
 
 /* ===================================
@@ -446,12 +444,13 @@ static void highlight_selected(int c) {
 static void init_xml()
 {
   char *filename;
-  filename = g_strdup_printf("%s/%s/board%d.xml", PACKAGE_DATA_DIR, gcomprisBoard->boarddir,
-			     gcomprisBoard->level);
-  g_warning("filename = %s %s %s\n", filename,PACKAGE_DATA_DIR,gcomprisBoard->boarddir);
 
-  assert(g_file_test(filename, G_FILE_TEST_EXISTS));
-  assert(read_xml_file(filename)== TRUE);
+  filename = gc_file_find_absolute("%s/board%d.xml",
+			     gcomprisBoard->boarddir,
+			     gcomprisBoard->level);
+
+  g_assert(read_xml_file(filename)== TRUE);
+
   g_free(filename);
 }
 
@@ -459,47 +458,32 @@ static void init_xml()
 static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
   char *text = NULL;
-  char * tmp = NULL;
   char *sColor = NULL;
-  int color = 0;
   int i;
-  gchar *lang;
 
   xmlnode = xmlnode->xmlChildrenNode;
 
   xmlnode = xmlnode->next;
 
-  while (xmlnode != NULL) {
-    if (!strcmp(xmlnode->name, "pixmapfile"))
-      backgroundFile = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+  while (xmlnode != NULL)
+    {
+      if (!strcmp((char *)xmlnode->name, "pixmapfile"))
+	backgroundFile = (char *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
 
-    lang = xmlGetProp(xmlnode,"lang");
-
-    // try to match color[i]
-    for (i=0; i<8; i++) {
-      sColor = g_strdup_printf("color%d", i+1);
-      if (!strcmp(xmlnode->name, sColor)) {
-	if (lang == NULL) { // get default value
-	  text = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	  colors[i] = text;
-	} else { // get correct language
-	  if ( !strncmp(lang, gcompris_get_locale(), strlen(lang)) ) {
-	    text = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	    g_warning("color prop::lang=%s locale=%s text=%s\n", lang, gcompris_get_locale(), text);
-	    colors[i] = text;
-	  }
-	}
-	g_free(sColor);
-	break;
-      }
-      g_free(sColor);
-    } // end for
-    xmlnode = xmlnode->next;
-  }
-
-  g_warning("colors found in XML:\n");
-  for (color=0; color<8; color++)
-    g_warning("%d %s\n", color, colors[color]);
+      // try to match color[i]
+      for (i=0; i<8; i++)
+	{
+	  sColor = g_strdup_printf("color%d", i+1);
+	  if (!strcmp((char *)xmlnode->name, sColor))
+	    {
+	      colors[i] = gettext((char *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1));
+	      g_free(sColor);
+	      break;
+	    }
+	  g_free(sColor);
+	} // end for
+      xmlnode = xmlnode->next;
+    }
 
   // I really don't know why this test, but otherwise, the list is doubled
   // with 1 line on 2 filled with NULL elements
@@ -514,8 +498,8 @@ static void parse_doc(xmlDocPtr doc)
   xmlNodePtr node;
 
   for(node = doc->children->children; node != NULL; node = node->next) {
-    if ( g_strcasecmp(node->name, "Board") == 0 )
-      add_xml_data(doc, node,NULL);
+    if ( g_strcasecmp((char *)node->name, "Board") == 0 )
+      add_xml_data(doc, node, NULL);
   }
 
 }
@@ -529,16 +513,9 @@ static gboolean read_xml_file(char *fname)
 
   g_return_val_if_fail(fname!=NULL,FALSE);
 
-  /* if the file doesn't exist */
-  if(!g_file_test(fname, G_FILE_TEST_EXISTS))
-    {
-      g_warning("Couldn't find file %s !", fname);
-      return FALSE;
-    }
-  g_warning("found file %s !", fname);
-
   /* parse the new file and put the result into newdoc */
-  doc = xmlParseFile(fname);
+  doc = gc_net_load_xml(fname);
+
   /* in case something went wrong */
   if(!doc)
     return FALSE;
@@ -548,7 +525,7 @@ static gboolean read_xml_file(char *fname)
      /* if it doesn't have a name */
      !doc->children->name ||
      /* if it isn't a ImageId node */
-     g_strcasecmp(doc->children->name,"AdvancedColors")!=0) {
+     g_strcasecmp((char *)doc->children->name,"AdvancedColors")!=0) {
     xmlFreeDoc(doc);
     return FALSE;
   }
