@@ -1,6 +1,6 @@
 /* gcompris - algebra.c
  *
- * Time-stamp: <2006/03/02 00:38:14 bruno>
+ * Time-stamp: <2006/08/21 23:29:57 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -52,16 +52,18 @@ static char *expected_result = NULL;
 
 static gboolean operation_done[11];
 
-typedef struct {
+typedef struct _ToBeFoundItem ToBeFoundItem;
+
+struct _ToBeFoundItem{
   guint index;
   GnomeCanvasItem *item;
   GnomeCanvasItem *focus_item;
   GnomeCanvasItem *bad_item;
-  char *next;  /* Help : Should point to a ToBeFoundItem but don't know how to recurse on it */
-  char *previous;
+  ToBeFoundItem *next;
+  ToBeFoundItem *previous;
   char value;
   gboolean in_error;
-} ToBeFoundItem;
+};
 static ToBeFoundItem *currentToBeFoundItem = NULL;
 
 static GnomeCanvasGroup *boardRootItem = NULL;
@@ -133,13 +135,13 @@ static void pause_board (gboolean pause)
     return;
 
   /* Make the timer follow our pause status */
-  gcompris_timer_pause(pause);
+  gc_timer_pause(pause);
 
   if(gamewon == TRUE && pause == FALSE) /* the game is won */
       algebra_next_level();
 
   if(leavenow == TRUE && pause == FALSE)
-    board_finished(BOARD_FINISHED_RANDOM);
+    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
 
   board_paused = pause;
 }
@@ -156,18 +158,18 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery2_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery2_background.png");
 
       /* set initial values for this level */
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=9;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=10; /* Go to next level after this number of 'play' */
-      gcompris_score_start(SCORESTYLE_NOTE, 
+      gc_score_start(SCORESTYLE_NOTE, 
 			   gcomprisBoard->width - 220, 
 			   gcomprisBoard->height - 50, 
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
       /* The mode defines the operation */
 
@@ -200,7 +202,7 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       algebra_destroy_all_items();
     }
   gcomprisBoard = NULL;
@@ -338,7 +340,7 @@ static void timer_end()
   gamewon = FALSE;
   leavenow = TRUE;
   algebra_destroy_all_items();
-  gcompris_display_bonus(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, BONUS_SMILEY);
 }
 
 
@@ -346,8 +348,8 @@ static void timer_end()
 static void algebra_next_level() 
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_bar_set_level(gcomprisBoard);
+  gc_score_set(gcomprisBoard->sublevel);
 
   algebra_destroy_all_items();
 
@@ -359,7 +361,7 @@ static void algebra_next_level()
 							    NULL));
 
   maxtime = 20;
-  gcompris_timer_display(TIMER_X, TIMER_Y, 
+  gc_timer_display(TIMER_X, TIMER_Y, 
 			 GCOMPRIS_TIMER_BALLOON, maxtime, timer_end);
 
   /* Try the next level */
@@ -378,9 +380,9 @@ static void algebra_destroy_item(GnomeCanvasItem *item)
 static void algebra_destroy_all_items()
 {
   GnomeCanvasItem *item;
-  gboolean stop = FALSE;
+  ToBeFoundItem *next;
 
-  gcompris_timer_end();
+  gc_timer_end();
 
   while(g_list_length(item_list)>0) 
     {
@@ -388,29 +390,12 @@ static void algebra_destroy_all_items()
       algebra_destroy_item(item);
     }
 
-  if(currentToBeFoundItem!=NULL)
-    {
-      /* Move toBeFoundItem to the most next digit */
-      while(!stop)
-	{
-	  if(currentToBeFoundItem->next!=NULL)
-	    currentToBeFoundItem = (ToBeFoundItem *)currentToBeFoundItem->next;
-	  else
-	    stop = TRUE;
-	}
-      
-      /* Now free toBeFoundItems */
-      while(!stop)
-	{
-	  if(currentToBeFoundItem->previous!=NULL)
-	    {
-	      currentToBeFoundItem = (ToBeFoundItem *)currentToBeFoundItem->previous;
-	      free(currentToBeFoundItem->next);
-	    }
-	  else
-	    stop = TRUE;
-	}
-    }
+  while(currentToBeFoundItem)
+  {
+      next = currentToBeFoundItem -> next;
+      g_free(currentToBeFoundItem);
+      currentToBeFoundItem = next;
+  }
 
   if(boardRootItem!=NULL)
     gtk_object_destroy (GTK_OBJECT(boardRootItem));
@@ -439,7 +424,7 @@ static void display_operand(GnomeCanvasGroup *parent,
       item = gnome_canvas_item_new (parent,
 				    gnome_canvas_text_get_type (),
 				    "text", &operand, 
-				    "font", gcompris_skin_font_board_huge_bold,
+				    "font", gc_skin_font_board_huge_bold,
 				    "anchor", GTK_ANCHOR_CENTER,
 				    "x", x_align-((strlen(operand_str)-i)*NUMBERSWIDTH),
 				    "y", y,
@@ -452,7 +437,7 @@ static void display_operand(GnomeCanvasGroup *parent,
 	  focus_item = gnome_canvas_item_new (parent,
 					      gnome_canvas_text_get_type (),
 					      "text", "_",
-					      "font", gcompris_skin_font_board_huge_bold,
+					      "font", gc_skin_font_board_huge_bold,
 					      "anchor", GTK_ANCHOR_CENTER,
 					      "x", x_align-((strlen(operand_str)-i)*NUMBERSWIDTH),
 					      "y", y,
@@ -464,7 +449,7 @@ static void display_operand(GnomeCanvasGroup *parent,
 	  bad_item = gnome_canvas_item_new (parent,
 					    gnome_canvas_text_get_type (),
 					    "text", "/",
-					    "font", gcompris_skin_font_board_huge_bold,
+					    "font", gc_skin_font_board_huge_bold,
 					    "anchor", GTK_ANCHOR_CENTER,
 					    "x", x_align-((strlen(operand_str)-i)*NUMBERSWIDTH),
 					    "y", y,
@@ -484,12 +469,12 @@ static void display_operand(GnomeCanvasGroup *parent,
 	  toBeFoundItem->value='?';
 	  toBeFoundItem->item=item;
 	  toBeFoundItem->focus_item=focus_item;
-	  toBeFoundItem->previous=(char *)previousToBeFoundItem;
+	  toBeFoundItem->previous=previousToBeFoundItem;
 	  toBeFoundItem->next=NULL;
 
 	  /* I Create a double linked list with the toBeFoundItem in order to navigate through them */
 	  if(previousToBeFoundItem!=NULL)
-	    previousToBeFoundItem->next=(char *)toBeFoundItem;
+	    previousToBeFoundItem->next=toBeFoundItem;
 
 	  previousToBeFoundItem=toBeFoundItem;
 
@@ -552,7 +537,7 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
   item = gnome_canvas_item_new (parent,
 				gnome_canvas_text_get_type (),
 				"text", currentOperation, 
-				"font", gcompris_skin_font_board_huge_bold,
+				"font", gc_skin_font_board_huge_bold,
 				"x", x,
 				"y", y,
 				"anchor", GTK_ANCHOR_CENTER,
@@ -564,7 +549,7 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
   item = gnome_canvas_item_new (parent,
 				gnome_canvas_text_get_type (),
 				"text", "=", 
-				"font", gcompris_skin_font_board_huge_bold,
+				"font", gc_skin_font_board_huge_bold,
 				"x", x_align + NUMBERSWIDTH*(strlen(second_operand_str)+1),
 				"y", y,
 				"anchor", GTK_ANCHOR_CENTER,
@@ -578,19 +563,19 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
     {
     case PLUSSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand+second_operand);
-      audioOperand = "plus";
+      audioOperand = "sounds/$LOCALE/misc/plus.ogg";
       break;
     case MINUSSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand-second_operand);
-      audioOperand = "minus";
+      audioOperand = "sounds/$LOCALE/misc/minus.ogg";
       break;
     case BYSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand*second_operand);
-      audioOperand = "by";
+      audioOperand = "sounds/$LOCALE/misc/by.ogg";
       break;
     case DIVIDESIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand/second_operand);
-      audioOperand = "outof";
+      audioOperand = "sounds/$LOCALE/misc/outof.ogg";
       break;
     default:
       g_error("Bad Operation");
@@ -600,11 +585,34 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
 		  y_firstline, expected_result, TRUE);
   
 
-  gcompris_play_ogg(first_operand_str, audioOperand , second_operand_str, "equal", NULL);
+  {
+    gchar *str1 = NULL;
+    gchar *str2 = NULL;
 
-  g_free(first_operand_str);
-  g_free(second_operand_str);
+    if(strlen(first_operand_str)==1)
+      str1 = gc_sound_alphabet(first_operand_str);
+    else
+      str1 = g_strdup_printf("%s.ogg", first_operand_str);
 
+    if(strlen(second_operand_str)==1)
+      str2 = gc_sound_alphabet(second_operand_str);
+    else
+      str2 = g_strdup_printf("%s.ogg", second_operand_str);
+
+    g_free(first_operand_str);
+    g_free(second_operand_str);
+
+    first_operand_str = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str1);
+    second_operand_str = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str2);
+
+    gc_sound_play_ogg(first_operand_str, audioOperand , second_operand_str, "sounds/$LOCALE/misc/equal.ogg", NULL);
+
+    g_free(str1);
+    g_free(str2);
+
+    g_free(first_operand_str);
+    g_free(second_operand_str);
+  }
   return (item);
 }
 
@@ -685,7 +693,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
       currentToBeFoundItem=toBeFoundItem;
 
-      gcompris_play_ogg ("gobble", NULL);
+      gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
       break;
       
     default:
@@ -791,26 +799,15 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
 
     gamewon = TRUE;
     algebra_destroy_all_items();
-    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, BONUS_SMILEY);
     init_operation();
     return;
   }
   algebra_next_level();
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
