@@ -17,14 +17,8 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
-#define SOUNDLISTFILE PACKAGE
-
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
 
@@ -67,7 +61,10 @@ static void		 destroy_board(void);
 #define HORIZONTAL_SEPARATION 20
 #define VERTICAL_SEPARATION 20
 
-static char* background_images[] = {"gcompris/animals/tiger1_by_Ralf_Schmode","gcompris/animals/tigerdrink001.jpg","gcompris/animals/tigercub003.jpg", "gcompris/animals/tigerplay001.jpg"};
+static char* background_images[] = {"gcompris/animals/tiger1_by_Ralf_Schmode",
+				    "gcompris/animals/tigerdrink001.jpg",
+				    "gcompris/animals/tigercub003.jpg",
+				    "gcompris/animals/tigerplay001.jpg"};
 static const char  oper_values[] = {'+', '-', 'x', ':', '='};
 static const char *oper_images[] = {"plus", "minus", "by", "div", "equal"};
 static const int   num_values[] = {1,2,3,4,5,6,7,8,9,10,25,50,100};
@@ -192,29 +189,29 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
     g_warning("loading pixmaps in start_board\n");
     for (i=0; i<NUM_VALUES; i++) {
       str = g_strdup_printf("%s/%d.png", gcomprisBoard->boarddir,num_values[i]);
-      num_pixmap[i] = gcompris_load_pixmap(str);
+      num_pixmap[i] = gc_pixmap_load(str);
       g_free(str);
     }
     for (i=0; i<5; i++) {
       str = g_strdup_printf("%s/%s.png", gcomprisBoard->boarddir,oper_images[i]);
-      oper_pixmap[i] = gcompris_load_pixmap(str);
+      oper_pixmap[i] = gc_pixmap_load(str);
       g_free(str);
     }
 
     str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir,"button.png");
-    button_pixmap = gcompris_load_pixmap(str);
+    button_pixmap = gc_pixmap_load(str);
     g_free(str);
 
-    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),"gcompris/animals/tiger1_by_Ralf_Schmode.jpg");
+    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),"gcompris/animals/tiger1_by_Ralf_Schmode.jpg");
     gcomprisBoard->level=1;
     gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
     gcomprisBoard->sublevel=1;
     gcomprisBoard->number_of_sublevel=NUMBER_OF_SUBLEVELS; /* Go to next level after this number of 'play' */
-    gcompris_score_start(SCORESTYLE_NOTE,
+    gc_score_start(SCORESTYLE_NOTE,
 			 50,
 			 gcomprisBoard->height - 50,
 			 gcomprisBoard->number_of_sublevel);
-    gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+    gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
     algebra_guesscount_next_level();
 
@@ -228,7 +225,7 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
 static void end_board () {
   if(gcomprisBoard!=NULL) {
     pause_board(TRUE);
-    gcompris_score_end();
+    gc_score_end();
     destroy_board();
     algebra_guesscount_destroy_all_items();
   }
@@ -259,13 +256,13 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
 /* ==================================== */
 /* set initial values for the next level */
 static void algebra_guesscount_next_level() {
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   algebra_guesscount_destroy_all_items();
   gamewon = FALSE;
   token_count = 0;
 
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   /* Try the next level */
   algebra_guesscount_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -285,11 +282,11 @@ static int token_result() {
   if (token_count < 2)
     return NO_RESULT;
 
-  assert(ptr_token_selected[0]->isNumber);
+  g_assert(ptr_token_selected[0]->isNumber);
   result = num_values[ptr_token_selected[0]->num];
 
   for (i=2; i<token_count; i+=2) {
-    assert(!ptr_token_selected[i-1]->isNumber);
+    g_assert(!ptr_token_selected[i-1]->isNumber);
     switch (ptr_token_selected[i-1]->oper) {
     case '+' : 	result += num_values[ptr_token_selected[i]->num];
       break;
@@ -354,7 +351,7 @@ static int generate_numbers() {
     r = 2 + minus + divide;
 
     switch (RAND(1,r)) {
-    case 1 : 	
+    case 1 :
       answer_oper[i] = '+';
       result += num_values[answer_num_index[i+1]];
       break;
@@ -372,21 +369,21 @@ static int generate_numbers() {
       if (minus) {
 	answer_oper[i] = '-';
 	result -= num_values[answer_num_index[i+1]];
-	assert(result >= 0);
+	g_assert(result >= 0);
       } else {
 	answer_oper[i] = ':';
-	assert(result%num_values[answer_num_index[i+1]] == 0);
+	g_assert(result%num_values[answer_num_index[i+1]] == 0);
 	result /= num_values[answer_num_index[i+1]];
       }
       break;
-    case 4 : 
+    case 4 :
       if ( RAND(0,1) == 0) {
 	answer_oper[i] = '-';
 	result -= num_values[answer_num_index[i+1]];
-	assert(result >= 0);
+	g_assert(result >= 0);
       } else {
 	answer_oper[i] = ':';
-	assert(result%num_values[answer_num_index[i+1]] == 0);
+	g_assert(result%num_values[answer_num_index[i+1]] == 0);
 	result /= num_values[answer_num_index[i+1]];
       }
       break;
@@ -414,7 +411,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
     calcul_line_item_back[i*2] = gnome_canvas_item_new (boardRootItem,
 							gnome_canvas_text_get_type (),
 							"text", BLANK,
-							"font", gcompris_skin_font_board_title_bold,
+							"font", gc_skin_font_board_title_bold,
 							"x", (double) X_EQUAL+BUTTON_WIDTH*1.5 + 1,
 							"y", (double) y_equal_offset[i]+BUTTON_HEIGHT/2 + 1,
 							"anchor", GTK_ANCHOR_CENTER,
@@ -423,7 +420,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
     calcul_line_item[i*2] = gnome_canvas_item_new (boardRootItem,
 						   gnome_canvas_text_get_type (),
 						   "text", BLANK,
-						   "font", gcompris_skin_font_board_title_bold,
+						   "font", gc_skin_font_board_title_bold,
 						   "x", (double) X_EQUAL+BUTTON_WIDTH*1.5,
 						   "y", (double) y_equal_offset[i]+BUTTON_HEIGHT/2,
 						   "anchor", GTK_ANCHOR_CENTER,
@@ -435,7 +432,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
     calcul_line_item_back[i*2+1] = gnome_canvas_item_new (boardRootItem,
 							  gnome_canvas_text_get_type (),
 							  "text", BLANK,
-							  "font", gcompris_skin_font_board_title_bold,
+							  "font", gc_skin_font_board_title_bold,
 							  "x", (double) X_NUM1+BUTTON_WIDTH/2 + 1,
 							  "y", (double) y_equal_offset[i+1]+BUTTON_HEIGHT/2 + 1,
 							  "anchor", GTK_ANCHOR_CENTER,
@@ -444,7 +441,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
     calcul_line_item[i*2+1] = gnome_canvas_item_new (boardRootItem,
 						     gnome_canvas_text_get_type (),
 						     "text", BLANK,
-						     "font", gcompris_skin_font_board_title_bold,
+						     "font", gc_skin_font_board_title_bold,
 						     "x", (double) X_NUM1+BUTTON_WIDTH/2,
 						     "y", (double) y_equal_offset[i+1]+BUTTON_HEIGHT/2,
 						     "anchor", GTK_ANCHOR_CENTER,
@@ -465,7 +462,8 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
 					  "height_set", TRUE,
 					  NULL);
     xOffset += BUTTON_WIDTH+HORIZONTAL_SEPARATION;
-    gtk_signal_connect(GTK_OBJECT(oper_item[i]), "event", (GtkSignalFunc) item_event_oper, (void *) &(token_value[i*2+1]));
+    gtk_signal_connect(GTK_OBJECT(oper_item[i]), "event", (GtkSignalFunc) item_event_oper,
+		       GINT_TO_POINTER(&(token_value[i*2+1])) );
     token_value[i*2+1].isNumber = FALSE;
     token_value[i*2+1].isMoved = FALSE;
     token_value[i*2+1].oper = oper_values[i];
@@ -476,7 +474,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
   result_item_back = gnome_canvas_item_new (boardRootItem,
 					    gnome_canvas_text_get_type (),
 					    "text", str,
-					    "font", gcompris_skin_font_board_title_bold,
+					    "font", gc_skin_font_board_title_bold,
 					    "x", (double) xOffset+BUTTON_WIDTH +1,
 					    "y", (double) Y_OPE+BUTTON_HEIGHT/2 +1,
 					    "anchor", GTK_ANCHOR_CENTER,
@@ -485,7 +483,7 @@ static GnomeCanvasItem *algebra_guesscount_create_item(GnomeCanvasGroup *parent)
   result_item_front = gnome_canvas_item_new (boardRootItem,
 					     gnome_canvas_text_get_type (),
 					     "text", str,
-					     "font", gcompris_skin_font_board_title_bold,
+					     "font", gc_skin_font_board_title_bold,
 					     "x", (double) xOffset+BUTTON_WIDTH,
 					     "y", (double) Y_OPE+BUTTON_HEIGHT/2,
 					     "anchor", GTK_ANCHOR_CENTER,
@@ -541,10 +539,10 @@ static void game_won() {
     gcomprisBoard->level++;
 
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) {
-      board_finished(BOARD_FINISHED_TUXPLANE);
+      gc_bonus_end_display(BOARD_FINISHED_TUXPLANE);
       return;
     }
-    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),background_images[gcomprisBoard->level-1]);
+    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),background_images[gcomprisBoard->level-1]);
   }
   algebra_guesscount_next_level();
 }
@@ -560,13 +558,13 @@ static void process_time(){
     gtk_timeout_remove (process_time_id);
     process_time_id = 0;
   }
-  gcompris_display_bonus(gamewon, BONUS_RANDOM);
+  gc_bonus_display(gamewon, BONUS_RANDOM);
 }
 /* ==================================== */
 static int oper_char_to_pixmap_index(char oper) {
   int i;
 
-  assert(oper == '+' || oper == '-' || oper == 'x' || oper == ':' || oper == '=');
+  g_assert(oper == '+' || oper == '-' || oper == 'x' || oper == ':' || oper == '=');
 
   for (i=0; i<5; i++)
     if (oper_values[i] == oper)
@@ -639,7 +637,7 @@ static gint item_event_num(GnomeCanvasItem *item, GdkEvent *event, gpointer data
       if (item != ptr_token_selected[token_count-1]->item)
 	return FALSE;
       // we put back in its original place a number item
-      item_absolute_move(item, t->xOffset_original, Y_NUM);
+      gc_item_absolute_move(item, t->xOffset_original, Y_NUM);
       token_count--;
       update_line_calcul();
       t->isMoved = FALSE;
@@ -654,13 +652,13 @@ static gint item_event_num(GnomeCanvasItem *item, GdkEvent *event, gpointer data
 	return FALSE;
       }
 
-      item_absolute_move(item, x_token_offset[token_count-1], y_token_offset[token_count-1]);
+      gc_item_absolute_move(item, x_token_offset[token_count-1], y_token_offset[token_count-1]);
       t->isMoved = TRUE;
 
       // update result text items
       if (token_count != 1 && token_count % 2 == 1) {
 	sprintf(str,"%d",token_result());
-	
+
 	gnome_canvas_item_set(calcul_line_item[token_count-3], "text", str, NULL);
 	gnome_canvas_item_set(calcul_line_item_back[token_count-3], "text", str, NULL);
 
