@@ -1,15 +1,15 @@
 /*
  * gcompris - awele.c Copyright (C) 2005 Frederic Mazzarol This program is
- * free software; you can redistribute it and/or modify it under the terms 
+ * free software; you can redistribute it and/or modify it under the terms
  * of the GNU General Public License as published by the Free Software
  * Foundation; either version 2 of the License, or (at your option) any
  * later version.  This program is distributed in the hope that it will
  * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.  You should have received a
- * copy of the GNU General Public License along with this program; if not, 
+ * copy of the GNU General Public License along with this program; if not,
  * write to the Free Software Foundation, Inc., 59 Temple Place, Suite
- * 330, Boston, MA 02111-1307 USA 
+ * 330, Boston, MA 02111-1307 USA
  */
 
 #include "gcompris/gcompris.h"
@@ -52,7 +52,7 @@ static GcomprisAnimation *animation;
 static GcomprisAnimCanvasItem *anim_item;
 
 /*
- * Description of this plugin 
+ * Description of this plugin
  */
 static BoardPlugin menu_bp = {
 	NULL,
@@ -105,14 +105,14 @@ static void pause_board (gboolean pause)
 	      timeout = g_timeout_add (2000,
 				       (GSourceFunc) to_computer,
 				       NULL);
-	      anim_item = gcompris_activate_animation( boardRootItem,
+	      anim_item = gc_anim_activate( boardRootItem,
 						       animation );
 	      gnome_canvas_item_show(GNOME_CANVAS_ITEM(anim_item->canvas));
 	    }
 	}
 	else{
 	  if (computer_turn){
-	    gcompris_deactivate_animation(anim_item);
+	    gc_anim_deactivate(anim_item);
 	    if (timeout){
 	      g_source_remove(timeout);
 	      timeout = 0;
@@ -139,18 +139,18 @@ start_board (GcomprisBoard * agcomprisBoard)
 		gcomprisBoard->number_of_sublevel = 1;	/* Go to next level after
 							 * this number of 'play' */
 
-		str = gcompris_image_to_skin("button_reload.png");
-		pixmap = gcompris_load_pixmap(str);
+		str = gc_skin_image_get("button_reload.png");
+		pixmap = gc_pixmap_load(str);
 		g_free(str);
 		if(pixmap) {
-		  gcompris_bar_set_repeat_icon(pixmap);
+		  gc_bar_set_repeat_icon(pixmap);
 		  gdk_pixbuf_unref(pixmap);
-		  gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_REPEAT_ICON);
+		  gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT_ICON);
 		} else {
-		  gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_REPEAT);
+		  gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT);
 		}
 
-		animation = gcompris_load_animation( "connect4/sablier.txt" );
+		animation = gc_anim_load( "connect4/sablier.txt" );
 
 		awele_next_level ();
 
@@ -160,7 +160,7 @@ start_board (GcomprisBoard * agcomprisBoard)
 }
 
 /*
- * ======================================= 
+ * =======================================
  */
 static void
 end_board ()
@@ -168,7 +168,7 @@ end_board ()
 	if (gcomprisBoard != NULL)
 	{
 		pause_board (TRUE);
-		gcompris_free_animation(animation);
+		gc_anim_free(animation);
 		awele_destroy_all_items ();
 	}
 	gcomprisBoard = NULL;
@@ -182,7 +182,7 @@ is_our_board (GcomprisBoard * gcomprisBoard)
 		if (g_strcasecmp (gcomprisBoard->type, "awele") == 0)
 		{
 			/*
-			 * Set the plugin entry 
+			 * Set the plugin entry
 			 */
 			gcomprisBoard->plugin = &menu_bp;
 
@@ -198,7 +198,7 @@ is_our_board (GcomprisBoard * gcomprisBoard)
  */
 static void repeat (){
   if (computer_turn){
-    gcompris_deactivate_animation(anim_item);
+    gc_anim_deactivate(anim_item);
     if (timeout){
       g_source_remove(timeout);
       timeout = 0;
@@ -218,14 +218,14 @@ set_level (guint level)
       gcomprisBoard->sublevel = 1;
 
       if (computer_turn){
-	gcompris_deactivate_animation(anim_item);
+	gc_anim_deactivate(anim_item);
 	if (timeout){
 	  g_source_remove(timeout);
 	  timeout = 0;
 	}
       }
       awele_next_level();
-      
+
     }
 }
 
@@ -233,36 +233,36 @@ set_level (guint level)
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
 /*
- * set initial values for the next level 
+ * set initial values for the next level
  */
 static void
 awele_next_level ()
 {
         gchar *img;
 
-	img = gcompris_image_to_skin ("gcompris-bg.jpg");
-	gcompris_set_background (gnome_canvas_root (gcomprisBoard->canvas),
+	img = gc_skin_image_get ("gcompris-bg.jpg");
+	gc_set_background (gnome_canvas_root (gcomprisBoard->canvas),
 				 img);
 	g_free(img);
 
-	gcompris_bar_set_level (gcomprisBoard);
+	gc_bar_set_level (gcomprisBoard);
 
 	awele_destroy_all_items ();
 	gamewon = FALSE;
 	computer_turn = FALSE;
 
 	/*
-	 * Create the level 
+	 * Create the level
 	 */
 	awele_create_item (gnome_canvas_root (gcomprisBoard->canvas));
-	
+
 	if ((gcomprisBoard->level % 2) ==0){
 	  computer_turn = TRUE;
 	  staticAwale->player = HUMAN;
 	  timeout = g_timeout_add (2000,
 				   (GSourceFunc) to_computer,
 				   NULL);
-	  anim_item = gcompris_activate_animation( boardRootItem,
+	  anim_item = gc_anim_activate( boardRootItem,
 						   animation );
 	  gnome_canvas_item_show(GNOME_CANVAS_ITEM(anim_item->canvas));
 
@@ -272,10 +272,10 @@ awele_next_level ()
 }
 
 /*
- * ==================================== 
+ * ====================================
  */
 /*
- * Destroy all the items 
+ * Destroy all the items
  */
 static void
 awele_destroy_all_items ()
@@ -302,7 +302,7 @@ awele_destroy_all_items ()
 }
 
 /*
- * ==================================== 
+ * ====================================
  */
 static GnomeCanvasItem *
 awele_create_item (GnomeCanvasGroup * parent)
@@ -323,9 +323,9 @@ awele_create_item (GnomeCanvasGroup * parent)
 				     (double) 0, "y", (double) 0, NULL));
 
 	/*
-	 * Load the cute frame 
+	 * Load the cute frame
 	 */
-	pixmap = gcompris_load_pixmap ("awele/awele_frame.png");
+	pixmap = gc_pixmap_load ("awele/awele_frame.png");
 
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_pixbuf_get_type (),
@@ -350,21 +350,21 @@ awele_create_item (GnomeCanvasGroup * parent)
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", _("NORTH"),
-				 "font", gcompris_skin_font_board_medium,
+				 "font", gc_skin_font_board_medium,
 				 "x", (double) x + 1,
 				 "y", (double) y + 1,
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_shadow,
+				 "fill_color_rgba", gc_skin_color_shadow,
 				 NULL);
 
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", _("NORTH"),
-				 "font", gcompris_skin_font_board_medium,
+				 "font", gc_skin_font_board_medium,
 				 "x", (double) x,
 				 "y", (double) y,
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_text_button,
+				 "fill_color_rgba", gc_skin_color_text_button,
 				 NULL);
 
 	  x = 765;
@@ -372,21 +372,21 @@ awele_create_item (GnomeCanvasGroup * parent)
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", _("SOUTH"),
-				 "font", gcompris_skin_font_board_medium,
+				 "font", gc_skin_font_board_medium,
 				 "x", (double) x + 1,
 				 "y", (double) y + 1,
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_shadow,
+				 "fill_color_rgba", gc_skin_color_shadow,
 				 NULL);
 
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", _("SOUTH"),
-				 "font", gcompris_skin_font_board_medium,
+				 "font", gc_skin_font_board_medium,
 				 "x", (double) x,
 				 "y", (double) y,
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_text_button,
+				 "fill_color_rgba", gc_skin_color_text_button,
 				 NULL);
 
 	}
@@ -413,20 +413,20 @@ awele_create_item (GnomeCanvasGroup * parent)
 	graphsElt = (GRAPHICS_ELT *) g_malloc (sizeof (GRAPHICS_ELT));
 
 	/*
-	 * Boucle pour creer et positionner les boutons qui serviront 
+	 * Boucle pour creer et positionner les boutons qui serviront
 	 * a selectionner la case a jouer
 	 */
 	for (i = 0; i < NBHOLE / 2; i++)
 	{
 		sprintf (buffer, "%d", i + 1);
 		xpmFile[12] = buffer[0];
-		graphsElt->pixbufButton[i] = gcompris_load_pixmap (xpmFile);
+		graphsElt->pixbufButton[i] = gc_pixmap_load (xpmFile);
 		xpmFileNotify[12] = buffer[0];
 		graphsElt->pixbufButtonNotify[i] =
-			gcompris_load_pixmap (xpmFileNotify);
+			gc_pixmap_load (xpmFileNotify);
 		xpmFileClic[12] = buffer[0];
 		graphsElt->pixbufButtonClicked[i] =
-			gcompris_load_pixmap (xpmFileClic);
+			gc_pixmap_load (xpmFileClic);
 
 		/*
 		 * Ajustement de l'ordonnee x, pour positionner le bouton sur la barre de boutons.
@@ -493,11 +493,11 @@ awele_create_item (GnomeCanvasGroup * parent)
 		graphsElt->nbBeansHole[i] =
 			gnome_canvas_item_new (boardRootItem,
 					       gnome_canvas_text_get_type (),
-					       "text", buffer, "font",
-					       "12x24", "size", 14000, "x",
-					       (double) (caseCoord[i] + 45),
-					       "y",
-					       (double) ((i < 6) ? 378 : 94),
+					       "text", buffer,
+					       "font", "sans 12",
+					       "size", 14000,
+					       "x", (double) (caseCoord[i] + 45),
+					       "y", (double) ((i < 6) ? 378 : 94),
 					       "fill_color", "black", NULL);
 	}
 
@@ -518,7 +518,7 @@ awele_create_item (GnomeCanvasGroup * parent)
 								(), "text",
 								buffer,
 								"font",
-								"12x24",
+								"sans 12",
 								"size", 20000,
 								"x",
 								(double) x1,
@@ -538,7 +538,7 @@ awele_create_item (GnomeCanvasGroup * parent)
 	{
 		sprintf (buffer, "%d", i + 1);
 		xpmFile[12] = buffer[0];
-		graphsElt->pixbufBeans[i] = gcompris_load_pixmap (xpmFile);
+		graphsElt->pixbufBeans[i] = gc_pixmap_load (xpmFile);
 	}
 
 	/**
@@ -551,7 +551,7 @@ awele_create_item (GnomeCanvasGroup * parent)
 	graphsElt->msg = gnome_canvas_item_new (boardRootItem,
 						gnome_canvas_text_get_type (),
 						"text", _("Choose a house"),
-						"font", "12x24",
+						"font", "sans 12",
 						"size", 20000,
 						"x", (double) 400,
 						"y", (double) 500,
@@ -564,33 +564,33 @@ awele_create_item (GnomeCanvasGroup * parent)
 
 
 /*
- * ==================================== 
+ * ====================================
  */
 static void
 game_won ()
 {
   if (sublevel_finished){
     gcomprisBoard->sublevel++;
-    
+
     if (gcomprisBoard->sublevel > gcomprisBoard->number_of_sublevel)
       {
 	/*
-	 * Try the next level 
+	 * Try the next level
 	 */
 	gcomprisBoard->sublevel = 1;
 	gcomprisBoard->level++;
 	if (gcomprisBoard->level > gcomprisBoard->maxlevel)
 	  {		// the
-			// current 
+			// current
 			// board
 			// is
-			// finished 
+			// finished
 			// : bail
 			// out
-	    board_finished (BOARD_FINISHED_RANDOM);
+	    gc_bonus_end_display (BOARD_FINISHED_RANDOM);
 	    return;
 	  }
-	
+
       }
   }
   sublevel_finished = FALSE;
@@ -612,7 +612,7 @@ initBoardGraphics (GRAPHICS_ELT * graphsElt)
 
 
 	//if (graphsElt->ptBeansHoleLink != NULL)
-	//      free(graphsElt->ptBeansHoleLink);       
+	//      free(graphsElt->ptBeansHoleLink);
 
 	graphsElt->ptBeansHoleLink =
 		(BEANHOLE_LINK *) malloc (NBTOTALBEAN *
@@ -663,7 +663,7 @@ static gboolean  to_computer(gpointer data)
 
   coup = think (staticAwale, gcomprisBoard->level);
 
-  gcompris_deactivate_animation(anim_item);
+  gc_anim_deactivate(anim_item);
   computer_turn = FALSE;
 
   if (coup >= 0){
@@ -684,18 +684,18 @@ static gboolean  to_computer(gpointer data)
       /* Human player win by catching all the beans left. */
       gamewon = TRUE;
       sublevel_finished = TRUE;
-      gcompris_display_bonus(TRUE, BONUS_FLOWER);
+      gc_bonus_display(TRUE, BONUS_FLOWER);
     }
   } else {
-    /* computer can't play. Why? human is hungry and i cannot give it 
+    /* computer can't play. Why? human is hungry and i cannot give it
        to eat */
     /* if human has 24 beans, it's draw (human win in gcompris) */
     /* if not, all staying are captured by computer and computer win */
     gamewon = TRUE;
     sublevel_finished = (staticAwale->CapturedBeans[HUMAN] ==  24);
-    gcompris_display_bonus(sublevel_finished, BONUS_FLOWER);
+    gc_bonus_display(sublevel_finished, BONUS_FLOWER);
   }
-  
+
   timeout = 0;
   return FALSE;
 }
@@ -741,7 +741,7 @@ buttonClick (GtkWidget * item, GdkEvent * event, gpointer data)
 			"pixbuf",
 			graphsElt->pixbufButtonClicked[numeroCase],
 			"y", (double) Y_BOUTONS + 3, NULL);
-	  
+
 	  g_object_set (graphsElt->msg, "text", "", NULL);
 
 	  AWALE *tmpaw = moveAwale (numeroCase, staticAwale);
@@ -761,11 +761,11 @@ buttonClick (GtkWidget * item, GdkEvent * event, gpointer data)
 		timeout = g_timeout_add (2000,
 					 (GSourceFunc) to_computer,
 					 NULL);
-		anim_item = gcompris_activate_animation( boardRootItem,
+		anim_item = gc_anim_activate( boardRootItem,
 							 animation );
 	      }
 	    }
-	  
+
 	  break;
 	case GDK_BUTTON_RELEASE:
 	  g_object_set (GTK_OBJECT
@@ -797,15 +797,15 @@ static BEANHOLE_LINK *
 updateNbBeans (int alpha)
 {
 
-  char buffer[3];		//Manipulation chaines de caracteres            
+  char buffer[3];		//Manipulation chaines de caracteres
   int i, j, k, idxTabBeans = 0;	//Compteur Boucle Manipulation Elements graphiques
   static short int nbActiveBean = NBTOTALBEAN;	//nbre graine restant sur plateau
   static short int nbOldActiveBean;	//nbre graine restant sur plateau au tour precedent
   BEANHOLE_LINK *ptBeansHoleLink = NULL;	//pointeur sur structures stockant les item graines et la case dans laquelle elles se trouvent.
-  
+
   /**
-   *	Sauvegarde du nombre de graines restantes sur le plateau de jeu 
-   *	pour le prochain appel a la fonction. 
+   *	Sauvegarde du nombre de graines restantes sur le plateau de jeu
+   *	pour le prochain appel a la fonction.
    *	Mise a jour de nbActiveBean avec nouvelle configuration du plateau de jeu.
    */
   if (alpha)
@@ -816,11 +816,11 @@ updateNbBeans (int alpha)
     {
       nbOldActiveBean = nbActiveBean;
     }
-  
+
   nbActiveBean =
     NBTOTALBEAN - (staticAwale->CapturedBeans[HUMAN] +
 		   staticAwale->CapturedBeans[COMPUTER]);
-  
+
   /**
    *	Destruction d'autant d'elements graphiques graines
    *	qu'il y a eu de captures pdt ce tour de jeu
@@ -830,21 +830,21 @@ updateNbBeans (int alpha)
     {
       gtk_object_destroy (GTK_OBJECT (ptBeansHoleLink->beanPixbuf));
     }
-  
-  
+
+
   /**
-   *	Allocation d'un nouvel espace memoire stockant les item graines 
-   *	et la case dans laquelle elles se trouvent. Puis liberation de la fin de 
+   *	Allocation d'un nouvel espace memoire stockant les item graines
+   *	et la case dans laquelle elles se trouvent. Puis liberation de la fin de
    *	l'ancien espace memoire.
    */
-  
+
   ptBeansHoleLink =
     (BEANHOLE_LINK *) realloc (graphsElt->ptBeansHoleLink,
 			       nbActiveBean *
 			       sizeof (BEANHOLE_LINK));
-  
+
   /**
-   *	Pour chaque case du plateau, mise a jour du nbre de graines qu'elle contient. 
+   *	Pour chaque case du plateau, mise a jour du nbre de graines qu'elle contient.
    *	Et pour chaque graine de cette case, deplacement d'un element graphique type graine
    *	dans cette case. Et mise a jour de l'information hole dans la structure BEANHOLE_LINK.
    */
@@ -852,14 +852,14 @@ updateNbBeans (int alpha)
     {
       sprintf (buffer, "%d", staticAwale->board[i]);
       gnome_canvas_item_set (graphsElt->nbBeansHole[i], "text", buffer, NULL);
-      
+
       for (j = 0;
 	   j < staticAwale->board[i] && idxTabBeans < nbActiveBean;
 	   j++, idxTabBeans++)
 	{
-	  
+
 	  k = 0 + rand () % 4;
-	  
+
 	  gnome_canvas_item_set (ptBeansHoleLink[idxTabBeans].
 				 beanPixbuf, "x",
 				 (double) caseCoord[i] +
@@ -867,16 +867,16 @@ updateNbBeans (int alpha)
 				 (double) (((i <
 					     6) ? 260 : 130) +
 					   rand () % 60), NULL);
-	  
+
 	  ptBeansHoleLink[idxTabBeans].hole = i;
 	}
-      
+
     }
-  
+
   /**
    *	Renvoi du pointeur sur la zone memoire retaillee (n'a probablement pas change d'adresse).
    */
-  
+
   graphsElt->ptBeansHoleLink = ptBeansHoleLink;
   return ptBeansHoleLink;
 }
@@ -900,11 +900,11 @@ updateCapturedBeans ()
 		sprintf (buffer, "%d", staticAwale->CapturedBeans[i]);
 		g_object_set (graphsElt->Captures[i], "text", buffer, NULL);
  		if (staticAwale->CapturedBeans[i] > 24)
- 		  { 
+ 		  {
  		    gamewon = TRUE;
 		    sublevel_finished = (i==0);
- 		    gcompris_display_bonus(sublevel_finished, BONUS_FLOWER);
- 		  } 
+ 		    gc_bonus_display(sublevel_finished, BONUS_FLOWER);
+ 		  }
 	}
 }
 
