@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -170,7 +166,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       canal_lock_next_level();
 
-      gcompris_bar_set(0);
+      gc_bar_set(0);
 
       animation = FALSE;
 
@@ -229,10 +225,10 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void canal_lock_next_level()
 {
 
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  "canal_lock/canal_lock_bg.png");
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   canal_lock_destroy_all_items();
   gamewon = FALSE;
@@ -272,11 +268,11 @@ static GnomeCanvasItem *canal_lock_create_item(GnomeCanvasGroup *parent)
 							    NULL));
 
   /* The boat */
-  pixmap = gcompris_load_pixmap("gcompris/misc/tuxboat.png");
+  pixmap = gc_pixmap_load("gcompris/misc/tuxboat.png");
 
   tuxboat_item = gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_pixbuf_get_type (),
-					"pixbuf",  pixmap, 
+					"pixbuf",  pixmap,
 					"x", (double) (LEFT_CANAL_WIDTH - gdk_pixbuf_get_width(pixmap)) / 2,
 					"y", (double) BASE_LINE - LEFT_CANAL_HEIGHT - gdk_pixbuf_get_height(pixmap)*0.9,
 					NULL);
@@ -284,9 +280,10 @@ static GnomeCanvasItem *canal_lock_create_item(GnomeCanvasGroup *parent)
 		     (GtkSignalFunc) item_event,
 		     NULL);
   gtk_signal_connect(GTK_OBJECT(tuxboat_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
   tuxboat_width = gdk_pixbuf_get_width(pixmap);
+  gdk_pixbuf_unref(pixmap);
 
   /* This is the ground canal */
   gnome_canvas_item_new (boardRootItem,
@@ -405,7 +402,7 @@ static GnomeCanvasItem *canal_lock_create_item(GnomeCanvasGroup *parent)
 			 NULL);
 
   /* And to finish, the 2 canal locks */
-  canallock_left_item = 
+  canallock_left_item =
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_rect_get_type (),
 			   "x1", (double) LEFT_CANAL_WIDTH + MIDDLE_CANAL_WIDTH * 0.1,
@@ -419,7 +416,7 @@ static GnomeCanvasItem *canal_lock_create_item(GnomeCanvasGroup *parent)
 		     (GtkSignalFunc) item_event,
 		     NULL);
 
-  canallock_right_item = 
+  canallock_right_item =
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_rect_get_type (),
 			   "x1", (double) LEFT_CANAL_WIDTH + MIDDLE_CANAL_WIDTH * 0.9,
@@ -447,10 +444,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   canal_lock_next_level();
 }
@@ -492,12 +489,12 @@ static void move_boat()
   else
     {
       /* No possible move */
-      gcompris_play_ogg ("crash", NULL);
+      gc_sound_play_ogg ("sounds/crash.ogg", NULL);
       animation = FALSE;
       return;
     }
 
-  gnome_canvas_item_get_bounds(tuxboat_item, &timer_item_x1, &timer_item_y1, 
+  gnome_canvas_item_get_bounds(tuxboat_item, &timer_item_x1, &timer_item_y1,
 			       &timer_item_x2, &timer_item_y2);
 
   timer_item = tuxboat_item;
@@ -526,14 +523,14 @@ static void update_water()
       lock_water_low = !lock_water_low;
       y1 = BASE_LINE - RIGHT_CANAL_HEIGHT;
     }
-  else 
+  else
     {
       /* The water level is correct */
       animation = FALSE;
       return;
     }
 
-  gnome_canvas_item_get_bounds(canal_middle_item, &timer_item_x1, &timer_item_y1, 
+  gnome_canvas_item_get_bounds(canal_middle_item, &timer_item_x1, &timer_item_y1,
 			       &timer_item_x2, &timer_item_y2);
 
   timer_item = canal_middle_item;
@@ -559,7 +556,7 @@ static void toggle_lock(GnomeCanvasItem *item)
     return;
   animation = TRUE;
 
-  gnome_canvas_item_get_bounds(item, &timer_item_x1, &timer_item_y1, 
+  gnome_canvas_item_get_bounds(item, &timer_item_x1, &timer_item_y1,
 			       &timer_item_x2, &timer_item_y2);
 
   if(item == lock_left_item)
@@ -607,7 +604,7 @@ static void toggle_lock(GnomeCanvasItem *item)
 
 
 /* ==================================== */
-static gboolean animate_step() 
+static gboolean animate_step()
 {
 
   if(!gcomprisBoard)
@@ -617,12 +614,12 @@ static gboolean animate_step()
   timer_item_y1 += timer_step_y1;
 
   if(GNOME_IS_CANVAS_PIXBUF(timer_item))
-    gnome_canvas_item_set(timer_item, 
+    gnome_canvas_item_set(timer_item,
 			  "x", timer_item_x1,
 			  "y", timer_item_y1,
 			  NULL);
   else if(GNOME_IS_CANVAS_RECT(timer_item))
-    gnome_canvas_item_set(timer_item, 
+    gnome_canvas_item_set(timer_item,
 			  "x1", timer_item_x1,
 			  "y1", timer_item_y1,
 			  NULL);
@@ -632,10 +629,10 @@ static gboolean animate_step()
     {
       double item_x1, item_y1, item_x2, item_y2;
 
-      gnome_canvas_item_get_bounds(tuxboat_item, &item_x1, &item_y1, 
+      gnome_canvas_item_get_bounds(tuxboat_item, &item_x1, &item_y1,
 				   &item_x2, &item_y2);
 
-      gnome_canvas_item_set(tuxboat_item, 
+      gnome_canvas_item_set(tuxboat_item,
 			    "y", item_y1 + timer_step_y1,
 			    NULL);
     }
@@ -667,7 +664,7 @@ static gboolean animate_step()
 static void hightlight(GnomeCanvasItem *item, gboolean status)
 {
   guint color = 0;
-  
+
   /* This is an image, not a rectangle */
   if(item == tuxboat_item)
     return;
@@ -702,7 +699,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   if(board_paused)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       hightlight(item, TRUE);
@@ -715,13 +712,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       /* If there is already an animation do nothing */
       if(animation)
 	return FALSE;
-	   
+
       if(item == lock_left_item)
 	{
 	  if(lock_water_low && canallock_right_up)
 	      toggle_lock(item);
 	  else
-	    gcompris_play_ogg ("crash", NULL);
+	    gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 
 	}
       else if(item == lock_right_item)
@@ -729,21 +726,21 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  if(!lock_water_low && canallock_left_up)
 	      toggle_lock(item);
 	  else
-	    gcompris_play_ogg ("crash", NULL);
+	    gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 	}
       else if(item == canallock_left_item && canallock_right_up)
 	{
 	  if(lock_right_up)
 	      toggle_lock(item);
 	  else
-	    gcompris_play_ogg ("crash", NULL);
+	    gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 	}
       else if(item == canallock_right_item && canallock_left_up)
 	{
 	  if(lock_left_up)
 	      toggle_lock(item);
 	  else
-	    gcompris_play_ogg ("crash", NULL);
+	    gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 	}
       else if(item == tuxboat_item)
 	{
@@ -751,7 +748,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	}
       else
 	{
-	  gcompris_play_ogg ("crash", NULL);
+	  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 	}
       break;
     default:
@@ -763,7 +760,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   /*
     gamewon = TRUE;
     canal_lock_destroy_all_items();
-    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, BONUS_SMILEY);
   */
   return FALSE;
 }
