@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -61,7 +57,6 @@ static gboolean  engine_local_err_cb (GIOChannel *source,
 				      gpointer data);
 static void	 display_white_turn  (gboolean whiteturn);
 static void	 display_info	     (gchar *info);
-static int	 get_square          (double x, double y);
 static int	 get_square_from_coord (double x, double y);
 
 #define CHESSBOARD_X	50
@@ -178,16 +173,28 @@ static void pause_board (gboolean pause)
   board_paused = pause;
 }
 
+void gnuchess_died(int signum)
+{
+  gnuchess_pid = 0;
+  gc_dialog(_("Error: The external program gnuchess died unexpectedly"), gc_board_stop);
+}
+
 /*
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  
-#ifndef WIN32  
-  if (!g_file_test (GNUCHESS, G_FILE_TEST_EXISTS)) {
-    
-    gcompris_dialog(_("Error: The external program gnuchess is mandatory\nto play chess in gcompris.\nFind this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\nAnd check it is located here: "GNUCHESS), gcompris_end_board);
-    
+
+  gnuchess_pid = 0;
+
+#ifndef WIN32
+  signal(SIGTRAP, gnuchess_died);
+  signal(SIGPIPE, gnuchess_died);
+  if (!g_file_test (GNUCHESS, G_FILE_TEST_EXISTS))
+    {
+    gc_dialog(_("Error: The external program gnuchess is required\nto play chess in gcompris.\n"
+		"Find this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\n"
+		"And check it is located here: "GNUCHESS),
+	      gc_board_stop);
     return;
   }
 #endif
@@ -196,7 +203,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
 
       gcomprisBoard=agcomprisBoard;
-      
+
       /* Default mode */
       if(!gcomprisBoard->mode)
 	gameType=COMPUTER;
@@ -206,51 +213,60 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	gameType=PARTYEND;
       else if(g_strncasecmp(gcomprisBoard->mode, "movelearn", 1)==0)
 	gameType=MOVELEARN;
-      
+
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=1;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      
+
       switch(gameType)
 	{
 	case PARTYEND:
 	case MOVELEARN:
 	  gcomprisBoard->maxlevel=9;
-	  gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+	  gc_bar_set(GC_BAR_LEVEL);
 	  break;
 	default:
-	  gcompris_bar_set(0);
+	  gc_bar_set(0);
 	}
 
       if(start_child (GNUCHESS, &read_chan,
-		      &write_chan, &gnuchess_pid)==FALSE) {
-	gcompris_dialog(_("Error: The external program gnuchess is mandatory\nto play chess in gcompris.\nFind this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\nAnd check it is in "GNUCHESS), gcompris_end_board);
-	return;
-      }
-      
-      read_cb = g_io_add_watch (read_chan, G_IO_IN,
+		      &write_chan, &gnuchess_pid)==FALSE)
+	{
+	  gc_dialog(_("Error: The external program gnuchess is mandatory\n"
+		      "to play chess in gcompris.\n"
+		      "First install it, and check it is in "GNUCHESS), gc_board_stop);
+	  return;
+	}
+
+      read_cb = g_io_add_watch (read_chan, G_IO_IN|G_IO_PRI,
 				engine_local_cb, NULL);
       err_cb = g_io_add_watch (read_chan, G_IO_HUP,
 			       engine_local_err_cb, NULL);
-      
+
       write_child (write_chan, "xboard\n");
       write_child (write_chan, "protover 2\n");
       write_child (write_chan, "post\n");
       write_child (write_chan, "easy\n");
       write_child (write_chan, "level 100 1 0\n");
       write_child (write_chan, "depth 1\n");
-      
+      write_child (write_chan, "time 500\n");
+
       chess_next_level();
-      
+
       gamewon = FALSE;
       pause_board(FALSE);
+
     }
 }
 
 /* ======================================= */
 static void end_board ()
 {
+#ifndef WIN32
+  signal(SIGTRAP, NULL);
+  signal(SIGPIPE, NULL);
+#endif
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
@@ -301,12 +317,12 @@ static void chess_next_level()
   register gshort rank;
   gchar *img;
 
-  img = gcompris_image_to_skin("gcompris-bg.jpg");
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
+  img = gc_skin_image_get("gcompris-bg.jpg");
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  img);
   g_free(img);
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   chess_destroy_all_items();
   gamewon = FALSE;
@@ -324,8 +340,8 @@ static void chess_next_level()
       break;
     }
   /* Init our internal chessboard */
-  for (rank = 1; rank <= 8; rank++) { 
-    for (square = A1 + ((rank - 1) * 10); 
+  for (rank = 1; rank <= 8; rank++) {
+    for (square = A1 + ((rank - 1) * 10);
 	 square <= H1 + ((rank - 1) * 10);
 	 square++) {
 
@@ -336,10 +352,10 @@ static void chess_next_level()
 	chessboard[square] = gsquare;
 	chessboard[square]->piece_item = NULL;
 	chessboard[square]->square = square;
-	
+
     }
-  }    
-   
+  }
+
   /* Try the next level */
   chess_create_item(gnome_canvas_root(gcomprisBoard->canvas));
 }
@@ -363,11 +379,11 @@ static void chess_destroy_all_items()
 
   position = NULL;
 
-  for (rank = 1; rank <= 8; rank++) { 
-    for (square = A1 + ((rank - 1) * 10); 
+  for (rank = 1; rank <= 8; rank++) {
+    for (square = A1 + ((rank - 1) * 10);
 	 square <= H1 + ((rank - 1) * 10);
 	 square++) {
-      
+
       if(chessboard[square]!=NULL)
 	{
 	  g_free(chessboard[square]);
@@ -378,7 +394,8 @@ static void chess_destroy_all_items()
 }
 
 /* ==================================== */
-static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
+static GnomeCanvasItem *
+chess_create_item(GnomeCanvasGroup *parent)
 {
   guint color;
   GnomeCanvasItem *item = NULL;
@@ -397,17 +414,17 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 
 							    NULL));
 
-  for (rank = 1; rank <= 8; rank++) { 
-    for (square = A1 + ((rank - 1) * 10); 
+  for (rank = 1; rank <= 8; rank++) {
+    for (square = A1 + ((rank - 1) * 10);
 	 square <= H1 + ((rank - 1) * 10);
 	 square++) {
       int x,y;
-      
+
       x = square % 10 - 1;
       y = square / 10 - 2;
 
       color=((x+y)%2?BLACK_COLOR:WHITE_COLOR);
-      
+
       item  = gnome_canvas_item_new (boardRootItem,
 				     gnome_canvas_rect_get_type (),
 				     "x1", (double) CHESSBOARD_X + (x * SQUARE_WIDTH),
@@ -431,26 +448,20 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
   need_slash = FALSE;
 
   /* Display the pieces */
-  for (rank = 8; rank >= 1; rank--) { 
-    for (square = A1 + ((rank - 1) * 10); 
+  for (rank = 8; rank >= 1; rank--) {
+    for (square = A1 + ((rank - 1) * 10);
 	 square <= H1 + ((rank - 1) * 10);
-	 square++) 
+	 square++)
       {
 	GdkPixbuf *pixmap = NULL;
 	char *str;
 	gint x, y;
-	char *temp;
-	char *san;
 
 	piece = position->square[square];
 
 	x = square % 10 - 1;
 	y = square / 10 - 2;
 
-	/* Destination square */
-	san = g_new0 (char, 12);
-	temp = san;
-	square_to_ascii (&temp, square);
 	//	printf ( "%c%s\n", piece_to_ascii(piece), san);
 
 	if(need_slash)
@@ -463,7 +474,7 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 	  {
 
 	    if( (white_side && BPIECE(piece)) ||
-		(!white_side && WPIECE(piece)) ) 
+		(!white_side && WPIECE(piece)) )
 	      {
 		white_side = !white_side;
 		//		write_child (write_chan, "c\n");
@@ -490,10 +501,6 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 	    need_slash = TRUE;
 	  }
 
-  	temp = san;
-	san = g_strdup (temp);
-	g_free (temp);
-
 	//	printf("square=%d piece=%d x=%d y=%d\n", square, piece, x, y);
 	if(piece != EMPTY)
 	  {
@@ -501,25 +508,25 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 	      str = g_strdup_printf("chess/B%c.png", piece_to_ascii(piece));
 	    else
 	      str = g_strdup_printf("chess/W%c.png", piece_to_ascii(piece));
-	    
-	    pixmap = gcompris_load_pixmap(str);
+
+	    pixmap = gc_pixmap_load(str);
 	    //	    g_warning("loading piece %s\n",   str);
 	    g_free(str);
 	    item = gnome_canvas_item_new (boardRootItem,
 					  gnome_canvas_pixbuf_get_type (),
-					  "pixbuf", pixmap, 
+					  "pixbuf", pixmap,
 					  "x", (double)CHESSBOARD_X + (x * SQUARE_WIDTH) +
 					  (guint)((SQUARE_WIDTH-gdk_pixbuf_get_width(pixmap))/2),
 					  "y", (double) CHESSBOARD_Y + ((7-y) * SQUARE_HEIGHT) +
 					  (guint)((SQUARE_HEIGHT-gdk_pixbuf_get_height(pixmap))/2),
 					  NULL);
-	    
+
 	    chessboard[square]->piece_item = item;
 	    if(WPIECE(piece))
-	      gtk_signal_connect(GTK_OBJECT(item), "event", 
+	      gtk_signal_connect(GTK_OBJECT(item), "event",
 				 (GtkSignalFunc) item_event, NULL);
 	    else
-	      gtk_signal_connect(GTK_OBJECT(item), "event", 
+	      gtk_signal_connect(GTK_OBJECT(item), "event",
 				 (GtkSignalFunc) item_event_black, NULL);
 
 	    gdk_pixbuf_unref(pixmap);
@@ -544,10 +551,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   chess_next_level();
 }
@@ -561,11 +568,11 @@ static void display_white_turn(gboolean whiteturn)
       turn_item = gnome_canvas_item_new (boardRootItem,
 					 gnome_canvas_text_get_type (),
 					 "text",       " ",
-					 "font",       gcompris_skin_font_board_big,
+					 "font",       gc_skin_font_board_big,
 					 "x", (double) TURN_X,
 					 "y", (double) TURN_Y,
 					 "anchor",     GTK_ANCHOR_CENTER,
-					 "fill_color_rgba", gcompris_skin_color_content,
+					 "fill_color_rgba", gc_skin_color_content,
 					 NULL);
     }
 
@@ -582,11 +589,11 @@ static void display_info(gchar *info)
       info_item = gnome_canvas_item_new (boardRootItem,
 					 gnome_canvas_text_get_type (),
 					 "text",       " ",
-					 "font",       gcompris_skin_font_board_big,
+					 "font",       gc_skin_font_board_big,
 					 "x", (double) INFO_X,
 					 "y", (double) INFO_Y,
 					 "anchor",     GTK_ANCHOR_CENTER,
-					 "fill_color_rgba", gcompris_skin_color_subtitle,
+					 "fill_color_rgba", gc_skin_color_subtitle,
 					 NULL);
     }
 
@@ -607,7 +614,7 @@ static void move_piece_to(Square from, Square to)
   double ofset_x, ofset_y;
   double x1, y1, x2, y2;
   Piece piece = NONE;
-      
+
 
   g_warning("move_piece_to from=%d to=%d\n", from, to);
 
@@ -626,7 +633,7 @@ static void move_piece_to(Square from, Square to)
     {
       if (to & 128) {
 	piece = ((to & 127) >> 3 ) + WP - 1;
-	to = (to & 7) + A8;            
+	to = (to & 7) + A8;
 	printf("  Promoting white piece to %d\n", piece);
       }
     }
@@ -649,14 +656,14 @@ static void move_piece_to(Square from, Square to)
 
   x = to % 10;
   y = to / 10 -1;
-  
+
   g_warning("   move_piece_to to    x=%d y=%d\n", x, y);
 
   dest_square = chessboard[to];
 
   /* Show the moved piece */
   gnome_canvas_item_set(dest_square->square_item,
-			"outline_color", 
+			"outline_color",
 			(BPIECE(position->square[to])?"red":"blue"),
 			NULL);
 
@@ -701,12 +708,12 @@ static void move_piece_to(Square from, Square to)
 	str = g_strdup_printf("chess/B%c.png", piece_to_ascii(piece));
       else
 	str = g_strdup_printf("chess/W%c.png", piece_to_ascii(piece));
-	      
-      pixmap = gcompris_load_pixmap(str);
+
+      pixmap = gc_pixmap_load(str);
       g_free(str);
       g_warning("loading piece %c\n",  piece_to_ascii(piece));
       gnome_canvas_item_set (dest_square->piece_item,
-			     "pixbuf", pixmap, 
+			     "pixbuf", pixmap,
 			     NULL);
 
     }
@@ -721,18 +728,6 @@ static void move_piece_to(Square from, Square to)
 
 }
 
-/*
- * Return a square suitable for position functions
- */
-static int
-get_square (double x, double y)
-{
-
-  return (A1 + (Square) (x-1)
-	  + 10 * (Square)(y-1));
-
-}
-
 /*
  * Return a square suitable for position functions
  */
@@ -764,15 +759,15 @@ void hightlight_possible_moves(GSquare *gsquare)
   else
     position_set_color_to_move(position, BLACK);
 
-  for (rank = 1; rank <= 8; rank++) { 
-    for (square = A1 + ((rank - 1) * 10); 
+  for (rank = 1; rank <= 8; rank++) {
+    for (square = A1 + ((rank - 1) * 10);
 	 square <= H1 + ((rank - 1) * 10);
 	 square++) {
 
 
 	square_test = position_move_normalize (position, gsquare->square, chessboard[square]->square);
 
-	if (square_test) 
+	if (square_test)
 	  {
 	    color=((rank+square)%2?BLACK_COLOR_H:WHITE_COLOR_H);
 
@@ -790,7 +785,7 @@ void hightlight_possible_moves(GSquare *gsquare)
 				  "outline_color", "black",
 				  NULL);
 	  }
-      }      
+      }
   }
 
   /* Set back the current color to move */
@@ -801,7 +796,7 @@ void hightlight_possible_moves(GSquare *gsquare)
 			"outline_color",
 			(BPIECE(position->square[gsquare->square])?"red":"blue"),
 			NULL);
-  
+
 }
 
 /* ==================================== */
@@ -836,11 +831,11 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
 	x = item_x;
 	y = item_y;
-	
+
 	fleur = gdk_cursor_new(GDK_FLEUR);
 	gnome_canvas_item_raise_to_top(item);
-	gnome_canvas_item_grab(item,
-			       GDK_POINTER_MOTION_MASK | 
+	gc_canvas_item_grab(item,
+			       GDK_POINTER_MOTION_MASK |
 			       GDK_BUTTON_RELEASE_MASK,
 			       fleur,
 			       event->button.time);
@@ -851,7 +846,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       }
       break;
     case GDK_MOTION_NOTIFY:
-       if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
+       if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
          {
            new_x = item_x;
            new_y = item_y;
@@ -861,9 +856,9 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
            y = new_y;
          }
        break;
-           
+
      case GDK_BUTTON_RELEASE:
-       if(dragging) 
+       if(dragging)
 	 {
 	   guint x, y;
 	   double ofset_x, ofset_y;
@@ -872,7 +867,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	   Square to;
 
 	   to = get_square_from_coord(event->button.x, event->button.y);
-	   g_warning("===== Source square = %d Destination square = %d\n", gsquare->square, 
+	   g_warning("===== Source square = %d Destination square = %d\n", gsquare->square,
 		  to);
 
 	   to = position_move_normalize (position, gsquare->square, to);
@@ -891,25 +886,25 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	   else
 	     {
 	       g_warning("====== MOVE from %d REFUSED\n", gsquare->square);
-	   
+
 	       /* Find the ofset to move the piece back to where it was*/
 	       gnome_canvas_item_get_bounds  (item,
 					      &x1,
 					      &y1,
 					      &x2,
 					      &y2);
-	       
+
 	       x = gsquare->square % 10;
 	       y = gsquare->square / 10 -1;
-	       
+
 	       ofset_x = (CHESSBOARD_X + SQUARE_WIDTH  * (x-1)) - x1 + (SQUARE_WIDTH  - (x2-x1))/2;
 	       ofset_y = (CHESSBOARD_Y + SQUARE_HEIGHT * (8-y)) - y1 + (SQUARE_HEIGHT - (y2-y1))/2;
 	       g_warning("ofset = x=%f y=%f\n", ofset_x, ofset_y);
-	       
+
 	       gnome_canvas_item_move(item, ofset_x, ofset_y);
 	     }
 
-	   gnome_canvas_item_ungrab(item, event->button.time);
+	   gc_canvas_item_ungrab(item, event->button.time);
 	   dragging = FALSE;
 
 	   position_display(position);
@@ -957,9 +952,12 @@ item_event_black(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 /*======================================================================*/
 /*======================================================================*/
 static void
-engine_local_destroy (GPid gnuchess_pid) 
+engine_local_destroy (GPid gnuchess_pid)
 {
 
+  if(!gnuchess_pid)
+    return;
+
   g_warning("engine_local_destroy () \n");
   write_child (write_chan, "quit\n");
 
@@ -968,7 +966,7 @@ engine_local_destroy (GPid gnuchess_pid)
 
   g_io_channel_close (read_chan);
   g_io_channel_unref (read_chan);
-  
+
   g_io_channel_close (write_chan);
   g_io_channel_unref (write_chan);
 
@@ -976,49 +974,78 @@ engine_local_destroy (GPid gnuchess_pid)
     g_spawn_close_pid(gnuchess_pid);
 }
 
+/** We got data back from gnuchess, we parse them here
+ *
+ */
 static gboolean
 engine_local_cb (GIOChannel *source,
 		 GIOCondition condition,
 		 gpointer data)
 {
-  static char buf[1024];
-  static char *b=buf;
-  
+  gchar buf[1000];
+  char *b=buf;
+  GError *err = NULL;
   char *p,*q;
-  ssize_t len;
-  
-  g_io_channel_read (read_chan, b, sizeof (buf) - 1 - (b - buf), &len);
-  
+  gsize len = 0;
+  GIOStatus status = G_IO_STATUS_NORMAL;
+
+  g_warning("engine_local_cb");
+
+  status = g_io_channel_read_chars(source,
+				   buf,
+				   1000,
+				   &len,
+				   &err);
+
+  g_warning("g_io_channel_read_line len=%d", (int)len);
+  if(status == G_IO_STATUS_ERROR)
+    {
+      g_warning("g_io_channel_read_chars error=%s",
+		err->message);
+      /* FIXME: Not sure what to do */
+      return FALSE;
+    }
+
+  if(status != G_IO_STATUS_NORMAL)
+    {
+      g_warning("g_io_channel_read_chars error=%d",
+		status);
+      /* FIXME: Not sure what to do */
+      return FALSE;
+    }
+
+  g_warning("engine_local_cb read=%s\n", buf);
+
   if (len > 0) {
     b[len] = 0;
     b += len;
   }
-  
+
   while (1) {
     char tmp;
-    
+
     q = strchr (buf,'\n');
     if (q == NULL) break;
     tmp = *(q+1);
     *(q+1) = '\0';
-    
+
     *q='\0';
     *(q+1) = tmp;
-    
+
     g_warning("engine_local_cb read=%s\n", buf);
-    
+
     /* parse for  NUMBER ... MOVE */
     if (isdigit (*buf))
       {
 	if ((p = strstr (buf, "...")))
 	  {
 	    Square from, to;
-	  
+
 	    g_warning("computer number moves to %s\n", p+4);
-	  
+
 	    if (san_to_move (position, p+4, &from, &to))
 	      ascii_to_move (position, p+4, &from, &to);
-	  
+
 	    position_move (position, from, to);
 	    move_piece_to(from , to);
 	  }
@@ -1035,7 +1062,7 @@ engine_local_cb (GIOChannel *source,
 	Square from, to;
 
 	p = strstr (buf, ":");
-	printf("computer moves to %s\n", p+1);
+	g_warning("computer moves to %s\n", p+1);
 
 	if (san_to_move (position, p+1, &from, &to))
 	  ascii_to_move (position, p+1, &from, &to);
@@ -1043,7 +1070,7 @@ engine_local_cb (GIOChannel *source,
 	position_move (position, from, to);
 	move_piece_to(from , to);
       }
-    
+
     /* parse for illegal move */
     if (!strncmp ("Illegal move",buf,12))
       {
@@ -1080,7 +1107,7 @@ engine_local_cb (GIOChannel *source,
     memmove (buf, q+1, sizeof(buf) - ( q + 1 - buf));
     b -= (q + 1 - buf);
   }
-  
+
   return TRUE;
 }
 
@@ -1089,8 +1116,8 @@ engine_local_err_cb (GIOChannel *source,
 		     GIOCondition condition,
 		     gpointer data)
 {
-  g_error ("Local Engine connection died");
-  
+  gnuchess_pid = 0;
+  gc_dialog(_("Error: The external program gnuchess died unexpectingly"), gc_board_stop);
   return FALSE;
 }
 
@@ -1100,15 +1127,15 @@ engine_local_err_cb (GIOChannel *source,
  *----------------------------------------*/
 
 static gboolean
-start_child (char *cmd, 
-	     GIOChannel **read_chan, 
+start_child (char *cmd,
+	     GIOChannel **read_chan,
 	     GIOChannel **write_chan,
 	     GPid *Child_Process)
 {
   gint   Child_In, Child_Out, Child_Err;
   GError *gerror = NULL;
 
-  gchar *Child_Argv[]={ cmd, NULL };
+  gchar *Child_Argv[]={ cmd, "-e", NULL };
 
   g_warning("Ready to start child");
 
@@ -1116,7 +1143,7 @@ start_child (char *cmd,
 				G_SPAWN_SEARCH_PATH,
 				NULL, NULL, Child_Process, &Child_In, &Child_Out,
 				&Child_Err, &gerror)) {
-    
+
     g_warning("Error message '%s'", gerror->message);
     g_warning("Error code    '%d'", gerror->code);
     g_error_free (gerror);
@@ -1130,30 +1157,49 @@ start_child (char *cmd,
   *read_chan = g_io_channel_unix_new (Child_Out);
   *write_chan = g_io_channel_unix_new (Child_In);
 
+  if(g_io_channel_set_encoding(*write_chan, NULL, NULL) != G_IO_STATUS_NORMAL)
+    g_warning("Failed to set NULL encoding");
+
+  if(g_io_channel_set_flags (*read_chan, G_IO_FLAG_NONBLOCK, NULL) != G_IO_STATUS_NORMAL)
+    g_warning("Failed to set NON BLOCKING IO");
+
+  if(g_io_channel_set_flags (*write_chan, G_IO_FLAG_NONBLOCK, NULL) != G_IO_STATUS_NORMAL)
+    g_warning("Failed to set NON BLOCKING IO");
+
   return(TRUE);
 }
 
-
-static void 
-write_child (GIOChannel *write_chan, char *format, ...) 
+/** Write a command to the gnuchess backend
+ *
+ */
+static void
+write_child (GIOChannel *write_chan, char *format, ...)
 {
-  GIOError err;
+  GIOStatus err;
   va_list ap;
-  char *buf;
-  int len;	
+  gchar *buf;
+  gsize len;
+  GError *error = NULL;
 
   va_start (ap, format);
 
   buf = g_strdup_vprintf (format, ap);
 
-  err = g_io_channel_write (write_chan, buf, strlen (buf), &len);
-  if (err != G_IO_ERROR_NONE)
-    g_warning ("Writing to child process failed");
+  err = g_io_channel_write_chars (write_chan, buf, strlen (buf), &len, &error);
 
-  g_warning ("%s", buf);  
+  if (err == G_IO_STATUS_ERROR)
+    g_error ("Error writing: %s\n", error->message);
+
+  if (err != G_IO_STATUS_NORMAL)
+    g_warning ("Writing to child process failed");
+  else
+    g_warning ("Wrote '%s' to gnuchess", buf);
+
+  err = g_io_channel_flush (write_chan, &error);
+  if (err == G_IO_STATUS_ERROR)
+    g_error ("Error flushing: %s\n", error->message);
 
   va_end (ap);
 
   g_free (buf);
 }
-
