@@ -17,10 +17,8 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
 #include <glib.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -29,7 +27,7 @@
 #define SOUNDLISTFILE PACKAGE
 
 static GcomprisBoard *gcomprisBoard = NULL;
-static gboolean board_paused = TRUE;
+static gboolean board_paused;
 
 static void		 start_board (GcomprisBoard *agcomprisBoard);
 static void		 pause_board (gboolean pause);
@@ -44,7 +42,7 @@ static void		 highlight_selected(GnomeCanvasItem *);
 static void		 game_won(void);
 static void		 repeat(void);
 static void		 config_start(GcomprisBoard *agcomprisBoard,
-					     GcomprisProfile *aProfile);
+				      GcomprisProfile *aProfile);
 static void		 config_stop(void);
 
 
@@ -55,6 +53,10 @@ static void		 config_stop(void);
 #define NUMBER_OF_LEVELS 5
 #define MAX_NUMBER_OF_LETTERS 4
 
+#define NOT_OK		0
+#define OK		1
+#define OK_NO_INIT	2
+
 #define TEXT_COLOR "white"
 
 static GnomeCanvasGroup *boardRootItem = NULL;
@@ -68,7 +70,6 @@ static GnomeCanvasItem *click_on_letter_create_item(GnomeCanvasGroup *parent);
 static void click_on_letter_destroy_all_items(void);
 static void click_on_letter_next_level(void);
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
-static gint phone_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
 static gboolean sounds_are_fine();
 
 static int right_position;
@@ -76,7 +77,6 @@ static int number_of_letters=MAX_NUMBER_OF_LETTERS;
 static gchar *right_letter;
 
 static gchar *alphabet;
-static void quit_board();
 
 static void sound_played(gchar *file);
 
@@ -99,7 +99,7 @@ static BoardPlugin menu_bp =
     end_board,
     is_our_board,
     NULL,
-    process_ok,
+    NULL,
     set_level,
     NULL,
     repeat,
@@ -119,7 +119,7 @@ GET_BPLUGIN_INFO(click_on_letter)
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
  *
  */
-static void pause_board (gboolean pause)
+     static void pause_board (gboolean pause)
 {
   if(gcomprisBoard==NULL)
     return;
@@ -136,9 +136,12 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
+  int ready;
 
-  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  board_paused = TRUE;
+
+  gc_locale_set(g_hash_table_lookup( config, "locale_sound"));
 
   gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
 
@@ -149,29 +152,37 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
   g_hash_table_destroy(config);
 
-  sounds_are_fine();
+  ready = sounds_are_fine();
+
+  gc_sound_pause();
 
   if (agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery4_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			      "images/scenery4_background.png");
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
       gcomprisBoard->sublevel=1;
-      gcomprisBoard->number_of_sublevel=NUMBER_OF_SUBLEVELS; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_REPEAT);
-      gcompris_score_start(SCORESTYLE_NOTE,
-			   50,
-			   50,
-			   gcomprisBoard->number_of_sublevel);
 
-      click_on_letter_next_level();
+      /* Go to next level after this number of 'play' */
+      gcomprisBoard->number_of_sublevel=NUMBER_OF_SUBLEVELS;
 
-      gamewon = FALSE;
-      pause_board(FALSE);
+      if(ready)
+	{
+	  /* Warning, bar buttons are set in click_on_letter_next_level()
+	     to avoid them to appear in the case a dialog is displayed */
+	  gc_score_start(SCORESTYLE_NOTE,
+			       50,
+			       50,
+			       gcomprisBoard->number_of_sublevel);
 
-      
+	  if(ready == OK)
+	    click_on_letter_next_level();
 
+	  gamewon = FALSE;
+	  pause_board(FALSE);
+	}
     }
 
 }
@@ -180,16 +191,13 @@ static void end_board ()
 {
   if(gcomprisBoard!=NULL)
     {
-      printf("end_board 1\n");
       pause_board(TRUE);
-      printf("end_board 1\n");
-      gcompris_score_end();
-      printf("end_board 1\n");
+      gc_score_end();
       click_on_letter_destroy_all_items();
-      printf("end_board 1\n");
     }
-  gcompris_reset_locale();
+  gc_locale_reset();
   gcomprisBoard = NULL;
+  gc_sound_resume();
 }
 
 /* ======================================= */
@@ -222,100 +230,100 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 /* ======================================= */
 static void repeat ()
 {
-   if(gcomprisBoard!=NULL)
+  if(gcomprisBoard!=NULL)
     {
-
       gchar *str1 = NULL;
       gchar *right_letter_ogg = NULL;
 
-      right_letter_ogg = gcompris_alphabet_sound(right_letter);
-      str1 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", right_letter_ogg);
+      str1 = gc_sound_alphabet(right_letter);
 
-      if(str1) {
-	gcompris_play_ogg_cb(str1, sound_played);
+      right_letter_ogg = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str1);
+      g_free(str1);
+
+      if(right_letter_ogg) {
+	gc_sound_play_ogg_cb(right_letter_ogg, sound_played);
       }
 
-      g_free(str1);
       g_free(right_letter_ogg);
     }
 }
 
-static gboolean sounds_are_fine ()
+static gboolean sounds_are_fine()
 {
-  char *str1 = NULL;
-  char *str2 = NULL;
-  GcomprisProperties	*properties = gcompris_get_properties();
-  gchar *locale = NULL;
-  gboolean fine = TRUE;
+  char *letter_str;
+  char *str2;
+  GcomprisProperties	*properties = gc_prop_get();
+
+  if(!properties->fx)
+    {
+      gc_dialog(_("Error: this activity cannot be played with the\nsound effects disabled.\nGo to the configuration dialog to\nenable the sound"), gc_board_stop);
+      return(NOT_OK);
+    }
 
   /* TRANSLATORS: Put here the alphabet in your language */
   alphabet=_("abcdefghijklmnopqrstuvwxyz");
-  assert(g_utf8_validate(alphabet,-1,NULL)); // require by all utf8-functions
-  
+  g_assert(g_utf8_validate(alphabet, -1, NULL)); // require by all utf8-functions
+
   gchar *letter = g_new0(gchar, 8);
-  g_unichar_to_utf8 ( g_utf8_get_char (alphabet), letter);
-
-  str1 = gcompris_alphabet_sound(letter);
+  g_unichar_to_utf8(g_utf8_get_char(alphabet), letter);
+  letter_str = gc_sound_alphabet(letter);
   g_free(letter);
-  str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", str1);
-  g_free(str1);
-  
-  if (!str2){
-    locale = g_strndup(gcompris_get_locale(), 2);
-    gcompris_reset_locale();
-    gcompris_change_locale("en_US");
 
-    /* TRANSLATORS: Put here the alphabet in your language */
-    alphabet=_("abcdefghijklmnopqrstuvwxyz");
-    assert(g_utf8_validate(alphabet,-1,NULL)); // require by all utf8-functions
-    
-    gchar *letter = g_new0(gchar, 8);
-    g_unichar_to_utf8 ( g_utf8_get_char (alphabet), letter);
+  str2 = gc_file_find_absolute("sounds/$LOCALE/alphabet/%s", letter_str);
 
-    str1 = gcompris_alphabet_sound(letter);
-    g_free(letter);
-    str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", str1);
-    g_free(str1);
+  if (!str2)
+    {
+      gchar *locale = NULL;
 
-    if (!str2){
-      gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages assetml-voices-alphabet-%s or %s"),
+      locale = g_strndup(gc_locale_get(), 2);
+      gc_locale_reset();
+      gc_locale_set("en_US");
+
+      str2 = gc_file_find_absolute("sounds/en/alphabet/%s", letter_str);
+
+      if (!str2)
+	{
+	  gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages with gcompris voices for the locale '%s' or '%s'"),
 					locale, "en");
-      gcompris_dialog(msg, board_stop);
-      g_free(msg);
-      return (fine);
+	  gc_dialog(msg, gc_board_stop);
+	  g_free(msg);
+	  return (NOT_OK);
+	}
+      else
+	{
+	  gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages with GCompris voices for the locale '%s' ! Fallback to english, sorry!"), locale);
+	  gc_dialog(msg, click_on_letter_next_level);
+	  g_free(msg);
+	  g_free(str2);
+	  return(OK_NO_INIT);
+	}
     }
-    else{
-      gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages assetml-voices-alphabet-%s ! Fallback to english, sorry!"), locale);
-      gcompris_dialog(msg, NULL);
-      g_free(msg);
+  else
+    {
+      g_free(str2);
     }
-  }
 
-  fine = TRUE;
-  if(!properties->fx) {
-    gcompris_dialog(_("Error: this activity cannot be played with the\nsound effects disabled.\nGo to the configuration dialogue to\nenable the sound"), board_stop);
-    fine = FALSE;
-  }
-
-  g_free(str2);
-  
-  return(fine);
-  
+  return(OK);
 }
 
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
 /* set initial values for the next level */
-static void click_on_letter_next_level()
+static void
+click_on_letter_next_level()
 {
-  gcompris_bar_set_level(gcomprisBoard);
+  /* It must be set it for the warning dialogs */
+  gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL|GC_BAR_REPEAT);
+
+  gc_bar_set_level(gcomprisBoard);
 
   click_on_letter_destroy_all_items();
   gamewon = FALSE;
   selected_button = NULL;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
   g_free (right_letter);
   /* Try the next level */
+  gc_sound_play_ogg("sounds/$LOCALE/misc/click_on_letter.ogg", NULL);
   click_on_letter_create_item(gnome_canvas_root(gcomprisBoard->canvas));
 }
 /* ==================================== */
@@ -342,52 +350,49 @@ static GnomeCanvasItem *click_on_letter_create_item(GnomeCanvasGroup *parent)
   int numbers[number_of_letters];
 
   gchar *letters[number_of_letters];
-  assert(number_of_letters<=length_of_aphabet); // because we must set unique letter on every "vagon"
+  g_assert(number_of_letters<=length_of_aphabet); // because we must set unique letter on every "vagon"
 
   for (i=0;i<number_of_letters;i++){
-	numbers[i]=((int)(((float)length_of_aphabet)*rand()/(RAND_MAX+1.0)));
+    numbers[i]=((int)(((float)length_of_aphabet)*rand()/(RAND_MAX+1.0)));
 
-	// check that the letter has not been taken yet	
-	for(j=0;j<i;j++){
-		if (numbers[i]==numbers[j]) {
-			i--;
-			continue;
-		}
-	}
+    // check that the letter has not been taken yet
+    for(j=0;j<i;j++){
+      if (numbers[i]==numbers[j]) {
+	i--;
+	continue;
+      }
+    }
 
   }
 
-
-
-
   for (i=0;i<number_of_letters;i++){
-   gchar *copy_from=g_utf8_offset_to_pointer(alphabet, numbers[i]);
-   gchar *copy_to=g_utf8_offset_to_pointer(alphabet, numbers[i]+1);
-   letters[i]=g_strndup(copy_from,copy_to-copy_from);
+    gchar *copy_from=g_utf8_offset_to_pointer(alphabet, numbers[i]);
+    gchar *copy_to=g_utf8_offset_to_pointer(alphabet, numbers[i]+1);
+    letters[i]=g_strndup(copy_from,copy_to-copy_from);
 
-   if (uppercase_only)
-     letters[i]=g_utf8_strup(copy_from,copy_to-copy_from);
-   else {
-     switch (gcomprisBoard->level) {
-        case 1	:
-        case 2  : letters[i]=g_strndup(copy_from,copy_to-copy_from); break;
-        case 3  : letters[i]=g_utf8_strup(copy_from,copy_to-copy_from); break;
-	default : 
-	  if ( rand() > (RAND_MAX/2) ) 
-	    letters[i]=g_strndup(copy_from,copy_to-copy_from);
-	  else 
-	    letters[i]=g_utf8_strup(copy_from,copy_to-copy_from);
-     }
-   }
+    if (uppercase_only)
+      letters[i]=g_utf8_strup(copy_from,copy_to-copy_from);
+    else {
+      switch (gcomprisBoard->level) {
+      case 1	:
+      case 2  : letters[i]=g_strndup(copy_from,copy_to-copy_from); break;
+      case 3  : letters[i]=g_utf8_strup(copy_from,copy_to-copy_from); break;
+      default :
+	if ( rand() > (RAND_MAX/2) )
+	  letters[i]=g_strndup(copy_from,copy_to-copy_from);
+	else
+	  letters[i]=g_utf8_strup(copy_from,copy_to-copy_from);
+      }
+    }
   }
 
   /*  */
   right_position = ((int)(((float)number_of_letters)*rand()/(RAND_MAX+1.0)));
-  assert(right_position >= 0  && right_position < number_of_letters);
+  g_assert(right_position >= 0  && right_position < number_of_letters);
   right_letter = g_utf8_strdown(letters[right_position],-1);
 
   repeat();
- 
+
 
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -397,37 +402,37 @@ static GnomeCanvasItem *click_on_letter_create_item(GnomeCanvasGroup *parent)
 							    NULL));
 
 
-  button_pixmap = gcompris_load_pixmap("images/wagon-yellow.png");
+  button_pixmap = gc_pixmap_load("images/wagon-yellow.png");
 
   yOffset = VERTICAL_SEPARATION;
   xOffset = 5;
 
 
   for (i=0; i< number_of_letters; i++) {
-
-  buttons[i] = gnome_canvas_item_new (boardRootItem,
-				   gnome_canvas_pixbuf_get_type (),
-				   "pixbuf",  button_pixmap,
-				   "x",  (double) xOffset,
-				   "y",  (double) yOffset,
-				   NULL);
+    buttons[i] = gnome_canvas_item_new (boardRootItem,
+					gnome_canvas_pixbuf_get_type (),
+					"pixbuf",  button_pixmap,
+					"x",  (double) xOffset,
+					"y",  (double) yOffset,
+					NULL);
 
 
-  l_items[i] = gnome_canvas_item_new (boardRootItem,
-				      gnome_canvas_text_get_type (),
-				      "text", g_strdup(letters[i]),
-				      "font", gcompris_skin_font_board_huge_bold,
-				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", 0x0000ffff,
-				      "x",  (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
-				      "y",  (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 - 5,
-				      NULL);
-  g_free(letters[i]);
-  xOffset +=HORIZONTAL_SEPARATION +gdk_pixbuf_get_width(button_pixmap);
+    l_items[i] = gnome_canvas_item_new (boardRootItem,
+					gnome_canvas_text_get_type (),
+					"text", letters[i],
+					"font", gc_skin_font_board_huge_bold,
+					"anchor", GTK_ANCHOR_CENTER,
+					"fill_color_rgba", 0x0000ffff,
+					"x",  (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
+					"y",  (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 - 5,
+					NULL);
 
-  gtk_signal_connect(GTK_OBJECT(l_items[i]), "event", (GtkSignalFunc) item_event, GINT_TO_POINTER(i));
-  gtk_signal_connect(GTK_OBJECT(buttons[i]), "event",  (GtkSignalFunc) item_event, GINT_TO_POINTER(i));
-  //  gtk_signal_connect(GTK_OBJECT(buttons[i]), "event", (GtkSignalFunc) gcompris_item_event_focus, NULL);
+    g_free(letters[i]);
+    xOffset +=HORIZONTAL_SEPARATION +gdk_pixbuf_get_width(button_pixmap);
+
+    gtk_signal_connect(GTK_OBJECT(l_items[i]), "event", (GtkSignalFunc) item_event, GINT_TO_POINTER(i));
+    gtk_signal_connect(GTK_OBJECT(buttons[i]), "event",  (GtkSignalFunc) item_event, GINT_TO_POINTER(i));
+    //  gtk_signal_connect(GTK_OBJECT(buttons[i]), "event", (GtkSignalFunc) gc_item_focus_event, NULL);
   }
 
 
@@ -445,7 +450,7 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_TUXPLANE);
+      gc_bonus_end_display(BOARD_FINISHED_TUXPLANE);
       return;
     }
   }
@@ -454,7 +459,7 @@ static void game_won()
 
 /* ==================================== */
 static gboolean process_ok_timeout() {
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
   return FALSE;
 }
 
@@ -463,18 +468,6 @@ static void process_ok() {
   g_timeout_add(TIME_CLICK_TO_BONUS, process_ok_timeout, NULL);
 }
 /* ==================================== */
-static gint phone_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
-  switch (event->type)
-    {
-    case GDK_BUTTON_PRESS:
-      repeat();
-      break;
-    default:
-      break;
-    }
-  return TRUE;
-}
-/* ==================================== */
 static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
@@ -492,13 +485,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     case GDK_BUTTON_PRESS:
       /* We really don't want the user to change his/her mind */
       board_paused = TRUE;
-  
+
       if ( pos == right_position ) {
 	gamewon = TRUE;
       } else {
 	gamewon = FALSE;
       }
-     highlight_selected(item);
+      highlight_selected(item);
       process_ok();
       break;
 
@@ -517,26 +510,26 @@ static void highlight_selected(GnomeCanvasItem * item) {
   /* Replace text item by button item */
   button = item;
   for (i=0; i<number_of_letters;i++) {
-     if ( l_items[i] == item ) {
-	button = buttons[i];
-     }
+    if ( l_items[i] == item ) {
+      button = buttons[i];
+    }
   }
 
   if (selected_button != NULL && selected_button != button) {
-  	button_pixmap = gcompris_load_pixmap("images/wagon-yellow.png");
-	/* Warning changing the image needs to update pixbuf_ref for the focus usage */
-	g_object_set_data (G_OBJECT (selected_button), "pixbuf_ref", button_pixmap);
-  	gnome_canvas_item_set(selected_button, "pixbuf", button_pixmap, NULL);
-  	gdk_pixbuf_unref(button_pixmap);
+    button_pixmap = gc_pixmap_load("images/wagon-yellow.png");
+    /* Warning changing the image needs to update pixbuf_ref for the focus usage */
+    gc_item_focus_free(selected_button, NULL);
+    gnome_canvas_item_set(selected_button, "pixbuf", button_pixmap, NULL);
+    gdk_pixbuf_unref(button_pixmap);
   }
 
   if (selected_button != button) {
-  	button_pixmap_selected = gcompris_load_pixmap("images/wagon-green.png");
-	/* Warning changing the image needs to update pixbuf_ref for the focus usage */
-	g_object_set_data (G_OBJECT (button), "pixbuf_ref", button_pixmap_selected);
-  	gnome_canvas_item_set(button, "pixbuf", button_pixmap_selected, NULL);
-  	selected_button = button;
-  	gdk_pixbuf_unref(button_pixmap_selected);
+    button_pixmap_selected = gc_pixmap_load("images/wagon-green.png");
+    /* Warning changing the image needs to update pixbuf_ref for the focus usage */
+      gc_item_focus_free(button, NULL);
+    gnome_canvas_item_set(button, "pixbuf", button_pixmap_selected, NULL);
+    selected_button = button;
+    gdk_pixbuf_unref(button_pixmap_selected);
   }
 
 }
@@ -555,58 +548,62 @@ static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
 static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+			  gpointer value,
+			  gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 
   return NULL;
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+static void
+conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
+
     return;
   }
-    
+
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
-  
+
   board_conf = NULL;
   profile_conf = NULL;
 
   if (gcomprisBoard){
     GHashTable *config;
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
 
-    gcompris_reset_locale();
-    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
-    
+    gc_locale_reset();
+    gc_locale_set(g_hash_table_lookup(config, "locale_sound"));
+
     gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
-    
-    if (up_init_str && (strcmp(up_init_str, "True")==0))
-      uppercase_only = TRUE;
-    else
-      uppercase_only = FALSE;
-    
+    if (up_init_str)
+      {
+	if(strcmp(up_init_str, "True")==0)
+	  uppercase_only = TRUE;
+	else
+	  uppercase_only = FALSE;
+      }
+
     if (profile_conf)
       g_hash_table_destroy(config);
-    
+
     sounds_are_fine();
-    
+
     click_on_letter_next_level();
-    
+
     gamewon = FALSE;
     pause_board(FALSE);
-    
+
   }
 
   board_conf = NULL;
@@ -615,7 +612,7 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
 
 static void
 config_start(GcomprisBoard *agcomprisBoard,
-		    GcomprisProfile *aProfile)
+	     GcomprisProfile *aProfile)
 {
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
@@ -624,24 +621,20 @@ config_start(GcomprisBoard *agcomprisBoard,
     pause_board(TRUE);
 
   gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-				 agcomprisBoard->name, 
+				 agcomprisBoard->name,
 				 aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window( label, 
-				 (GcomprisConfCallback )conf_ok);
-  
+  gc_board_config_window_display(label, conf_ok);
+
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
-  gchar *locale = g_hash_table_lookup( config, "locale");
-  
-  gcompris_combo_locales( locale);
+  gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
 
-  //gcompris_separator();
- 
-  //gcompris_combo_locales_asset( "Select sound locale", locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+  gc_board_config_combo_locales_asset( "Select sound locale", saved_locale_sound,
+				"sounds/$LOCALE/colors/purple.ogg");
 
   gboolean up_init = FALSE;
 
@@ -650,18 +643,18 @@ config_start(GcomprisBoard *agcomprisBoard,
   if (up_init_str && (strcmp(up_init_str, "True")==0))
     up_init = TRUE;
 
-  gcompris_boolean_box(_("Uppercase only text"),
+  gc_board_config_boolean_box(_("Uppercase only text"),
 		       "uppercase_only",
 		       up_init);
 
-
+  g_hash_table_destroy(config);
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 config_stop()
 {
 }
@@ -669,5 +662,5 @@ config_stop()
 static void
 sound_played (gchar *file)
 {
-        g_warning ("Sound_played %s\n", file);
+  g_warning ("Sound_played %s\n", file);
 }
