@@ -1,6 +1,6 @@
 /* gcompris - clickgame.c
  *
- * Time-stamp: <2005/10/10 00:21:56 bruno>
+ * Time-stamp: <2006/08/21 23:30:07 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -33,23 +33,25 @@
 
 static gboolean board_paused = TRUE;
 
-static GList *item_list = NULL;
+static GList *item_list = NULL;     // onscreen fish
 static GList *item2del_list = NULL;
 
 static GcomprisBoard *gcomprisBoard = NULL;
 
-static gint dummy_id = 0;
+static gulong event_handle_id;
+static gint move_items_id = 0;
 static gint animate_id = 0;
 static gint drop_items_id = 0;
 
-static GList *pixmaplist = NULL;
-static  GList *imagelist = NULL;
-
 typedef struct {
   double speed;
+  gint fright;
+  gint stun;
   gint currentItem;
   GnomeCanvasItem *rootitem;
-  GList *item_list;
+  GSList *fwd_frames;
+  GSList *rev_frames;
+  GSList *cur_frames;  // points to fwd_frames or rev_frames
 } FishItem;
 
 static void	 clickgame_start (GcomprisBoard *agcomprisBoard);
@@ -59,31 +61,73 @@ static gboolean	 clickgame_is_our_board (GcomprisBoard *gcomprisBoard);
 static void	 clickgame_set_level (guint level);
 static void	 clickgame_config(void);
 
-static FishItem *clickgame_create_item(GnomeCanvasGroup *parent);
+static FishItem *clickgame_create_item();
 static gint	 clickgame_drop_items (GtkWidget *widget, gpointer data);
 static gint	 clickgame_move_items (GtkWidget *widget, gpointer data);
 static gint	 clickgame_animate_items (GtkWidget *widget, gpointer data);
 static void	 clickgame_destroy_item(FishItem *fishitem);
 static void	 clickgame_destroy_items(void);
 static void	 clickgame_destroy_all_items(void);
-static void	 setup_item(FishItem *fishitem);
-static void	 load_random_pixmap(void);
 static void	 clickgame_next_level(void);
 
 static int gamewon;
 static void	 game_won(void);
 
 static  guint32              fallSpeed = 0;
-static  double               speed = 0.0;
+static  double               moveSpeed = 0.0;
 static  double               imageZoom = 0.0;
 
+
+static const gchar *smallFish[] =
+  {
+    "%s/cichlid1_%d.png",
+    "%s/cichlid4_%d.png",
+    "%s/collaris_%d.png",
+    "%s/discus3_%d.png",
+    "%s/eel_%d.png",
+    "%s/teeth_%d.png",
+    "%s/f02_%d.png",
+  };
+#define NUM_SMALLFISH G_N_ELEMENTS(smallFish)
+
+static const gchar *medFish[] =
+  {
+    "%s/f00_%d.png",
+    "%s/f01_%d.png",
+    "%s/f03_%d.png",
+    "%s/f04_%d.png",
+    "%s/f05_%d.png",
+    "%s/f06_%d.png",
+    "%s/f11_%d.png",
+    "%s/f12_%d.png",
+    "%s/f13_%d.png",
+    "%s/QueenAngel_%d.png",
+    "%s/six_barred_%d.png",
+    "%s/shark1_%d.png",
+  };
+#define NUM_MEDFISH G_N_ELEMENTS(medFish)
+
+static const gchar *bigFish[] =
+  {
+    "%s/blueking2_%d.png",
+    "%s/butfish_%d.png",
+    "%s/discus2_%d.png",
+    "%s/f07_%d.png",
+    "%s/f08_%d.png",
+    "%s/f09_%d.png",
+    "%s/f10_%d.png",
+    "%s/manta_%d.png",
+    "%s/newf1_%d.png",
+  };
+#define NUM_BIGFISH G_N_ELEMENTS(bigFish)
+
 /* Description of this plugin */
 static BoardPlugin menu_bp =
 {
    NULL,
    NULL,
    "Click On Me",
-   "Left-Click with the mouse on all swimming fish before they leave the fishtank",
+   "Click with the mouse on all swimming fish before they leave the fishtank",
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -126,9 +170,9 @@ static void clickgame_pause (gboolean pause)
 
   if(pause)
     {
-      if (dummy_id) {
-	gtk_timeout_remove (dummy_id);
-	dummy_id = 0;
+      if (move_items_id) {
+	gtk_timeout_remove (move_items_id);
+	move_items_id = 0;
       }
       if (animate_id) {
 	gtk_timeout_remove (animate_id);
@@ -145,8 +189,8 @@ static void clickgame_pause (gboolean pause)
 	drop_items_id = gtk_timeout_add (200,
 					 (GtkFunction) clickgame_drop_items, NULL);
       }
-      if(!dummy_id) {
-	dummy_id = gtk_timeout_add (200, (GtkFunction) clickgame_move_items, NULL);
+      if(!move_items_id) {
+	move_items_id = gtk_timeout_add (200, (GtkFunction) clickgame_move_items, NULL);
       }
       if(!animate_id) {
 	animate_id = gtk_timeout_add (200, (GtkFunction) clickgame_animate_items, NULL);
@@ -156,82 +200,244 @@ static void clickgame_pause (gboolean pause)
   board_paused = pause;
 }
 
+static void
+fish_reverse_direction (FishItem *fish)
+{
+  fish->speed = -fish->speed;
+
+  gnome_canvas_item_hide(g_slist_nth_data(fish->cur_frames,
+					  fish->currentItem));
+
+  fish->cur_frames =
+    fish->speed<0? fish->rev_frames : fish->fwd_frames;
+
+  gnome_canvas_item_show(g_slist_nth_data(fish->cur_frames,
+					  fish->currentItem));
+}
+
+static void
+fish_gobble (FishItem *fishitem)
+{
+  clickgame_destroy_item(fishitem);
+  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+
+  gcomprisBoard->sublevel++;
+  gc_score_set(gcomprisBoard->sublevel);
+
+  if(gcomprisBoard->sublevel>=gcomprisBoard->number_of_sublevel) {
+    gamewon = TRUE;
+    clickgame_destroy_all_items();
+    gc_bonus_display(gamewon, BONUS_FLOWER);
+    return;
+  }
+  /* Drop a new item now to speed up the game */
+  if(g_list_length(item_list)==0)
+    {
+      /* Remove any pending new item creation to sync the falls */
+      if (drop_items_id)
+	gtk_timeout_remove (drop_items_id);
+      drop_items_id =
+	gtk_timeout_add (0, (GtkFunction) clickgame_drop_items, NULL);
+    }
+}
+
+static gint
+canvas_event(GnomeCanvas *canvas, GdkEvent *event)
+{
+  FishItem *fish;
+  double mouse_x = event->button.x;
+  double mouse_y = event->button.y;
+  int ii;
+
+  switch (event->type)
+     {
+     case GDK_BUTTON_PRESS:
+       switch(event->button.button)
+         {
+         case 1:
+         case 2:
+         case 3:
+           if (gcomprisBoard->level >= 3 &&
+	       !(event->button.state & GDK_SHIFT_MASK)) {
+	     for (ii=0; (fish=g_list_nth_data(item_list, ii)); ii++) {
+	       double dx, dy, near;
+	       double x1,x2,y1,y2;
+	       int react;
+	       gnome_canvas_item_get_bounds (fish->rootitem, &x1, &y1, &x2, &y2);
+	       //printf("fish %d\n", ii);
+
+	       dy = (mouse_y - (y1 + (y2 - y1) / 2)) / ((y2 - y1) / 2);
+	       //printf("dy = %.2f\n", dy);
+	       if (fabs(dy) > 3) continue;
+
+	       dx = (mouse_x - (x1 + (x2 - x1) / 2)) / ((x2 - x1) / 2);
+	       //printf("dx = %.2f\n", dx);
+	       if (fabs(dx) > 3) continue;
+
+	       // 0 to .9
+	       near = (sqrt(2*3*3) - sqrt(dx*dx + dy*dy))/(1.11 * sqrt(2*3*3));
+	       //printf("near = %.2f\n", near);
+
+	       react = ((rand() % 1000 < near * 1000) +
+			(rand() % 1000 < near * 1000));
+	       if (react) {
+		 if (gnome_canvas_get_item_at (canvas, mouse_x, mouse_y) !=
+		     g_slist_nth_data (fish->cur_frames, fish->currentItem) &&
+		     (dx > 0) ^ (fish->speed < 0))
+		   fish_reverse_direction (fish);
+		 else
+		   react += 1;
+	       }
+	       if (react >= 2)
+		 fish->fright +=
+		   (1000 + rand() % (int)(near * 2000)) / moveSpeed;
+	     }
+	   }
+	   break;
+	 default: break;
+	 }
+       break;
+     default:
+       break;
+     }
+
+  return FALSE;
+}
+
+static gint
+item_event(GnomeCanvasItem *item, GdkEvent *event, FishItem *fishitem)
+{
+   static double x, y;
+   double new_x, new_y;
+   GdkCursor *fleur;
+   static int dragging;
+   double item_x, item_y;
+
+   if(!gcomprisBoard)
+     return FALSE;
+
+   if(board_paused)
+     return FALSE;
+
+   item_x = event->button.x;
+   item_y = event->button.y;
+   gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
+
+   switch (event->type)
+     {
+     case GDK_BUTTON_PRESS:
+       switch(event->button.button)
+         {
+         case 1:
+         case 2:
+         case 3:
+           if (event->button.state & GDK_SHIFT_MASK)
+             {
+               x = item_x;
+               y = item_y;
+
+               fleur = gdk_cursor_new(GDK_FLEUR);
+               gc_canvas_item_grab(item,
+                                      GDK_POINTER_MOTION_MASK |
+                                      GDK_BUTTON_RELEASE_MASK,
+                                      fleur,
+                                      event->button.time);
+               gdk_cursor_destroy(fleur);
+               dragging = TRUE;
+             }
+           else
+             {
+	       if (gcomprisBoard->level >= 5 && !fishitem->stun) {
+		 fishitem->stun = 500 * (1 + gcomprisBoard->maxlevel - gcomprisBoard->level) / moveSpeed;
+		 fishitem->fright += 500 / moveSpeed;
+	       } else {
+		 fish_gobble (fishitem);
+	       }
+             }
+           break;
+
+         case 4:
+	   /* fish up */
+	   gnome_canvas_item_move(item, 0.0, -3.0);
+	   break;
+
+         case 5:
+	   /* fish down */
+	   gnome_canvas_item_move(item, 0.0, 3.0);
+	   break;
+
+         default:
+           break;
+         }
+       break;
+
+     case GDK_MOTION_NOTIFY:
+       if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
+         {
+           new_x = item_x;
+           new_y = item_y;
+
+           gnome_canvas_item_move(item, new_x - x, new_y - y);
+           x = new_x;
+           y = new_y;
+         }
+       break;
+
+     case GDK_BUTTON_RELEASE:
+       if(dragging)
+	 {
+	   gc_canvas_item_ungrab(item, event->button.time);
+	   dragging = FALSE;
+	 }
+       break;
+
+     default:
+       break;
+     }
+
+   return FALSE;
+ }
+
 /*
  */
 static void clickgame_start (GcomprisBoard *agcomprisBoard)
 {
-  gint		 i;
-  gchar		*str;
-  gchar		*filename;
-  GDir		*dir;
-  const gchar	*one_dirent;
+  if (!agcomprisBoard)
+    return;
 
-  if(agcomprisBoard!=NULL)
-    {
-      gcomprisBoard = agcomprisBoard;
+  gcomprisBoard = agcomprisBoard;
 
-      /* Load the Pixpmaps directory file names */
-      filename = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, gcomprisBoard->boarddir);      
-      dir = g_dir_open(filename, 0, NULL);
-      
-      if (!dir)
-	g_error (_("Couldn't open dir: %s"),filename);
+  /* set initial values for this level */
+  gcomprisBoard->level = 1;
+  gcomprisBoard->maxlevel=6;
+  gcomprisBoard->number_of_sublevel=10; /* Go to next level after this number of 'play' */
+  gc_score_start(SCORESTYLE_NOTE,
+		 gcomprisBoard->width - 220,
+		 gcomprisBoard->height - 50,
+		 gcomprisBoard->number_of_sublevel);
+  gc_bar_set(GC_BAR_LEVEL);
 
-      g_free(filename);
-
-      while((one_dirent = g_dir_read_name(dir)) != NULL) {
-
-	str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir, one_dirent);
-	str[strlen(str)-5]='x';
-	
-	if(g_list_find_custom(pixmaplist, str, (GCompareFunc) strcmp) == NULL) {
-	  pixmaplist = g_list_append (pixmaplist, str);
-	}
-      }
-      g_dir_close(dir);
-
-
-      /* set initial values for this level */
-      gcomprisBoard->level = 1;
-      gcomprisBoard->maxlevel=6;
-      gcomprisBoard->number_of_sublevel=10; /* Go to next level after this number of 'play' */
-      gcompris_score_start(SCORESTYLE_NOTE, 
-			   gcomprisBoard->width - 220, 
-			   gcomprisBoard->height - 50, 
-			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
-
-      clickgame_next_level();
-
-      clickgame_pause(FALSE);
-
-    }
+  event_handle_id =
+    gtk_signal_connect(GTK_OBJECT(gcomprisBoard->canvas), "event",
+		       (GtkSignalFunc) canvas_event, 0);
+  clickgame_next_level();
 
+  clickgame_pause(FALSE);
 }
 
 static void
 clickgame_end ()
 {
-  int i;
-
   if(gcomprisBoard!=NULL)
     {
       clickgame_pause(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       clickgame_destroy_all_items();
+      gtk_signal_disconnect(GTK_OBJECT(gcomprisBoard->canvas),
+			    event_handle_id);
       gcomprisBoard->level = 1;       // Restart this game to zero
     }
   gcomprisBoard = NULL;
-
-  i=g_list_length(pixmaplist);
-  for(i=0; i<g_list_length(pixmaplist); i++) {
-    g_free(g_list_nth_data(item_list, i));
-  }
-
-  if(pixmaplist) {
-    g_list_free(pixmaplist);
-    pixmaplist = NULL;
-  }
 }
 
 static void
@@ -246,14 +452,14 @@ clickgame_set_level (guint level)
 }
 
 static gboolean
-clickgame_is_our_board (GcomprisBoard *gcomprisBoard)
+clickgame_is_our_board (GcomprisBoard *board)
 {
-  if (gcomprisBoard)
+  if (board)
     {
-      if(g_strcasecmp(gcomprisBoard->type, "clickgame")==0)
+      if(g_strcasecmp(board->type, "clickgame")==0)
 	{
 	  /* Set the plugin entry */
-	  gcomprisBoard->plugin=&menu_bp;
+	  board->plugin=&menu_bp;
 
 	  return TRUE;
 	}
@@ -276,46 +482,40 @@ clickgame_config ()
 /*-------------------------------------------------------------------------------*/
 
 /* set initial values for the next level */
-static void clickgame_next_level() 
+static void clickgame_next_level()
 {
-
-  switch(gcomprisBoard->level)
+  static /*const*/ gchar *bglist[] =
     {
-    case 1:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      "gcompris/nur00523.jpg");
-      break;
-    case 2:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-      			      "gcompris/nur03006.jpg");
-      break;
-    case 3:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      "gcompris/nur03011.jpg");
-      break;
-    case 4:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      "gcompris/nur03010.jpg");
-      break;
-    case 5:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      "gcompris/nur03013.jpg");
-      break;
-    default:
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      "gcompris/nur03505.jpg");
-    }
+      "clickgame/nur00523.jpg",
+      "clickgame/nur03006.jpg",
+      "clickgame/nur03011.jpg",
+      "clickgame/nur03010.jpg",
+      "clickgame/nur03013.jpg",
+      "clickgame/nur03505.jpg"
+    };
 
-  gcompris_bar_set_level(gcomprisBoard);
+  int bgx = gcomprisBoard->level - 1;
+
+  if (bgx < 0 || G_N_ELEMENTS(bglist) <= bgx)
+    bgx = G_N_ELEMENTS(bglist) - 1;
+
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), bglist[bgx]);
+
+  gc_bar_set_level(gcomprisBoard);
 
   /* Try the next level */
-  speed=100+(40/(gcomprisBoard->level));
+  moveSpeed=100+(40/(gcomprisBoard->level));
   fallSpeed=5000-gcomprisBoard->level*200;
-  /* Make the images tend to 0.5 ratio */
-  imageZoom=0.5+(0.5/(gcomprisBoard->level));
+  imageZoom = 0.75 + 0.25 * ((gcomprisBoard->maxlevel - gcomprisBoard->level + 1) / gcomprisBoard->maxlevel);
   gcomprisBoard->sublevel=0;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
+  while (g_list_length (item_list) < 3) {
+    FishItem *fish = clickgame_create_item();
+    if (!fish) break;
+    gnome_canvas_item_move(fish->rootitem,
+                          fish->speed * (rand() % 200), 0.0);
+  }
 }
 
 
@@ -326,23 +526,31 @@ static void clickgame_animate_item(FishItem *fishitem)
   /* Manage the animation */
   currentItem = fishitem->currentItem;
   fishitem->currentItem++;
-  if(fishitem->currentItem >= g_list_length(fishitem->item_list))
+  if(fishitem->currentItem >= g_slist_length(fishitem->cur_frames))
     fishitem->currentItem=0;
 
-  gnome_canvas_item_show((GnomeCanvasItem *)g_list_nth_data(fishitem->item_list, 
-							    fishitem->currentItem));
+  gnome_canvas_item_show((GnomeCanvasItem *)g_slist_nth_data(fishitem->cur_frames,
+							     fishitem->currentItem));
 
-  gnome_canvas_item_hide((GnomeCanvasItem *)g_list_nth_data(fishitem->item_list, 
-							    currentItem));
+  gnome_canvas_item_hide((GnomeCanvasItem *)g_slist_nth_data(fishitem->cur_frames,
+							     currentItem));
 }
 
 static void clickgame_move_item(FishItem *fishitem)
 {
+  double sp = fishitem->speed;
   double x1, y1, x2, y2;
 
   GnomeCanvasItem *item = fishitem->rootitem;
 
-  gnome_canvas_item_move(item, fishitem->speed, 0.0);
+  if (fishitem->stun) {
+    --fishitem->stun;
+    sp *= .1 + (rand() % 100) / 1000.0;
+  } else if (fishitem->fright) {
+    --fishitem->fright;
+    sp *= 3 + (rand() % 3000) / 1000.0;
+  }
+  gnome_canvas_item_move(item, sp, 0.0);
 
 
   gnome_canvas_item_get_bounds    (item,
@@ -355,17 +563,23 @@ static void clickgame_move_item(FishItem *fishitem)
     {
       if(x1>gcomprisBoard->width) {
 	item2del_list = g_list_append (item2del_list, fishitem);
-	gcompris_play_ogg ("crash", NULL);
+	gc_sound_play_ogg ("crash", NULL);
       }
     }
   else
     {
       if(x2<0) {
 	item2del_list = g_list_append (item2del_list, fishitem);
-	gcompris_play_ogg ("crash", NULL);
+	gc_sound_play_ogg ("crash", NULL);
       }
     }
 
+  while (g_list_length (item_list) < 3) {
+    FishItem *fish = clickgame_create_item();
+    if (!fish) break;
+    gnome_canvas_item_move(fish->rootitem,
+                          fish->speed * (rand() % 200), 0.0);
+  }
 }
 
 static void clickgame_destroy_item(FishItem *fishitem)
@@ -376,7 +590,8 @@ static void clickgame_destroy_item(FishItem *fishitem)
   item2del_list = g_list_remove (item2del_list, fishitem);
   gtk_object_destroy (GTK_OBJECT(item));
 
-  g_list_free(fishitem->item_list);
+  g_slist_free (fishitem->fwd_frames);
+  g_slist_free (fishitem->rev_frames);
   g_free(fishitem);
 }
 
@@ -385,7 +600,7 @@ static void clickgame_destroy_items()
 {
   FishItem *fishitem;
 
-  while(g_list_length(item2del_list)>0) 
+  while(g_list_length(item2del_list)>0)
     {
       fishitem = g_list_nth_data(item2del_list, 0);
       clickgame_destroy_item(fishitem);
@@ -395,22 +610,11 @@ static void clickgame_destroy_items()
 /* Destroy all the items */
 static void clickgame_destroy_all_items()
 {
-  FishItem *fishitem;
-
-  while(g_list_length(item_list)>0) 
+  while(item_list)
     {
-      fishitem = g_list_nth_data(item_list, 0);
+      FishItem *fishitem = g_list_nth_data(item_list, 0);
       clickgame_destroy_item(fishitem);
     }
-  if(item_list) {
-    g_list_free(item_list);
-    item_list = NULL;
-  }
-
-  if(imagelist) {
-    g_list_free(imagelist);
-    imagelist = NULL;
-  }
 }
 
 /*
@@ -424,8 +628,8 @@ static gint clickgame_move_items (GtkWidget *widget, gpointer data)
   /* Destroy items that falls out of the canvas */
   clickgame_destroy_items();
 
-  dummy_id = gtk_timeout_add (speed,
-			      (GtkFunction) clickgame_move_items, NULL);
+  move_items_id = gtk_timeout_add (moveSpeed,
+				   (GtkFunction) clickgame_move_items, NULL);
 
   return(FALSE);
 }
@@ -444,27 +648,85 @@ static gint clickgame_animate_items (GtkWidget *widget, gpointer data)
   return(FALSE);
 }
 
-static FishItem *clickgame_create_item(GnomeCanvasGroup *parent)
+static GSList *load_random_fish(gboolean smallish)
 {
+  int fish;
+  const gchar **extraFish;
+  const gchar **surpriseFish;
+  int num_extra;
+  int num_surprise;
+
+  if (smallish) {
+    extraFish = smallFish;
+    num_extra = NUM_SMALLFISH;
+    surpriseFish = bigFish;
+    num_surprise = NUM_BIGFISH;
+  } else {
+    extraFish = bigFish;
+    num_extra = NUM_BIGFISH;
+    surpriseFish = smallFish;
+    num_surprise = NUM_SMALLFISH;
+  }
+
+  fish = rand() % (NUM_MEDFISH + num_extra + 2);
+
+  const gchar *path;
+  if (fish < NUM_MEDFISH) {
+    path = medFish[fish];
+  } else if (fish < NUM_MEDFISH + num_extra) {
+    path = extraFish[fish - NUM_MEDFISH];
+  } else {
+    fish = rand() % num_surprise;
+    path = surpriseFish[fish];
+  }
+
+  int frame = 0;
+  GSList *ilist = 0;
+  while(1)
+    {
+      if (frame) {
+	gchar *exists = gc_file_find_absolute (path, "fishes", frame);
+	g_free (exists);
+	if (!exists) break;
+      }
+
+      GdkPixbuf *pixmap = gc_pixmap_load (path, "fishes", frame);
+      if (!pixmap) break;
+
+      ilist = g_slist_prepend (ilist, pixmap);
+      ++frame;
+    }
+  return g_slist_reverse (ilist);
+}
+
+static FishItem *
+clickgame_create_item()
+{
+  GnomeCanvasGroup *parent = gnome_canvas_root(gcomprisBoard->canvas);
   GdkPixbuf *pixmap = NULL;
   GdkPixbuf *pixmap2 = NULL;
-  GnomeCanvasItem *rootitem, *item;
+  GnomeCanvasItem *rootitem;
   FishItem *fishitem;
   double x;
   gint i, length;
+  GSList *ilist;
 
   /* Avoid to have too much items displayed */
   if(g_list_length(item_list)>5)
     return NULL;
 
-  load_random_pixmap();
+  // select smallish fish on even levels, also see imageZoom
+  ilist = load_random_fish (!(gcomprisBoard->level & 1));
 
   fishitem = g_malloc(sizeof(FishItem));
   fishitem->currentItem   = 0;
   fishitem->speed = (double)(rand()%(60))/10 - 3;
-  fishitem->item_list = NULL;
+  fishitem->fright = 0;
+  fishitem->stun = 0;
+  fishitem->fwd_frames = NULL;
+  fishitem->rev_frames = NULL;
 
-  pixmap = (GdkPixbuf *)g_list_nth_data(imagelist, 0);
+  pixmap = (GdkPixbuf *)g_slist_nth_data(ilist, 0);
 
   if(pixmap==NULL)
     return NULL;
@@ -474,7 +736,7 @@ static FishItem *clickgame_create_item(GnomeCanvasGroup *parent)
       x = (double) gcomprisBoard->width;
       fishitem->speed=MIN(fishitem->speed, -1);
     }
-  else 
+  else
     {
       x = (double) -gdk_pixbuf_get_width(pixmap)*imageZoom;
       fishitem->speed=MAX(fishitem->speed, 1);
@@ -489,60 +751,72 @@ static FishItem *clickgame_create_item(GnomeCanvasGroup *parent)
 							 imageZoom))),
 			   NULL);
 
+  gtk_signal_connect(GTK_OBJECT(rootitem), "event",
+		     (GtkSignalFunc) item_event, fishitem);
 
   fishitem->rootitem = rootitem;
 
-  length = g_list_length(imagelist);
+  length = g_slist_length(ilist);
   for(i=0; i<length; i++)
     {
-      pixmap = (GdkPixbuf *)g_list_nth_data(imagelist, i);
+      GnomeCanvasItem *fwd, *rev;
 
-      pixmap2 = pixbuf_copy_mirror(pixmap, (fishitem->speed<0?TRUE:FALSE), FALSE);
+      pixmap = (GdkPixbuf *)g_slist_nth_data(ilist, i);
+      pixmap2 = pixbuf_copy_mirror(pixmap, TRUE, FALSE);
 
+      fwd = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				   gnome_canvas_pixbuf_get_type (),
+				   "pixbuf", pixmap,
+				   "x", 0.0,
+				   "y", 0.0,
+				   "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
+				   "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
+				   "width_set", TRUE,
+				   "height_set", TRUE,
+				   NULL);
+      rev = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				   gnome_canvas_pixbuf_get_type (),
+				   "pixbuf", pixmap2,
+				   "x", 0.0,
+				   "y", 0.0,
+				   "width", (double) gdk_pixbuf_get_width(pixmap2)*imageZoom,
+				   "height", (double) gdk_pixbuf_get_height(pixmap2)*imageZoom,
+				   "width_set", TRUE,
+				   "height_set", TRUE,
+				   NULL);
       gdk_pixbuf_unref(pixmap);
-
-      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap2, 
-				    "x", 0.0,
-				    "y", 0.0,
-				    "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
-				    "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
-				    "width_set", TRUE, 
-				    "height_set", TRUE,
-				    NULL);
       gdk_pixbuf_unref(pixmap2);
 
-      if(i==fishitem->currentItem)
-	gnome_canvas_item_show(item);
-      else
-	gnome_canvas_item_hide(item);
-	
-      fishitem->item_list = g_list_append (fishitem->item_list, item);
+      fishitem->fwd_frames = g_slist_prepend (fishitem->fwd_frames, fwd);
+      fishitem->rev_frames = g_slist_prepend (fishitem->rev_frames, rev);
+
+      gnome_canvas_item_hide (fwd);
+      gnome_canvas_item_hide (rev);
     }
 
-  for(i=0; i<length; i++)
-    {
-      pixmap = (GdkPixbuf *)g_list_nth_data(imagelist, 0);
-      imagelist = g_list_remove(imagelist, pixmap);
-    }
+  g_slist_free (ilist);
+
+  fishitem->fwd_frames = g_slist_reverse (fishitem->fwd_frames);
+  fishitem->rev_frames = g_slist_reverse (fishitem->rev_frames);
+
+  fishitem->cur_frames =
+    fishitem->speed<0? fishitem->rev_frames : fishitem->fwd_frames;
+
+  gnome_canvas_item_show(g_slist_nth_data(fishitem->cur_frames,
+					  fishitem->currentItem));
+
   item_list = g_list_append (item_list, fishitem);
 
   return (fishitem);
 }
 
-static void clickgame_add_new_item() 
-{
-  setup_item (clickgame_create_item(gnome_canvas_root(gcomprisBoard->canvas)));
-}
-
 /*
  * This is called on a low frequency and is used to drop new items
  *
  */
 static gint clickgame_drop_items (GtkWidget *widget, gpointer data)
 {
-  clickgame_add_new_item();
+  clickgame_create_item();
 
   drop_items_id = gtk_timeout_add (fallSpeed,
 				   (GtkFunction) clickgame_drop_items, NULL);
@@ -559,210 +833,11 @@ static void game_won()
     gcomprisBoard->sublevel=0;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   clickgame_next_level();
 }
 
-static gint
-item_event(GnomeCanvasItem *item, GdkEvent *event, FishItem *fishitem)
-{
-   static double x, y;
-   double new_x, new_y;
-   GdkCursor *fleur;
-   static int dragging;
-   double item_x, item_y;
-
-   if(!gcomprisBoard)
-     return FALSE;
-
-   if(board_paused)
-     return FALSE;
-
-   item_x = event->button.x;
-   item_y = event->button.y;
-   gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
-
-   switch (event->type) 
-     {
-     case GDK_BUTTON_PRESS:
-       switch(event->button.button) 
-         {
-         case 1:
-           if (event->button.state & GDK_SHIFT_MASK)
-             {
-               x = item_x;
-               y = item_y;
-               
-               fleur = gdk_cursor_new(GDK_FLEUR);
-               gnome_canvas_item_grab(item,
-                                      GDK_POINTER_MOTION_MASK | 
-                                      GDK_BUTTON_RELEASE_MASK,
-                                      fleur,
-                                      event->button.time);
-               gdk_cursor_destroy(fleur);
-               dragging = TRUE;
-             }
-           else 
-             {
-	       clickgame_destroy_item(fishitem);
-	       gcompris_play_ogg ("gobble", NULL);
-	       
-	       gcomprisBoard->sublevel++;
-	       gcompris_score_set(gcomprisBoard->sublevel);
-	       
-	       if(gcomprisBoard->sublevel>=gcomprisBoard->number_of_sublevel) {
-		 gamewon = TRUE;
-		 clickgame_destroy_all_items();
-		 gcompris_display_bonus(gamewon, BONUS_FLOWER);
-		 return FALSE;
-	       }
-	       /* Drop a new item now to speed up the game */
-	       if(g_list_length(item_list)==0)
-		 {
-		   if (drop_items_id) {
-		     /* Remove pending new item creation to sync the falls */
-		     gtk_timeout_remove (drop_items_id);
-		     drop_items_id = 0;
-		   }
-		   if(!drop_items_id) {
-		     drop_items_id = gtk_timeout_add (0,
-						      (GtkFunction) clickgame_drop_items,
-						      NULL);
-		   }
-		 }
-             }
-           break;
-
-         case 3:
-	   /* Speed up the fish */
-	   if(fishitem->speed>0)
-	     fishitem->speed = MAX(fishitem->speed+1 , 5);
-	   else
-	     fishitem->speed = MIN(fishitem->speed-1, -5);
-	   break;
-
-         case 2:
-	   /* Slow the fish */
-	   if(fishitem->speed>0)
-	     fishitem->speed = MAX(fishitem->speed-1, 1);
-	   else
-	     fishitem->speed = MIN(fishitem->speed+1, -1);
-	   break;
-
-         case 4:
-	   /* fish up */
-	   gnome_canvas_item_move(item, 0.0, -3.0);
-	   break;
-
-         case 5:
-	   /* fish down */
-	   gnome_canvas_item_move(item, 0.0, 3.0);
-	   break;
-
-         default:
-           break;
-         }
-       break;
-
-     case GDK_MOTION_NOTIFY:
-       if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
-         {
-           new_x = item_x;
-           new_y = item_y;
-             
-           gnome_canvas_item_move(item, new_x - x, new_y - y);
-           x = new_x;
-           y = new_y;
-         }
-       break;
-           
-     case GDK_BUTTON_RELEASE:
-       if(dragging) 
-	 {
-	   gnome_canvas_item_ungrab(item, event->button.time);
-	   dragging = FALSE;
-	 }
-       break;
-
-     default:
-       break;
-     }
-         
-   return FALSE;
- }
-
-static void
-setup_item(FishItem *fishitem)
-{
-  if(fishitem)
-      gtk_signal_connect(GTK_OBJECT(fishitem->rootitem), "event",
-			 (GtkSignalFunc) item_event,
-			 fishitem);
-}
-
-/*
- * Return the list of pixmap in the global
- * imagelist
- */
-static void load_random_pixmap()
-{
-  GdkPixbuf *pixmap;
-  int i, j;
-  gchar *str = NULL;
-  gboolean cont = TRUE;
-
-  if(g_list_length(pixmaplist)<=0)
-    return;
-
-  i=rand()%(g_list_length(pixmaplist));
-
-  str = (char *)g_list_nth_data(pixmaplist, i);
-  if(str==NULL)
-    return;
-
-  /* First image */
-  j=0;
-
-  while(cont)
-    {
-      gchar *filename;
-      gchar numstr[2];
-
-      sprintf(numstr, "%d", j++);
-      str[strlen(str)-5]=numstr[0];
-
-      filename = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, str);
-
-      if (!g_file_test (filename, G_FILE_TEST_EXISTS))
-	{
-	  cont = FALSE;
-	}
-      else
-	{
-	  pixmap = gcompris_load_pixmap (str);
-
-	  if(pixmap) {
-	    imagelist = g_list_append (imagelist, pixmap);
-	  } else {
-	    cont = FALSE;
-	  }
-	}
-
-      g_free (filename);
-    }
-
-}
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
