@@ -1,6 +1,6 @@
 /* gcompris - clockgame.c
  *
- * Time-stamp: <2006/04/05 01:16:11 bruno>
+ * Time-stamp: <2006/08/21 23:33:07 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -133,8 +133,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gchar *img;
       gcomprisBoard=agcomprisBoard;
 
-      img = gcompris_image_to_skin("clockgame-bg.jpg");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
+      img = gc_skin_image_get("clockgame-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      img);
       g_free(img);
 
@@ -147,18 +147,18 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=3; /* Go to next level after this number of 'play' */
-      gcompris_score_start(SCORESTYLE_NOTE,
+      gc_score_start(SCORESTYLE_NOTE,
 			   gcomprisBoard->width - 220,
 			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
       clockgame_next_level();
 
       gamewon = FALSE;
       pause_board(FALSE);
 
-      gcompris_set_cursor(GCOMPRIS_LINE_CURSOR);
+      gc_cursor_set(GCOMPRIS_LINE_CURSOR);
     }
 
 }
@@ -170,11 +170,11 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       destroy_all_items();
     }
   gcomprisBoard = NULL;
-  gcompris_set_cursor(GCOMPRIS_DEFAULT_CURSOR);
+  gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
 }
 
 static void
@@ -215,8 +215,8 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 static void clockgame_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_bar_set_level(gcomprisBoard);
+  gc_score_set(gcomprisBoard->sublevel);
 
   destroy_all_items();
 
@@ -248,6 +248,12 @@ destroy_all_items()
 static void display_digital_time(GnomeCanvasItem *item, GcomprisTime *time)
 {
   gchar *text = NULL;
+  int temps;
+
+  temps = (time->hour+12)*3600 + time->minute*60 + time->second;
+  time->hour = (temps / 3600) % 12;
+  time->minute = (temps / 60) % 60;
+  time->second = temps % 60;
 
   if(item==NULL)
     return;
@@ -269,7 +275,6 @@ static void display_hour(guint hour)
   double needle_size = clock_size*0.70;
   double ang;
   GnomeCanvasPoints *canvasPoints;
-  canvasPoints = gnome_canvas_points_new (2);
 
   if(hour_item==NULL)
     return;
@@ -279,6 +284,7 @@ static void display_hour(guint hour)
   ang += currentTime.minute * M_PI / 360;
   ang += currentTime.second * M_PI / 21600;
 
+  canvasPoints = gnome_canvas_points_new (2);
   canvasPoints->coords[0]=cx;
   canvasPoints->coords[1]=cy;
   canvasPoints->coords[2]=cx + needle_size * sin(ang);
@@ -297,15 +303,14 @@ static void display_hour(guint hour)
 
   currentTime.hour=hour;
   display_digital_time(digital_time_item, &currentTime);
+  display_digital_time(digital_time_item_s, &currentTime);
 }
 
-
 static void display_minute(guint minute)
 {
   double needle_size = clock_size;
   double ang;
   GnomeCanvasPoints *canvasPoints;
-  canvasPoints = gnome_canvas_points_new (2);
 
   if(minute_item==NULL)
     return;
@@ -313,6 +318,7 @@ static void display_minute(guint minute)
   ang = minute * M_PI / 30;
   ang += currentTime.second * M_PI / 1800;
 
+  canvasPoints = gnome_canvas_points_new (2);
   canvasPoints->coords[0]=cx;
   canvasPoints->coords[1]=cy;
   canvasPoints->coords[2]=cx + needle_size * sin(ang);
@@ -331,6 +337,7 @@ static void display_minute(guint minute)
 
   currentTime.minute=minute;
   display_digital_time(digital_time_item, &currentTime);
+  display_digital_time(digital_time_item_s, &currentTime);
 }
 
 static void display_second(guint second)
@@ -338,7 +345,6 @@ static void display_second(guint second)
   double needle_size = clock_size;
   double ang;
   GnomeCanvasPoints *canvasPoints;
-  canvasPoints = gnome_canvas_points_new (2);
 
   /* No seconds at first levels */
   if(second_item==NULL || gcomprisBoard->level<=2)
@@ -346,6 +352,7 @@ static void display_second(guint second)
 
   ang = second * M_PI / 30;
 
+  canvasPoints = gnome_canvas_points_new (2);
   canvasPoints->coords[0]=cx;
   canvasPoints->coords[1]=cy;
   canvasPoints->coords[2]=cx + needle_size * sin(ang);
@@ -364,6 +371,7 @@ static void display_second(guint second)
 
   currentTime.second=second;
   display_digital_time(digital_time_item, &currentTime);
+  display_digital_time(digital_time_item_s, &currentTime);
 }
 
 
@@ -401,7 +409,7 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 	  canvasPoints->coords[1]=cy - (needle_size-hour_point_size) * cos(ang);
 	  color="darkblue";
 	  color_text="red";
-	  font = gcompris_skin_font_board_small;
+	  font = gc_skin_font_board_small;
 	}
       else
 	{
@@ -410,7 +418,7 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 	  canvasPoints->coords[1]=cy - (needle_size-min_point_size) * cos(ang);
 	  color="red";
 	  color_text="red";
-	  font = gcompris_skin_font_board_tiny;
+	  font = gc_skin_font_board_tiny;
 	}
 
       canvasPoints->coords[2]=cx + needle_size * sin(ang);
@@ -466,7 +474,7 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_text_get_type (),
 			       "text", "",
-			       "font", gcompris_skin_font_board_medium,
+			       "font", gc_skin_font_board_medium,
 			       "x", (double) cx + 1.0,
 			       "y", (double) cy +  needle_size/2 + 1.0,
 			       "anchor", GTK_ANCHOR_CENTER,
@@ -478,7 +486,7 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_text_get_type (),
 			       "text", "",
-			       "font", gcompris_skin_font_board_medium,
+			       "font", gc_skin_font_board_medium,
 			       "x", (double) cx,
 			       "y", (double) cy +  needle_size/2,
 			       "anchor", GTK_ANCHOR_CENTER,
@@ -542,32 +550,32 @@ clockgame_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Set the watch to:"),
-			 "font", gcompris_skin_font_board_small,
+			 "font", gc_skin_font_board_small,
 			 "x", (double) gcomprisBoard->width*0.17 + 1.0,
 			 "y", (double) cy + needle_size +  needle_size / 3 - 30 + 1.0,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 "fill_color_rgba", gc_skin_color_shadow,
 			 NULL);
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Set the watch to:"),
-			 "font", gcompris_skin_font_board_small,
+			 "font", gc_skin_font_board_small,
 			 "x", (double) gcomprisBoard->width*0.17,
 			 "y", (double) cy + needle_size +  needle_size / 3 - 30,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_get_color("clockgame/text"),
+			 "fill_color_rgba", gc_skin_get_color("clockgame/text"),
 			 NULL);
 
   time_to_find_item_s =
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_text_get_type (),
 			   "text", "",
-			   "font", gcompris_skin_font_board_big_bold,
+			   "font", gc_skin_font_board_big_bold,
 			   "x", (double) gcomprisBoard->width*0.17 + 1.0,
 			   "y", (double) cy + needle_size +  needle_size / 3 + 1.0,
 			   "anchor", GTK_ANCHOR_CENTER,
-			   "fill_color_rgba", gcompris_skin_color_shadow,
+			   "fill_color_rgba", gc_skin_color_shadow,
 			   NULL);
   display_digital_time(time_to_find_item_s, &timeToFind);
 
@@ -575,11 +583,11 @@ clockgame_create_item(GnomeCanvasGroup *parent)
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_text_get_type (),
 			   "text", "",
-			   "font", gcompris_skin_font_board_big_bold,
+			   "font", gc_skin_font_board_big_bold,
 			   "x", (double) gcomprisBoard->width*0.17,
 			   "y", (double) cy + needle_size +  needle_size / 3,
 			   "anchor", GTK_ANCHOR_CENTER,
-			   "fill_color_rgba", gcompris_skin_get_color("clockgame/text"),
+			   "fill_color_rgba", gc_skin_get_color("clockgame/text"),
 			   NULL);
   display_digital_time(time_to_find_item, &timeToFind);
 
@@ -615,10 +623,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   clockgame_next_level();
 }
@@ -635,7 +643,7 @@ static void process_ok()
       /* Oups, you're wrong */
       gamewon = FALSE;
     }
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
 }
 
 
@@ -663,7 +671,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       y = item_y;
 
       fleur = gdk_cursor_new(GDK_FLEUR);
-      gnome_canvas_item_grab(item,
+      gc_canvas_item_grab(item,
 			     GDK_POINTER_MOTION_MASK |
 			     GDK_BUTTON_RELEASE_MASK,
 			     fleur,
@@ -692,11 +700,23 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    display_hour(angle * 6 / M_PI);
 	  else if(item==minute_item)
 	  {
+	    if(currentTime.minute > 45 && angle * 30 / M_PI < 15)
+	      currentTime.hour++;
+
+	    if(currentTime.minute < 15 && angle * 30 / M_PI > 45)
+	      currentTime.hour--;
+
 	    display_minute(angle * 30 / M_PI);
 	    display_hour(currentTime.hour);
 	  }
 	  else if(item==second_item)
 	  {
+	    if(currentTime.second > 45 && angle * 30 / M_PI < 15)
+	      currentTime.minute++;
+
+	    if(currentTime.second < 15 && angle * 30 / M_PI > 45)
+	      currentTime.minute--;
+
 	    display_second(angle * 30 / M_PI);
 	    display_minute(currentTime.minute);
 	    display_hour(currentTime.hour);
@@ -710,7 +730,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     case GDK_BUTTON_RELEASE:
       if(dragging)
 	{
-	  gnome_canvas_item_ungrab(item, event->button.time);
+	  gc_canvas_item_ungrab(item, event->button.time);
 	  dragging = FALSE;
 	}
       break;
@@ -727,11 +747,11 @@ static void get_random_hour(GcomprisTime *time)
 {
 
   time->hour=rand()%12;
-  
+
   if(gcomprisBoard->level>3)
     time->second=rand()%60;
   else time->second=0;
-  
+
   time->minute=rand()%60;
 
   switch(gcomprisBoard->level)
@@ -747,14 +767,3 @@ static void get_random_hour(GcomprisTime *time)
     }
 
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
