@@ -17,9 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -69,9 +66,6 @@ static gchar *colors[LAST_COLOR*2] = {
 static int X[] = {75,212,242,368,414,533,578,709};
 static int Y[] = {25,170,180,335,337,500};
 
-/* if board has alternate locale */
-static gchar *locale_sound = NULL;
-
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
@@ -89,7 +83,7 @@ static BoardPlugin menu_bp =
     end_board,
     is_our_board,
     NULL,
-    process_ok,
+    NULL,
     NULL,//set_level,
     NULL,
     repeat,
@@ -101,7 +95,7 @@ static BoardPlugin menu_bp =
  *
  * =====================================================================*/
 GET_BPLUGIN_INFO(colors)
-     
+
 
 /* ======================= */
 /* = config_start        = */
@@ -110,17 +104,18 @@ GET_BPLUGIN_INFO(colors)
 static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
-static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+static void save_table (gpointer key,
+			gpointer value,
+			gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+static void
+conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
@@ -129,36 +124,28 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   }
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
-  
+
   if (gcomprisBoard){
-    GHashTable *config = gcompris_get_board_conf();
-  
+    GHashTable *config = gc_db_get_board_conf();
+
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
 
-    if (locale_sound)
-      g_free(locale_sound);
-    locale_sound = g_strdup(g_hash_table_lookup( config, "locale_sound"));
-  
+    gc_locale_reset();
+    gc_locale_set(g_hash_table_lookup(config, "locale_sound"));
+
     if (profile_conf)
       g_hash_table_destroy(config);
 
     colors_next_level();
 
     pause_board(FALSE);
-  
+
   }
   board_conf = NULL;
   profile_conf = NULL;
-  
-}
-
-static gboolean check_text(gchar *key, gchar *text, GtkLabel *label){
-  gtk_label_set_markup(label, text);
-
-  return TRUE;
 }
 
 static void
@@ -170,33 +157,33 @@ colors_config_start(GcomprisBoard *agcomprisBoard,
 
   gchar *label;
 
-
   if (gcomprisBoard)
     pause_board(TRUE);
-  
+
   label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
 			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
+  gc_board_config_window_display(label, conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
-  
-  gcompris_combo_locales_asset( "Select sound locale", saved_locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+
+  gc_board_config_combo_locales_asset( "Select sound locale", saved_locale_sound,
+				"sounds/$LOCALE/colors/purple.ogg");
 
   g_hash_table_destroy(config);
 
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 colors_config_stop()
 {
 }
@@ -210,7 +197,7 @@ static void pause_board (gboolean pause)
   if(gcomprisBoard==NULL)
     return;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
   if(gamewon == TRUE && pause == FALSE) /* the game is won */
     game_won();
 
@@ -221,27 +208,29 @@ static void pause_board (gboolean pause)
  *
  * =====================================================================*/
 static void start_board (GcomprisBoard *agcomprisBoard) {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
   GList * list = NULL;
   int * item;
   int i;
 
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
+
+  gc_locale_set(g_hash_table_lookup(config, "locale_sound"));
 
-  locale_sound = g_strdup(g_hash_table_lookup( config, "locale_sound"));
-  
   g_hash_table_destroy(config);
 
+  gc_sound_pause();
+
   if(agcomprisBoard!=NULL) {
     gcomprisBoard=agcomprisBoard;
-    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "colors/colors_bg.png");
+    gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "colors/colors_bg.png");
     gcomprisBoard->level=1;
     gcomprisBoard->maxlevel=1;
 
     if(properties->fx) {
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_REPEAT);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_REPEAT);
     } else {
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG);
+      gc_bar_set(GC_BAR_CONFIG);
     }
 
     gamewon = FALSE;
@@ -271,7 +260,7 @@ static void end_board () {
 
   if(gcomprisBoard!=NULL){
     pause_board(TRUE);
-    gcompris_score_end();
+    gc_score_end();
     colors_destroy_all_items();
     // free list
     while (g_list_length(listColors) > 0)
@@ -279,7 +268,9 @@ static void end_board () {
     g_list_free(listColors);
     listColors=NULL;
   }
+  gc_locale_reset();
   gcomprisBoard = NULL;
+  gc_sound_resume();
 }
 
 /* =====================================================================
@@ -312,51 +303,42 @@ static void repeat (){
   if(gcomprisBoard!=NULL)
     {
       char *str  = NULL;
-      char *str1 = NULL;
-      char *str2 = NULL;
-      GcomprisProperties	*properties = gcompris_get_properties();
+      GcomprisProperties *properties = gc_prop_get();
 
-      str1 = g_strdup_printf("%s%s", colors[GPOINTER_TO_INT(g_list_nth_data(listColors, 0))*2],
-			     ".ogg");
-      str2 = gcompris_get_asset_file_locale("gcompris colors", NULL, "audio/x-ogg", str1, locale_sound);
+      str = g_strdup_printf("sounds/$LOCALE/colors/%s.ogg",
+			    colors[GPOINTER_TO_INT(g_list_nth_data(listColors, 0))*2]);
 
       /* If we don't find a sound in our locale or the sounds are disabled */
-      if(str2 && properties->fx) {
-	gcompris_play_ogg(str2, NULL);
-      }
+      if(str && properties->fx)
+	{
+	  gc_sound_play_ogg(str, NULL);
+	}
       else
 	{
 	  str = g_strdup_printf(gettext(colors[GPOINTER_TO_INT(g_list_nth_data(listColors, 0))*2+1]));
-	  
+
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", str,
-				 "font", gcompris_skin_font_board_huge_bold,
+				 "font", gc_skin_font_board_huge_bold,
 				 "x", (double) BOARDWIDTH/2+2,
 				 "y", (double) BOARDHEIGHT-25+2,
 				 "anchor", GTK_ANCHOR_CENTER,
 				 "fill_color", "black",
 				 NULL);
-	  
+
 	  gnome_canvas_item_new (boardRootItem,
 				 gnome_canvas_text_get_type (),
 				 "text", str,
-				 "font", gcompris_skin_font_board_huge_bold,
+				 "font", gc_skin_font_board_huge_bold,
 				 "x", (double) BOARDWIDTH/2,
 				 "y", (double) BOARDHEIGHT-25,
 				 "anchor", GTK_ANCHOR_CENTER,
 				 "fill_color", "blue",
 				 NULL);
-	  
-	  
-	  g_free(str);
 	}
-      
-
-
-      g_free(str1);
-      g_free(str2);
 
+      g_free(str);
     }
 }
 /* =====================================================================
@@ -384,7 +366,7 @@ static GnomeCanvasItem *colors_create_item(GnomeCanvasGroup *parent) {
 							    NULL));
 
   str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir, "colors_highlight.png");
-  highlight_pixmap = gcompris_load_pixmap(str);
+  highlight_pixmap = gc_pixmap_load(str);
 
   highlight_image_item = gnome_canvas_item_new (boardRootItem,
 						gnome_canvas_pixbuf_get_type (),
@@ -417,7 +399,7 @@ static void game_won() {
   listColors = g_list_remove(listColors, g_list_nth_data(listColors,0));
 
   if( g_list_length(listColors) <= 0 ) { // the current board is finished : bail out
-    board_finished(BOARD_FINISHED_TUXLOCO);
+    gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
     return;
   }
 
@@ -427,12 +409,12 @@ static void game_won() {
  *
  * =====================================================================*/
 static gboolean process_ok_timeout() {
-  gcompris_display_bonus(gamewon, BONUS_GNU);
+  gc_bonus_display(gamewon, BONUS_GNU);
   return FALSE;
 }
 
 static void process_ok() {
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
   // leave time to display the right answer
   g_timeout_add(TIME_CLICK_TO_BONUS, process_ok_timeout, NULL);
 }
@@ -486,7 +468,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 static void highlight_selected(int c) {
   int x, y;
 
-  assert(c>=0 && c<=9);
+  g_assert(c>=0 && c<=9);
 
   if (c<8) {
     x = (X[(c%4)*2] + X[(c%4)*2+1]) /2;
@@ -501,5 +483,5 @@ static void highlight_selected(int c) {
   x -= highlight_width/2;
   y -= highlight_height/2;
   gnome_canvas_item_show(highlight_image_item);
-  item_absolute_move(highlight_image_item, x, y);
+  gc_item_absolute_move(highlight_image_item, x, y);
 }
