@@ -17,11 +17,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "gcompris/gcompris.h"
 
@@ -202,14 +198,14 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	gcomprisBoard->maxlevel = MAX_LEVEL;
 	gcomprisBoard->sublevel = 1;
 	gcomprisBoard->number_of_sublevel = 1; /* Go to next level after this number of 'play' */
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+	gc_bar_set(GC_BAR_LEVEL);
 
-	img = gcompris_image_to_skin("gcompris-bg.jpg");
-	gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+	img = gc_skin_image_get("gcompris-bg.jpg");
+	gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 				img);
 	g_free(img);
 
-	
+
 	crane_next_level();
 
 	gamewon = FALSE;
@@ -236,7 +232,7 @@ static void end_board () {
 static void set_level (guint level) {
 
   if (gcomprisBoard != NULL) {
-	  
+
       gcomprisBoard->level = level;
       gcomprisBoard->sublevel = 1;
       crane_next_level();
@@ -263,7 +259,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
 /* set initial values for the next level */
 static void crane_next_level() {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   crane_destroy_all_items();
   gamewon = FALSE;
@@ -271,7 +267,7 @@ static void crane_next_level() {
   /* Try the next level */
   crane_create_item();
 }
-  
+
 /* ==================================== */
 /* Destroy all the items */
 static void crane_destroy_all_items()
@@ -303,7 +299,7 @@ static GnomeCanvasItem *crane_create_item()
 				     NULL));
 
 
-  pixmap = gcompris_load_pixmap("crane/crane-bg.png");
+  pixmap = gc_pixmap_load("crane/crane-bg.png");
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_pixbuf_get_type(),
 			 "pixbuf", pixmap,
@@ -345,15 +341,15 @@ static GnomeCanvasItem *crane_create_item()
 // Display an happy face for end of level
 static void bonus() {
 
-  gcompris_display_bonus(gamewon, BONUS_SMILEY);
-  gcompris_play_ogg ("bonus", NULL);
+  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   timer_id = 0;
 }
 
 // Display a 'end of game' animation
 static void finished() {
 
-  board_finished(BOARD_FINISHED_RANDOM);
+  gc_bonus_end_display(BOARD_FINISHED_RANDOM);
   timer_id = 0;
 }
 
@@ -441,7 +437,7 @@ static gint arrow_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 	  my_move.y = 1;
 	  break;
 	}
-			       
+
 	// Check if the move doesn't go out of the frame
 	if (is_allowed_move(dx1, dy1, direction)) {
 
@@ -470,7 +466,7 @@ static gint arrow_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
       gamewon = TRUE;
       timer_id = g_timeout_add (1200, (GtkFunction) bonus, NULL);
   }
-  
+
   return FALSE;
 }
 
@@ -482,19 +478,19 @@ static void draw_arrow() {
   int i;
   crane_object arrow[4];
 
-  arrow[0].pixmap = gcompris_load_pixmap("crane/arrow_down.png");
+  arrow[0].pixmap = gc_pixmap_load("crane/arrow_down.png");
   arrow[0].x = CRANE_BUTTON_DOWN_X;
   arrow[0].y = CRANE_BUTTON_DOWN_Y;
-  
-  arrow[1].pixmap = gcompris_load_pixmap("crane/arrow_up.png");
+
+  arrow[1].pixmap = gc_pixmap_load("crane/arrow_up.png");
   arrow[1].x = CRANE_BUTTON_UP_X;
   arrow[1].y = CRANE_BUTTON_UP_Y;
 
-  arrow[2].pixmap = gcompris_load_pixmap("crane/arrow_left.png");
+  arrow[2].pixmap = gc_pixmap_load("crane/arrow_left.png");
   arrow[2].x = CRANE_BUTTON_LEFT_X;
   arrow[2].y = CRANE_BUTTON_LEFT_Y + 2;
 
-  arrow[3].pixmap = gcompris_load_pixmap("crane/arrow_right.png");
+  arrow[3].pixmap = gc_pixmap_load("crane/arrow_right.png");
   arrow[3].x = CRANE_BUTTON_RIGHT_X;
   arrow[3].y = CRANE_BUTTON_RIGHT_Y - 2;
 
@@ -509,7 +505,7 @@ static void draw_arrow() {
   	gtk_signal_connect(GTK_OBJECT(item_arrow), "event",
 			   (GtkSignalFunc) arrow_event, GINT_TO_POINTER(i));
 	gtk_signal_connect(GTK_OBJECT(item_arrow), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
 	gdk_pixbuf_unref( arrow[i].pixmap);
 
@@ -538,7 +534,7 @@ static void draw_redhands() {
 					  "width_pixels", (guint) 7,
 					  NULL);
 
-  pixmap = gcompris_load_pixmap("crane/selected.png");
+  pixmap = gc_pixmap_load("crane/selected.png");
 
   red_hands = gnome_canvas_item_new (boardRootItem,
 	gnome_canvas_pixbuf_get_type(),
@@ -551,12 +547,12 @@ static void draw_redhands() {
 	"height_set", TRUE,
 	"anchor", GTK_ANCHOR_NW,
 	NULL);
-  
+
   gdk_pixbuf_unref(pixmap);
 
   gnome_canvas_item_hide(red_hands);
 
-} 
+}
 
 // Draw the drak frame (horizontal and vertical lines) that helps positionning elements
 static void draw_frame(int x, int y) {
@@ -623,7 +619,7 @@ static void place_item(int x, int y, int active) {
 	if (valeur == -1)
 		continue;
 
-	pixmap = gcompris_load_pixmap(imageList[valeur]);
+	pixmap = gc_pixmap_load(imageList[valeur]);
 	item_image = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
 				    "pixbuf", pixmap,
@@ -699,7 +695,7 @@ void shuffle_list(int list[], int size) {
   int rand1, rand2, buffer;
 
   for (i = 0 ; i < size ; i++) {
-	  
+
 	rand1 = RAND(0, size-1);
 	rand2 = RAND(0, size-1);
 
@@ -720,13 +716,13 @@ static void select_item(GnomeCanvasItem *item, int sound) {
   // Place redhands in (O;O)
   gnome_canvas_item_get_bounds(red_hands, &dx1, &dy1, &dx2, &dy2);
   gnome_canvas_item_move(red_hands, -(dx1), -(dy1));
- 
-  // Place redhands 'around' the selected item 
+
+  // Place redhands 'around' the selected item
   gnome_canvas_item_get_bounds(item, &dx1, &dy1, &dx2, &dy2);
   gnome_canvas_item_move(red_hands, dx1 - 1 , dy1 - 1);
 
   gnome_canvas_item_show(red_hands);
- 
+
   crane_rope->coords[0] = (dx1 + dx2) / 2;
   crane_rope->coords[1] = CRANE_ROPE_Y;
   crane_rope->coords[2] = (dx1 + dx2) / 2;
@@ -736,7 +732,7 @@ static void select_item(GnomeCanvasItem *item, int sound) {
 			 "points", crane_rope,
 			 NULL);
 
-  if (sound) gcompris_play_ogg ("gobble", NULL);
+  if (sound) gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 
   selected_item = item;
 }
