@@ -24,11 +24,12 @@
 #include <libxml/parser.h>
 
 #include <math.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
+#include "gcompris/pixbuf_util.h"
 
 #define SOUNDLISTFILE PACKAGE
-#define IMG_DATA_SET PACKAGE_DATA_DIR "/dataset"
 #define FILE_SELECTOR_ROOT "drawings"
 
 /* Represent the drawing area */
@@ -190,7 +191,6 @@ static void	 display_color_selector(GnomeCanvasGroup *parent);
 static void	 display_tool_selector(GnomeCanvasGroup *parent);
 static void	 display_drawing_area(GnomeCanvasGroup *parent);
 static void	 display_grid(gboolean status);
-static gint	 color_event(GnomeCanvasItem *item, GdkEvent *event, gchar *color);
 static gint	 ext_color_event(GnomeCanvasItem *item, GdkEvent *event, gpointer color_rgba);
 static void	 set_current_tool(GnomeCanvasItem *item, gint tool);
 static gint	 tool_event(GnomeCanvasItem *item, GdkEvent *event, gint tool);
@@ -201,11 +201,10 @@ static gint	 item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem
 static void	 highlight_color_item(GnomeCanvasItem *item);
 static guint	 get_tool_cursor(ToolList tool);
 static guint	 get_resize_cursor(AnchorType anchor);
-static void	 realign_to_grid(GnomeCanvasItem *item);
 static void	 snap_to_grid(double *x, double *y);
 static void	 image_selected(gchar *image);
-static void	 load_drawing(gchar *file);
-static void	 save_drawing(gchar *file);
+static void	 load_drawing(gchar *file, gchar *type);
+static void	 save_drawing(gchar *file, gchar *type);
 
 /* Description of this plugin */
 static BoardPlugin menu_bp =
@@ -267,8 +266,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      img = gcompris_image_to_skin("gcompris-bg.jpg");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
+      img = gc_skin_image_get("gcompris-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
 			      img);
       g_free(img);
 
@@ -276,7 +275,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel=1;
-      gcompris_bar_set(0);
+      gc_bar_set(0);
 
       gcomprisBoard->number_of_sublevel=0;
       gcomprisBoard->sublevel = 0;
@@ -286,7 +285,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       drawing_area_x2 = gcomprisBoard->width  - 15;
       drawing_area_y2 = gcomprisBoard->height - 78;
 
-      gcompris_bar_set(0);
+      gc_bar_set(0);
 
       draw_next_level();
 
@@ -305,7 +304,7 @@ end_board ()
 
   if(gcomprisBoard!=NULL)
     {
-      gcompris_set_cursor(GCOMPRIS_DEFAULT_CURSOR);
+      gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
       pause_board(TRUE);
       draw_destroy_all_items();
       gcomprisBoard->level = 1;       // Restart this game to zero
@@ -328,10 +327,10 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
   switch (keyval)
     {
     case GDK_F1:
-      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
+      gc_selector_file_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
       break;
     case GDK_F2:
-      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
+      gc_selector_file_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
       break;
     case GDK_Shift_L:
     case GDK_Shift_R:
@@ -448,7 +447,7 @@ config ()
 static void draw_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   draw_destroy_all_items();
 
@@ -503,7 +502,7 @@ static void display_color_selector(GnomeCanvasGroup *parent)
   gint c  = 0;
   guint color_pixmap_height = 0;
 
-  pixmap = gcompris_load_pixmap("draw/color-selector.png");
+  pixmap = gc_pixmap_load("draw/color-selector.png");
   if(pixmap)
     {
       x = (drawing_area_x2 - drawing_area_x1
@@ -596,7 +595,7 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
   gint y   = 0;
   guint toolIndex = 0;
 
-  pixmap = gcompris_load_pixmap("draw/tool-selector.png");
+  pixmap = gc_pixmap_load("draw/tool-selector.png");
   if(pixmap)
     {
       x = 3;
@@ -613,7 +612,7 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
   y += 15;
   x  = 10;
   x2 = 55;
-  pixmap = gcompris_load_pixmap(tool_pixmap_name[0 + PIXMAP_ON]);
+  pixmap = gc_pixmap_load(tool_pixmap_name[0 + PIXMAP_ON]);
   if(pixmap)
     {
       item = gnome_canvas_item_new (parent,
@@ -630,7 +629,7 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
 
       gtk_signal_connect(GTK_OBJECT(item), "event",
 			 (GtkSignalFunc) tool_event,
-			 (void *)TOOL_SAVE);
+			 GINT_TO_POINTER(TOOL_SAVE) );
 
     }
   currentTool = TOOL_SAVE;
@@ -639,7 +638,7 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
   for( toolIndex = 1 ; toolIndex < NUMBER_OF_TOOL ; toolIndex++)
     {
       y += (toolIndex%2 == 0 ? SELECTOR_VERTICAL_SPACING : 0);
-      pixmap = gcompris_load_pixmap(tool_pixmap_name[(2*toolIndex) + PIXMAP_OFF]);
+      pixmap = gc_pixmap_load(tool_pixmap_name[(2*toolIndex) + PIXMAP_OFF]);
 
       if(pixmap)
 	{
@@ -669,7 +668,7 @@ static void display_tool_selector(GnomeCanvasGroup *parent)
 
 	  gtk_signal_connect(GTK_OBJECT(item), "event",
 			     (GtkSignalFunc) tool_event,
-			     (void *)toolIndex);
+			     GINT_TO_POINTER(toolIndex));
 	}
     }
 }
@@ -683,7 +682,7 @@ static void display_grid(gboolean status)
   guint x, y;
   GdkPixbuf *pixmap = NULL;
 
-  pixmap = gcompris_load_pixmap(tool_pixmap_name[(TOOL_GRID*2) +
+  pixmap = gc_pixmap_load(tool_pixmap_name[(TOOL_GRID*2) +
 						 (status == TRUE ? PIXMAP_ON : PIXMAP_OFF)]);
   if(pixmap)
     {
@@ -752,36 +751,6 @@ static void display_grid(gboolean status)
     }
 }
 
-/*
- * Given an object, realign it to the grid
- * if the grid is on
- * FIXME: Does not work yet as expected
- */
-static void realign_to_grid(GnomeCanvasItem *item)
-{
-
-  if(grid_step!=0)
-    {
-      double x1, y1, x2, y2;
-      double xsnap1, ysnap1;
-
-      gnome_canvas_item_get_bounds  (item,
-				     &x1,
-				     &y1,
-				     &x2,
-				     &y2);
-
-      xsnap1 = x1;
-      ysnap1 = y1;
-      snap_to_grid(&xsnap1, &ysnap1);
-
-      // Realign our object on the grid
-      gnome_canvas_item_move(item,
-			     x1 - xsnap1,
-			     y1 - ysnap1);
-    }
-}
-
 /*
  * Given a pair (x,y) rewrite them so that (x,y) is on a grid node
  * Do nothing if grid_step is 0
@@ -865,7 +834,7 @@ static void set_current_tool(GnomeCanvasItem *item, gint tool)
 
   if(currentToolItem)
     {
-      pixmap = gcompris_load_pixmap(tool_pixmap_name[(currentTool*2) + PIXMAP_OFF]);
+      pixmap = gc_pixmap_load(tool_pixmap_name[(currentTool*2) + PIXMAP_OFF]);
       if(pixmap)
 	{
 	  gnome_canvas_item_set (currentToolItem,
@@ -878,7 +847,7 @@ static void set_current_tool(GnomeCanvasItem *item, gint tool)
   currentTool = tool;
   currentToolItem = item;
 
-  pixmap = gcompris_load_pixmap(tool_pixmap_name[(currentTool*2) + PIXMAP_ON]);
+  pixmap = gc_pixmap_load(tool_pixmap_name[(currentTool*2) + PIXMAP_ON]);
   if(pixmap)
     {
       gnome_canvas_item_set (item,
@@ -908,18 +877,18 @@ tool_event(GnomeCanvasItem *item, GdkEvent *event, gint tool)
 	  switch(tool)
 	    {
 	    case TOOL_LOAD:
-	      //	      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
+	      //	      gc_selector_file_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
 	      break;
 	    case TOOL_SAVE:
-	      //	      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
+	      //	      gc_selector_file_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
 	      break;
 	    case TOOL_GRID:
 	      display_grid((grid_step==0 ? TRUE : FALSE));
 	      return TRUE;
 	      break;
 	    case TOOL_IMAGE:
-	      gcompris_images_selector_start(gcomprisBoard, IMG_DATA_SET, image_selected);
-	    break;
+	      gc_selector_images_start(gcomprisBoard, "dataset", image_selected);
+	      break;
 	    case TOOL_RAISE:
 	    case TOOL_LOWER:
 	      if(selected_anchors_item)
@@ -1094,7 +1063,6 @@ static void reset_anchors_line(AnchorsItem *anchorsItem)
 {
   GnomeCanvasItem *item;
   double x1, x2, y1, y2;
-  double x, y;
   GnomeCanvasPoints *points;
 
   item = anchorsItem->item;
@@ -1830,7 +1798,7 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
       // This is an image
       x = (drawing_area_x2-drawing_area_x1)/2;
       y = (drawing_area_y2-drawing_area_y1)/2;
-      pixmap = gcompris_load_pixmap(imagename);
+      pixmap = gc_pixmap_load(imagename);
       item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
 				    gnome_canvas_pixbuf_get_type (),
 				    "pixbuf", pixmap,
@@ -1922,7 +1890,7 @@ static GnomeCanvasItem *create_item(double x, double y, gchar *imagename)
 	item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(item_root_item),
 				      gnome_canvas_text_get_type (),
 				      "text", "?",
-				      "font", gcompris_skin_font_board_big_bold,
+				      "font", gc_skin_font_board_big_bold,
 				      "x", (double) x,
 				      "y", (double) y,
 				      "anchor", GTK_ANCHOR_CENTER,
@@ -2008,7 +1976,7 @@ item_event_resize(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsIt
 	case 1:
 	  fleur = gdk_cursor_new(get_resize_cursor(anchor));
 	  
-	  gnome_canvas_item_grab(item,
+	  gc_canvas_item_grab(item,
 				 GDK_POINTER_MOTION_MASK |
 				 GDK_BUTTON_RELEASE_MASK,
 				 fleur,
@@ -2031,17 +1999,17 @@ item_event_resize(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsIt
     case GDK_BUTTON_RELEASE:
       if(dragging)
 	{
-	  gnome_canvas_item_ungrab(item, event->button.time);
+	  gc_canvas_item_ungrab(item, event->button.time);
 	  dragging = FALSE;
 	  draggingItem = NULL;
 	}
       break;
     case GDK_ENTER_NOTIFY:
-      gcompris_set_cursor(get_resize_cursor(anchor));
+      gc_cursor_set(get_resize_cursor(anchor));
       break;
 
     case GDK_LEAVE_NOTIFY:
-      gcompris_set_cursor(get_tool_cursor(currentTool));
+      gc_cursor_set(get_tool_cursor(currentTool));
       break;
 
     case GDK_MOTION_NOTIFY:
@@ -2126,7 +2094,7 @@ static void recreate_item(GnomeCanvasItem *item)
 /**
  * Callback for the drawing load
  */
-static void load_drawing(gchar *file)
+static void load_drawing(gchar *file, gchar *type)
 {
 
 }
@@ -2134,7 +2102,7 @@ static void load_drawing(gchar *file)
 /**
  * Callback for the drawing save
  */
-static void save_drawing(gchar *file)
+static void save_drawing(gchar *file, gchar *type)
 {
 
 }
@@ -2179,7 +2147,7 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
 
 	    fleur = gdk_cursor_new(GDK_FLEUR);
 
-	    gnome_canvas_item_grab(item,
+	    gc_canvas_item_grab(item,
 				   GDK_POINTER_MOTION_MASK |
 				   GDK_BUTTON_RELEASE_MASK,
 				   fleur,
@@ -2223,12 +2191,12 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
 	    break;
 
 	  case TOOL_ROTATE_CW:
-	    item_rotate_relative(anchorsItem->rootitem, 10);
+	    gc_item_rotate_relative(anchorsItem->rootitem, 10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 
 	  case TOOL_ROTATE_CCW:
-	    item_rotate_relative(anchorsItem->rootitem, -10);
+	    gc_item_rotate_relative(anchorsItem->rootitem, -10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 
@@ -2268,11 +2236,11 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
 	  switch(currentTool) {
 	    /* Perform the reverse operation when it makes sense */
 	  case TOOL_ROTATE_CW:
-	    item_rotate_relative(anchorsItem->rootitem, -10);
+	    gc_item_rotate_relative(anchorsItem->rootitem, -10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 	  case TOOL_ROTATE_CCW:
-	    item_rotate_relative(anchorsItem->rootitem, 10);
+	    gc_item_rotate_relative(anchorsItem->rootitem, 10);
 	    reset_anchors_bounded(anchorsItem);
 	    break;
 	  case TOOL_RAISE:
@@ -2296,7 +2264,7 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
     case GDK_BUTTON_RELEASE:
       if(dragging)
 	{
-	  gnome_canvas_item_ungrab(item, event->button.time);
+	  gc_canvas_item_ungrab(item, event->button.time);
 	  dragging = FALSE;
 	  draggingItem = NULL;
 
@@ -2316,17 +2284,17 @@ item_event_move(GnomeCanvasItem *item, GdkEvent *event, AnchorsItem *anchorsItem
       case TOOL_DELETE:
       case TOOL_FILL:
       case TOOL_TEXT:
-	gcompris_set_cursor(get_tool_cursor(currentTool));
+	gc_cursor_set(get_tool_cursor(currentTool));
 	break;
       case TOOL_SELECT:
-	gcompris_set_cursor(GDK_FLEUR);
+	gc_cursor_set(GDK_FLEUR);
 	break;
       default:
 	break;
       }
       break;
     case GDK_LEAVE_NOTIFY:
-      gcompris_set_cursor(get_tool_cursor(currentTool));
+      gc_cursor_set(get_tool_cursor(currentTool));
       break;
 
     case GDK_MOTION_NOTIFY:
@@ -2432,11 +2400,11 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, void *shape)
       break;
 
     case GDK_ENTER_NOTIFY:
-      gcompris_set_cursor(get_tool_cursor(currentTool));
+      gc_cursor_set(get_tool_cursor(currentTool));
       break;
 
     case GDK_LEAVE_NOTIFY:
-      gcompris_set_cursor(GCOMPRIS_DEFAULT_CURSOR);
+      gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
       break;
 
     case GDK_MOTION_NOTIFY:
