@@ -17,9 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
 #include <string.h>
 
 #include "gcompris/gcompris.h"
@@ -147,12 +144,12 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->disable_im_context = TRUE;
 
       gcomprisBoard->level=1;
-      gcomprisBoard->maxlevel=5;
+      gcomprisBoard->maxlevel=9;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      "images/enumerate_background.png");
 
       enumerate_next_level();
@@ -201,7 +198,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     case GDK_Mode_switch:
     case GDK_dead_circumflex:
     case GDK_Num_Lock:
-      return FALSE; 
+      return FALSE;
     case GDK_KP_Enter:
     case GDK_Return:
       process_ok();
@@ -211,7 +208,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
   sprintf(str, "%c", keyval);
 
   item = answer_item[current_focus];
-      
+
   if(GNOME_IS_CANVAS_TEXT(item))
     {
       gchar *oldtext;
@@ -256,7 +253,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
       gnome_canvas_item_set (item,
 			     "text", newtext,
 			     NULL);
-	      
+
       g_free(oldtext);
     }
 
@@ -296,7 +293,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void enumerate_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   enumerate_destroy_all_items();
   gamewon = FALSE;
@@ -305,30 +302,42 @@ static void enumerate_next_level()
   switch(gcomprisBoard->level)
     {
     case 1:
-      number_of_item_type = 2;
+      number_of_item_type = 1;
       number_of_item_max  = 5;
       break;
     case 2:
+      number_of_item_type = 2;
+      number_of_item_max  = 5;
+      break;
+    case 3:
       number_of_item_type = 3;
+      number_of_item_max  = 5;
+      break;
+    case 4:
+      number_of_item_type = 3;
+      number_of_item_max  = 5;
+      break;
+    case 5:
+      number_of_item_type = 4;
+      number_of_item_max  = 5;
+      break;
+    case 6:
+      number_of_item_type = 4;
       number_of_item_max  = 6;
       break;
-    case 3: 
+    case 7:
       number_of_item_type = 4;
       number_of_item_max  = 7;
       break;
-    case 4:
-      number_of_item_type = 5;
-      number_of_item_max  = 8;
-      break;
-    case 5:
-      number_of_item_type = 6;
+    case 8:
+      number_of_item_type = 4;
       number_of_item_max  = 10;
       break;
     default:
-      number_of_item_type = 6;
+      number_of_item_type = 5;
       number_of_item_max = 10;
     }
-      
+
   current_focus = 0;
 
   /* Try the next level */
@@ -366,7 +375,7 @@ static GnomeCanvasItem *enumerate_create_item(GnomeCanvasGroup *parent)
   for(i=0; i<number_of_item_type; i++)
     {
 
-      pixmap = gcompris_load_pixmap(imageList[i]);
+      pixmap = gc_pixmap_load(imageList[i]);
 
       answer_to_find[i] = RAND(1, number_of_item_max);
       answer[i] = 0;
@@ -380,11 +389,11 @@ static GnomeCanvasItem *enumerate_create_item(GnomeCanvasGroup *parent)
 
 	  item = gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_pixbuf_get_type (),
-					"pixbuf", pixmap, 
+					"pixbuf", pixmap,
 					"x", (double) x,
 					"y", (double) y,
 					NULL);
-      
+
 	  gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
 	}
 
@@ -393,26 +402,26 @@ static GnomeCanvasItem *enumerate_create_item(GnomeCanvasGroup *parent)
       /* Display the answer area */
       current_y -= ANSWER_HEIGHT*2;
 
-      pixmap_answer = gcompris_load_pixmap("images/enumerate_answer.png");
+      pixmap_answer = gc_pixmap_load("images/enumerate_answer.png");
 
       item = \
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_pixbuf_get_type (),
-			       "pixbuf", pixmap_answer, 
+			       "pixbuf", pixmap_answer,
 			       "x", (double) ANSWER_X - ANSWER_WIDTH/2,
 			       "y", (double) current_y - ANSWER_HEIGHT/2,
 			       NULL);
 
-      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event_focus, (void *)i);
+      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event_focus, GINT_TO_POINTER(i));
 
       gdk_pixbuf_unref(pixmap_answer);
 
-      pixmap_answer = gcompris_load_pixmap("images/enumerate_answer_focus.png");
+      pixmap_answer = gc_pixmap_load("images/enumerate_answer_focus.png");
 
       answer_item_focus[i] = \
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_pixbuf_get_type (),
-			       "pixbuf", pixmap_answer, 
+			       "pixbuf", pixmap_answer,
 			       "x", (double) ANSWER_X - ANSWER_WIDTH/2,
 			       "y", (double) current_y - ANSWER_HEIGHT/2,
 			       NULL);
@@ -422,33 +431,34 @@ static GnomeCanvasItem *enumerate_create_item(GnomeCanvasGroup *parent)
 
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) ANSWER_X,
 				    "y", (double) current_y,
-				    "width", (double) ANSWER_WIDTH,
+				    "width", (double) gdk_pixbuf_get_width(pixmap)*ANSWER_HEIGHT/gdk_pixbuf_get_height(pixmap),
 				    "height", (double) ANSWER_HEIGHT,
-				    "width_set", TRUE, 
+				    "width_set", TRUE,
 				    "height_set", TRUE,
 				    NULL);
 
 
-      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event_focus, (void *)i);
+      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event_focus,  GINT_TO_POINTER(i));
 
       gtk_signal_connect(GTK_OBJECT(item), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
-      
+
       answer_item[i] = \
 	gnome_canvas_item_new (boardRootItem,
 			       gnome_canvas_text_get_type (),
 			       "text", "?",
-			       "font", gcompris_skin_font_board_big,
-			       "x", (double) ANSWER_X + 2*ANSWER_WIDTH,
+			       "font", gc_skin_font_board_big,
+			       "x", (double) ANSWER_X + 2.5*ANSWER_WIDTH,
 			       "y", (double) current_y + ANSWER_HEIGHT/2,
 			       "anchor", GTK_ANCHOR_EAST,
 			       "fill_color", "blue",
 			       NULL);
-      gtk_signal_connect(GTK_OBJECT(answer_item[i]), "event", (GtkSignalFunc) item_event_focus, (void *)i);
+      gtk_signal_connect(GTK_OBJECT(answer_item[i]), "event", (GtkSignalFunc) item_event_focus,
+			 GINT_TO_POINTER(i));
 
     }
 
@@ -466,10 +476,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   enumerate_next_level();
 }
@@ -479,17 +489,19 @@ static gint
 item_event_focus(GnomeCanvasItem *item, GdkEvent *event, guint index)
 {
 
-   switch (event->type) 
+   switch (event->type)
      {
      case GDK_BUTTON_PRESS:
        gnome_canvas_item_hide(answer_item_focus[current_focus]);
        current_focus = index;
        gnome_canvas_item_show(answer_item_focus[current_focus]);
+       return TRUE;
        break;
      default:
        break;
      }
 
+   return FALSE;
 }
 
 /* ==================================== */
@@ -510,20 +522,20 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     return FALSE;
 
 
-   switch (event->type) 
+   switch (event->type)
      {
      case GDK_BUTTON_PRESS:
-       switch(event->button.button) 
+       switch(event->button.button)
          {
          case 1:
 	   x = item_x;
 	   y = item_y;
-	   
+
 	   gnome_canvas_item_raise_to_top(item);
 
 	   fleur = gdk_cursor_new(GDK_FLEUR);
-	   gnome_canvas_item_grab(item,
-				  GDK_POINTER_MOTION_MASK | 
+	   gc_canvas_item_grab(item,
+				  GDK_POINTER_MOTION_MASK |
 				  GDK_BUTTON_RELEASE_MASK,
 				  fleur,
 				  event->button.time);
@@ -549,11 +561,11 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
        break;
 
      case GDK_MOTION_NOTIFY:
-       if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
+       if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
          {
 	   double x1, x2, y1, y2;
 
-	   gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2); 
+	   gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2);
 
            new_x = item_x;
            new_y = item_y;
@@ -573,11 +585,11 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	   y = new_y;
          }
        break;
-           
+
      case GDK_BUTTON_RELEASE:
-       if(dragging) 
+       if(dragging)
 	 {
-	   gnome_canvas_item_ungrab(item, event->button.time);
+	   gc_canvas_item_ungrab(item, event->button.time);
 	   dragging = FALSE;
 	 }
        break;
@@ -585,7 +597,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
      default:
        break;
      }
-  
+
   return FALSE;
 }
 
@@ -603,10 +615,10 @@ static void process_ok()
 
   if(win) {
     gamewon = TRUE;
-    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, BONUS_SMILEY);
   } else {
     gamewon = FALSE;
-    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, BONUS_SMILEY);
   }
 }
 
