@@ -47,8 +47,6 @@ static gint		 piece_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data
 static void		 scramble (GnomeCanvasItem **board, guint number_of_scrambles);
 static char		*get_piece_color (int piece);
 
-static int number_of_scrambles = 0;
-
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
@@ -111,7 +109,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
       fifteen_next_level();
 
@@ -164,12 +162,12 @@ static void fifteen_next_level()
 {
   gchar *img;
 
-  img = gcompris_image_to_skin("gcompris-bg.jpg");
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+  img = gc_skin_image_get("gcompris-bg.jpg");
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  img);
   g_free(img);
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   fifteen_destroy_all_items();
   gamewon = FALSE;
@@ -206,7 +204,7 @@ static GnomeCanvasItem *fifteen_create_item(GnomeCanvasGroup *parent)
 							    NULL));
 
   /* Load the cute frame */
-  pixmap = gcompris_load_pixmap("images/fifteen_frame.png");
+  pixmap = gc_pixmap_load("images/fifteen_frame.png");
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_pixbuf_get_type (),
@@ -251,7 +249,7 @@ static GnomeCanvasItem *fifteen_create_item(GnomeCanvasGroup *parent)
 				  "text", buf,
 				  "x", (double) PIECE_SIZE / 2.0,
 				  "y", (double) PIECE_SIZE / 2.0,
-				  "font", gcompris_skin_font_board_medium,
+				  "font", gc_skin_font_board_medium,
 				  "anchor", GTK_ANCHOR_CENTER,
 				  "fill_color", "black",
 				  NULL);
@@ -275,7 +273,7 @@ static GnomeCanvasItem *fifteen_create_item(GnomeCanvasGroup *parent)
     case 2:
       scramble(board, 50);
       break;
-    case 3: 
+    case 3:
     case 4:
       scramble(board, 100);
       break;
@@ -285,7 +283,7 @@ static GnomeCanvasItem *fifteen_create_item(GnomeCanvasGroup *parent)
     default:
       scramble(board, 256);
     }
-      
+
   return NULL;
 }
 /* ==================================== */
@@ -298,10 +296,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   fifteen_next_level();
 }
@@ -328,7 +326,7 @@ test_win (GnomeCanvasItem **board)
 
   gamewon = TRUE;
   fifteen_destroy_all_items();
-  gcompris_display_bonus(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, BONUS_SMILEY);
 
 }
 
@@ -354,7 +352,6 @@ get_piece_color (int piece)
 static gint
 piece_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
-  GnomeCanvas *canvas;
   GnomeCanvasItem **board;
   GnomeCanvasItem *text;
   int num, pos, newpos;
@@ -362,8 +359,7 @@ piece_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   double dx = 0.0, dy = 0.0;
   int move;
 
-  canvas = GNOME_CANVAS_GROUP(item->parent);
-  board = g_object_get_data (G_OBJECT (canvas), "board");
+  board = g_object_get_data (G_OBJECT (item->parent), "board");
   num = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "piece_num"));
   pos = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "piece_pos"));
   text = g_object_get_data (G_OBJECT (item), "text");
