@@ -1,9 +1,9 @@
 /* gcompris - gletters.c
  *
- * Time-stamp: <2006/03/19 23:15:02 yves>
+ * Time-stamp: <2006/08/21 23:33:17 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
- * 
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -19,7 +19,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -36,7 +36,7 @@ static gint drop_items_id = 0;
 
 /* Sublevels are now allocated dynamically
  * based on the number of chars at that level
- * Set DEFAULT_SUBLEVEL to the minimum 
+ * Set DEFAULT_SUBLEVEL to the minimum
  * number of sublevels you want
  */
 
@@ -64,14 +64,14 @@ static float dropRateBase = DROP_RATE_BASE;
 static float dropRateMult = DROP_RATE_MULT;
 
 /* both letters_array and keymap are read in
- * dynamically at run-time from files based on 
+ * dynamically at run-time from files based on
  * user locale
  */
 
 /* letters_array contains letters you want shown
  * on each play level
  * there can be an arbitrary number of levels,
- * but there are only graphics to level 9 
+ * but there are only graphics to level 9
  * so that's where we stop
  */
 
@@ -79,8 +79,8 @@ static float dropRateMult = DROP_RATE_MULT;
 static int maxLevel;
 static char *letters_array[MAXLEVEL];
 
-/* keymap contains pairs of chars. The first char is 
- * on the keyboard map, the second is the unichar that 
+/* keymap contains pairs of chars. The first char is
+ * on the keyboard map, the second is the unichar that
  * is also represented by that key.  That way, if there is more
  * than one character represented by a key, the user doesn't
  * have to use alternate input methods.
@@ -167,16 +167,17 @@ GET_BPLUGIN_INFO(gletters)
 static void level_set_score() {
   int l;
 
-  g_message("letters_array length for level %d is %d\n",gcomprisBoard->level,
+  g_message("letters_array length for level %d is %ld\n",
+	    gcomprisBoard->level,
 	    g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1));
   l = g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1)/3;
-  gcomprisBoard->number_of_sublevel=(DEFAULT_SUBLEVEL>l?DEFAULT_SUBLEVEL:l);
+  gcomprisBoard->number_of_sublevel = (DEFAULT_SUBLEVEL>l?DEFAULT_SUBLEVEL:l);
 
-  gcompris_score_start(SCORESTYLE_NOTE, 
-		       gcomprisBoard->width - 220, 
-		       gcomprisBoard->height - 50, 
+  gc_score_start(SCORESTYLE_NOTE,
+		       gcomprisBoard->width - 220,
+		       gcomprisBoard->height - 50,
 		       gcomprisBoard->number_of_sublevel);
-  gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
+  gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
 }
 
 static void pause_board (gboolean pause)
@@ -224,17 +225,17 @@ int load_default_charset() {
 
   /* TRANSLATORS: Put here the numbers in your language */
   numbers=_("0123456789");
-  assert(g_utf8_validate(numbers,-1,NULL)); // require by all utf8-functions
-  
+  g_assert(g_utf8_validate(numbers,-1,NULL)); // require by all utf8-functions
+
   /* TRANSLATORS: Put here the alphabet lowercase in your language */
   alphabet_lowercase=_("abcdefghijklmnopqrstuvwxyz");
-  assert(g_utf8_validate(alphabet_lowercase,-1,NULL)); // require by all utf8-functions
-  
+  g_assert(g_utf8_validate(alphabet_lowercase,-1,NULL)); // require by all utf8-functions
+
   g_warning("Using lowercase %s", alphabet_lowercase);
-  
+
   /* TRANSLATORS: Put here the alphabet uppercase in your language */
   alphabet_uppercase=_("ABCDEFGHIJKLMNOPQRSTUVWXYZ");
-  assert(g_utf8_validate(alphabet_uppercase,-1,NULL)); // require by all utf8-functions
+  g_assert(g_utf8_validate(alphabet_uppercase,-1,NULL)); // require by all utf8-functions
   g_warning("Using uppercase %s", alphabet_uppercase);
 
   letters_array[0] = g_strdup(alphabet_uppercase);
@@ -242,7 +243,7 @@ int load_default_charset() {
 				     alphabet_uppercase,
 				     numbers);
   if (!uppercase_only){
-  letters_array[2] = g_strdup(alphabet_lowercase); 
+  letters_array[2] = g_strdup(alphabet_lowercase);
   letters_array[3] = g_strdup_printf("%s%s",
 				     alphabet_lowercase,
 				     numbers);
@@ -250,12 +251,12 @@ int load_default_charset() {
 				     alphabet_lowercase,
 				     alphabet_uppercase);
   letters_array[5] = g_strdup_printf("%s%s%s",
-				     alphabet_lowercase, 
+				     alphabet_lowercase,
 				     alphabet_uppercase,
 				     numbers);
   } else{
     g_warning("Uppercase only is set");
-      letters_array[2] = g_strdup(alphabet_uppercase); 
+      letters_array[2] = g_strdup(alphabet_uppercase);
     letters_array[3] = g_strdup_printf("%s%s",
 				       alphabet_uppercase,
 				       numbers);
@@ -266,7 +267,7 @@ int load_default_charset() {
 				       alphabet_uppercase,
 				       numbers);
   }
-    
+
 
   keyMapSize = 0;
   maxLevel = 6;
@@ -288,9 +289,9 @@ int whitespace(char *buffer) {
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
 
-  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
 
@@ -312,7 +313,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
       load_default_charset();
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
       gcomprisBoard->maxlevel=maxLevel;
       gcomprisBoard->level = 1;
       level_set_score();
@@ -331,19 +332,19 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       gletters_destroy_all_items();
       g_message("freeing memory");
-      for (i = 0; i < maxLevel; i++) 
+      for (i = 0; i < maxLevel; i++)
 	g_free(letters_array[i]);
 
-      for (i = 0; i < keyMapSize; i++) 
+      for (i = 0; i < keyMapSize; i++)
 	g_free(keyMap[i]);
 
       g_free(keyMap);
     }
 
-  gcompris_reset_locale();
+  gc_locale_reset();
 
   gcomprisBoard = NULL;
 }
@@ -366,21 +367,24 @@ static void add_char(char *key, char *value, char *char_list)
   strcat(char_list, key);
 }
 
-gboolean *unichar_comp (gpointer key,
+gboolean unichar_comp(gpointer key,
 		      gpointer value,
 		      gpointer user_data)
 {
   gunichar *target = (gunichar *) user_data;
   if (*((gunichar *)key) == *target)
     return TRUE;
-  return FALSE;    
+
+  return FALSE;
 }
 
-gint is_falling_letter(gunichar  unichar) {
+gint is_falling_letter(gunichar  unichar)
+{
   GnomeCanvasItem *item;
-  if (item = g_hash_table_find         (letters_table,
-				       unichar_comp,
-				       &unichar))
+
+  if ((item = g_hash_table_find(letters_table,
+			       unichar_comp,
+				&unichar)))
     {
       player_win(item);
       return TRUE;
@@ -414,7 +418,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str) {
   for (i=0; i < length_passed; i++){
     c = g_utf8_get_char (string_passed);
     if (is_falling_letter(c)){
-      gcompris_im_reset();
+      gc_im_reset();
       return TRUE;
     }
 
@@ -426,15 +430,15 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str) {
       level_uppercase = 3;
 
     /* for 2 (or all) first level don't care abour uppercase/lowercase */
-    if ((gcomprisBoard->level < level_uppercase) && 
+    if ((gcomprisBoard->level < level_uppercase) &&
 	(is_falling_letter(g_unichar_toupper(c)))){
-      gcompris_im_reset();
+      gc_im_reset();
       return TRUE;
     }
 
     string_passed = g_utf8_next_char (string_passed);
   }
-  
+
   list_of_letters[0] = '\0';
 
   /* We have to loop to concat the letters */
@@ -444,7 +448,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str) {
 
   /* Log what happened, what was expected, what we got */
 
-  gcompris_log_set_comment(gcomprisBoard, list_of_letters, str);
+  gc_log_set_comment(gcomprisBoard, list_of_letters, str);
   g_free(str);
 
   return TRUE;
@@ -473,11 +477,11 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 /*-------------------------------------------------------------------------------*/
 
 /* set initial values for the next level */
-static void gletters_next_level() 
+static void gletters_next_level()
 {
 
   gamewon = FALSE;
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   gletters_destroy_all_items();
 
@@ -486,7 +490,7 @@ static void gletters_next_level()
   fallSpeed=dropRateBase+(dropRateMult/gcomprisBoard->level);
 
   gcomprisBoard->sublevel=1;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 }
 
 
@@ -501,7 +505,7 @@ static void gletters_move_item(GnomeCanvasItem *item)
 				   &y1,
 				   &x2,
 				   &y2);
-  
+
   if(y1>gcomprisBoard->height) {
     item2del_list = g_list_append (item2del_list, item);
     player_loose();
@@ -519,7 +523,7 @@ static void gletters_destroy_item(GnomeCanvasItem *item)
   item2del_list = g_list_remove (item2del_list, item);
 
   /* Remove old letter; this destroy the canvas item  */
-  g_warning("destroying %c", key);
+  g_warning("destroying %d", *key);
   g_hash_table_remove (letters_table, key);
 
 }
@@ -529,7 +533,7 @@ static void gletters_destroy_items()
 {
   GnomeCanvasItem *item;
 
-  while(g_list_length(item2del_list)>0) 
+  while(g_list_length(item2del_list)>0)
     {
       item = g_list_nth_data(item2del_list, 0);
       gletters_destroy_item(item);
@@ -542,7 +546,7 @@ static void gletters_destroy_all_items()
   GnomeCanvasItem *item;
 
   if(item_list)
-    while(g_list_length(item_list)>0) 
+    while(g_list_length(item_list)>0)
       {
 	item = g_list_nth_data(item_list, 0);
 	gletters_destroy_item(item);
@@ -566,14 +570,14 @@ static gint gletters_move_items (GtkWidget *widget, gpointer data)
   /* Destroy items that falls out of the canvas */
   gletters_destroy_items();
 
-  dummy_id = gtk_timeout_add (speed, 
+  dummy_id = gtk_timeout_add (speed,
 			      (GtkFunction) gletters_move_items, NULL);
 
   return(FALSE);
 }
 
 
-GDestroyNotify destroy_canvas_item(gpointer item)
+void destroy_canvas_item(gpointer item)
 {
   //g_free(g_object_get_data (G_OBJECT(item),"unichar_key"));
   //g_free(g_object_get_data (G_OBJECT(item),"utf8_key"));
@@ -583,7 +587,6 @@ GDestroyNotify destroy_canvas_item(gpointer item)
 static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 {
   GnomeCanvasItem *item;
-  gchar *str2 = NULL;
   gint i,j,k;
   guint x;
   gunichar *lettersItem;
@@ -591,46 +594,55 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 
   if (!letters_table)
     {
-      letters_table= g_hash_table_new_full (g_int_hash, g_int_equal, g_free, destroy_canvas_item);
+      letters_table = g_hash_table_new_full (g_int_hash, g_int_equal, g_free, destroy_canvas_item);
     }
 
   /* Beware, since we put the letters in a hash table, we do not allow the same
-     letter to be displayed two times 
-  */
+   * letter to be displayed two times
+   */
 
   g_warning("dump: %d, %s\n",gcomprisBoard->level,letters_array[gcomprisBoard->level-1]);
 
-  k=g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1);
+  k = g_utf8_strlen(letters_array[gcomprisBoard->level-1],-1);
 
   lettersItem = g_new(gunichar,1);
   gint attempt=0;
-  do {
+  do
+    {
+      attempt++;
+      str_p = letters_array[gcomprisBoard->level-1];
+      i = (int)((float)k*rand()/(RAND_MAX+1.0));
 
-    attempt++;
-    str_p=letters_array[gcomprisBoard->level-1];
-    i=(int)((float)k*rand()/(RAND_MAX+1.0));
+      for(j = 0; j < i; j++)
+	{
+	  str_p=g_utf8_next_char(str_p);
+	}
 
-    for( j = 0; j < i; j++) {
-      str_p=g_utf8_next_char(str_p);
+      *lettersItem = g_utf8_get_char (str_p);
+
+    } while((attempt<MAX_RAND_ATTEMPTS) && (item_find_by_title(lettersItem)!=NULL));
+
+  if (item_find_by_title(lettersItem)!=NULL)
+    {
+      g_free(lettersItem);
+      return NULL;
     }
 
-    *lettersItem = g_utf8_get_char (str_p);
-
-  } while((attempt<MAX_RAND_ATTEMPTS) && (item_find_by_title(lettersItem)!=NULL));
-
-  if (item_find_by_title(lettersItem)!=NULL)  {g_free(lettersItem); return NULL;}
   letter = g_new0(gchar, 6);
   g_unichar_to_utf8 ( *lettersItem, letter);
 
-  gchar *letter_unichar_name= gcompris_alphabet_sound(letter);
-  str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg",letter_unichar_name);
-
   if (with_sound)
-    gcompris_play_ogg(str2, NULL);
+    {
+      gchar *str2 = NULL;
+      gchar *letter_unichar_name = gc_sound_alphabet(letter);
 
-  g_free(letter_unichar_name);
-  g_free(str2);
+      str2 = g_strdup_printf("sounds/$LOCALE/alphabet/%s", letter_unichar_name);
 
+      gc_sound_play_ogg(str2, NULL);
+
+      g_free(letter_unichar_name);
+      g_free(str2);
+    }
 
   item =					\
     gnome_canvas_item_new (parent,
@@ -643,7 +655,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(item),
 			 gnome_canvas_text_get_type (),
 			 "text", letter,
-			 "font", gcompris_skin_font_board_huge_bold,
+			 "font", gc_skin_font_board_huge_bold,
 			 "x", (double) x,
 			 "y", (double) -20,
 			 "anchor", GTK_ANCHOR_CENTER,
@@ -653,7 +665,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(item),
 			 gnome_canvas_text_get_type (),
 			 "text", letter,
-			 "font", gcompris_skin_font_board_huge_bold,
+			 "font", gc_skin_font_board_huge_bold,
 			 "x", (double) x,
 			 "y", (double) -22,
 			 "anchor", GTK_ANCHOR_CENTER,
@@ -668,12 +680,14 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
   /* Add letter to hash table of all falling letters. */
   g_hash_table_insert (letters_table, lettersItem, item);
 
+  g_free(letter);
+
   g_warning("done\n");
 
   return (item);
 }
 
-static void gletters_add_new_item() 
+static void gletters_add_new_item()
 {
   gletters_create_item(gnome_canvas_root(gcomprisBoard->canvas));
 }
@@ -696,7 +710,7 @@ static void player_win(GnomeCanvasItem *item)
   g_message("in player_win\n");
 
   gletters_destroy_item(item);
-  gcompris_play_ogg ("gobble", NULL);
+  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 
   gcomprisBoard->sublevel++;
 
@@ -705,18 +719,18 @@ static void player_win(GnomeCanvasItem *item)
       /* Try the next level */
       gcomprisBoard->level++;
       if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-        gcompris_score_end();
-	board_finished(BOARD_FINISHED_RANDOM);
+        gc_score_end();
+	gc_bonus_end_display(BOARD_FINISHED_RANDOM);
 	return;
       }
 
       gamewon = TRUE;
       gletters_destroy_all_items();
-      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, BONUS_SMILEY);
     }
   else
     {
-      gcompris_score_set(gcomprisBoard->sublevel);
+      gc_score_set(gcomprisBoard->sublevel);
 
       /* Drop a new item now to speed up the game */
       if(g_list_length(item_list)==0)
@@ -739,7 +753,7 @@ static void player_loose()
 {
   g_warning("entering player_loose\n");
 
-  gcompris_play_ogg ("crash", NULL);
+  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
   g_warning("leaving player_loose\n");
 }
 
@@ -754,7 +768,7 @@ item_find_by_title (const gunichar *title)
 {
   if (!letters_table)
     return NULL;
-  
+
   return g_hash_table_lookup (letters_table, title);
 }
 
@@ -771,67 +785,69 @@ item_find_by_title (const gunichar *title)
 static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
-static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+static void save_table (gpointer key,
+			gpointer value,
+			gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+/* a GcomprisConfCallback
+ */
+static void conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
     return;
   }
-    
-  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
-  
+
+  g_hash_table_foreach(table, save_table, NULL);
+
   if (gcomprisBoard){
-    gcompris_reset_locale();
+    gc_locale_reset();
 
     GHashTable *config;
 
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
-    
-    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
-    
+
+    gc_locale_set(g_hash_table_lookup( config, "locale"));
+
     gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
-    
+
     if (up_init_str && (strcmp(up_init_str, "True")==0))
       uppercase_only = TRUE;
     else
       uppercase_only = FALSE;
 
     gchar *control_sound = g_hash_table_lookup( config, "with_sound");
-    
+
     if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
       with_sound = TRUE;
     else
       with_sound = FALSE;
-    
+
     if (profile_conf)
       g_hash_table_destroy(config);
 
-    load_default_charset();    
-    
+    load_default_charset();
+
     level_set_score();
     gletters_next_level();
-    
+
     pause_board(FALSE);
-    
+
   }
 
   board_conf = NULL;
   profile_conf = NULL;
- 
+
 }
 
 static void
@@ -845,20 +861,20 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
 
   if (gcomprisBoard)
     pause_board(TRUE);
-  
+
   label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
 			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
+  gc_board_config_window_display(label, (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *locale = g_hash_table_lookup( config, "locale");
-  
-  gcompris_combo_locales( locale);
+
+  gc_board_config_combo_locales( locale);
 
   gboolean up_init = FALSE;
 
@@ -867,40 +883,29 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
   if (up_init_str && (strcmp(up_init_str, "True")==0))
     up_init = TRUE;
 
-  gcompris_separator();
+  gc_board_conf_separator();
 
   gchar *control_sound = g_hash_table_lookup( config, "with_sound");
   if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
     with_sound = TRUE;
   else
     with_sound = FALSE;
-  
-  GtkCheckButton  *sound_control = gcompris_boolean_box("Enable sounds", "with_sound", with_sound);
- 
-  gcompris_separator();
 
-  gcompris_boolean_box(_("Uppercase only text"),
+  gc_board_config_boolean_box("Enable sounds", "with_sound", with_sound);
+
+  gc_board_conf_separator();
+
+  gc_board_config_boolean_box(_("Uppercase only text"),
 		       "uppercase_only",
 		       up_init);
-  
+
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 gletter_config_stop()
 {
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
