@@ -40,26 +40,6 @@
 
 void taninitstart(void);
 
-/********************************/
-/* int main (int argc, char *argv[]) */
-/* { */
-/*    textdomain ("gtans"); */
-
-/*   gtk_set_locale (); */
-/*   gtk_init (&argc, &argv); */
-
-/*   /\* */
-/*     add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps"); */
-/*     add_pixmap_directory (PACKAGE_SOURCE_DIR "/pixmaps"); */
-/*   *\/ */
-
-/*   taninitstart(); */
-
-/*   gtk_main (); */
-/*   return 0; */
-/* } */
-
-
 /* GCompris */
 
 static void start_board (GcomprisBoard *agcomprisBoard);
@@ -113,9 +93,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 1;
-      gcompris_bar_set(0);
+      gc_bar_set(0);
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/gtans_bg.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/gtans_bg.png");
 
       selectedgrande = FALSE;
       taninitstart();
@@ -269,7 +249,6 @@ static gboolean dumtabpxpixmode[3],*tabpxpixmode=dumtabpxpixmode-PXSTART; /* mod
 static gboolean tabcolalloc[GCNBR];   /* couleur allouee ? */
 static gchar *userconf=NULL;          /* nom complet du fichier de config local */
 static gchar *usergtdir=NULL;         /* nom du home directory local */
-static guint provmsg=0;              /* nr. du dernier msg. provisoire */
 static tanflfig flfigpetite;
 static tanfpnt fpntspetite[FLPNTMAX];
 
@@ -1291,7 +1270,7 @@ void tansetdefconfig (void){
   colortab[GCPETITEHLP].blue = (colortab[GCPETITEFG].blue+colortab[GCPETITEBG].blue)/2;
   
   /* Gcompris */
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
   gchar *deffigfile = g_strconcat(properties->package_data_dir,"/gtans/figures/default.figures", NULL); 
 
   tanallocname(&figfilename, deffigfile);
@@ -1849,7 +1828,7 @@ void taninitstart(void){
   int i;
   char* accurstr;
 
-  usergtdir = gcompris_get_current_board_dirname();
+  usergtdir = gc_prop_current_board_dirname_get();
 
   for (i = PXSTART; i<PXNBR+PXSTART; i++){
     tabpxnam[i] = NULL;
