@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -71,7 +67,7 @@ static int number_of_item_y = 0;
 static int item_width;
 static int item_height;
 
-static guint colorlist [] = 
+static guint colorlist [] =
   {
     0x00FFFFFF,
     0xA00000FF,
@@ -146,6 +142,7 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
+    gchar *img;
 
   if(agcomprisBoard!=NULL)
     {
@@ -154,11 +151,11 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
-
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      gcompris_image_to_skin("gcompris-bg.jpg"));
+      gc_bar_set(GC_BAR_LEVEL);
 
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			      img = gc_skin_image_get("gcompris-bg.jpg"));
+      g_free(img);
       hanoi_next_level();
 
       gamewon = FALSE;
@@ -209,7 +206,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void hanoi_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   hanoi_destroy_all_items();
   gamewon = FALSE;
@@ -225,7 +222,7 @@ static void hanoi_next_level()
       number_of_item_x = 4;
       number_of_item_y = 5;
       break;
-    case 3: 
+    case 3:
       number_of_item_x = 5;
       number_of_item_y = 6;
     case 4:
@@ -244,7 +241,7 @@ static void hanoi_next_level()
       number_of_item_x = 5;
       number_of_item_y = 7;
     }
-      
+
 
   /* Try the next level */
   hanoi_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -258,7 +255,7 @@ static void hanoi_destroy_all_items()
   if(boardRootItem!=NULL)
     {
       gtk_object_destroy (GTK_OBJECT(boardRootItem));
-      
+
       /* Cleanup our memory structure */
       for(i=0; i<(number_of_item_x+2); i++)
 	{
@@ -282,7 +279,7 @@ static void dump_solution()
     {
       for(j=0; j<number_of_item_y; j++)
 	{
-	  g_warning("(%d,%d=%2d/%d) ",  position[i][j]->i,  position[i][j]->j, position[i][j]->color, 
+	  g_warning("(%d,%d=%2d/%d) ",  position[i][j]->i,  position[i][j]->j, position[i][j]->color,
 		 position[i][j]->on_top);
 	}
       g_warning("\n");
@@ -308,7 +305,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   GnomeCanvasPathDef *path;
   guint w;
   GdkPixbuf *pixmap = NULL;
-      
+
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
 							    gnome_canvas_group_get_type (),
@@ -316,11 +313,11 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 							    "y", (double) 0,
 							    NULL));
 
-  pixmap = gcompris_load_skin_pixmap("gcompris-shapelabel.png");
+  pixmap = gc_skin_pixmap_load("gcompris-shapelabel.png");
   if(pixmap) {
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", pixmap, 
+			   "pixbuf", pixmap,
 			   "x",	(double)BOARDWIDTH/2,
 			   "y",	(double)BOARDHEIGHT - 35,
 			   "width", (double) BOARDWIDTH - 20,
@@ -333,7 +330,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Build the same tower in the empty area as the one you see on the right-hand side."),
-			 "font", gcompris_skin_font_board_medium,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2 +1,
 			 "y", (double) BOARDHEIGHT - 50 +1,
 			 "anchor", GTK_ANCHOR_NORTH,
@@ -344,11 +341,11 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Build the same tower in the empty area as the one you see on the right-hand side."),
-			 "font", gcompris_skin_font_board_medium,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) BOARDHEIGHT - 50,
 			 "anchor", GTK_ANCHOR_NORTH,
-			 "fill_color_rgba", gcompris_skin_color_text_button,
+			 "fill_color_rgba", gc_skin_color_text_button,
 			 "justification", GTK_JUSTIFY_CENTER,
 			 NULL);
 
@@ -374,10 +371,10 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   /* Initialize a random goal and store the color index in position[number_of_item_x] */
   for(i=0; i<(number_of_item_y); i++)
     {
-      guint color = (guint)RAND(0, NUMBER_OF_COLOR);
+      guint color = (guint)RAND(0, NUMBER_OF_COLOR-1);
       position[number_of_item_x+1][i]->color = color;
       used_colors[color] = TRUE;
-      
+
     }
 
   /* Randomly place the solution */
@@ -411,12 +408,13 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 	  if(position[i][j]->color == -1)
 	    {
 	      /* Take only a color that is not part of the goal */
-	      guint color = (guint)RAND(0, NUMBER_OF_COLOR);
+	      guint color = (guint)RAND(0, NUMBER_OF_COLOR-1);
 	      //printf(" i,j=%d,%d random color = %d used_colors[color]=%d\n", i,j,color, used_colors[color]);
 	      while(used_colors[color])
 		{
 		  //printf("  used_colors[%d]=%d\n", color, used_colors[color]);
-		if(color++>NUMBER_OF_COLOR)
+        color++;
+		if(color >= NUMBER_OF_COLOR)
 		  color = 0;
 		}
 
@@ -499,7 +497,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 				     item_width * i + item_width/2, baseline + w + 10,
 				     item_width * i + item_width/2 - w, baseline);
       gnome_canvas_path_def_closepath_current (path);
-        
+
       item = gnome_canvas_item_new (boardRootItem,
 				    GNOME_TYPE_CANVAS_SHAPE,
 				    "fill_color_rgba", 0x20FF30FF,
@@ -541,7 +539,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 		 gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_text_get_type (),
 					"text", &car,
-					"font", gcompris_skin_font_board_tiny,
+					"font", gc_skin_font_board_tiny,
 					"x", (double) position[i][j]->xt,
 					"y", (double) position[i][j]->yt,
 					"anchor", GTK_ANCHOR_NORTH,
@@ -571,10 +569,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   hanoi_next_level();
 }
@@ -614,12 +612,12 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 
   if(!data->on_top)
     return FALSE;
-	  
+
   item_x = event->button.x;
   item_y = event->button.y;
   gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
-  
-  switch (event->type) 
+
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       gnome_canvas_item_set(item,
@@ -634,19 +632,19 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 			    NULL);
       break;
     case GDK_BUTTON_PRESS:
-      switch(event->button.button) 
+      switch(event->button.button)
 	{
 	case 1:
-	  
+
 	  x = item_x;
 	  y = item_y;
-	  
+
 	  gnome_canvas_item_raise_to_top(data->item);
 	  gnome_canvas_item_raise_to_top(data->item_text);
-	  
+
 	  fleur = gdk_cursor_new(GDK_FLEUR);
-	  gnome_canvas_item_grab(data->item,
-				 GDK_POINTER_MOTION_MASK | 
+	  gc_canvas_item_grab(data->item,
+				 GDK_POINTER_MOTION_MASK |
 				 GDK_BUTTON_RELEASE_MASK,
 				 fleur,
 				 event->button.time);
@@ -655,33 +653,33 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  break;
 	}
       break;
-      
+
     case GDK_MOTION_NOTIFY:
-      if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
+      if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
 	{
 	  new_x = item_x;
 	  new_y = item_y;
-	  
+
 	  gnome_canvas_item_move(data->item     , new_x - x, new_y - y);
 	  gnome_canvas_item_move(data->item_text, new_x - x, new_y - y);
 	  x = new_x;
 	  y = new_y;
 	}
       break;
-      
+
     case GDK_BUTTON_RELEASE:
-      if(dragging) 
+      if(dragging)
 	{
 	  gint i;
 	  gint tmpi, tmpj;
 	  double tmpx, tmpy;
 	  PieceItem *piece_src;
 	  PieceItem *piece_dst;
-	  gint col, line;
-	  
-	  gnome_canvas_item_ungrab(data->item, event->button.time);
+	  gint col = 0, line;
+
+	  gc_canvas_item_ungrab(data->item, event->button.time);
 	  dragging = FALSE;
-	  
+
 	  /* Search the column (x) where this item is ungrabbed */
 	  for(i=0; i<=number_of_item_x; i++)
 	    if(position[i][0]->x   < item_x &&
@@ -693,8 +691,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  if(col<0 || col > number_of_item_x || col == data->i)
 	    {
 	      /* Return to the original position */
-	      item_absolute_move (data->item     , data->x , data->y);
-	      item_absolute_move (data->item_text, data->xt, data->yt);
+	      gc_item_absolute_move (data->item     , data->x , data->y);
+	      gc_item_absolute_move (data->item_text, data->xt, data->yt);
 
 	      /* FIXME : Workaround for bugged canvas */
 	      gnome_canvas_update_now(gcomprisBoard->canvas);
@@ -708,13 +706,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  for(i=number_of_item_y-1; i>=0; i--)
 	    if(position[col][i]->color == -1)
 	      line = i;
-	  
+
 	  /* Bad drop / Too many pieces here */
 	  if(line >= number_of_item_y)
 	    {
 	      /* Return to the original position */
-	      item_absolute_move (data->item     , data->x , data->y);
-	      item_absolute_move (data->item_text, data->xt, data->yt);
+	      gc_item_absolute_move (data->item     , data->x , data->y);
+	      gc_item_absolute_move (data->item_text, data->xt, data->yt);
 
 	      /* FIXME : Workaround for bugged canvas */
 	      gnome_canvas_update_now(gcomprisBoard->canvas);
@@ -725,17 +723,17 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  /* Update ontop values for the piece under the grabbed one */
 	  if(data->j>0)
 	    position[data->i][data->j-1]->on_top = TRUE;
-	  
+
 	  /* Update ontop values for the piece under the ungrabbed one */
 	  if(line>0)
 	    position[col][line-1]->on_top = FALSE;
-	  
+
 	  /* Move the piece */
 	  piece_dst = position[col][line];
 	  piece_src = data;
-	  item_absolute_move (data->item     , piece_dst->x , piece_dst->y);
-	  item_absolute_move (data->item_text, piece_dst->xt, piece_dst->yt);
-	  
+	  gc_item_absolute_move (data->item     , piece_dst->x , piece_dst->y);
+	  gc_item_absolute_move (data->item_text, piece_dst->xt, piece_dst->yt);
+
 	  /* FIXME : Workaround for bugged canvas */
 	  gnome_canvas_update_now(gcomprisBoard->canvas);
 
@@ -746,21 +744,21 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  piece_src->y = piece_dst->y;
 	  piece_dst->x = tmpx;
 	  piece_dst->y = tmpy;
-	  
+
 	  tmpx    = data->xt;
 	  tmpy    = data->yt;
 	  piece_src->xt = piece_dst->xt;
 	  piece_src->yt = piece_dst->yt;
 	  piece_dst->xt = tmpx;
 	  piece_dst->yt = tmpy;
-	  
+
 	  tmpi    = data->i;
 	  tmpj    = data->j;
 	  position[tmpi][tmpj]->i = piece_dst->i;
 	  position[tmpi][tmpj]->j = piece_dst->j;
 	  piece_dst->i  = tmpi;
 	  piece_dst->j  = tmpj;
-	  
+
 	  position[piece_src->i][piece_src->j] = piece_src;
 	  position[piece_dst->i][piece_dst->j] = piece_dst;
 
@@ -769,16 +767,16 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	    {
 	      gamewon = TRUE;
 	      hanoi_destroy_all_items();
-	      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	      gc_bonus_display(gamewon, BONUS_SMILEY);
 	    }
 	}
       break;
-      
+
     default:
       break;
     }
-  
-  
+
+
   return FALSE;
 }
 
