@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -130,10 +126,10 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=2;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      gcompris_image_to_skin("gcompris-bg.jpg"));
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			      gc_skin_image_get("gcompris-bg.jpg"));
 
       boardRootItem = NULL;
 
@@ -187,7 +183,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void hanoi_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   hanoi_destroy_all_items();
   gamewon = FALSE;
@@ -207,7 +203,7 @@ static void hanoi_destroy_all_items()
   if(boardRootItem!=NULL)
     {
       gtk_object_destroy (GTK_OBJECT(boardRootItem));
-      
+
       /* Cleanup our memory structure */
       for(i=0; i<number_of_item_x; i++)
 	{
@@ -231,8 +227,8 @@ static void dump_solution()
     {
       for(j=0; j<number_of_item_y; j++)
 	{
-	  printf("(%d,%d= width=%d top=%d) ",  position[i][j]->i, position[i][j]->j, 
-		    position[i][j]->width, 
+	  printf("(%d,%d= width=%d top=%d) ",  position[i][j]->i, position[i][j]->j,
+		    position[i][j]->width,
 		    position[i][j]->on_top);
 	}
       printf("\n");
@@ -250,7 +246,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   GnomeCanvasItem *item = NULL;
   GdkPixbuf *pixmap = NULL;
   gchar *filename;
-      
+
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
 							    gnome_canvas_group_get_type (),
@@ -258,11 +254,11 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 							    "y", (double) 0,
 							    NULL));
 
-  pixmap = gcompris_load_skin_pixmap("gcompris-shapelabel.png");
+  pixmap = gc_skin_pixmap_load("gcompris-shapelabel.png");
   if(pixmap) {
     gnome_canvas_item_new (boardRootItem,
 			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", pixmap, 
+			   "pixbuf", pixmap,
 			   "x",	(double)BOARDWIDTH/2,
 			   "y",	(double)BOARDHEIGHT - 35,
 			   "width", (double) BOARDWIDTH - 20,
@@ -275,22 +271,22 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Move the entire stack to the right peg, one disc at a time"),
-			 "font", gcompris_skin_font_board_medium,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2 +1,
 			 "y", (double) BOARDHEIGHT - 50 +1,
 			 "anchor", GTK_ANCHOR_NORTH,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 "fill_color_rgba", gc_skin_color_shadow,
 			 "justification", GTK_JUSTIFY_CENTER,
 			 NULL);
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Move the entire stack to the right peg, one disc at a time"),
-			 "font", gcompris_skin_font_board_medium,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) BOARDHEIGHT - 50,
 			 "anchor", GTK_ANCHOR_NORTH,
-			 "fill_color_rgba", gcompris_skin_color_text_button,
+			 "fill_color_rgba", gc_skin_color_text_button,
 			 "justification", GTK_JUSTIFY_CENTER,
 			 NULL);
 
@@ -351,8 +347,8 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 	}
 
       /* The disc support */
-      pixmap = gcompris_load_pixmap ("images/disc_support.png");
-      
+      pixmap = gc_pixmap_load ("images/disc_support.png");
+
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
 				    "x", (double) item_width * i + item_width/2,
@@ -373,7 +369,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 	  if(position[i][j]->width != -1)
 	    {
 	      filename = g_strdup_printf("%s%d.png", "images/disc", j+1);
-	      pixmap = gcompris_load_pixmap (filename);
+	      pixmap = gc_pixmap_load (filename);
 
 	      item = gnome_canvas_item_new (boardRootItem,
 					    gnome_canvas_pixbuf_get_type (),
@@ -405,10 +401,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   hanoi_next_level();
 }
@@ -448,32 +444,32 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 
   if(!data->on_top)
     return FALSE;
-	  
+
   item_x = event->button.x;
   item_y = event->button.y;
   gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
-  
-  switch (event->type) 
+
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
-      gcompris_set_image_focus(item, TRUE);
+      gc_item_focus_set(item, TRUE);
       break;
     case GDK_LEAVE_NOTIFY:
-      gcompris_set_image_focus(item, FALSE);
+      gc_item_focus_set(item, FALSE);
       break;
     case GDK_BUTTON_PRESS:
-      switch(event->button.button) 
+      switch(event->button.button)
 	{
 	case 1:
-	  
+
 	  x = item_x;
 	  y = item_y;
-	  
+
 	  gnome_canvas_item_raise_to_top(data->item);
-	  
+
 	  fleur = gdk_cursor_new(GDK_FLEUR);
-	  gnome_canvas_item_grab(data->item,
-				 GDK_POINTER_MOTION_MASK | 
+	  gc_canvas_item_grab(data->item,
+				 GDK_POINTER_MOTION_MASK |
 				 GDK_BUTTON_RELEASE_MASK,
 				 fleur,
 				 event->button.time);
@@ -482,21 +478,21 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  break;
 	}
       break;
-      
+
     case GDK_MOTION_NOTIFY:
-      if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
+      if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
 	{
 	  new_x = item_x;
 	  new_y = item_y;
-	  
+
 	  gnome_canvas_item_move(data->item, new_x - x, new_y - y);
 	  x = new_x;
 	  y = new_y;
 	}
       break;
-      
+
     case GDK_BUTTON_RELEASE:
-      if(dragging) 
+      if(dragging)
 	{
 	  gint i;
 	  gint tmpi, tmpj;
@@ -512,12 +508,12 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  disc_w = gdk_pixbuf_get_width(pixmap)/2;
 	  disc_h = gdk_pixbuf_get_height(pixmap)/2;
 	  gdk_pixbuf_unref(pixmap);
-      
-	  gnome_canvas_item_ungrab(data->item, event->button.time);
+
+	  gc_canvas_item_ungrab(data->item, event->button.time);
 	  dragging = FALSE;
-	  
+
 	  /* Search the column (x) where this item is ungrabbed */
-	  if(item_x > (position[number_of_item_x-1][0]->x 
+	  if(item_x > (position[number_of_item_x-1][0]->x
 		       - (position[number_of_item_x-1][0]->x - position[number_of_item_x-2][0]->x) / 2))
 	     col = number_of_item_x-1;
 	  else if(item_x < position[0][0]->x)
@@ -536,7 +532,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  if(col<0 || col > number_of_item_x || col == data->i)
 	    {
 	      /* Return to the original position */
-	      item_absolute_move (data->item , data->x - disc_w, data->y - disc_h);
+	      gc_item_absolute_move (data->item , data->x - disc_w, data->y - disc_h);
 
 	      /* FIXME : Workaround for bugged canvas */
 	      gnome_canvas_update_now(gcomprisBoard->canvas);
@@ -550,13 +546,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  for(i=number_of_item_y-1; i>=0; i--)
 	    if(position[col][i]->width == -1)
 	      line = i;
-	  
+
 	  /* Bad drop / Too many pieces here or larger disc is above */
-	  if(line > number_of_item_y || 
+	  if(line > number_of_item_y ||
 	     (line > 0 && position[col][line-1]->width != -1 && position[col][line-1]->width < data->width))
 	    {
 	      /* Return to the original position */
-	      item_absolute_move (data->item , data->x - disc_w, data->y - disc_h);
+	      gc_item_absolute_move (data->item , data->x - disc_w, data->y - disc_h);
 
 	      /* FIXME : Workaround for bugged canvas */
 	      gnome_canvas_update_now(gcomprisBoard->canvas);
@@ -567,19 +563,19 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  /* Update ontop values for the piece under the grabbed one */
 	  if(data->j>0)
 	    position[data->i][data->j-1]->on_top = TRUE;
-	  
+
 	  /* Update ontop values for the piece under the ungrabbed one */
 	  if(line>0)
 	    position[col][line-1]->on_top = FALSE;
-	  
+
 	  /* Move the piece */
 	  piece_dst = position[col][line];
 	  piece_src = data;
 
-	  item_absolute_move (data->item,
+	  gc_item_absolute_move (data->item,
 			      piece_dst->x - disc_w,
 			      piece_dst->y - disc_h);
-	  
+
 	  /* FIXME : Workaround for bugged canvas */
 	  gnome_canvas_update_now(gcomprisBoard->canvas);
 
@@ -590,14 +586,14 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	  piece_src->y = piece_dst->y;
 	  piece_dst->x = tmpx;
 	  piece_dst->y = tmpy;
-	  
+
 	  tmpi    = data->i;
 	  tmpj    = data->j;
 	  position[tmpi][tmpj]->i = piece_dst->i;
 	  position[tmpi][tmpj]->j = piece_dst->j;
 	  piece_dst->i  = tmpi;
 	  piece_dst->j  = tmpj;
-	  
+
 	  position[piece_src->i][piece_src->j] = piece_src;
 	  position[piece_dst->i][piece_dst->j] = piece_dst;
 
@@ -606,16 +602,16 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
 	    {
 	      gamewon = TRUE;
 	      hanoi_destroy_all_items();
-	      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	      gc_bonus_display(gamewon, BONUS_SMILEY);
 	    }
 	}
       break;
-      
+
     default:
       break;
     }
-  
-  
+
+
   return FALSE;
 }
 
