@@ -17,11 +17,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#define DEBUG 0
-
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -46,14 +42,9 @@ static void		 highlight_selected(GnomeCanvasItem *);
 static void		 game_won(void);
 
 static void		 config_start(GcomprisBoard *agcomprisBoard,
-					     GcomprisProfile *aProfile);
+				      GcomprisProfile *aProfile);
 static void		 config_stop(void);
 
-#ifdef DEBUG
-static void		 dump_xml(void);
-#endif
-
-
 typedef struct {
   char  *pixmapfile;
   char  *text1;
@@ -141,7 +132,7 @@ GET_BPLUGIN_INFO(imageid)
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
  *
  */
-static void pause_board (gboolean pause)
+     static void pause_board (gboolean pause)
 {
   if(gcomprisBoard==NULL)
     return;
@@ -158,16 +149,16 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
 
-  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   g_hash_table_destroy(config);
 
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "imageid/imageid-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "imageid/imageid-bg.jpg");
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
       gcomprisBoard->sublevel=1;
@@ -175,12 +166,12 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       init_xml();
 
       gcomprisBoard->number_of_sublevel = NUMBER_OF_SUBLEVELS;
-      assert(NUMBER_OF_LEVELS*NUMBER_OF_SUBLEVELS == g_list_length(board_list));
-      gcompris_score_start(SCORESTYLE_NOTE,
+      g_assert(NUMBER_OF_LEVELS*NUMBER_OF_SUBLEVELS == g_list_length(board_list));
+      gc_score_start(SCORESTYLE_NOTE,
 			   50,
 			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
 
       imageid_next_level();
 
@@ -196,12 +187,12 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       imageid_destroy_all_items();
       destroy_board_list();
     }
 
-  gcompris_reset_locale();  
+  gc_locale_reset();
 
   gcomprisBoard = NULL;
 }
@@ -239,13 +230,13 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 /* set initial values for the next level */
 static void imageid_next_level()
 {
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   imageid_destroy_all_items();
   selected_button = NULL;
   gamewon = FALSE;
 
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   /* Try the next level */
   imageid_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -256,7 +247,7 @@ static void imageid_next_level()
 static void imageid_destroy_all_items()
 {
   if(boardRootItem!=NULL)
-      gtk_object_destroy (GTK_OBJECT(boardRootItem));
+    gtk_object_destroy (GTK_OBJECT(boardRootItem));
 
   boardRootItem = NULL;
 }
@@ -271,12 +262,12 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
   Board * board;
 
   board_number = (gcomprisBoard->level-1) * NUMBER_OF_SUBLEVELS + gcomprisBoard->sublevel-1;
-/*  if (board_number >= g_list_length(board_list))
-	board_number = g_list_length(board_list)-1;
-*/
-  assert(board_number >= 0  && board_number < g_list_length(board_list));
+  /*  if (board_number >= g_list_length(board_list))
+      board_number = g_list_length(board_list)-1;
+  */
+  g_assert(board_number >= 0  && board_number < g_list_length(board_list));
   place = ((int)(3.0*rand()/(RAND_MAX+1.0)));
-  assert(place >= 0  && place < 3);
+  g_assert(place >= 0  && place < 3);
 
   right_word = place+1;
 
@@ -287,13 +278,13 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 							    "y", (double) 0,
 							    NULL));
 
-  button_pixmap = gcompris_load_skin_pixmap("button_large.png");
+  button_pixmap = gc_skin_pixmap_load("button_large.png");
   /* display the image */
   board = g_list_nth_data(board_list, board_number);
-  assert(board != NULL);
+  g_assert(board != NULL);
 
   str = g_strdup_printf("%s/%s", gcomprisBoard->boarddir, board->pixmapfile);
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   x = IMAGE_AREA_X1 + ( IMAGE_AREA_X2 - IMAGE_AREA_X1 - gdk_pixbuf_get_width(pixmap))/2;
   y = IMAGE_AREA_Y1 + ( IMAGE_AREA_Y2 - IMAGE_AREA_Y1 - gdk_pixbuf_get_height(pixmap))/2;
@@ -337,81 +328,81 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
   yp = (gcomprisBoard->height - 3*gdk_pixbuf_get_height(button_pixmap) - 2*VERTICAL_SEPARATION)/2;
 
   button1 = gnome_canvas_item_new (boardRootItem,
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf",  button_pixmap,
-				"x",  (double) xp,
-				"y",  (double) yp,
-				NULL);
+				   gnome_canvas_pixbuf_get_type (),
+				   "pixbuf",  button_pixmap,
+				   "x",  (double) xp,
+				   "y",  (double) yp,
+				   NULL);
   gnome_canvas_item_new (boardRootItem,
-				      gnome_canvas_text_get_type (),
-				      "text", buf[0],
-				      "font", gcompris_skin_font_board_big,
-				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
-				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
-				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_shadow,
-				      NULL);
+			 gnome_canvas_text_get_type (),
+			 "text", buf[0],
+			 "font", gc_skin_font_board_big,
+			 "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+			 "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 NULL);
   text1_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[0],
-				      "font", gcompris_skin_font_board_big,
+				      "font", gc_skin_font_board_big,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_text_button,
+				      "fill_color_rgba", gc_skin_color_text_button,
 				      NULL);
 
   yp += gdk_pixbuf_get_height(button_pixmap) + VERTICAL_SEPARATION;
   button2 = gnome_canvas_item_new (boardRootItem,
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf",  button_pixmap,
-				"x",  (double) xp,
-				"y",  (double) yp,
-				NULL);
+				   gnome_canvas_pixbuf_get_type (),
+				   "pixbuf",  button_pixmap,
+				   "x",  (double) xp,
+				   "y",  (double) yp,
+				   NULL);
   gnome_canvas_item_new (boardRootItem,
-				      gnome_canvas_text_get_type (),
-				      "text", buf[1],
-				      "font", gcompris_skin_font_board_big,
-				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
-				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
-				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_shadow,
-				      NULL);
+			 gnome_canvas_text_get_type (),
+			 "text", buf[1],
+			 "font", gc_skin_font_board_big,
+			 "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+			 "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 NULL);
   text2_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[1],
-				      "font", gcompris_skin_font_board_big,
+				      "font", gc_skin_font_board_big,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_text_button,
+				      "fill_color_rgba", gc_skin_color_text_button,
 				      NULL);
 
   yp += gdk_pixbuf_get_height(button_pixmap) + VERTICAL_SEPARATION;
   button3 = gnome_canvas_item_new (boardRootItem,
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf",  button_pixmap,
-				"x",  (double) xp,
-				"y",  (double) yp,
-				NULL);
+				   gnome_canvas_pixbuf_get_type (),
+				   "pixbuf",  button_pixmap,
+				   "x",  (double) xp,
+				   "y",  (double) yp,
+				   NULL);
 
   gnome_canvas_item_new (boardRootItem,
-				      gnome_canvas_text_get_type (),
-				      "text", buf[2],
-				      "font", gcompris_skin_font_board_big,
-				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
-				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
-				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_shadow,
-				      NULL);
+			 gnome_canvas_text_get_type (),
+			 "text", buf[2],
+			 "font", gc_skin_font_board_big,
+			 "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+			 "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 NULL);
   text3_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[2],
-				      "font", gcompris_skin_font_board_big,
+				      "font", gc_skin_font_board_big,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color_rgba", gcompris_skin_color_text_button,
+				      "fill_color_rgba", gc_skin_color_text_button,
 				      NULL);
 
   gdk_pixbuf_unref(button_pixmap);
@@ -435,21 +426,21 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-	board_finished(BOARD_FINISHED_TUXLOCO);
-	return;
-      }
+      gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
+      return;
+    }
   }
   imageid_next_level();
 }
 
 /* ==================================== */
 static gboolean process_ok_timeout() {
-  gcompris_display_bonus(gamewon, BONUS_SMILEY);
-	return FALSE;
+  gc_bonus_display(gamewon, BONUS_SMILEY);
+  return FALSE;
 }
 
 static void process_ok() {
-	// leave time to display the right answer
+  // leave time to display the right answer
   g_timeout_add(TIME_CLICK_TO_BONUS, process_ok_timeout, NULL);
 }
 /* ==================================== */
@@ -477,7 +468,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       if (item == text3_item)
 	temp = button3;
 
-      assert(temp == button1 || temp == button2 || temp == button3);
+      g_assert(temp == button1 || temp == button2 || temp == button3);
 
       if ( ( temp == button1 && right_word == 1) ||
 	   ( temp == button2 && right_word == 2) ||
@@ -518,16 +509,16 @@ static void highlight_selected(GnomeCanvasItem * item) {
   }
 
   if (selected_button != NULL && selected_button != button) {
-  	button_pixmap = gcompris_load_skin_pixmap("button_large.png");
-  	gnome_canvas_item_set(selected_button, "pixbuf", button_pixmap, NULL);
-  	gdk_pixbuf_unref(button_pixmap);
+    button_pixmap = gc_skin_pixmap_load("button_large.png");
+    gnome_canvas_item_set(selected_button, "pixbuf", button_pixmap, NULL);
+    gdk_pixbuf_unref(button_pixmap);
   }
 
   if (selected_button != button) {
-  	button_pixmap_selected = gcompris_load_skin_pixmap("button_large_selected.png");
-  	gnome_canvas_item_set(button, "pixbuf", button_pixmap_selected, NULL);
-  	selected_button = button;
-  	gdk_pixbuf_unref(button_pixmap_selected);
+    button_pixmap_selected = gc_skin_pixmap_load("button_large_selected.png");
+    gnome_canvas_item_set(button, "pixbuf", button_pixmap_selected, NULL);
+    selected_button = button;
+    gdk_pixbuf_unref(button_pixmap_selected);
   }
 
 }
@@ -537,21 +528,8 @@ static void highlight_selected(GnomeCanvasItem * item) {
  *                XML stuff
  *                Ref : shapegame.c
  * ==================================== */
-static void init_xml()
-{
-  char *filename;
-  filename = g_strdup_printf("%s/%s/board1.xml", PACKAGE_DATA_DIR, gcomprisBoard->boarddir);
-  g_warning("filename = %s %s %s\n", filename,PACKAGE_DATA_DIR,gcomprisBoard->boarddir);
-
-  assert(g_file_test(filename, G_FILE_TEST_EXISTS));
-  assert(read_xml_file(filename)== TRUE);
-  g_free(filename);
-#ifdef DEBUG
-  dump_xml();
-#endif
-}
 /* ======  for DEBUG ========  */
-#ifdef DEBUG
+#if 0
 static void dump_xml() {
   GList *list;
   g_warning("XML lentgh = %d\n", g_list_length(board_list));
@@ -559,60 +537,78 @@ static void dump_xml() {
   for(list = board_list; list != NULL; list = list->next) {
     Board * board = list->data;
     g_warning("xml = %s %s %s %s\n", board->pixmapfile, board->text1, board->text2, board->text3);
-    }
+  }
 }
 #endif
 
+static void init_xml()
+{
+  char *filename;
+
+  filename = gc_file_find_absolute("%s/board1.xml",
+				   gcomprisBoard->boarddir);
+
+  g_assert(read_xml_file(filename)== TRUE);
+  g_free(filename);
+
+}
 /* ==================================== */
 static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
-  char *pixmapfile = NULL;
-  char *text1 = NULL, *text2 = NULL, *text3 = NULL;
+  gchar *pixmapfile = NULL;
+  gchar *text1 = NULL, *text2 = NULL, *text3 = NULL;
   Board * board = g_new(Board,1);
+  gboolean found_text1 = FALSE, found_text2 = FALSE, found_text3 = FALSE;
 
   xmlnode = xmlnode->xmlChildrenNode;
 
   xmlnode = xmlnode->next;
 
-  while (xmlnode != NULL) {
-  	gchar *lang = xmlGetProp(xmlnode,"lang");
-	if (!strcmp(xmlnode->name, "pixmapfile") && (lang==NULL
-	    || !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
-	  {
-	    pixmapfile = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	  }
-	if (!strcmp(xmlnode->name, "text1") && (lang==NULL
-	    || !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
-	  {
-		text1 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	  }
-	if (!strcmp(xmlnode->name, "text2") && (lang==NULL
-	    || !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
-	  {
-	    text2 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	  }
-	if (!strcmp(xmlnode->name, "text3") && (lang==NULL
-	    || !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
-	  {
-	    text3 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-	  }
-	xmlnode = xmlnode->next;
-	}
-	// I really don't know why this test, but otherwise, the list is doubled
-	// with 1 line on 2 filled with NULL elements
-	if ( (pixmapfile == NULL || text1 == NULL || text2 == NULL || text3 == NULL))
-		return;
+  while(xmlnode!=NULL) {
 
-	board->pixmapfile = g_strdup(pixmapfile);
-	board->text1 = g_strdup(text1);
-	board->text2 = g_strdup(text2);
-	board->text3 = g_strdup(text3);
+    if (!strcmp((char *)xmlnode->name, "pixmapfile"))
+      pixmapfile = (gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
 
-	board_list = g_list_append (board_list, board);
+    if (!found_text1 && !strcmp((char *)xmlnode->name, "text1"))
+      {
+	if(text1==NULL)
+	  {
+	    text1 = \
+	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	  }
+      }
+
+    if (!found_text2 && !strcmp((char *)xmlnode->name, "text2"))
+      {
+	if(text2==NULL)
+	  {
+	    text2 = \
+	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	  }
+      }
+
+    if (!found_text3 && !strcmp((char *)xmlnode->name, "text3"))
+      {
+	if(text3==NULL)
+	  {
+	    text3 = \
+	      g_strdup(gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1)));
+	  }
+      }
+
+    xmlnode = xmlnode->next;
+  }
+  // I really don't know why this test, but otherwise, the list is doubled
+  // with 1 line on 2 filled with NULL elements
+  if ( (pixmapfile == NULL || text1 == NULL || text2 == NULL || text3 == NULL))
+    return;
+
+  board->pixmapfile = pixmapfile;
+  board->text1 = text1;
+  board->text2 = text2;
+  board->text3 = text3;
+
+  board_list = g_list_append (board_list, board);
 }
 
 /* ==================================== */
@@ -621,8 +617,8 @@ static void parse_doc(xmlDocPtr doc)
   xmlNodePtr node;
 
   for(node = doc->children->children; node != NULL; node = node->next) {
-    if ( g_strcasecmp(node->name, "Board") == 0 )
-    	add_xml_data(doc, node,NULL);
+    if ( g_strcasecmp((gchar *)node->name, "Board") == 0 )
+      add_xml_data(doc, node,NULL);
   }
 
 }
@@ -636,16 +632,9 @@ static gboolean read_xml_file(char *fname)
 
   g_return_val_if_fail(fname!=NULL,FALSE);
 
-  /* if the file doesn't exist */
-  if(!g_file_test(fname, G_FILE_TEST_EXISTS))
-    {
-      g_warning("Couldn't find file %s !", fname);
-      return FALSE;
-    }
-  g_warning("found file %s !", fname);
-
   /* parse the new file and put the result into newdoc */
-  doc = xmlParseFile(fname);
+  doc = gc_net_load_xml(fname);
+
   /* in case something went wrong */
   if(!doc)
     return FALSE;
@@ -655,7 +644,7 @@ static gboolean read_xml_file(char *fname)
      /* if it doesn't have a name */
      !doc->children->name ||
      /* if it isn't a ImageId node */
-     g_strcasecmp(doc->children->name,"ImageId")!=0) {
+     g_strcasecmp((char *)doc->children->name,"ImageId")!=0) {
     xmlFreeDoc(doc);
     return FALSE;
   }
@@ -666,8 +655,9 @@ static gboolean read_xml_file(char *fname)
 }
 /* ======================================= */
 static void destroy_board_list() {
-Board *board;
- while(g_list_length(board_list)>0)
+  Board *board;
+
+  while(g_list_length(board_list)>0)
     {
       board = g_list_nth_data(board_list, 0);
       board_list = g_list_remove (board_list, board);
@@ -677,11 +667,11 @@ Board *board;
 
 /* ======================================= */
 static void destroy_board(Board * board) {
-	g_free(board->pixmapfile);
-	g_free(board->text1);
-	g_free(board->text2);
-	g_free(board->text3);
-	g_free(board);
+  g_free(board->pixmapfile);
+  g_free(board->text1);
+  g_free(board->text2);
+  g_free(board->text3);
+  g_free(board);
 }
 
 
@@ -697,13 +687,14 @@ static void destroy_board(Board * board) {
 static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
-static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+/* GHFunc */
+static void save_table (gpointer key,
+			gpointer value,
+			gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 }
 
@@ -712,23 +703,23 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
-    return;
+    return NULL;
   }
-    
+
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
 
   if (gcomprisBoard) {
-    gcompris_reset_locale();
+    gc_locale_reset();
 
     GHashTable *config;
 
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
 
-    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
-  
+    gc_locale_set(g_hash_table_lookup( config, "locale"));
+
     if (profile_conf)
       g_hash_table_destroy(config);
 
@@ -740,15 +731,16 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
 
     pause_board(FALSE);
   }
-  
+
   board_conf = NULL;
   profile_conf = NULL;
 
+  return NULL;
 }
 
 static void
 config_start(GcomprisBoard *agcomprisBoard,
-		    GcomprisProfile *aProfile)
+	     GcomprisProfile *aProfile)
 {
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
@@ -757,28 +749,28 @@ config_start(GcomprisBoard *agcomprisBoard,
     pause_board(TRUE);
 
   gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-				 agcomprisBoard->name, 
+				 agcomprisBoard->name,
 				 aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window( label, 
+  gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *locale = g_hash_table_lookup( config, "locale");
-  
-  gcompris_combo_locales( locale);
+
+  gc_board_config_combo_locales( locale);
 
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 config_stop()
 {
 }
