@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -146,7 +142,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
       minigolf_next_level();
 
@@ -198,9 +194,9 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void minigolf_next_level()
 {
 
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),"images/foot_background.png");
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),"images/foot_background.png");
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   minigolf_destroy_all_items();
   gamewon = FALSE;
@@ -226,8 +222,12 @@ static void minigolf_destroy_all_items()
   boardRootItem = NULL;
 
   if(item_list)
-    g_list_free(item_list);
-
+  {
+      int i;
+      for( i=0; i< g_list_length(item_list); i++)
+          g_free(g_list_nth_data(item_list,i));
+      g_list_free(item_list);
+  }
   item_list = NULL;
 }
 /* ==================================== */
@@ -258,10 +258,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   minigolf_next_level();
 }
@@ -285,7 +285,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MachItem *machItem)
   if(board_paused)
     return FALSE;
 
-   switch (event->type) 
+   switch (event->type)
      {
 
      case GDK_BUTTON_PRESS:
@@ -299,12 +299,12 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MachItem *machItem)
        machItem->vyo = ((item_y-y1)<width/2?(width/2-(item_y-y1))*20:-1*(width/2-(y2-item_y))*20);
        machItem->vxo = ((item_x-x1)<width/2?(width/2-(item_x-x1))*20:-1*(width/2-(x2-item_x))*20);
        break;
-       
+
      default:
        break;
      }
-   
-   
+
+
    return FALSE;
 }
 
@@ -337,7 +337,7 @@ static MachItem *create_machine_item(MachItemType machItemType, double x, double
 
   machItem->type	= machItemType;
 
-  switch (machItemType) 
+  switch (machItemType)
     {
     case MACH_HORZ_WALL:
       width = 100;
@@ -443,7 +443,7 @@ static MachItem *create_machine_item(MachItemType machItemType, double x, double
       gtk_signal_connect(GTK_OBJECT(machItem->item), "event",
 			 (GtkSignalFunc) item_event,
 			 machItem);
-     
+
       break;
     case MACH_FLYING_BALL:
       width = 40;
@@ -489,7 +489,7 @@ static MachItem *create_machine_item(MachItemType machItemType, double x, double
   return machItem;
 }
 
-/* 
+/*
  * Returns true if at least 3 corners of 's' rectangle are inside 'd' rectangle
  *
  */
@@ -499,7 +499,7 @@ static gint rectangle_in(double sx1, double sy1, double sx2, double sy2,
   guint corner_in = 0;
   //  printf("rectangle_in %10f %10f %10f %10f\n             %10f %10f %10f %10f\n", sx1,sy1,sx2,sy2,dx1,dy1,dx2,dy2);
 
-  if(sx1>dx1 && sx1<dx2 && sy1>dy1 && sy1<dy2) 
+  if(sx1>dx1 && sx1<dx2 && sy1>dy1 && sy1<dy2)
     corner_in++;
 
   if(sx2>dx1 && sx2<dx2 && sy2>dy1 && sy2<dy2)
@@ -539,7 +539,7 @@ static void minigolf_move(GList *item_list)
 	  gnome_canvas_item_get_bounds(item, &x1, &y1, &x2, &y2);
 
 	  machItem->times += times_inc;
-	  
+
 	  /* Collision detection */
 	  for(j=0; j<g_list_length(item_list); j++)
 	    {
@@ -551,7 +551,7 @@ static void minigolf_move(GList *item_list)
 
 	      if(collMachItem != machItem) {
 
-		if(rectangle_in(x1, y1, x2, y2, 
+		if(rectangle_in(x1, y1, x2, y2,
 				collMachItem->xpos,
 				collMachItem->ypos,
 				collMachItem->xpos + collMachItem->width,
@@ -560,17 +560,17 @@ static void minigolf_move(GList *item_list)
 		    //printf("!!! Collision detected with:\n");
 		    //dump_machItem(collMachItem);
 		    collision = TRUE;
-		    
+
 		    gamewon = TRUE;
 		    minigolf_destroy_all_items();
-		    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+		    gc_bonus_display(gamewon, BONUS_SMILEY);
 		    return;
 		  }
 	      }
 	    }
 
-	  ypos=machItem->yposo 
-	    + (machItem->vyo*machItem->times) 
+	  ypos=machItem->yposo
+	    + (machItem->vyo*machItem->times)
 	    + (.5*machItem->ay * (machItem->times*machItem->times));
 
 	  /* Simulate going slower */
@@ -581,8 +581,8 @@ static void minigolf_move(GList *item_list)
 	    machItem->vyo = 0;
 	  }
 
-	  xpos=machItem->xposo 
-	    + (machItem->vxo*machItem->times) 
+	  xpos=machItem->xposo
+	    + (machItem->vxo*machItem->times)
 	    + (.5*machItem->ax * (machItem->times*machItem->times));
 
 	  /* Simulate going slower */
@@ -599,7 +599,7 @@ static void minigolf_move(GList *item_list)
 	  /* v = u + at */
 	  machItem->vxo += (machItem->ax * machItem->times);
 	  machItem->vyo += (machItem->ay * machItem->times);
-	  
+
 	  if(machItem->ypos >= MIN_Y2 - machItem->height -1)
 	    machItem->ypos = MIN_Y2 - machItem->height;
 
@@ -613,8 +613,8 @@ static void minigolf_move(GList *item_list)
 	    machItem->xpos = MIN_X2;
 
 
-	  item_absolute_move(item, machItem->xpos, machItem->ypos);
-	  
+	  gc_item_absolute_move(item, machItem->xpos, machItem->ypos);
+
 	  if((machItem->ypos>=MIN_Y2-machItem->height-BORDER && (y1 - machItem->ypos)<=0) || collision == TRUE)
 	    {
 	      machItem->vyo   = machItem->vyo * -0.5;
@@ -622,11 +622,11 @@ static void minigolf_move(GList *item_list)
 	      machItem->times = 0;
 	      machItem->yposo = machItem->ypos;
 	      machItem->xposo = machItem->xpos;
-	      
+
 	      /* Floor touch */
 	      //machItem->vxo *= 0.9;
 	    }
-	  
+
 	  if((y1<=MIN_Y1 && (y1 - machItem->ypos)>=0) || collision == TRUE)
 	    {
 	      machItem->vyo   = machItem->vyo * -0.5;
