@@ -170,7 +170,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	gcomprisBoard->maxlevel = 9;
 	gcomprisBoard->sublevel = 1;
 	gcomprisBoard->number_of_sublevel = 1;	// Go to next level after this number of 'play'
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+	gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
 	if (strcmp(gcomprisBoard->mode, "minus") == 0)
 		board_mode = MODE_MINUS;
@@ -179,8 +179,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	else
 		board_mode = DEFAULT_MODE;
 
-	img = gcompris_image_to_skin("gcompris-bg.jpg");
-	gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), img);
+	img = gc_skin_image_get("gcompris-bg.jpg");
+	gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), img);
 	g_free(img);
 
 	magic_hat_next_level();
@@ -225,10 +225,10 @@ static void process_ok() {
 
   if (ok) {
 	gamewon = TRUE;
-	gcompris_play_ogg ("bonus", NULL);
+	gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
 
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
 
 }
 
@@ -263,7 +263,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
 /* set initial values for the next level */
 static void magic_hat_next_level() {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   magic_hat_destroy_all_items();
   gamewon = FALSE;
@@ -301,9 +301,9 @@ static GnomeCanvasItem *magic_hat_create_item()
 				     NULL));
 
   if (board_mode == MODE_MINUS)
-	pixmap = gcompris_load_pixmap("magic_hat/magic_hat_minus_bg.png");
+	pixmap = gc_pixmap_load("magic_hat/magic_hat_minus_bg.png");
   else
-	pixmap = gcompris_load_pixmap("magic_hat/magic_hat_plus_bg.png");
+	pixmap = gc_pixmap_load("magic_hat/magic_hat_plus_bg.png");
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_pixbuf_get_type(),
@@ -405,7 +405,7 @@ static GnomeCanvasItem *magic_hat_create_item()
 // Display a 'end of game' animation
 static void finished() {
 
-  board_finished(BOARD_FINISHED_RANDOM);
+  gc_bonus_end_display(BOARD_FINISHED_RANDOM);
   timer_id = 0;
 }
 
@@ -496,9 +496,9 @@ static void draw_hat(int type) {
   GdkPixbuf *image;
 
   if (type == STARS)
-	image = gcompris_load_pixmap("magic_hat/hat.png");
+	image = gc_pixmap_load("magic_hat/hat.png");
   else
-	image = gcompris_load_pixmap("magic_hat/hat-point.png");
+	image = gc_pixmap_load("magic_hat/hat-point.png");
 
   hat = gnome_canvas_item_new (boardRootItem,
 		gnome_canvas_pixbuf_get_type(),
@@ -516,7 +516,7 @@ static void draw_hat(int type) {
 
   if (type == STARS) {
 	 hat_event_id = gtk_signal_connect(GTK_OBJECT(hat), "event", (GtkSignalFunc) hat_event, NULL);
-	 gtk_signal_connect(GTK_OBJECT(hat), "event", (GtkSignalFunc) gcompris_item_event_focus, NULL);
+	 gtk_signal_connect(GTK_OBJECT(hat), "event", (GtkSignalFunc) gc_item_focus_event, NULL);
   }
 }
 
@@ -537,11 +537,11 @@ static void place_item(frame * my_frame, int type) {
   double x, y;
 
   GdkPixbuf *image_name[MAX_LIST];
-  GdkPixbuf *image_star_clear = gcompris_load_pixmap("magic_hat/star-clear.png");
+  GdkPixbuf *image_star_clear = gc_pixmap_load("magic_hat/star-clear.png");
 
-  image_name[0] = gcompris_load_pixmap("magic_hat/star1.png");
-  image_name[1] = gcompris_load_pixmap("magic_hat/star2.png");
-  image_name[2] = gcompris_load_pixmap("magic_hat/star3.png");
+  image_name[0] = gc_pixmap_load("magic_hat/star1.png");
+  image_name[1] = gc_pixmap_load("magic_hat/star2.png");
+  image_name[2] = gc_pixmap_load("magic_hat/star3.png");
 
   x = my_frame->coord_x;
   y = my_frame->coord_y;
@@ -605,7 +605,6 @@ static void place_item(frame * my_frame, int type) {
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 
 	int index = GPOINTER_TO_INT(data);
-	GdkPixbuf *pixmap;
 
 	if (board_paused)
 		return FALSE;
@@ -616,34 +615,36 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 	if ((event->type == GDK_BUTTON_PRESS) && (event->button.button == 1)) {
 
 		if (frame_player.array_star_type[index / MAX_ITEM][index % MAX_ITEM] >= 0) {
+		  GdkPixbuf *pixmap;
 			
-			// Desactivate the star
-			frame_player.nb_stars[index / MAX_ITEM]--;
-			frame_player.array_star_type[index / MAX_ITEM][index % MAX_ITEM] = -1;
+		  // Desactivate the star
+		  frame_player.nb_stars[index / MAX_ITEM]--;
+		  frame_player.array_star_type[index / MAX_ITEM][index % MAX_ITEM] = -1;
 
-			pixmap = gcompris_load_pixmap("magic_hat/star-clear.png");
+		  pixmap = gc_pixmap_load("magic_hat/star-clear.png");
 
-			gnome_canvas_item_set(item, "pixbuf", pixmap, NULL);
+		  gnome_canvas_item_set(item, "pixbuf", pixmap, NULL);
 
-			gdk_pixbuf_unref(pixmap);
+		  gdk_pixbuf_unref(pixmap);
 
 		} else {
+		  GdkPixbuf *pixmap = NULL;
 
-			// Activate the star
-			frame_player.nb_stars[index / MAX_ITEM]++;
-			frame_player.array_star_type[index / MAX_ITEM][index % MAX_ITEM] = index / MAX_ITEM;
+		  // Activate the star
+		  frame_player.nb_stars[index / MAX_ITEM]++;
+		  frame_player.array_star_type[index / MAX_ITEM][index % MAX_ITEM] = index / MAX_ITEM;
 
-			switch(index / MAX_ITEM)
-			  {
-			  case 0: pixmap = gcompris_load_pixmap("magic_hat/star1.png"); break;
-			  case 1: pixmap = gcompris_load_pixmap("magic_hat/star2.png"); break;
-			  case 2: pixmap = gcompris_load_pixmap("magic_hat/star3.png"); break;
-			  }
-			gnome_canvas_item_set(item, "pixbuf", pixmap, NULL);
+		  switch(index / MAX_ITEM)
+		    {
+		    case 0: pixmap = gc_pixmap_load("magic_hat/star1.png"); break;
+		    case 1: pixmap = gc_pixmap_load("magic_hat/star2.png"); break;
+		    case 2: pixmap = gc_pixmap_load("magic_hat/star3.png"); break;
+		    }
+		  gnome_canvas_item_set(item, "pixbuf", pixmap, NULL);
 
-			gdk_pixbuf_unref(pixmap);
+		  gdk_pixbuf_unref(pixmap);
 		}
-		gcompris_play_ogg ("gobble", NULL);
+		gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 	}
 	
 	return FALSE;
@@ -665,7 +666,7 @@ static gint hat_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 		gtk_signal_disconnect(GTK_OBJECT(hat), hat_event_id);
 
 		// 'open' the hat
-		item_rotate_with_center(hat, -20.0, 0, MH_HAT_HEIGHT);
+		gc_item_rotate_with_center(hat, -20.0, 0, MH_HAT_HEIGHT);
 
 		// Make the items move from/out the hat, depending on the mode
 		// Wait a few seconds between the two frames
