@@ -1,9 +1,9 @@
 /* gcompris - memory.c
  *
- * Time-stamp: <2006/03/31 22:46:09 yves>
+ * Time-stamp: <2006/08/21 23:33:28 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
- * 
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -19,7 +19,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-// FIXME: Cleanup of MemoryItem created struct is not done 
+// FIXME: Cleanup of MemoryItem created struct is not done
 
 #include <errno.h>
 #include <string.h>
@@ -31,7 +31,7 @@
 #define MAX_MEMORY_WIDTH  7
 #define MAX_MEMORY_HEIGHT 6
 
-//#define TEXT_FONT gcompris_skin_font_board_huge_bold
+//#define TEXT_FONT gc_skin_font_board_huge_bold
 #define TEXT_FONT "Serif bold 28"
 
 static gchar *op_fonts[10] =
@@ -276,8 +276,7 @@ static gchar *soundList[] =
 
 #define NUMBER_OF_SOUNDS G_N_ELEMENTS(soundList)
 
-
-
+static SoundPolicy sound_policy;
 
 /* Description of this plugin */
 static BoardPlugin menu_bp =
@@ -613,13 +612,13 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
       break;
     }
 
-  } while (skip || ((j < max_token ) 
+  } while (skip || ((j < max_token )
 	   && (passed_token && result && g_list_find_custom(passed_token, result, (GCompareFunc)strcmp))));
 
   g_assert (j < max_token);
-	 
+
   passed_token = g_list_append( passed_token, result);
-  
+
   *returned_type = type;
 
   *string = result;
@@ -679,7 +678,7 @@ static void pause_board (gboolean pause)
 	}
       }
     }
-    
+
   }
 }
 /*
@@ -693,10 +692,10 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
       /* Default mode */
-      
+
       if(!gcomprisBoard->mode){
 	currentMode=MODE_NORMAL;
 	currentUiMode=UIMODE_NORMAL;
@@ -809,49 +808,63 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	  }
 	}
       }
-    
+
 
       if (currentUiMode == UIMODE_SOUND)
 	{
-	  gcompris_pause_sound();
-	  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/gcompris_band.png");
+	  GcomprisProperties	*properties = gc_prop_get();
+
+	  gc_sound_pause();
+
+	  /* initial state to restore */
+	  sound_policy = gc_sound_policy_get();
+
+	  gc_sound_policy_set(PLAY_AND_INTERRUPT);
+
+	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/gcompris_band.png");
 	  base_x1 = BASE_SOUND_X1;
 	  base_y1 = BASE_SOUND_Y1;
 	  base_x2 = BASE_SOUND_X2;
 	  base_y2 = BASE_SOUND_Y2;
 	  base_x1_tux = BASE_SOUND_X1_TUX;
+
+	  if(!properties->fx) {
+	    gc_dialog(_("Error: this activity cannot be played with the\nsound effects disabled.\nGo to the configuration dialog to\nenable the sound"), gc_board_stop);
+	    return;
+	  }
+
 	}
       else
 	{
-	  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
+	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
 	  base_x1 = BASE_CARD_X1;
 	  base_y1 = BASE_CARD_Y1;
 	  base_x2 = BASE_CARD_X2;
 	  base_y2 = BASE_CARD_Y2;
 	  base_x1_tux = BASE_CARD_X1_TUX;
 	}
-      
-      
+
+
       /* TRANSLATORS: Put here the numbers in your language */
       numbers=_("0123456789");
-      assert(g_utf8_validate(numbers,-1,NULL)); // require by all utf8-functions
-      
+      g_assert(g_utf8_validate(numbers,-1,NULL)); // require by all utf8-functions
+
       /* TRANSLATORS: Put here the alphabet lowercase in your language */
       alphabet_lowercase=_("abcdefghijklmnopqrstuvwxyz");
-      assert(g_utf8_validate(alphabet_lowercase,-1,NULL)); // require by all utf8-functions
-      
+      g_assert(g_utf8_validate(alphabet_lowercase,-1,NULL)); // require by all utf8-functions
+
       g_warning("Using lowercase %s", alphabet_lowercase);
-      
+
       /* TRANSLATORS: Put here the alphabet uppercase in your language */
       alphabet_uppercase=_("ABCDEFGHIJKLMNOPQRSTUVWXYZ");
-      assert(g_utf8_validate(alphabet_uppercase,-1,NULL)); // require by all utf8-functions
+      g_assert(g_utf8_validate(alphabet_uppercase,-1,NULL)); // require by all utf8-functions
       g_warning("Using uppercase %s", alphabet_uppercase);
-      
+
       /* TRANSLATORS: Put here the mathematical operators "+-" for  your language. */
       operators=_("+-×÷");
       g_assert(g_utf8_validate(operators,-1,NULL)); // require by all utf8-functions
       g_warning("Using operators %s", operators);
-      
+
       op_add = g_malloc0(2*sizeof(gunichar));
       g_utf8_strncpy(op_add, g_utf8_offset_to_pointer (operators,0),1);
 
@@ -872,25 +885,27 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	tux_memory_size = tux_memory_sizes[gcomprisBoard->level];
 	tux_memory = g_queue_new ();
       }
-      
+
       Paused = FALSE;
-      
+
       to_tux = FALSE;
       if (currentUiMode == UIMODE_SOUND){
 	playing_sound = TRUE;
-	gcompris_play_ogg_cb("sounds/LuneRouge/musique/LRBuddhist_gong_05_by_Lionel_Allorge.ogg",start_callback);
+	gc_sound_play_ogg_cb("sounds/LuneRouge/musique/LRBuddhist_gong_05_by_Lionel_Allorge.ogg",start_callback);
       } else
 	playing_sound = FALSE;
-      
+
       memory_next_level();
-    }      
+    }
 }
 
 static void
 end_board ()
 {
-  if (currentUiMode == UIMODE_SOUND)
-    gcompris_resume_sound();
+  if (currentUiMode == UIMODE_SOUND) {
+    gc_sound_policy_set(sound_policy);
+    gc_sound_resume();
+  }
 
   if(gcomprisBoard!=NULL)
     {
@@ -902,6 +917,11 @@ end_board ()
 	tux_memory = NULL;
       }
     }
+  g_free(op_add);
+  g_free(op_minus);
+  g_free(op_mult);
+  g_free(op_div);
+  
   gcomprisBoard = NULL;
 }
 
@@ -956,10 +976,10 @@ static void update_scores()
 }
 
 /* set initial values for the next level */
-static void memory_next_level() 
+static void memory_next_level()
 {
-  gcompris_bar_set_level(gcomprisBoard);
-  
+  gc_bar_set_level(gcomprisBoard);
+
   memory_destroy_all_items();
 
   boardRootItem = GNOME_CANVAS_GROUP(
@@ -1023,29 +1043,29 @@ static void memory_destroy_all_items()
 	if (memoryArray[x][y])
 	  g_free(memoryArray[x][y]->second_value);
 	g_free(memoryArray[x][y]);
-	memoryArray[x][y] = NULL;	
+	memoryArray[x][y] = NULL;
       }
 
   GList *list;
 
   for (list = passed_token; list != NULL; list=list->next)
     g_free(list->data);
-  
+
   g_list_free(passed_token);
-  
+
   passed_token = NULL;
-    
+
   if (currentMode == MODE_TUX){
     for (list = winning_pairs; list != NULL; list=list->next)
       g_free(list->data);
-    
+
     g_list_free(winning_pairs);
-    
+
     winning_pairs = NULL;
     while (g_queue_pop_head (tux_memory));
     //tux_memory = NULL;
   }
-  
+
 }
 
 /*
@@ -1097,19 +1117,19 @@ static void get_image(MemoryItem *memoryItem, guint x, guint y)
       get_random_token ( TYPE_IMAGE, &memoryItem->type,  &memoryItem->data, NULL);
       g_assert (memoryItem->type ==  TYPE_IMAGE);
       break;
-      
+
     case 5:
       /* Limited Text mode Numbers only */
       get_random_token ( TYPE_NUMBER, &memoryItem->type,  &memoryItem->data, NULL);
       g_assert (memoryItem->type ==  TYPE_NUMBER);
       break;
-      
+
     case 6:
       /* Limited Text mode Numbers + Capitals */
       get_random_token ( TYPE_NUMBER | TYPE_UPPERCASE, &memoryItem->type,  &memoryItem->data, NULL);
       g_assert((memoryItem->type == TYPE_NUMBER)||(memoryItem->type==TYPE_UPPERCASE));
       break;
-      
+
     default:
       /* Text mode ALL */
       get_random_token ( TYPE_NUMBER | TYPE_UPPERCASE | TYPE_LOWERCASE, &memoryItem->type,  &memoryItem->data, NULL);
@@ -1145,7 +1165,7 @@ static void get_image(MemoryItem *memoryItem, guint x, guint y)
     get_random_token ( TYPE_ADD | TYPE_MINUS |TYPE_MULT | TYPE_DIV , &memoryItem->type,  &memoryItem->data, &memoryItem->second_value);
     g_assert (memoryItem->type & (TYPE_ADD | TYPE_MINUS |TYPE_MULT | TYPE_DIV));
     break;
-    
+
   default:
     g_error("Don't now in what mode run !");
     break;
@@ -1157,7 +1177,7 @@ static void get_image(MemoryItem *memoryItem, guint x, guint y)
   // Randomly set the pair
   rx = (int)(numberOfColumn*((double)rand()/RAND_MAX));
   ry = (int)(numberOfLine*((double)rand()/RAND_MAX));
-	
+
   while(memoryArray[rx][ry])
     {
       rx++;
@@ -1195,10 +1215,10 @@ static void create_item(GnomeCanvasGroup *parent)
 
 
   if (currentUiMode == UIMODE_SOUND) {
-    GdkPixbuf *pixmap =  gcompris_load_pixmap("images/transparent_square2.png");
+    GdkPixbuf *pixmap =  gc_pixmap_load("images/transparent_square2.png");
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", pixmap, 
+			   "pixbuf", pixmap,
 			   "x", (double) (currentMode == MODE_TUX ? base_x1_tux : base_x1) - 20,
 			   "y", (double) base_y1 - 15,
 			   NULL);
@@ -1206,18 +1226,19 @@ static void create_item(GnomeCanvasGroup *parent)
   }
 
   if (currentMode == MODE_TUX){
-    GdkPixbuf *pixmap_tux =  gcompris_load_pixmap("images/tux-teacher.png");
+    GdkPixbuf *pixmap_tux =  gc_pixmap_load("images/tux-teacher.png");
 
     tux = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				 gnome_canvas_pixbuf_get_type (),
-				 "pixbuf", pixmap_tux, 
+				 "pixbuf", pixmap_tux,
 				 "x", (double) 50,
 				 "y", (double) 20,
 				 NULL);
+    gdk_pixbuf_unref(pixmap_tux);
     
     tux_score_s = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				       gnome_canvas_text_get_type (),
-				       "font", gcompris_skin_font_board_huge_bold,
+				       "font", gc_skin_font_board_huge_bold,
 				       "x", (double) 100+1.0,
 				       "y", (double) 200+1.0,
 				       "anchor", GTK_ANCHOR_CENTER,
@@ -1226,7 +1247,7 @@ static void create_item(GnomeCanvasGroup *parent)
 
     player_score_s = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 					  gnome_canvas_text_get_type (),
-					  "font", gcompris_skin_font_board_huge_bold,
+					  "font", gc_skin_font_board_huge_bold,
 					  "x", (double) 100+1.0,
 					  "y", (double) BASE_CARD_Y2 - 20+1.0,
 					  "anchor", GTK_ANCHOR_CENTER,
@@ -1235,7 +1256,7 @@ static void create_item(GnomeCanvasGroup *parent)
 
     tux_score = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				       gnome_canvas_text_get_type (),
-				       "font", gcompris_skin_font_board_huge_bold,
+				       "font", gc_skin_font_board_huge_bold,
 				       "x", (double) 100,
 				       "y", (double) 200,
 				       "anchor", GTK_ANCHOR_CENTER,
@@ -1244,7 +1265,7 @@ static void create_item(GnomeCanvasGroup *parent)
 
     player_score = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 					  gnome_canvas_text_get_type (),
-					  "font", gcompris_skin_font_board_huge_bold,
+					  "font", gc_skin_font_board_huge_bold,
 					  "x", (double) 100,
 					  "y", (double) BASE_CARD_Y2 - 20,
 					  "anchor", GTK_ANCHOR_CENTER,
@@ -1258,7 +1279,7 @@ static void create_item(GnomeCanvasGroup *parent)
 	{
 
 	  memoryItem = g_malloc0(sizeof(MemoryItem));
-	  
+
 	  memoryItem->rootItem = \
 	    gnome_canvas_item_new (parent,
 				   gnome_canvas_group_get_type (),
@@ -1267,73 +1288,73 @@ static void create_item(GnomeCanvasGroup *parent)
 				   NULL);
 
 	  if (currentUiMode == UIMODE_SOUND)
-	    pixmap = gcompris_load_pixmap("gcompris/misc/Tux_mute.png");
+	    pixmap = gc_pixmap_load("gcompris/misc/Tux_mute.png");
 	  else
-	    pixmap = gcompris_load_pixmap("gcompris/misc/backcard.png");
+	    pixmap = gc_pixmap_load("gcompris/misc/backcard.png");
 
 	  memoryItem->backcardItem = \
 	    gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				   gnome_canvas_pixbuf_get_type (),
-				   "pixbuf", pixmap, 
+				   "pixbuf", pixmap,
 				   "x", (double) 0,
 				   "y", (double) 0,
 				   "width", (double) width2,
 				   "height", (double) height2,
-				   "width_set", TRUE, 
+				   "width_set", TRUE,
 				   "height_set", TRUE,
 				   NULL);
 	  gdk_pixbuf_unref(pixmap);
 
 	  if (currentUiMode != UIMODE_SOUND){
-	    pixmap = gcompris_load_pixmap("gcompris/misc/emptycard.png");
+	    pixmap = gc_pixmap_load("gcompris/misc/emptycard.png");
 	    memoryItem->framecardItem = \
 	      gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
+				     "pixbuf", pixmap,
 				     "x", (double) 0,
 				     "y", (double) 0,
 				     "width", (double) width2,
 				     "height", (double) height2,
-				     "width_set", TRUE, 
+				     "width_set", TRUE,
 				     "height_set", TRUE,
 				     NULL);
 	    gnome_canvas_item_hide(memoryItem->framecardItem);
 	    gdk_pixbuf_unref(pixmap);
 	  }
-  
+
 
 	  // Display the image itself while taking care of its size and maximize the ratio
 	  get_image(memoryItem, x, y);
 
 	  if (currentUiMode == UIMODE_SOUND){
-	    pixmap = gcompris_load_pixmap("gcompris/misc/Tux_play.png");
+	    pixmap = gc_pixmap_load("gcompris/misc/Tux_play.png");
 	    memoryItem->frontcardItem =	\
 	      gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
+				     "pixbuf", pixmap,
 				     "x", (double) 0,
 				     "y", (double) 0,
 				     "width", (double) width2,
 				     "height", (double) height2,
-				     "width_set", TRUE, 
+				     "width_set", TRUE,
 				     "height_set", TRUE,
 				     NULL);
 	    gdk_pixbuf_unref(pixmap);
 	  }
 	  else {
 	    if(memoryItem->type == TYPE_IMAGE) {
-	      pixmap = gcompris_load_pixmap(memoryItem->data);
-	      
+	      pixmap = gc_pixmap_load(memoryItem->data);
+
 	      yratio=(height2*0.8)/(float)gdk_pixbuf_get_height(pixmap);
 	      xratio=(width2*0.8)/(float)gdk_pixbuf_get_width(pixmap);
 	      yratio=xratio=MIN(xratio, yratio);
 	      card_shadow_w = width*0.05;
 	      card_shadow_h = height*0.05;
-	      
+
 	      memoryItem->frontcardItem =	\
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				       gnome_canvas_pixbuf_get_type (),
-				       "pixbuf", pixmap, 
+				       "pixbuf", pixmap,
 				       "x", (double) ((width2)-
 						      gdk_pixbuf_get_width(pixmap)*xratio*0.8)/2 -
 				       card_shadow_w,
@@ -1342,11 +1363,11 @@ static void create_item(GnomeCanvasGroup *parent)
 				       card_shadow_h,
 				       "width", (double) gdk_pixbuf_get_width(pixmap)*xratio*0.8,
 				       "height", (double) gdk_pixbuf_get_height(pixmap)*yratio*0.8,
-				       "width_set", TRUE, 
+				       "width_set", TRUE,
 				       "height_set", TRUE,
 				       NULL);
 	      gdk_pixbuf_unref(pixmap);
-	      
+
 	    } else {
 	      gchar *font;
 	      if (memoryItem->type & (TYPE_ADD|TYPE_MINUS|TYPE_MULT|TYPE_DIV))
@@ -1364,7 +1385,7 @@ static void create_item(GnomeCanvasGroup *parent)
 				       "anchor", GTK_ANCHOR_CENTER,
 				       "fill_color_rgba", 0x559ADDFF,
 				       NULL);
-	      
+
 	    }
 	  }
 
@@ -1381,15 +1402,15 @@ static void create_item(GnomeCanvasGroup *parent)
 
 static void player_win()
 {
-  gcompris_play_ogg ("bonus", NULL);
+  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   /* Try the next level */
   if (tux_pairs <= player_pairs)
     gcomprisBoard->level++;
   if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-    board_finished(BOARD_FINISHED_RANDOM);
+    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
     return;
   }
-  gcompris_display_bonus((tux_pairs <= player_pairs), BONUS_RANDOM);
+  gc_bonus_display((tux_pairs <= player_pairs), BONUS_RANDOM);
 
 }
 
@@ -1404,7 +1425,7 @@ static void display_card(MemoryItem *memoryItem, CardStatus cardStatus)
 	gnome_canvas_item_hide(memoryItem->backcardItem);
 	gnome_canvas_item_show(memoryItem->frontcardItem);
 	playing_sound = TRUE;
-	gcompris_play_ogg_cb (memoryItem->data, sound_callback);
+	gc_sound_play_ogg_cb (memoryItem->data, sound_callback);
 	break;
       case ON_BACK:
 	gnome_canvas_item_show(memoryItem->backcardItem);
@@ -1456,7 +1477,7 @@ static gint hide_card (GtkWidget *widget, gpointer data)
       if ((((WINNING *) list->data)->first == firstCard) || (((WINNING *) list->data)->first == secondCard) || (((WINNING *) list->data)->second == firstCard) || (((WINNING *) list->data)->second == secondCard) ){
 	to_remove = g_list_append( to_remove, list->data);
       }
-  
+
     for (list =  to_remove; list != NULL; list=list->next){
       void *data = list->data;
       winning_pairs = g_list_remove (winning_pairs, list->data);
@@ -1522,12 +1543,12 @@ static void check_win()
 
   // Check win
   if (compare_card((gpointer) firstCard, (gpointer) secondCard) == 0) {
-    gcompris_play_ogg ("gobble", NULL);
+    gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
     win_id = g_timeout_add (timeout,
 			    (GSourceFunc) hide_card, NULL);
     return;
   }
-  
+
   if (currentMode == MODE_TUX){
 		 /* time to tux to play, after a delay */
     to_tux = TRUE;
@@ -1536,7 +1557,7 @@ static void check_win()
 			    (GSourceFunc) tux_play, NULL);
     return;
   }
-  
+
 }
 
 static gint
@@ -1546,10 +1567,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
   if(!gcomprisBoard)
     return FALSE;
 
-   switch (event->type) 
+   switch (event->type)
      {
      case GDK_BUTTON_PRESS:
-       switch(event->button.button) 
+       switch(event->button.button)
          {
          case 1:
 
@@ -1562,7 +1583,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
 
 	   if (playing_sound){
 	     g_warning("wait a minute, the sound is playing !");
-	     return FALSE;
+	     //return FALSE;
 	   }
 
 	   if(win_id)
@@ -1573,7 +1594,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
 	       display_card(firstCard, ON_BACK);
 	       firstCard = NULL;
 	       display_card(secondCard, ON_BACK);
-	       secondCard = NULL;	       
+	       secondCard = NULL;
 	     }
 
 	   if(!firstCard)
@@ -1601,12 +1622,12 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
 		 check_win();
 		 return TRUE;
 	       }
-	     
+
 	     }
 	   break;
 	 default:
 	   break;
-	 }	   
+	 }
      default:
        break;
      }
@@ -1694,7 +1715,7 @@ static gint tux_play(){
       display_card(firstCard, ON_BACK);
       firstCard = NULL;
       display_card(secondCard, ON_BACK);
-      secondCard = NULL;	       
+      secondCard = NULL;
     }
 
   if (winning_pairs){
@@ -1714,7 +1735,7 @@ static gint tux_play(){
       if (currentUiMode == UIMODE_SOUND)
 	return FALSE;
       else {
-	gcompris_play_ogg ("gobble", NULL);
+	gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 	win_id = g_timeout_add (1000,
 				(GSourceFunc) hide_card, NULL);
 	return TRUE;
@@ -1725,13 +1746,13 @@ static gint tux_play(){
   // Randomly set the pair
   rx = (int)(numberOfColumn*((double)rand()/RAND_MAX));
   ry = (int)(numberOfLine*((double)rand()/RAND_MAX));
-  
-  gboolean  stay_unknown = (remainingCards > (g_queue_get_length (tux_memory) 
+
+  gboolean  stay_unknown = (remainingCards > (g_queue_get_length (tux_memory)
 					      + (firstCard ? 1 : 0)));
 
-  g_warning("remainingCards %d tux_memory %d -> stay_unknown %d ", 
-	    remainingCards, 
-	    g_queue_get_length (tux_memory), 
+  g_warning("remainingCards %d tux_memory %d -> stay_unknown %d ",
+	    remainingCards,
+	    g_queue_get_length (tux_memory),
 	    stay_unknown );
 
   while((memoryArray[rx][ry]->hidden) || (memoryArray[rx][ry] == firstCard)
@@ -1748,7 +1769,7 @@ static gint tux_play(){
 	    ry=0;
 	}
     }
-  
+
   if (!firstCard){
     g_warning("case 3");
     firstCard = memoryArray[rx][ry];
@@ -1768,7 +1789,7 @@ static gint tux_play(){
       return FALSE;
     else {
       if (compare_card(firstCard, secondCard)==0){
-	gcompris_play_ogg ("gobble", NULL);
+	gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 	g_warning("Now tux win !");
 	win_id = g_timeout_add (1000,
 				(GSourceFunc) hide_card, NULL);
@@ -1794,7 +1815,7 @@ static void sound_callback(gchar *file)
     if (to_tux) {
       if (firstCard && secondCard){
 	if (compare_card(firstCard, secondCard)==0){
-	  gcompris_play_ogg ("gobble", NULL);
+	  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 	  win_id = g_timeout_add (1000,
 				  (GSourceFunc) hide_card, NULL);
 	  tux_id = g_timeout_add (2000,
@@ -1826,12 +1847,3 @@ static void start_callback(gchar *file){
 
   playing_sound = FALSE;
 }
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
