@@ -1,6 +1,6 @@
 /* gcompris - menu2.c
  *
- * Time-stamp: <2006/03/30 01:06:42 bruno>
+ * Time-stamp: <2006/08/21 23:34:21 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -24,6 +24,8 @@
  *
  * Seen from gcompris, the menu is a board like another.
  */
+#include <string.h>
+
 #include "gcompris/gcompris.h"
 #include "gcompris/gcompris_config.h"
 
@@ -45,6 +47,9 @@ static MenuItems *menuitems;
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
 
+/* We don't wan't the callback on boards to be accepted until the menu is fully displayed */
+static gboolean menu_displayed = FALSE;
+
 static void		 menu_start (GcomprisBoard *agcomprisBoard);
 static void		 menu_pause (gboolean pause);
 static void		 menu_end (void);
@@ -86,11 +91,9 @@ static double icon_size, icon_size_panel, icon_size_top, top_arrow_size;
 
 static gdouble get_ratio(GdkPixbuf *pixmap, gdouble size);
 
-GList *homeBoards = NULL;
-
-#define P_X 10
+#define P_X 0
 #define P_Y 10
-#define P_W 90
+#define P_W 80
 #define P_H 480
 
 #define T_X 175
@@ -172,7 +175,7 @@ static void menu_pause (gboolean pause)
 static void menu_start (GcomprisBoard *agcomprisBoard)
 {
 
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   current_x = 0.0;
   current_y = 0.0;
@@ -218,8 +221,8 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
 
       menuitems = g_new(MenuItems, 1);
 
-      img = gcompris_image_to_skin("gcompris-menu2bg.png");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
+      img = gc_skin_image_get("gcompris-menu2bg.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      img);
       g_free(img);
 
@@ -248,7 +251,7 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel=1;
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_ABOUT);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_ABOUT);
 
       /* FIXME : Workaround for bugged canvas */
       //gnome_canvas_update_now(gcomprisBoard->canvas);
@@ -271,12 +274,12 @@ static void create_panel(GnomeCanvasGroup *parent)
 
   gdouble x, y;
   gint int_y;
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   /* In normal mode, we show all the sections in panel */
   /* in direct submenu access, we show the icon of the submenu */
   if (strcmp(properties->root_menu,"/")==0)
-    panelBoards = gcompris_get_menulist(properties->root_menu);
+    panelBoards = gc_menu_getlist(properties->root_menu);
   else
     panelBoards = g_list_append(list, gcomprisBoard);
 
@@ -299,10 +302,10 @@ static void create_panel(GnomeCanvasGroup *parent)
   for (list = panelBoards; list != NULL; list = list->next){
     board = (GcomprisBoard *) list->data;
 
-    pixmap = gcompris_load_pixmap(board->icon_name);
+    pixmap = gc_pixmap_load(board->icon_name);
 
     ratio = get_ratio( pixmap, icon_size_panel);
-     
+
     item = gnome_canvas_item_new (parent,
 				  gnome_canvas_pixbuf_get_type (),
 				  "pixbuf", pixmap,
@@ -312,7 +315,7 @@ static void create_panel(GnomeCanvasGroup *parent)
 				  "height", (gdouble) gdk_pixbuf_get_height(pixmap)*ratio,
 				  "width-set", TRUE,
 				  "height-set", TRUE,
-				  "anchor", GTK_ANCHOR_NORTH,
+				  "anchor", GTK_ANCHOR_NW,
 				  NULL);
 
     gdk_pixbuf_unref(pixmap);
@@ -324,14 +327,14 @@ static void create_panel(GnomeCanvasGroup *parent)
     gtk_signal_connect(GTK_OBJECT(item), "event",
 		       (GtkSignalFunc) item_event,
 		       menuitems);
-    
+
     gtk_signal_connect(GTK_OBJECT(item), "event",
-		       (GtkSignalFunc) gcompris_item_event_focus,
+		       (GtkSignalFunc) gc_item_focus_event,
 		       NULL);
-   
+
   }
 
-  
+
 
 }
 
@@ -339,7 +342,9 @@ static void display_section (gchar *path)
 {
       GList		*boardlist;	/* List of Board */
 
-      boardlist = gcompris_get_menulist(path);
+      menu_displayed = FALSE;
+
+      boardlist = gc_menu_getlist(path);
 
       if (actualSectionItem)
 	gtk_object_destroy (GTK_OBJECT(actualSectionItem));
@@ -355,7 +360,7 @@ static void display_section (gchar *path)
 								"x", (double) 0,
 								"y", (double) 0,
 								NULL));
-       
+
 
       create_top (actualSectionItem, path);
 
@@ -364,6 +369,7 @@ static void display_section (gchar *path)
       if (strcmp(path,"home")!=0)
 	g_list_free(boardlist);
 
+      menu_displayed = TRUE;
 }
 
 static void
@@ -383,6 +389,9 @@ menu_end ()
 
   boardRootItem     = NULL;
   actualSectionItem = NULL;
+
+  g_list_free(panelBoards);
+
 }
 
 static gboolean
@@ -407,7 +416,7 @@ menu_config ()
   if(gcomprisBoard!=NULL)
     {
       menu_pause(TRUE);
-      gcompris_config_start();
+      gc_config_start();
     }
 }
 
@@ -421,8 +430,8 @@ menu_config ()
 static void display_board_icon(GcomprisBoard *board, MenuItems *menuitems)
 {
   /* FIXME: Check board is available for the current profile */
-  if (board!=NULL 
-      && board_check_file(board))
+  if (board!=NULL
+      && gc_board_check_file(board))
     {
       menu_create_item(actualSectionItem, menuitems, board);
     }
@@ -432,7 +441,7 @@ static void display_board_icon(GcomprisBoard *board, MenuItems *menuitems)
  * Calculate the next stop where to place an item
  * return false if there is no more space left
  */
-static gboolean next_spot() 
+static gboolean next_spot()
 {
   if(current_x==0.0)
     {
@@ -449,12 +458,12 @@ static gboolean next_spot()
       current_x =  display_x + icon_size/2.0;
       current_y += icon_size + display_int_y;
     }
-  
+
   if ( current_y > display_y + display_h - icon_size/2.0 )
     return FALSE;
   else
     return TRUE;
-  
+
 }
 
 static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, GcomprisBoard *board)
@@ -469,12 +478,12 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
   /*
    * Take care to load the board->icon_name from the dir specified
    * in the board->board_dir
-   * To make it simple and reuse the gcompris_load_pixmap, we overwrite temporarily
+   * To make it simple and reuse the gc_pixmap_load, we overwrite temporarily
    * the gcomprisBoard->board_dir and board->board_dir
    */
   tmp_board_dir = gcomprisBoard->board_dir;
   gcomprisBoard->board_dir = board->board_dir;
-  menu_pixmap = gcompris_load_pixmap(board->icon_name);
+  menu_pixmap = gc_pixmap_load(board->icon_name);
   gcomprisBoard->board_dir = tmp_board_dir;
 
   ratio = get_ratio (menu_pixmap, icon_size);
@@ -501,7 +510,7 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
   // display difficulty stars
   if (board->difficulty != NULL) {
     difficulty = atoi(board->difficulty);
-    gcompris_display_difficulty_stars(parent,
+    gc_difficulty_display(parent,
 				      (double)current_x - pixmap_w/2 - 25,
 				      (double)current_y - pixmap_h/2,
 				      (double) 0.6,
@@ -512,28 +521,18 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
   if(board->mandatory_sound_file)
     {
       gchar *soundfile = NULL;
-      gchar *soundfilename = NULL;
 
-      if(board->mandatory_sound_dataset) {
-	/* We have to search for an assetml sound */
-	soundfile = gcompris_get_asset_file(board->mandatory_sound_dataset, NULL, NULL, 
-					    board->mandatory_sound_file);
-      } else {
-	/* We search a fixed path sound file */
-	soundfilename = g_strdup_printf("%s/%s", "sounds", 
-				    board->mandatory_sound_file);
-	soundfile = gcompris_find_absolute_filename(soundfilename);
-	g_free(soundfilename);
-	g_warning("Checking mandatory_sound_file %s\n", soundfile);
-      }
+      /* We search a fixed path sound file */
+      soundfile = gc_file_find_absolute(board->mandatory_sound_file);
+      g_warning("Checking mandatory_sound_file %s\n", soundfile);
 
-      if (!g_file_test (soundfile, G_FILE_TEST_EXISTS) || !gcompris_get_properties()->audio_works) 
+      if (!soundfile || !gc_prop_get()->fx)
 	{
-	  pixmap = gcompris_load_skin_pixmap("voice_bad.png");
+	  pixmap = gc_skin_pixmap_load("voice_bad.png");
 	}
       else
 	{
-	  pixmap = gcompris_load_skin_pixmap("voice.png");
+	  pixmap = gc_skin_pixmap_load("voice.png");
 	}
 
       gnome_canvas_item_new (parent,
@@ -549,7 +548,7 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
   // display menu icon ========================== BEGIN
   if(g_strcasecmp(board->type, "menu")==0)
     {
-      pixmap = gcompris_load_skin_pixmap("menuicon.png");
+      pixmap = gc_skin_pixmap_load("menuicon.png");
       item =  gnome_canvas_item_new (parent,
 				     gnome_canvas_pixbuf_get_type (),
 				     "pixbuf", pixmap,
@@ -572,9 +571,9 @@ static void menu_create_item(GnomeCanvasGroup *parent, MenuItems *menuitems, Gco
   gtk_signal_connect(GTK_OBJECT(menu_button), "event",
 		     (GtkSignalFunc) item_event,
 		     menuitems);
-  
+
   gtk_signal_connect(GTK_OBJECT(menu_button), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 }
@@ -583,8 +582,6 @@ static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event,  MenuItems *menuitems)
 {
   GcomprisBoard *board;
-  GdkPixbuf *pixmap;
-      
 
   if(board_paused)
     return FALSE;
@@ -602,7 +599,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event,  MenuItems *menuitems)
 			       "text", board->title,
 			       NULL);
 
-      if(board->description 
+      if(board->description
 	 && G_IS_OBJECT(menuitems->description_item)
 	 && G_IS_OBJECT(menuitems->description_item_s))
 	set_content(menuitems->description_item,
@@ -652,42 +649,45 @@ item_event(GnomeCanvasItem *item, GdkEvent *event,  MenuItems *menuitems)
 
       break;
     case GDK_BUTTON_PRESS:
-	gcompris_play_ogg ("gobble", NULL);
-	
-	if (strcmp(board->type,"menu")==0){
-	  gchar *path = g_strdup_printf("%s/%s",board->section, board->name);
-	  GcomprisProperties	*properties = gcompris_get_properties();
+      if(!menu_displayed)
+	return TRUE;
 
-	  display_section(path);
+      gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 
-	  if (properties->menu_position)
-	    g_free(properties->menu_position);
+      if (strcmp(board->type,"menu")==0){
+	gchar *path = g_strdup_printf("%s/%s",board->section, board->name);
+	GcomprisProperties	*properties = gc_prop_get();
+
+	display_section(path);
+
+	if (properties->menu_position)
+	  g_free(properties->menu_position);
+
+	properties->menu_position = path;
+
+      }
+      else
+	gc_board_run_next (board);
 
-	  properties->menu_position = path;
-  
-	}
-	else
-	  board_run_next (board);
-	
       break;
 
     default:
       break;
     }
-  
+
   return FALSE;
 }
 
 /* Apply the style to the given RichText item  */
 static void
-set_content(GnomeCanvasRichText *item_content, 
+set_content(GnomeCanvasRichText *item_content,
 	    GnomeCanvasRichText *item_content_s,
 	    gchar *text) {
 
   GtkTextIter    iter_start, iter_end;
   GtkTextBuffer *buffer;
   GtkTextTag    *txt_tag;
-  gboolean success; 
+  gboolean success;
   gchar *color_string;
   GdkColor *color_s = (GdkColor *)malloc(sizeof(GdkColor));
   GdkColor *color   = (GdkColor *)malloc(sizeof(GdkColor));
@@ -707,41 +707,42 @@ set_content(GnomeCanvasRichText *item_content,
    * Set the shadow
    */
 
-  color_string = g_strdup_printf("#%x", gcompris_skin_color_shadow >> 8);
+  color_string = g_strdup_printf("#%x", gc_skin_color_shadow >> 8);
   gdk_color_parse(color_string, color_s);
-  success = gdk_colormap_alloc_color(gdk_colormap_get_system(), 
+  g_free(color_string);
+  success = gdk_colormap_alloc_color(gdk_colormap_get_system(),
 				     color_s,
-  				     FALSE, TRUE); 
+  				     FALSE, TRUE);
 
   buffer  = gnome_canvas_rich_text_get_buffer(GNOME_CANVAS_RICH_TEXT(item_content_s));
-  txt_tag = gtk_text_buffer_create_tag(buffer, NULL, 
+  txt_tag = gtk_text_buffer_create_tag(buffer, NULL,
 				       "foreground-gdk", color_s,
-				       "font",       gcompris_skin_font_board_medium,
+				       "font",       gc_skin_font_board_medium,
 				       NULL);
   gtk_text_buffer_get_end_iter(buffer, &iter_end);
   gtk_text_buffer_get_start_iter(buffer, &iter_start);
   gtk_text_buffer_apply_tag(buffer, txt_tag, &iter_start, &iter_end);
 
-  g_free(color_string);
-
-  /* 
+  /*
    * Set the text
    */
-  color_string = g_strdup_printf("#%x", gcompris_skin_get_color("menu/text") >> 8);
+  color_string = g_strdup_printf("#%x", gc_skin_get_color("menu/text") >> 8);
   gdk_color_parse(color_string, color);
-  success = gdk_colormap_alloc_color(gdk_colormap_get_system(), 
+  g_free(color_string);
+  success = gdk_colormap_alloc_color(gdk_colormap_get_system(),
 				     color,
-  				     FALSE, TRUE); 
+  				     FALSE, TRUE);
 
   buffer  = gnome_canvas_rich_text_get_buffer(GNOME_CANVAS_RICH_TEXT(item_content));
-  txt_tag = gtk_text_buffer_create_tag(buffer, NULL, 
+  txt_tag = gtk_text_buffer_create_tag(buffer, NULL,
 				       "foreground-gdk", color,
-				       "font",        gcompris_skin_font_board_medium,
+				       "font",        gc_skin_font_board_medium,
 				       NULL);
   gtk_text_buffer_get_end_iter(buffer, &iter_end);
   gtk_text_buffer_get_start_iter(buffer, &iter_start);
   gtk_text_buffer_apply_tag(buffer, txt_tag, &iter_start, &iter_end);
-
+  g_free(color);
+  g_free(color_s);
 }
 
 /** \brief create the area in which we display the board title and description
@@ -759,22 +760,22 @@ static void create_info_area(GnomeCanvasGroup *parent, MenuItems *menuitems)
     gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", " ",
-			   "font", gcompris_skin_font_board_big,
+			   "font", gc_skin_font_board_big,
 			   "x", (double) x + 1.0,
 			   "y", (double) y + 1.0,
 			   "anchor", GTK_ANCHOR_NORTH,
-			   "fill_color_rgba",  gcompris_skin_color_shadow,
+			   "fill_color_rgba",  gc_skin_color_shadow,
 			   NULL);
 
   menuitems->boardname_item = \
     gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", " ",
-			   "font", gcompris_skin_font_board_big,
+			   "font", gc_skin_font_board_big,
 			   "x", (double) x,
 			   "y", (double) y,
 			   "anchor", GTK_ANCHOR_NORTH,
-			   "fill_color_rgba",  gcompris_skin_get_color("menu/text"),
+			   "fill_color_rgba",  gc_skin_get_color("menu/text"),
 			   NULL);
 
   menuitems->description_item_s = \
@@ -810,11 +811,11 @@ static void create_info_area(GnomeCanvasGroup *parent, MenuItems *menuitems)
     gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", " ",
-			   "font", gcompris_skin_font_board_tiny,
+			   "font", gc_skin_font_board_tiny,
 			   "x", (double) x + 1.0,
 			   "y", (double) y + 90 + 1.0,
   			   "anchor", GTK_ANCHOR_NORTH,
-  			   "fill_color_rgba", gcompris_skin_color_shadow,
+  			   "fill_color_rgba", gc_skin_color_shadow,
   			   "justification", GTK_JUSTIFY_CENTER,
 			   NULL);
 
@@ -822,11 +823,11 @@ static void create_info_area(GnomeCanvasGroup *parent, MenuItems *menuitems)
     gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", " ",
-			   "font", gcompris_skin_font_board_tiny,
+			   "font", gc_skin_font_board_tiny,
 			   "x", (double) x,
 			   "y", (double) y + 90,
   			   "anchor", GTK_ANCHOR_NORTH,
-  			   "fill_color_rgba", gcompris_skin_get_color("menu/text"),
+  			   "fill_color_rgba", gc_skin_get_color("menu/text"),
   			   "justification", GTK_JUSTIFY_CENTER,
 			   NULL);
 
@@ -856,7 +857,7 @@ static gdouble get_ratio(GdkPixbuf *pixmap, gdouble size)
       if (pixmap_h > size)
 	ratio = size / pixmap_h;
     }
-  
+
   return ratio;
 
 }
@@ -872,13 +873,13 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 
   GnomeCanvasItem *item;
 
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   if (!path)
     return;
 
   splitted_section = g_strsplit (path, "/", 0);
-  
+
   path1 = g_strdup("");
 
   /* splitted_section[0] is always "" */
@@ -891,7 +892,7 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 
       g_free(path1);
       path1 = path2;
-      
+
       if (strcmp(path1, properties->root_menu)<0){
 	i++;
 	continue;
@@ -901,9 +902,9 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 	current_top_x = top_x;
 	current_top_y = top_y + top_h/2.0;
       } else {
-	pixmap = gcompris_load_skin_pixmap("button_forward.png");
+	pixmap = gc_skin_pixmap_load("button_forward.png");
 	ratio = get_ratio(pixmap, top_arrow_size);
-	
+
 	gnome_canvas_item_new (parent,
 			       gnome_canvas_pixbuf_get_type (),
 			       "pixbuf", pixmap,
@@ -919,15 +920,15 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 	gdk_pixbuf_unref(pixmap);
 
 	current_top_x += top_arrow_size + top_int_x;
-	
-      }
-      
-      board = gcompris_get_board_from_section(path1);
 
-      pixmap = gcompris_load_pixmap(board->icon_name);
+      }
+
+      board = gc_menu_section_get(path1);
+
+      pixmap = gc_pixmap_load(board->icon_name);
 
       ratio = get_ratio( pixmap, icon_size_top);
-     
+
       item = gnome_canvas_item_new (parent,
 				    gnome_canvas_pixbuf_get_type (),
 				    "pixbuf", pixmap,
@@ -941,29 +942,31 @@ static void create_top(GnomeCanvasGroup *parent, gchar *path)
 				    NULL);
 
       gdk_pixbuf_unref(pixmap);
-      
+
       current_top_x += top_int_x + icon_size_top;
-    
+
       g_object_set_data (G_OBJECT (item), "board", board);
-      
+
       gtk_signal_connect(GTK_OBJECT(item), "event",
 			 (GtkSignalFunc) item_event,
 			 menuitems);
-      
+
       gtk_signal_connect(GTK_OBJECT(item), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
- 
-      
+
+
 
       i++;
     }
 
+  g_strfreev(splitted_section);
   g_free(path1);
-  
+
 }
 
-static void              display_welcome (void)
+static void
+display_welcome (void)
 {
   GnomeCanvasItem *logo;
   GdkPixbuf *pixmap;
@@ -980,8 +983,8 @@ static void              display_welcome (void)
 								 "x", (double) 0,
 								 "y", (double) 0,
 								 NULL));
-  
-  pixmap = gcompris_load_skin_pixmap("gcompris-about.png");
+
+  pixmap = gc_skin_pixmap_load("gcompris-about.png");
 
 
   logo = gnome_canvas_item_new (actualSectionItem,
@@ -993,12 +996,12 @@ static void              display_welcome (void)
 				NULL);
 
   gdk_pixbuf_unref(pixmap);
- 
+
   if(G_IS_OBJECT(menuitems->boardname_item))
     gnome_canvas_item_set (menuitems->boardname_item,
 			   "text", "GCompris V" VERSION,
 			   NULL);
-  
+
   if(G_IS_OBJECT(menuitems->description_item)
      && G_IS_OBJECT(menuitems->description_item_s))
     set_content(menuitems->description_item,
@@ -1013,12 +1016,13 @@ static void              display_welcome (void)
     gnome_canvas_item_set (menuitems->boardname_item_s,
 			       "text", "GCompris V" VERSION,
 			   NULL);
-  
+
   if(G_IS_OBJECT(menuitems->author_item_s))
     gnome_canvas_item_set (menuitems->author_item_s,
 			   "text", "",
 			   NULL);
-  
+
+  menu_displayed = TRUE;
 }
 
 static void
@@ -1027,24 +1031,14 @@ menu_config_start(GcomprisBoard *agcomprisBoard,
   if(gcomprisBoard!=NULL)
     {
       menu_pause(TRUE);
-      gcompris_config_start();
+      gc_config_start();
     }
 }
 
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 menu_config_stop()
 {
 }
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
