@@ -17,9 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
 #include <string.h>
 
 #include "gcompris/gcompris.h"
@@ -138,7 +135,7 @@ static void pause_board (gboolean pause)
   if(gcomprisBoard==NULL)
     return;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
 
   if(gamewon == TRUE && pause == FALSE) /* the game is won */
     {
@@ -152,9 +149,9 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
 
-  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   g_hash_table_destroy(config);
 
@@ -162,8 +159,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gchar *img;
       gcomprisBoard=agcomprisBoard;
-      img = gcompris_image_to_skin("missingletter-bg.jpg");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+      img = gc_skin_image_get("missingletter-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      img);
       g_free(img);
       gcomprisBoard->level=1;
@@ -171,12 +168,12 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=NUMBER_OF_SUBLEVELS; /* Go to next level after this number of 'play' */
       init_xml();
-      assert(NUMBER_OF_LEVELS*NUMBER_OF_SUBLEVELS == g_list_length(board_list));
-      gcompris_score_start(SCORESTYLE_NOTE,
+      g_assert(NUMBER_OF_LEVELS*NUMBER_OF_SUBLEVELS == g_list_length(board_list));
+      gc_score_start(SCORESTYLE_NOTE,
 			   50,
 			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG | GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_CONFIG | GC_BAR_LEVEL);
 
       missing_letter_next_level();
 
@@ -191,12 +188,12 @@ static void end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       missing_letter_destroy_all_items();
       destroy_board_list();
     }
 
-  gcompris_reset_locale();
+  gc_locale_reset();
 
   gcomprisBoard = NULL;
 }
@@ -234,13 +231,13 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 /* set initial values for the next level */
 static void missing_letter_next_level()
 {
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   missing_letter_destroy_all_items();
   selected_button = NULL;
   gamewon = FALSE;
 
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   /* Try the next level */
   missing_letter_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -277,9 +274,9 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 
   board_number = (gcomprisBoard->level-1) * NUMBER_OF_SUBLEVELS + gcomprisBoard->sublevel-1;
 
-  assert(board_number >= 0  && board_number < g_list_length(board_list));
+  g_assert(board_number >= 0  && board_number < g_list_length(board_list));
   place = ((int)(3.0*rand()/(RAND_MAX+1.0)));
-  assert(place >= 0  && place < 3);
+  g_assert(place >= 0  && place < 3);
 
   right_word = place+1;
 
@@ -289,32 +286,32 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 							    "x", (double) 0,
 							    "y", (double) 0,
 							    NULL));
-  button_pixmap = gcompris_load_skin_pixmap("button.png");
+  button_pixmap = gc_skin_pixmap_load("button.png");
   /* display the image */
   board = g_list_nth_data(board_list, board_number);
-  assert(board != NULL);
+  g_assert(board != NULL);
   str = g_strdup_printf("%s/%s", "imageid"/*gcomprisBoard->boarddir*/, board->pixmapfile);
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   yOffset = (gcomprisBoard->height - gdk_pixbuf_get_height(button_pixmap) - gdk_pixbuf_get_height(pixmap) - 2*VERTICAL_SEPARATION)/2;
 
   text_s = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _(board->question),
-				"font", gcompris_skin_font_board_huge_bold,
+				"font", gc_skin_font_board_huge_bold,
 				"x", (double) txt_area_x + 1.0,
 				"y", (double) txt_area_y + 1.0,
 				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_get_color("missingletter/shadow"),
+				"fill_color_rgba", gc_skin_get_color("missingletter/shadow"),
 				NULL);
   text = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _(board->question),
-				"font", gcompris_skin_font_board_huge_bold,
+				"font", gc_skin_font_board_huge_bold,
 				"x", (double) txt_area_x,
 				"y", (double) txt_area_y,
 				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_get_color("missingletter/question"),
+				"fill_color_rgba", gc_skin_get_color("missingletter/question"),
 				NULL);
 
   gnome_canvas_item_get_bounds(text, &dx1, &dy1, &dx2, &dy2);
@@ -365,20 +362,20 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[0],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   "fill_color_rgba", gc_skin_color_shadow,
 				   NULL);
   l1_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[0],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_text_button,
+				   "fill_color_rgba", gc_skin_color_text_button,
 				   NULL);
 
   yOffset += HORIZONTAL_SEPARATION + gdk_pixbuf_get_height(button_pixmap);
@@ -391,20 +388,20 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[1],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   "fill_color_rgba", gc_skin_color_shadow,
 				   NULL);
   l2_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[1],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_text_button,
+				   "fill_color_rgba", gc_skin_color_text_button,
 				   NULL);
 
   yOffset += HORIZONTAL_SEPARATION + gdk_pixbuf_get_height(button_pixmap);
@@ -418,20 +415,20 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[2],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   "fill_color_rgba", gc_skin_color_shadow,
 				   NULL);
   l3_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[2],
-				   "font", gcompris_skin_font_board_huge_bold,
+				   "font", gc_skin_font_board_huge_bold,
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color_rgba", gcompris_skin_color_text_button,
+				   "fill_color_rgba", gc_skin_color_text_button,
 				   NULL);
 
   gdk_pixbuf_unref(button_pixmap);
@@ -454,7 +451,7 @@ static void game_won() {
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) {
-	board_finished(BOARD_FINISHED_TUXPLANE);
+	gc_bonus_end_display(BOARD_FINISHED_TUXPLANE);
 	return;
     }
   }
@@ -463,7 +460,7 @@ static void game_won() {
 
 /* ==================================== */
 static gboolean process_ok_timeout() {
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
   return FALSE;
 }
 
@@ -473,7 +470,7 @@ static void process_ok() {
     gnome_canvas_item_set(text_s, "text", board->answer, NULL);
   }
   // leave time to display the right answer
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
   g_timeout_add(TIME_CLICK_TO_BONUS, process_ok_timeout, NULL);
 }
 
@@ -502,7 +499,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       if (item == l3_item)
 	temp = button3;
 
-      assert(temp == button1 || temp == button2 || temp == button3);
+      g_assert(temp == button1 || temp == button2 || temp == button3);
 
       if ( ( temp == button1 && right_word == 1) ||
 	   ( temp == button2 && right_word == 2) ||
@@ -536,13 +533,13 @@ static void highlight_selected(GnomeCanvasItem * item) {
   }
 
   if (selected_button != NULL && selected_button != button) {
-  	button_pixmap = gcompris_load_skin_pixmap("button.png");
+  	button_pixmap = gc_skin_pixmap_load("button.png");
   	gnome_canvas_item_set(selected_button, "pixbuf", button_pixmap, NULL);
   	gdk_pixbuf_unref(button_pixmap);
   }
 
   if (selected_button != button) {
-  	button_pixmap_selected = gcompris_load_skin_pixmap("button_selected.png");
+  	button_pixmap_selected = gc_skin_pixmap_load("button_selected.png");
   	gnome_canvas_item_set(button, "pixbuf", button_pixmap_selected, NULL);
   	selected_button = button;
   	gdk_pixbuf_unref(button_pixmap_selected);
@@ -555,6 +552,7 @@ static void highlight_selected(GnomeCanvasItem * item) {
  *                Ref : shapegame.c
  * ==================================== */
 /* ======  for DEBUG ========  */
+#if 0
 static void dump_xml() {
   GList *list;
   g_warning("XML lentgh = %d\n", g_list_length(board_list));
@@ -564,42 +562,46 @@ static void dump_xml() {
     g_warning("xml = %s %s %s %s %s %s\n", board->pixmapfile, board->answer, board->question, board->l1, board->l2, board->l3);
   }
 }
+#endif
+
 /* ==================================== */
 static void init_xml()
 {
   char *filename;
-  filename = g_strdup_printf("%s/%s/board1.xml", PACKAGE_DATA_DIR, gcomprisBoard->boarddir);
-  assert(g_file_test(filename, G_FILE_TEST_EXISTS));
-  assert(read_xml_file(filename)== TRUE);
+
+  filename = gc_file_find_absolute("%s/board1.xml",
+				   gcomprisBoard->boarddir);
+
+  g_assert(read_xml_file(filename)== TRUE);
+
   g_free(filename);
-  dump_xml();
 }
 
 /* ==================================== */
 static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
-	//int i;
-  char *pixmapfile = NULL;
-  char *question = NULL, *answer = NULL;
-  char *l1 = NULL, *l2 = NULL, *l3 = NULL;
-  char *data = NULL;
+  gchar *pixmapfile = NULL;
+  gchar *question = NULL, *answer = NULL;
+  gchar *l1 = NULL, *l2 = NULL, *l3 = NULL;
+  gchar *data = NULL;
   Board * board = g_new(Board,1);
+  gboolean found = FALSE;
 
   xmlnode = xmlnode->xmlChildrenNode;
 
   xmlnode = xmlnode->next;
 
-  while (xmlnode != NULL) {
-    gchar *lang = xmlGetProp(xmlnode,"lang");
-    if (!strcmp(xmlnode->name, "pixmapfile") && (lang==NULL
-						 || !strcmp(lang, gcompris_get_locale())
-						 || !strncmp(lang, gcompris_get_locale(), 2)))
-      pixmapfile = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-    if (!strcmp(xmlnode->name, "data") && (lang==NULL
-					   || !strcmp(lang, gcompris_get_locale())
-					   || !strncmp(lang, gcompris_get_locale(), 2)))
+  while (xmlnode != NULL && !found) {
+
+    if (!strcmp((char *)xmlnode->name, "pixmapfile"))
+      pixmapfile = (gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+
+    if (!found && !strcmp((char *)xmlnode->name, "data"))
       {
-	data = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	if(data==NULL)
+	  {
+	    data = gettext((gchar *)xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1));
+	  }
       }
     xmlnode = xmlnode->next;
   }
@@ -612,21 +614,25 @@ static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 /*  if ((i=sscanf(data, "%s / %s / %s / %s / %s", answer, question, l1, l2, l3)) != 5)
 		printf("Error sscanf result != 5 = %i\n",i);
 */
-  answer = (char *)strtok(data,"/");
-  question = (char *)strtok(NULL,"/");
-  l1 = (char *)strtok(NULL,"/");
-  l2 = (char *)strtok(NULL,"/");
-  l3 = (char *)strtok(NULL,"/");
+  gchar **all_answer = g_strsplit(data, "/", 5);
 
-  assert(l1 != NULL  && l2 != NULL && l3 != NULL && answer != NULL && question != NULL);
+  answer = all_answer[0];
+  question = all_answer[1];
+  l1 = all_answer[2];
+  l2 = all_answer[3];
+  l3 = all_answer[4];
 
-  board->pixmapfile = g_strdup(pixmapfile);
+  g_assert(l1 != NULL  && l2 != NULL && l3 != NULL && answer != NULL && question != NULL);
+
+  board->pixmapfile = pixmapfile;
   board->question = g_strdup(question);
   board->answer = g_strdup(answer);
   board->l1 = g_strdup(l1);
   board->l2 = g_strdup(l2);
   board->l3 = g_strdup(l3);
 
+  g_strfreev(all_answer);
+
   board_list = g_list_append (board_list, board);
 }
 
@@ -636,7 +642,7 @@ static void parse_doc(xmlDocPtr doc)
   xmlNodePtr node;
 
   for(node = doc->children->children; node != NULL; node = node->next) {
-    if ( g_strcasecmp(node->name, "Board") == 0 )
+    if ( g_strcasecmp((gchar *)node->name, "Board") == 0 )
       add_xml_data(doc, node,NULL);
   }
 
@@ -652,16 +658,9 @@ static gboolean read_xml_file(char *fname)
 
   g_return_val_if_fail(fname!=NULL,FALSE);
 
-  /* if the file doesn't exist */
-  if(!g_file_test(fname, G_FILE_TEST_EXISTS))
-    {
-      g_warning("Couldn't find file %s !", fname);
-      return FALSE;
-    }
-  g_warning("found file %s !", fname);
-
   /* parse the new file and put the result into newdoc */
-  doc = xmlParseFile(fname);
+  doc = gc_net_load_xml(fname);
+
   /* in case something went wrong */
   if(!doc)
     return FALSE;
@@ -671,7 +670,7 @@ static gboolean read_xml_file(char *fname)
      /* if it doesn't have a name */
      !doc->children->name ||
      /* if it isn't a ImageId node */
-     g_strcasecmp(doc->children->name,"missing_letter")!=0) {
+     g_strcasecmp((char *)doc->children->name,"missing_letter")!=0) {
     xmlFreeDoc(doc);
     return FALSE;
   }
@@ -714,13 +713,14 @@ static void destroy_board(Board * board) {
 static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
-static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+/* GHFunc */
+static void save_table (gpointer key,
+			gpointer value,
+			gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 }
 
@@ -735,16 +735,16 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
 
   if (gcomprisBoard){
-    gcompris_reset_locale();
+    gc_locale_reset();
 
     GHashTable *config;
 
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
-    
-    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+
+    gc_locale_set(g_hash_table_lookup( config, "locale"));
 
     if (profile_conf)
       g_hash_table_destroy(config);
@@ -752,13 +752,12 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
     destroy_board_list();
 
     init_xml();
-    
+
     missing_letter_next_level();
-    
+
   }
 
-  
-  board_conf = NULL;
+    board_conf = NULL;
   profile_conf = NULL;
 
   return NULL;
@@ -775,28 +774,28 @@ config_start(GcomprisBoard *agcomprisBoard,
     pause_board(TRUE);
 
   gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-				 agcomprisBoard->name, 
+				 agcomprisBoard->name,
 				 aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window( label,
+  gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *locale = g_hash_table_lookup( config, "locale");
-  
-  gcompris_combo_locales( locale);
+
+  gc_board_config_combo_locales( locale);
 
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 config_stop()
 {
 }
