@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 #include "money_widget.h"
 
@@ -140,7 +136,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->level=1;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=10; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
       /* Default mode */
       if(!gcomprisBoard->mode)
@@ -203,18 +199,18 @@ gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void money_next_level()
 {
   GdkPixbuf       *pixmap = NULL;
-  guint		   min_price, max_price;
-  guint		   number_of_item;
+  guint		   min_price = 0, max_price = 0;
+  guint		   number_of_item = 0;
   guint		   i;
   gchar		  *display_format;
   gchar		  *img;
 
-  img = gcompris_image_to_skin("money-bg.png");
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+  img = gc_skin_image_get("money-bg.png");
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  img);
   g_free(img);
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   money_destroy_all_items();
   gamewon = FALSE;
@@ -266,7 +262,7 @@ static void money_next_level()
 	  money_widget_add(tux_money, MONEY_EURO_COIN_1E);
 	  money_widget_add(tux_money, MONEY_EURO_COIN_1E);
 	  break;
-	case 3: 
+	case 3:
 	  number_of_item = 2;
 	  min_price      = 20;
 	  max_price      = 30;
@@ -473,16 +469,16 @@ static void money_next_level()
     double object_price;
     gchar *text;
 
-    pixmap = gcompris_load_pixmap(imageList[RAND(0, NUMBER_OF_IMAGES-1)]);
+    pixmap = gc_pixmap_load(imageList[RAND(0, NUMBER_OF_IMAGES-1)]);
 
     gnome_canvas_item_new ( boardRootItem,
 			    gnome_canvas_pixbuf_get_type (),
 			    "pixbuf", pixmap,
-			    "x", (double) (i*BOARDWIDTH)/(number_of_item+1) 
+			    "x", (double) (i*BOARDWIDTH)/(number_of_item+1)
 			    - gdk_pixbuf_get_width(pixmap)/2,
 			    "y", (double) 200,
 			    NULL);
-    
+
     /* Diplay the price */
     object_price  = (double) RAND(min_price/number_of_item, max_price/number_of_item);
 
@@ -510,7 +506,7 @@ static void money_next_level()
     gnome_canvas_item_new(boardRootItem,
 			  gnome_canvas_text_get_type (),
 			  "text", text,
-			  "font", gcompris_skin_font_board_big,
+			  "font", gc_skin_font_board_big,
 			  "x", (double) (i*BOARDWIDTH)/(number_of_item+1),
 			  "y", (double) 180,
 			  "anchor", GTK_ANCHOR_CENTER,
@@ -549,10 +545,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   money_next_level();
 }
@@ -570,8 +566,8 @@ static void process_ok()
     {
       gamewon = TRUE;
       money_destroy_all_items();
-      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, BONUS_SMILEY);
     }
   else
-    gcompris_display_bonus(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, BONUS_SMILEY);
 }
