@@ -1,6 +1,6 @@
 /* gcompris - paratrooper.c
  *
- * Time-stamp: <2006/01/22 22:50:43 bruno>
+ * Time-stamp: <2006/08/21 23:34:30 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -153,7 +153,7 @@ static void pause_board (gboolean pause)
 	{
 	  gcomprisBoard->level++;
 	  if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-	    board_finished(BOARD_FINISHED_RANDOM);
+	    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
 	    return;
 	  }
 	  printf("paratrooper pause start next level\n");
@@ -184,13 +184,13 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
 
 
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 6;
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
       /* Init of paratrooper struct */
       paratrooperItem.rootitem = NULL;
@@ -305,7 +305,7 @@ static void paratrooper_next_level()
 
   gamewon = FALSE;
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   paratrooper_destroy_all_items();
 
@@ -319,7 +319,7 @@ static void paratrooper_next_level()
   planespeed_y = 0;
   planespeed_x = 4 + gcomprisBoard->level;
   str = g_strdup_printf("%s%s", pixmapsdir, "tuxplane.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
   plane_x = 0;
   plane_y = 40;
   planeitem = gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -348,7 +348,7 @@ static void paratrooper_next_level()
   /* Display the target */
   g_free(str);
   str = g_strdup_printf("%s%s", pixmapsdir, "fishingboat.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
   boat_x = 350;
   boat_y = gcomprisBoard->height-100;
   boat_landarea_y = boat_y+20;
@@ -385,7 +385,7 @@ static void paratrooper_next_level()
 
   g_free(str);
   str = g_strdup_printf("%s%s", pixmapsdir, "minitux.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   paratrooperItem.paratrooper = gnome_canvas_item_new (GNOME_CANVAS_GROUP(paratrooperItem.rootitem),
 						       gnome_canvas_pixbuf_get_type (),
@@ -403,7 +403,7 @@ static void paratrooper_next_level()
 
   g_free(str);
   str = g_strdup_printf("%s%s", pixmapsdir, "parachute.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   paratrooperItem.parachute = gnome_canvas_item_new (GNOME_CANVAS_GROUP(paratrooperItem.rootitem),
 						     gnome_canvas_pixbuf_get_type (),
@@ -573,7 +573,7 @@ static gint paratrooper_move_tux (GtkWidget *widget, gpointer data)
 	{
 	  gnome_canvas_item_hide(paratrooperItem.parachute);
 	  paratrooperItem.status = TUX_LANDED;
-	  gcompris_play_ogg ("bonus", NULL);
+	  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
 	  next_state();
 	}
       else
@@ -585,7 +585,7 @@ static gint paratrooper_move_tux (GtkWidget *widget, gpointer data)
 	    {
 	      gnome_canvas_item_hide(paratrooperItem.parachute);
 	      paratrooperItem.status = TUX_CRASHED;
-	      gcompris_play_ogg ("crash", NULL);
+	      gc_sound_play_ogg ("sounds/crash.ogg", NULL);
 	      next_state();
 	    }
 	}
@@ -609,7 +609,7 @@ static GnomeCanvasItem *paratrooper_create_cloud(GnomeCanvasGroup *parent)
 
 
   str = g_strdup_printf("%s%s", pixmapsdir, "cloud.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   if(windspeed>0)
     x = 0;
@@ -693,7 +693,7 @@ void next_state()
       break;
     case TUX_LANDED:
       gamewon = TRUE;
-      gcompris_display_bonus(gamewon, BONUS_TUX);
+      gc_bonus_display(gamewon, BONUS_TUX);
       break;
     case TUX_CRASHED:
       /* Restart */
@@ -729,14 +729,3 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, void *data)
          
    return FALSE;
  }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
