@@ -1,6 +1,6 @@
 /* gcompris - planegame.c
  *
- * Time-stamp: <2005/10/15 16:54:30 bruno>
+ * Time-stamp: <2006/08/21 23:34:38 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -46,9 +46,6 @@ typedef struct {
 } CloudItem;
 
 
-/* default gnome pixmap directory in which this game tales the icon */
-static char *pixmapsdir = "gcompris/misc/";
-
 static void start_board (GcomprisBoard *agcomprisBoard);
 static void pause_board (gboolean pause);
 static void end_board (void);
@@ -146,13 +143,13 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
 
 
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 2;
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_LEVEL);
 
       planegame_next_level();
 
@@ -169,7 +166,7 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       planegame_destroy_all_items();
       gcomprisBoard->level = 1;       // Restart this game to zero
     }
@@ -212,7 +209,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     case GDK_Hyper_L:
     case GDK_Hyper_R:
     case GDK_Num_Lock:
-      return FALSE; 
+      return FALSE;
     case GDK_KP_Enter:
     case GDK_Return:
       return TRUE;
@@ -259,11 +256,11 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 /*-------------------------------------------------------------------------------*/
 
 /* set initial values for the next level */
-static void planegame_next_level() 
+static void planegame_next_level()
 {
   GdkPixbuf *pixmap = NULL;
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   planegame_destroy_all_items();
 
@@ -276,17 +273,17 @@ static void planegame_next_level()
   /* Setup and Display the plane */
   planespeed_y = 0;
   planespeed_x = 0;
-  pixmap = gcompris_load_pixmap("gcompris/misc/tuxhelico.png");
+  pixmap = gc_pixmap_load("gcompris/misc/tuxhelico.png");
   plane_x = 50;
   plane_y = 300;
   planeitem = gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
+				     "pixbuf", pixmap,
 				     "x", (double) plane_x,
 				     "y", (double) plane_y,
 				     "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
 				     "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
-				     "width_set", TRUE, 
+				     "width_set", TRUE,
 				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
@@ -302,15 +299,15 @@ static void planegame_next_level()
   if(gcomprisBoard->level>1)
     {
       /* No scoring after level 1 */
-      gcompris_score_end();
+      gc_score_end();
     }
   else
     {
-      gcompris_score_start(SCORESTYLE_NOTE, 
-			   gcomprisBoard->width - 220, 
-			   gcomprisBoard->height - 50, 
+      gc_score_start(SCORESTYLE_NOTE,
+			   gcomprisBoard->width - 220,
+			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_score_set(gcomprisBoard->sublevel);
+      gc_score_set(gcomprisBoard->sublevel);
     }
 }
 
@@ -327,8 +324,8 @@ static void planegame_cloud_colision(CloudItem *clouditem)
 
   item = clouditem->rootitem;
 
-  gnome_canvas_item_get_bounds(planeitem,  &px1, &py1, &px2, &py2); 
-  gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2); 
+  gnome_canvas_item_get_bounds(planeitem,  &px1, &py1, &px2, &py2);
+  gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2);
 
   if(
      ISIN(x1, y1, px1, py1, px2, py2) ||
@@ -339,13 +336,13 @@ static void planegame_cloud_colision(CloudItem *clouditem)
     {
       if(plane_target == clouditem->number)
 	{
-	  gcompris_play_ogg ("gobble", NULL);
+	  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 	  item2del_list = g_list_append (item2del_list, clouditem);
 	  plane_target++;
 
 	  if(gcomprisBoard->level==1)
 	    {
-	      gcompris_score_set(plane_target);
+	      gc_score_set(plane_target);
 	    }
 
 	  if(plane_target==plane_last_target)
@@ -353,11 +350,11 @@ static void planegame_cloud_colision(CloudItem *clouditem)
 	      /* Try the next level */
 	      gcomprisBoard->level++;
 	      if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-		board_finished(BOARD_FINISHED_RANDOM);
+		gc_bonus_end_display(BOARD_FINISHED_RANDOM);
 		return;
 	      }
 	      planegame_next_level();
-	      gcompris_play_ogg ("bonus", NULL);
+	      gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
 	    }
 	}
     }
@@ -395,7 +392,7 @@ static void planegame_move_item(CloudItem *clouditem)
 				   &y1,
 				   &x2,
 				   &y2);
-  
+
   if(x2<0) {
     item2del_list = g_list_append (item2del_list, clouditem);
   }
@@ -418,7 +415,7 @@ static void planegame_destroy_items()
 {
   CloudItem *clouditem;
 
-  while(g_list_length(item2del_list)>0) 
+  while(g_list_length(item2del_list)>0)
     {
       clouditem = g_list_nth_data(item2del_list, 0);
       planegame_destroy_item(clouditem);
@@ -430,7 +427,7 @@ static void planegame_destroy_all_items()
 {
   CloudItem *clouditem;
 
-  while(g_list_length(item_list)>0) 
+  while(g_list_length(item_list)>0)
     {
       clouditem = g_list_nth_data(item_list, 0);
       planegame_destroy_item(clouditem);
@@ -484,7 +481,7 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
     }
   number = g_strdup_printf("%d", i);
 
-  pixmap = gcompris_load_pixmap("gcompris/misc/cloud.png");
+  pixmap = gc_pixmap_load("gcompris/misc/cloud.png");
 
   itemgroup = \
     gnome_canvas_item_new (parent,
@@ -498,12 +495,12 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
 
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(itemgroup),
 			 gnome_canvas_pixbuf_get_type (),
-			 "pixbuf", pixmap, 
+			 "pixbuf", pixmap,
 			 "x", (double) -gdk_pixbuf_get_width(pixmap)*imageZoom/2,
 			 "y", (double) -gdk_pixbuf_get_height(pixmap)*imageZoom/2,
 			 "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
 			 "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
-			 "width_set", TRUE, 
+			 "width_set", TRUE,
 			 "height_set", TRUE,
 			 NULL);
   gdk_pixbuf_unref(pixmap);
@@ -512,7 +509,7 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(itemgroup),
 			 gnome_canvas_text_get_type (),
 			 "text", number,
-			 "font", gcompris_skin_font_board_big,
+			 "font", gc_skin_font_board_big,
 			 "x", (double) 0,
 			 "y", (double) 0,
 			 "fill_color", "red",
@@ -532,7 +529,7 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
   return (itemgroup);
 }
 
-static void planegame_add_new_item() 
+static void planegame_add_new_item()
 {
   setup_item (planegame_create_item(gnome_canvas_root(gcomprisBoard->canvas)));
 }
@@ -559,27 +556,27 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
    static int dragging;
    double item_x, item_y;
 
-   if(!get_board_playing())
-     return FALSE;
+  if(!gcomprisBoard)
+    return FALSE;
 
    item_x = event->button.x;
    item_y = event->button.y;
    gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
 
-   switch (event->type) 
+   switch (event->type)
      {
      case GDK_BUTTON_PRESS:
-       switch(event->button.button) 
+       switch(event->button.button)
          {
          case 1:
            if (event->button.state & GDK_SHIFT_MASK)
              {
                x = item_x;
                y = item_y;
-               
+
                fleur = gdk_cursor_new(GDK_FLEUR);
-               gnome_canvas_item_grab(item,
-                                      GDK_POINTER_MOTION_MASK | 
+               gc_canvas_item_grab(item,
+                                      GDK_POINTER_MOTION_MASK |
                                       GDK_BUTTON_RELEASE_MASK,
                                       fleur,
                                       event->button.time);
@@ -594,21 +591,21 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
        break;
 
      case GDK_MOTION_NOTIFY:
-       if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) 
+       if (dragging && (event->motion.state & GDK_BUTTON1_MASK))
          {
            new_x = item_x;
            new_y = item_y;
-             
+
            gnome_canvas_item_move(item, new_x - x, new_y - y);
            x = new_x;
            y = new_y;
          }
        break;
-           
+
      case GDK_BUTTON_RELEASE:
-       if(dragging) 
+       if(dragging)
 	 {
-	   gnome_canvas_item_ungrab(item, event->button.time);
+	   gc_canvas_item_ungrab(item, event->button.time);
 	   dragging = FALSE;
 	 }
        break;
@@ -616,7 +613,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
      default:
        break;
      }
-         
+
    return FALSE;
  }
 
@@ -627,13 +624,3 @@ setup_item(GnomeCanvasItem *item)
 		     (GtkSignalFunc) item_event,
 		     NULL);
 }
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
