@@ -1,6 +1,6 @@
 #ifndef _PY_MOD_score_H_
 #define _PY_MOD_score_H_
 
-void python_gcompris_score_module_init(void);
+void python_gc_score_module_init(void);
 
 #endif
