@@ -47,9 +47,9 @@ static void	 pythonboard_ok (void);
 static void	 pythonboard_set_level (guint level);
 static void	 pythonboard_config(void);
 static void	 pythonboard_repeat (void);
-static void	 pythonboard_config_start (GcomprisBoard *agcomprisBoard,
+static void	 pythongc_board_config_start (GcomprisBoard *agcomprisBoard,
 					   GcomprisProfile *aProfile);
-static void	 pythonboard_config_stop (void);
+static void	 pythongc_board_config_stop (void);
 
 static gboolean  pythonboard_is_ready = FALSE;
 
@@ -75,11 +75,33 @@ static BoardPlugin menu_bp =
     pythonboard_set_level,
     pythonboard_config,
     pythonboard_repeat,
-    pythonboard_config_start,
-    pythonboard_config_stop
+    pythongc_board_config_start,
+    pythongc_board_config_stop
   };
 
-static BoardPlugin *bp_board = NULL;
+static BoardPlugin menu_bp_no_config =
+  {
+    NULL,
+    NULL,
+    N_("Python Board"),
+    N_("Special board that embeds python into gcompris."),
+    "Olivier Samyn <osamyn@ulb.ac.be>",
+    pythonboard_init,
+    NULL,
+    NULL,
+    NULL,
+    pythonboard_start,
+    pythonboard_pause,
+    pythonboard_end,
+    pythonboard_is_our_board,
+    pythonboard_key_press,
+    pythonboard_ok,
+    pythonboard_set_level,
+    pythonboard_config,
+    pythonboard_repeat,
+    NULL,
+    NULL
+  };
 
 /*
  * Return the plugin structure (Common to all gcompris boards)
@@ -99,7 +121,7 @@ GList *
 get_pythonboards_list()
 {
   GList *pythonboards_list = NULL;
-  GList *boards_list = gcompris_get_boards_list();
+  GList *boards_list = gc_menu_get_boards();
   GList *list;
   GcomprisBoard *board;
 
@@ -119,17 +141,13 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
   gchar* execstr;
   gchar* userplugindir;
 
-
-  gboolean has_config = TRUE;
   char* board_file_name;
   char* boardclass;
   gchar *boarddir;
   PyObject* module_dict;
   PyObject* py_boardclass;
-  PyObject* py_boardclass_args;
-  PyObject* py_config_start;
 
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties *properties = gc_prop_get();
 
   if (pythonboard_is_ready)
     return ;
@@ -150,22 +168,20 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
     pythonboard_is_ready = FALSE;
   } else {
     /* Add the python plugins dir to the python's search path */
-    execstr = g_strdup_printf("import sys; sys.path.append('%s')",PYTHON_PLUGIN_DIR);
 #ifndef DISABLE_USER_PLUGIN_DIR
     userplugindir = g_strconcat(g_get_home_dir(), "/.gcompris/Plugins/", NULL);
     execstr = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s')",
-			      userplugindir, PYTHON_PLUGIN_DIR);
+			      userplugindir, properties->package_python_plugin_dir);
     g_free(userplugindir);
 #else
-    execstr = g_strdup_printf("import sys; sys.path.append('%s')",PYTHON_PLUGIN_DIR );
+    execstr = g_strdup_printf("import sys; sys.path.append('%s')",properties->package_python_plugin_dir );
 #endif
+
+    g_warning("Executing %s\n", execstr);
     if(PyRun_SimpleString(execstr)!=0){
       pythonboard_is_ready = FALSE;
       g_warning("! Python disabled: Cannot add plugins dir into search path\n");
     } else {
-      /* Load the gcompris modules */
-      python_gcompris_module_init();
-
       /* Try to import pygtk modules */
       g_free(execstr);
       execstr = g_strdup("import gtk; import gtk.gdk");
@@ -173,78 +189,71 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
 	pythonboard_is_ready = FALSE;
 	g_warning("! Python disabled: Cannot import pygtk modules\n");
       } else {
-	/* Try to import gnome-python modules */
+	/* Try to import gcompris modules */
+
+	/* Load the gcompris modules */
+	python_gcompris_module_init();
+
 	g_free(execstr);
-	execstr = g_strdup("import gnome; import gnome.canvas");
+	execstr = g_strdup("import gcompris; import gcompris.bonus; "
+			   "import gcompris.score; import gcompris.sound;"
+			   "import gcompris.skin; import gcompris.timer;"
+			   "import gcompris.utils; import gcompris.anim");
 	if(PyRun_SimpleString(execstr)!=0){
 	  pythonboard_is_ready = FALSE;
-	  g_warning("! Python disabled: Cannot import gnome-python modules\n");
+	  g_warning("! Python disabled: Cannot import gcompris modules\n");
 	} else {
-	  /* Try to import gcompris modules */
-	  g_free(execstr);
-	  execstr = g_strdup("import gcompris; import gcompris.bonus; "
-			     "import gcompris.score; import gcompris.sound;"
-			     "import gcompris.skin; import gcompris.timer;"
-			     "import gcompris.utils; import gcompris.anim");
-	  if(PyRun_SimpleString(execstr)!=0){
-	    pythonboard_is_ready = FALSE;
-	    g_warning("! Python disabled: Cannot import gcompris modules\n");
-	  } else {
-	    GList *python_boards;
-	    GList *list;
+	  GList *python_boards;
+	  GList *list;
 
-	    /* Load the gcompris modules */
-	    python_gcompris_module_init();
+	  /* Get the list of python boards */
+	  python_boards = get_pythonboards_list();
 
-	    /* Get the list of python boards */
-	    python_boards = get_pythonboards_list();
+	  /* Search in the list each one with a config entry */
+	  for(list = python_boards; list != NULL; list = list->next) {
+	    GcomprisBoard *board = (GcomprisBoard *) list->data;
 
-	    /* Search in the list each one with a config entry */
-	    for(list = python_boards; list != NULL; list = list->next) {
-	      GcomprisBoard *board = (GcomprisBoard *) list->data;
+	    /* Python is now initialized we create some usefull variables */
+	    board_file_name = strchr(board->type, ':')+1;
+	    boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
 
-	      /* Python is now initialized we create some usefull variables */
-	      board_file_name = strchr(board->type, ':')+1;
-	      boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
+	    /* Test if board come with -L option */
 
-	      /* Test if board come with -L option */
+	    g_warning("board_dir: %s package_data_dir %s",
+		      board->board_dir,
+		      properties->package_python_plugin_dir);
 
-	      g_warning("board_dir: %s package_data_dir %s",
-			board->board_dir,
-			properties->package_data_dir);
+	    if (strcmp(board->board_dir, properties->package_python_plugin_dir)!=0){
+	      boarddir = g_strdup_printf("sys.path.append('%s/')", board->board_dir);
 
-	      if (strcmp(board->board_dir, properties->package_data_dir)!=0){ 
-		boarddir = g_strdup_printf("sys.path.append('%s/../python/')", board->board_dir);
-	      
-		PyRun_SimpleString(boarddir);
-		g_free(boarddir);
-	      }
-	      
-	      /* Insert the board module into the python's interpreter */
-	      python_board_module = PyImport_ImportModuleEx(board_file_name,
-							    globals,
-							    globals,
-							    NULL);
-
-	      if(python_board_module!=NULL){
-		/* Get the module dictionnary */
-		module_dict = PyModule_GetDict(python_board_module);
-	      
-		/* Get the python board class */
-		py_boardclass = PyDict_GetItemString(module_dict, boardclass);
-
-		if (PyObject_HasAttrString( py_boardclass, "config_start")) {
-		  config_boards = g_list_append(config_boards, board);
-		  g_warning("The board '%s' has a configuration entry", 
-			    board_file_name);
-		}
-	      }
-
-	      g_free(boardclass);
+	      PyRun_SimpleString(boarddir);
+	      g_free(boarddir);
 	    }
 
-	    g_list_free(python_boards);
+	    /* Insert the board module into the python's interpreter */
+	    python_board_module = PyImport_ImportModuleEx(board_file_name,
+							  globals,
+							  globals,
+							  NULL);
+
+	    if(python_board_module!=NULL){
+	      /* Get the module dictionnary */
+	      module_dict = PyModule_GetDict(python_board_module);
+
+	      /* Get the python board class */
+	      py_boardclass = PyDict_GetItemString(module_dict, boardclass);
+
+	      if (PyObject_HasAttrString( py_boardclass, "config_start")) {
+		config_boards = g_list_append(config_boards, board);
+		g_warning("The board '%s' has a configuration entry",
+			  board_file_name);
+	      }
+	    }
+
+	    g_free(boardclass);
 	  }
+
+	  g_list_free(python_boards);
 	}
       }
     }
@@ -281,7 +290,7 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
   char* board_file_name;
   gchar *userplugindir;
 
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   if(agcomprisBoard!=NULL){
     /* Initialize the python interpreter */
@@ -307,9 +316,9 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
     userplugindir = g_strconcat(g_get_home_dir(), "/.gcompris/Plugins/", NULL);
     boarddir = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s')",
 			       userplugindir,
-			       PYTHON_PLUGIN_DIR);
+			       properties->package_python_plugin_dir);
 #else
-    boarddir = g_strdup_printf("import sys; sys.path.append('%s')",PYTHON_PLUGIN_DIR );
+    boarddir = g_strdup_printf("import sys; sys.path.append('%s')",properties->package_python_plugin_dir );
 #endif
 
     PyRun_SimpleString(boarddir);
@@ -317,9 +326,9 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
 
 
     /* Test if board come with -L option */
-    if (strcmp(gcomprisBoard->board_dir, properties->package_data_dir)!=0){ 
+    if (strcmp(gcomprisBoard->board_dir, properties->package_data_dir)!=0){
       boarddir = g_strdup_printf("sys.path.append('%s/../python/')", gcomprisBoard->board_dir);
-      
+
       PyRun_SimpleString(boarddir);
       g_free(boarddir);
     }
@@ -414,58 +423,28 @@ static void pythonboard_end (void){
 /*
  * Return TRUE if the board is a python one.
  */
-static gboolean pythonboard_is_our_board (GcomprisBoard *agcomprisBoard){
+static gboolean pythonboard_is_our_board (GcomprisBoard *gcomprisBoard){
 
-  if (agcomprisBoard->plugin)
+  if (gcomprisBoard->plugin)
     return TRUE;
 
   if(pythonboard_is_ready) {
-    if (agcomprisBoard!=NULL) {
-
-      if (g_ascii_strncasecmp(agcomprisBoard->type, "python", 6)==0) {
-  
-	bp_board = g_malloc0(sizeof(BoardPlugin));
-	
-	bp_board->handle        = menu_bp.handle;
-	bp_board->filename      = menu_bp.filename;
-	bp_board->name          = menu_bp.name;
-	bp_board->description   = menu_bp.description;
-	bp_board->author        = menu_bp.author;
-	bp_board->init          = menu_bp.init;
-	bp_board->cleanup       = menu_bp.cleanup;
-	bp_board->about         = menu_bp.about;
-	bp_board->configure     = menu_bp.configure;
-	bp_board->start_board   = menu_bp.start_board;
-	bp_board->pause_board   = menu_bp.pause_board;
-	bp_board->end_board     = menu_bp.end_board;
-	bp_board->is_our_board  = menu_bp.is_our_board;
-	bp_board->key_press     = menu_bp.key_press;
-	bp_board->ok            = menu_bp.ok;
-	bp_board->set_level     = menu_bp.set_level;
-	bp_board->config        = menu_bp.config;
-	bp_board->repeat        = menu_bp.repeat;
-  
-	if (g_list_find (config_boards, agcomprisBoard)){
-	  bp_board->config_start  = menu_bp.config_start;
-	  bp_board->config_stop   = menu_bp.config_stop;
-	} else {
-	  bp_board->config_start  = NULL;
-	  bp_board->config_stop   = NULL;
-	}
+    if (gcomprisBoard!=NULL) {
 
+      if (g_ascii_strncasecmp(gcomprisBoard->type, "python", 6)==0) {
 
 	/* Set the plugin entry */
-	agcomprisBoard->plugin = bp_board;
-	
-	bp_board = NULL;
-	
-	//g_print("pythonboard: is our board = TRUE\n");
-	
+	if (g_list_find (config_boards, gcomprisBoard)){
+	  gcomprisBoard->plugin = &menu_bp;
+	} else {
+	  gcomprisBoard->plugin = &menu_bp_no_config;
+	}
+
 	return TRUE;
       }
     }
   }
-  agcomprisBoard->plugin=NULL;
+  gcomprisBoard->plugin=NULL;
   return FALSE;
 }
 
@@ -558,9 +537,11 @@ static void pythonboard_repeat (void){
 static gboolean python_run_by_config = FALSE;
 
 static void
-pythonboard_config_start (GcomprisBoard *agcomprisBoard,
+pythongc_board_config_start (GcomprisBoard *agcomprisBoard,
 			  GcomprisProfile *aProfile
-			  ){
+			  )
+{
+  GcomprisProperties *properties = gc_prop_get();
   PyObject* py_function_result;
   PyObject* module_dict;
   PyObject* py_boardclass;
@@ -575,19 +556,19 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
   gchar *userplugindir;
 
   g_assert (agcomprisBoard != NULL);
- 
+
   if(!Py_IsInitialized()){
     /* Initialize the python interpreter */
     Py_SetProgramName(python_prog_name);
     Py_Initialize();
-    
+
     PySys_SetArgv(1, python_args);
-    
+
     init_pygobject();
 
     main_module = PyImport_AddModule("__main__");
     globals = PyModule_GetDict(main_module);
-    
+
     if(globals==NULL){
       g_print("Cannot get info from the python interpreter. Seems there is a problem with this one.\n");
       return;
@@ -600,10 +581,10 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
     userplugindir = g_strconcat(g_get_home_dir(), "/.gcompris/Plugins/", NULL);
     boarddir = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s'); sys.path.append('%s')",
 			       userplugindir,
-			       PYTHON_PLUGIN_DIR,
+			       properties->package_python_plugin_dir,
 			       gcomprisBoard_config->board_dir);
 #else
-    boarddir = g_strdup_printf("import sys; sys.path.append('%s')",PYTHON_PLUGIN_DIR );
+    boarddir = g_strdup_printf("import sys; sys.path.append('%s')", properties->package_python_plugin_dir );
 #endif
 
     PyRun_SimpleString(boarddir);
@@ -617,7 +598,7 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
     python_gcompris_module_init();
 
     python_run_by_config = TRUE;
-   
+
   }
   else {
     main_module = PyImport_AddModule("__main__"); /* Borrowed reference */
@@ -627,7 +608,7 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
   /* Python is now initialized we create some usefull variables */
   board_file_name = strchr(agcomprisBoard->type, ':')+1;
   boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
-  
+
   /* Insert the board module into the python's interpreter */
   python_board_config_module = PyImport_ImportModuleEx(board_file_name,
 						       globals,
@@ -650,9 +631,9 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
     python_board_config_instance = PyInstance_New(py_boardclass, py_boardclass_args, NULL);
     Py_DECREF(py_boardclass_args);
 
-    py_function_result = PyObject_CallMethod(python_board_config_instance, 
-					     "config_start", 
-					     "O", 
+    py_function_result = PyObject_CallMethod(python_board_config_instance,
+					     "config_start",
+					     "O",
 					     gcompris_new_pyGcomprisProfileObject(aProfile));
 
     if( py_function_result != NULL){
@@ -663,7 +644,7 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
   } else {
     PyErr_Print();
   }
-  
+
   g_free(boardclass);
 }
 
@@ -673,7 +654,7 @@ pythonboard_config_start (GcomprisBoard *agcomprisBoard,
  * - call the board end function
  * - finalise python interpreter
  */
-static void pythonboard_config_stop (void){
+static void pythongc_board_config_stop (void){
   PyObject* result = NULL;
 
   if(python_gcomprisBoard_config!=NULL){
