@@ -1,25 +1,24 @@
 #  gcompris - algorithm
-# 
+#
 # Time-stamp: <2004/29/03 15:31 Ingo Konrad>
-# 
+#
 # Copyright (C) 2004 Christof Petig and Ingo Konrad
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
-import gnome
-import gnome.canvas
+#
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -32,20 +31,20 @@ import random
 def algo(index): return index %4
 def algo1(index): return index %3
 def algo2(index): return index %5
-def algo3(i): 
+def algo3(i):
   if i %6 > 2:
-   return 2 - i %3 
+   return 2 - i %3
   else:
    return i %3
 
 class Gcompris_algorithm:
   """The algorithm activity"""
-  
+
   def paint_image (self, i, x2, y2):
-    
-    
+
+
     return self.rootitem.add(
-        gnome.canvas.CanvasPixbuf,
+        gnomecanvas.CanvasPixbuf,
         pixbuf = self.pixlist[i],
         x=self.leftx+x2*self.distance,
         y=y2
@@ -65,15 +64,15 @@ class Gcompris_algorithm:
     self.board_paused  = 0;
     self.gamewon       = 0;
 
-  def start(self): 
-    gcompris.bar_set (0) 
+  def start(self):
+    gcompris.bar_set (0)
     gcompris.set_background(self.gcomprisBoard.canvas.root(),
                             "images/scenery5_background.png")
     self.gcomprisBoard.level=1
-    self.gcomprisBoard.sublevel=1 
+    self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=5
     self.gcomprisBoard.maxlevel = 1
-    
+
     self.symbollist = ["gcompris/misc/apple.png","gcompris/misc/strawberry.png","gcompris/misc/peer.png","gcompris/misc/football.png","gcompris/misc/cerise.png","gcompris/misc/egg.png","gcompris/misc/glass.png","gcompris/misc/eggpot.png"]
     self.pixlist = []
     for i in range (len(self.symbollist)):
@@ -89,15 +88,15 @@ class Gcompris_algorithm:
   def end(self):
     self.cleanup()
     print("Gcompris_algorithm end.")
-        
+
   def ok(self):
     print("Gcompris_algorithm ok.")
 
-  # Called by gcompris core 
+  # Called by gcompris core
   def pause(self, pause):
-    
+
     self.board_paused = pause
-    
+
     # When the bonus is displayed, it call us first with pause(1) and then with pause(0)
     # the game is won
     if(pause == 0):
@@ -105,20 +104,20 @@ class Gcompris_algorithm:
       self.gamewon = 0
 
     return
-  
+
   # ----------------------------------------------------------------------
   # ----------------------------------------------------------------------
   # ----------------------------------------------------------------------
 
 
   def cleanup(self):
-    
+
     # Remove the root item removes all the others inside it
-    if self.rootitem != None: 
+    if self.rootitem != None:
      self.rootitem.destroy()
      self.rootitem = None
      gcompris.score.end()
-    
+
   def display_current_level(self):
     self.cleanup()
     gcompris.score.start(gcompris.score.STYLE_NOTE, 570, 305,
@@ -129,7 +128,7 @@ class Gcompris_algorithm:
     # Create our rootitem. We put each canvas item in it so at the end we
     # only have to kill it. The canvas deletes all the items it contains automaticaly.
     self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=0.0,
       y=0.0
       )
@@ -156,33 +155,33 @@ class Gcompris_algorithm:
 
     # Display the uncomplete user area
     self.random_index = []
-    
+
     for i in range(self.anzahl):
      self.random_index.append(random.randrange(len(self.symbollist)))
-     
+
     for i in range(5):
      self.paint_image(self.random_index[self.algo(i)], i, 147)
-     
-    self.place = 5 
+
+    self.place = 5
     self.paint_qm ()
 
   def paint_qm (self):
-    self.qm = self.rootitem.add(gnome.canvas.CanvasText, text = "?", 
-     x = self.place*self.distance+30+self.leftx, 
-     y = 185, fill_color_rgba = 0x000000ffL, 
+    self.qm = self.rootitem.add(gnomecanvas.CanvasText, text = "?",
+     x = self.place*self.distance+30+self.leftx,
+     y = 185, fill_color_rgba = 0x000000ffL,
      font = gcompris.skin.get_font("gcompris/board/huge bold"))
-    
+
   def key_press(self, keyval, commit_str, preedit_str):
     print("got key %i" % keyval)
     return False
 
-  def set_level(self, level):  
+  def set_level(self, level):
     print("Gcompris_algorithm set level. %i" % level)
     self.gcomprisBoard.level=level;
     self.gcomprisBoard.sublevel=1;
     self.cleanup()
     self.display_current_level()
-  
+
   # Code that increments the sublevel and level
   # And bail out if no more levels are available
   # return 1 if continue, 0 if bail out
@@ -197,7 +196,7 @@ class Gcompris_algorithm:
         # the current board is finished : bail out
         gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
         return 0
-      
+
     self.display_current_level()
     return 1
 
