@@ -1,19 +1,19 @@
-#  gcompris - connect4 
-# 
-# Time-stamp: 
-# 
-# Copyright (C) 2005 Laurent Lacheny 
-# 
+#  gcompris - connect4
+#
+# Time-stamp:
+#
+# Copyright (C) 2005 Laurent Lacheny
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -24,8 +24,7 @@
 #
 
 import gobject
-import gnome
-import gnome.canvas
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -41,18 +40,16 @@ from  connect4p import human
 from  connect4p import minmax
 from  connect4p import board
 # ----------------------------------------
-# 
+#
 
 class Gcompris_connect4:
   """Connect 4 stones"""
 
 
   def __init__(self, gcomprisBoard):
-    print("Gcompris_connect4 __init__.")
     self.gcomprisBoard = gcomprisBoard
 
   def start(self):
-    print "Gcompris_connect4_start."
     self.boardSize = 490.0
     self.nbColumns = 7
     self.nbLines = 6
@@ -61,8 +58,8 @@ class Gcompris_connect4:
     self.maxLevel = 4
     self.firstPlayer = False
     self.boardItem = None
-    self.timerAnim = 0 
-    self.timerMachine = 0 
+    self.timerAnim = 0
+    self.timerMachine = 0
     self.humanVictory = 0
     self.machineHasPlayed = True
     self.endAnimCallback = None
@@ -70,13 +67,14 @@ class Gcompris_connect4:
     self.gcomprisBoard.maxlevel=9
     self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
+    self.winnercall = None
     gcompris.bar_set(gcompris.BAR_LEVEL)
     gcompris.bar_set_level(self.gcomprisBoard)
 
     # Create our rootitem. We put each canvas item in it so at the end we
     # only have to kill it. The canvas deletes all the items it contains automaticaly.
     self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=0.0,
       y=0.0
       )
@@ -89,7 +87,7 @@ class Gcompris_connect4:
       gcompris.bar_set(gcompris.BAR_LEVEL|gcompris.BAR_REPEAT)
 
     selector = self.rootitem.add(
-     gnome.canvas.CanvasPixbuf,
+     gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("connect4/back.png"),
       x=0.0,
       y=0.0
@@ -97,7 +95,7 @@ class Gcompris_connect4:
     selector.connect("event", self.columnItemEvent, 0)
 
     self.prof = self.rootitem.add(
-     gnome.canvas.CanvasPixbuf,
+     gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("connect4/tux-teacher.png"),
       x=10,
       y=350.0
@@ -107,12 +105,11 @@ class Gcompris_connect4:
 
     self.timericon = gcompris.anim.CanvasItem( gcompris.anim.Animation("connect4/sablier.txt"),
                                                self.rootitem )
-    self.timericon.gnome_canvas.hide()
+    self.timericon.gnomecanvas.hide()
 
     self.newGame()
 
   def end(self):
-    print "Gcompris_connect4 end."
     if self.timerAnim:
       gtk.timeout_remove(self.timerAnim)
     if self.timerMachine:
@@ -123,34 +120,31 @@ class Gcompris_connect4:
     # Remove the root item removes all the others inside it
     self.rootitem.destroy()
     self.boardItem.destroy()
-    
+
 
   def ok(self):
-    print("Gcompris_connect4 ok.")
+    pass
 
   def repeat(self):
-    print("Gcompris_connect4 repeat.", self.humanVictory)
     if self.humanVictory >= self.maxVictory:
       if self.gcomprisBoard.level < self.maxLevel:
         self.set_level(self.gcomprisBoard.level+1)
       else:
-        print "Level max is reached!"
         self.end()
         gcompris.end_board()
-    else: 
+    else:
       self.newGame()
 
   def config(self):
-    print("Gcompris_connect4 config.")
+    pass
 
 
   def key_press(self, keyval, commit_str, preedit_str):
-    print("Gcompris_connect4 key press. %i" % keyval)
-    self.timericon.gnome_canvas.hide()
+    self.timericon.gnomecanvas.hide()
     return False
 
   def pause(self, pause):
-    print("Gcompris_connect4 pause.")
+    pass
 
   # Called by gcompris when the user click on the level icon
   def set_level(self, level):
@@ -160,7 +154,7 @@ class Gcompris_connect4:
     gcompris.bar_set_level(self.gcomprisBoard)
     self.player1.setDifficulty(level)
     self.player2.setDifficulty(level)
-    self.humanVictory = 0 
+    self.humanVictory = 0
     self.newGame()
 
   # End of Initialisation
@@ -170,37 +164,37 @@ class Gcompris_connect4:
     if self.boardItem != None:
       self.boardItem.destroy()
     self.boardItem = self.gcomprisBoard.canvas.root().add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=(gcompris.BOARD_WIDTH-self.boardSize)/2.0,
-      y=50.0 
+      y=50.0
       )
     self.player1 = human.Human(self.gcomprisBoard.level)
     self.player2 = minmax.MinMax(self.gcomprisBoard.level, self.refreshScreen)
     self.board = board.Board()
     self.gamewon = False
+    self.machineHasPlayed = True
     self.winLine = None
     try:
       del self.redLine
     except:
       pass
-    self.firstPlayer = False 
+    self.firstPlayer = False
     self.prof.show()
 
   def columnItemEvent(self, widget, event, column):
     if event.type == gtk.gdk.BUTTON_PRESS:
       if event.button == 1 and self.gamewon == False and self.machineHasPlayed:
         column = int((event.x - (gcompris.BOARD_WIDTH-self.boardSize)/2.0) // self.stoneSize)
-        #print "columnItemEvent", column
         if not (column < 0 or column > (self.nbColumns-1)):
           gcompris.bar_hide(True)
           if self.play(self.player1, 1, column):
-            if self.gamewon == False:
-              self.timericon.gnome_canvas.show()
+            if self.winnercall == None:
+              self.timericon.gnomecanvas.show()
               self.endAnimCallback = self.machinePlay
               self.machineHasPlayed = False
-   
+
     return False
-  
+
   def profItemEvent(self, widget, event, column):
     #if event.type == gtk.gdk.BUTTON_PRESS and self.firstPlayer == False:
     if event.type == gtk.gdk.BUTTON_PRESS:
@@ -208,10 +202,10 @@ class Gcompris_connect4:
       self.machinePlay()
 
   def machinePlay(self):
-    print "ai starts"
+    # ai starts
     self.play(self.player2, 2, 0)
-    print "ai ends"
-    self.timericon.gnome_canvas.hide()
+    # ai ends
+    self.timericon.gnomecanvas.hide()
     self.prof.hide()
     self.endAnimCallback = self.machinePlayed
 
@@ -225,22 +219,22 @@ class Gcompris_connect4:
 
   def play(self, player, numPlayer, column):
     move = player.doMove(self.board, numPlayer, column)
-    
+
     if type(move) is types.IntType and rules.isMoveLegal(self.board, move):
 #      self.firstPlayer = True
       self.board.move(move, numPlayer)
       self.drawBoard(self.board)
       self.winLine = rules.isWinner(self.board, numPlayer)
-      
+
       if self.winLine:
-        self.winner(numPlayer)
+        self.winnercall = lambda : self.winner(numPlayer)
       elif rules.isBoardFull(self.board):
-        self.winner(0)
+        self.winnercall = lambda : self.winner(0)
       return True
-    
+
     gcompris.bar_hide(False)
     return False
-        
+
   def drawBoard(self, board):
     stone = self.board.state[self.board.last_move][-1]
     x = self.board.last_move
@@ -248,7 +242,7 @@ class Gcompris_connect4:
     file = "connect4/stone_%d.png" % stone
 
     self.stone = self.boardItem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
        pixbuf = gcompris.utils.load_pixmap(file),
        x=x*(self.boardSize/self.nbColumns),
        #y=(self.boardSize/self.nbColumns)*(self.nbLines-1-y)
@@ -265,12 +259,15 @@ class Gcompris_connect4:
       self.stone.set_property('y', y + (self.boardSize/self.nbColumns))
       self.timerAnim = gtk.timeout_add(200, self.animTimer)
     else:
+      if self.winnercall:
+        self.winnercall()
+        self.winnercall=None
+        self.endAnimCallback=None
       if self.endAnimCallback:
         self.endAnimCallback()
 
   def winner(self, player):
     self.gamewon = True
-    print 'The winner is:', player
 
     # It's a draw, no line to draw
     if player == 0:
@@ -282,18 +279,18 @@ class Gcompris_connect4:
         ((not self.firstPlayer) and (player==1))):
       self.humanVictory += 1
     else:
-      self.humanVictory = 0 
+      self.humanVictory = 0
     points = ( self.winLine[0][0]*(self.boardSize/self.nbColumns)+self.stoneSize/2,
                (self.boardSize/self.nbColumns)*(self.nbLines-1-self.winLine[0][1])+self.stoneSize/2,
                self.winLine[1][0]*(self.boardSize/self.nbColumns)+self.stoneSize/2,
                (self.boardSize/self.nbColumns)*(self.nbLines-1-self.winLine[1][1])+self.stoneSize/2
                )
-               
+
     self.redLine = self.boardItem.add(
-      gnome.canvas.CanvasLine,
+      gnomecanvas.CanvasLine,
        fill_color_rgba=0xFF0000FFL,
        points=points,
-       width_pixels = 8 
+       width_pixels = 8
        )
     self.redLine.set_property("cap-style", gtk.gdk.CAP_ROUND)
     if player == 1:
