@@ -1,24 +1,23 @@
 #  gcompris - electric
-# 
+#
 # Copyright (C) 2005 Bruno Coudoin
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
+#
 
-import gnome
-import gnome.canvas
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -26,8 +25,10 @@ import gcompris.admin
 import gcompris.bonus
 import gtk
 import gtk.gdk
+import gobject
 
 import os
+import tempfile
 
 # Set to True to debug
 debug = False
@@ -37,19 +38,19 @@ from gcompris import gcompris_gettext as _
 class Gcompris_electric:
   """Tux hide a number, you must guess it"""
 
-  def __init__(self, gcomprisBoard):    
+  def __init__(self, gcomprisBoard):
 
     self.gcomprisBoard = gcomprisBoard
 
     self.gcomprisBoard.disable_im_context = True
 
-    # Part of UI : tools buttons                               
+    # Part of UI : tools buttons
     # TOOL SELECTION
     self.tools = [
       ["DEL",    "draw/tool-del.png",     "draw/tool-del_on.png",     gcompris.CURSOR_DEL],
       ["SELECT", "draw/tool-select.png",  "draw/tool-select_on.png",  gcompris.CURSOR_SELECT]
       ]
-    
+
     # These are used to let us restart only after the bonus is displayed.
     # When the bonus is displayed, it call us first with pause(1) and then
     # with pause(0)
@@ -64,14 +65,14 @@ class Gcompris_electric:
     self.gnucap_binary = None
 
   def start(self):
-    
+
     self.gcomprisBoard.level=1
     self.gcomprisBoard.maxlevel=3
     self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
 
     gcompris.bar_set(gcompris.BAR_LEVEL)
-    
+
     gcompris.bar_set_level(self.gcomprisBoard)
 
     gcompris.set_background(self.gcomprisBoard.canvas.root(),
@@ -83,17 +84,16 @@ class Gcompris_electric:
     # Check gnucap is installed and save it's path in self.gnucap_binary
     #
     for binary in ("/usr/bin/gnucap",
-                   "/usr/local/bin/gnucap"):
-      try:
-        os.stat(binary)
+                   "/usr/local/bin/gnucap",
+                   "gnucap.exe"):
+      if(os.path.exists(binary)):
         self.gnucap_binary = binary
-      except:
-        pass
+        break
 
     if not self.gnucap_binary:
       gcompris.utils.dialog(_("Cannot find the 'gnucap' electric simulator.\nYou can download and install it from:\n<http://geda.seul.org/tools/gnucap/>\nTo be detected, it must be installed in\n/usr/bin/gnucap or /usr/local/bin/gnucap.\nYou can still use this activity to draw schematics without computer simulation."),
                             None)
-    
+
 
   def end(self):
 
@@ -106,15 +106,11 @@ class Gcompris_electric:
 
   def ok(self):
     pass
-    
+
   def repeat(self):
     if debug: print("Gcompris_electric repeat.")
 
 
-  def config(self):
-    if debug: print("Gcompris_electric config.")
-
-
   def key_press(self, keyval, commit_str, preedit_str):
     # Return  True  if you did process a key
     # Return  False if you did not processed a key
@@ -146,18 +142,6 @@ class Gcompris_electric:
 
     self.cleanup_game()
     self.display_game()
-    
-  ###################################################
-  # Configuration system
-  ###################################################
-  
-  #mandatory but unused yet
-  def config_stop(self):
-    pass
-
-  # Configuration function.
-  def config_start(self, profile):
-    pass
 
   #
   # End of Initialisation
@@ -180,14 +164,14 @@ class Gcompris_electric:
       self.gcomprisBoard.sublevel=1
       self.gcomprisBoard.level += 1
       gcompris.bar_set_level(self.gcomprisBoard)
-      
+
       if(self.gcomprisBoard.level>self.gcomprisBoard.maxlevel):
         # the current board is finished : bail out
         gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
         return 0
-      
+
     return 1
-  
+
   # Cleanup the board game
   def cleanup_game(self):
     self.gamewon = False
@@ -196,9 +180,13 @@ class Gcompris_electric:
       gtk.timeout_remove(self.gnucap_timer)
       self.gnucap_timer = 0
 
+    # remove the appended items from our tools
+    for i in range(0,len(self.tools)):
+      self.tools[i].pop()
+
     # No more component in the simulation set
     self.components = []
-      
+
     # Remove the root item removes all the others inside it
     self.rootitem.destroy()
 
@@ -209,7 +197,7 @@ class Gcompris_electric:
       # only have to kill it. The canvas deletes all the items it contains
       # automaticaly.
       self.rootitem = self.gcomprisBoard.canvas.root().add(
-          gnome.canvas.CanvasGroup,
+          gnomecanvas.CanvasGroup,
           x=0.0,
           y=0.0
           )
@@ -222,7 +210,7 @@ class Gcompris_electric:
       for i in range(0,len(self.tools)):
 
         item = self.rootitem.add(
-          gnome.canvas.CanvasPixbuf,
+          gnomecanvas.CanvasPixbuf,
           pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin(self.tools[i][1])),
           x=x,
           y=y
@@ -241,14 +229,14 @@ class Gcompris_electric:
 
         # Add the item in self.tools for later use
         self.tools[i].append(item)
-        
+
 
   # Return the textual form of the current selected tool
   # Return on of self.tools[i][0]
   def get_current_tools(self):
       return(self.tools[self.current_tool][0])
 
-    
+
   # Event when a tool is selected
   # Perform instant action or swich the tool selection
   def tool_item_event(self, item, event, tool):
@@ -260,13 +248,13 @@ class Gcompris_electric:
 
     return False
 
-  
+
   def assign_tool(self, newtool):
     # Deactivate old button
     item = self.tools[self.current_tool][4]
     item.set(pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin(self.tools[self.current_tool][1])))
 
-    # Activate new button                         
+    # Activate new button
     self.current_tool = newtool
     item = self.tools[newtool][4]
     item.set(pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin(self.tools[self.current_tool][2])))
@@ -290,6 +278,7 @@ class Gcompris_electric:
                        (Bulb, 0.11),
                        (Rheostat, 1000),
                        (Switch, None),
+                       (Switch2, None),
                        (Connection, None),
                        )
     elif(level == 3):
@@ -302,59 +291,62 @@ class Gcompris_electric:
                        (Connection, None),
                        (Diode, None),
                        )
-        
+
     Selector(self, component_set)
-    
 
 
-  
+
+
 # ----------------------------------------------------------------------
 # ----------------------------------------------------------------------
 # ----------------------------------------------------------------------
 # ----------------------------------------------------------------------
 
   def run_simulation(self):
+    if debug: print "run_simulation %s" %(self.gnucap_binary,)
     if not self.gnucap_binary:
       return
 
+    if debug: print "self.gnucap_timer = %d" %(self.gnucap_timer,)
     if not self.gnucap_timer:
-      self.gnucap_timer = gtk.timeout_add(self.gnucap_timer_interval, self.call_gnucap)
+      if debug: print "run_simulation timeout_add"
+      self.gnucap_timer = gobject.timeout_add(self.gnucap_timer_interval, self.call_gnucap)
 
   def call_gnucap(self):
     if not self.components:
       if debug: print "call_gnucap: No component"
       self.gnucap_timer = 0
       return
-    
-    connected = 0
+
+    connected = False
     for component in self.components:
       if component.is_connected():
-        connected = 1
+        connected = True
 
-    if not connected == 1:
-      if debug: print "call_gnucap: No connected component"
-    
-    filename = "/tmp/gcompris_electric.gnucap.%d" %(os.getpid(),)
+    if debug: print "call_gnucap create the tempfile"
 
-    f = file(filename, "w+")
+    fd, filename = tempfile.mkstemp(".gnucap", "gcompris_electric", None, True)
+    f = os.fdopen(fd, "w+t")
 
     gnucap = "Title GCompris\n"
 
     # Ugly hack: connect a 0 ohm (1 fempto) resistor between net 0
     # and first net found
-    if connected == 1:
-      gnucap += "R999999999 0 "
-      for component in self.components:
-        if component.is_connected():
-          gnucap += str(component.get_nodes()[0].get_wires()[0].get_wire_id())
-          break
-      gnucap += " 1f\n"
-    
+    gnucap += "R999999999 0 "
+    for component in self.components:
+      if component.is_connected():
+        gnucap += str(component.get_nodes()[0].get_wires()[0].get_wire_id())
+        break
+    gnucap += " 1f\n"
+
+    gnucap_print = ""
     for component in self.components:
       if component.is_connected():
         thisgnucap = component.to_gnucap("")
-        gnucap += thisgnucap
+        gnucap += thisgnucap[0]
+        gnucap_print += thisgnucap[1]
 
+    gnucap += gnucap_print
     gnucap += ".dc\n"
     gnucap += ".end\n"
     if debug: print gnucap
@@ -364,12 +356,14 @@ class Gcompris_electric:
     #
     # Run gnucap with the temporary datafile we created.
     #
+    if debug: print "calling gnucap: %s -b %s" % (self.gnucap_binary, filename)
     output = os.popen("%s -b %s" % (self.gnucap_binary, filename))
 
     #
     # Read and analyse gnucap result
     #
     if debug: print "---------------- GNUCAP OUTPUT PARSING ---------------------"
+    line = ""
     for line in output.readlines():
       if debug: print "==="
       if debug: print line
@@ -380,6 +374,14 @@ class Gcompris_electric:
     if debug: print "===>"
     if debug: print line
     if debug: print "===>"
+
+    # Close it to check errors
+    results = output.close()
+    if results:
+      print('Failed to run gnugap with error ', results)
+      self.gnucap_timer = 0
+      return
+
     values = []
     if(line.split()[0] == "0."):
       if debug: print "FOUND 0."
@@ -408,7 +410,7 @@ class Gcompris_electric:
             if debug: print "Warning: gnucap parsing mismatch"
             done = True
             continue
-            
+
           try:
             volt = self.convert_gnucap_value(values[i])
             amp = self.convert_gnucap_value(values[i+1])
@@ -420,16 +422,16 @@ class Gcompris_electric:
 
           i += 2
 
-      
-    os.remove(filename)
+
+    if not debug: os.remove(filename)
     self.gnucap_timer = 0
-    
+
   # Convert a gnucap value back in a regular number
   # Return a float value
   # Or a ValueError exception
   def convert_gnucap_value(self, value):
     unit = 1
-    
+
     if value.endswith("T"):
       unit = e12
       value = value.replace("T", "")
@@ -466,9 +468,9 @@ class Gcompris_electric:
     sign = 1
     if float(value) < 0:
       sign = -1
-    
+
     return (float(sign)*float(value)*unit)
-    
+
 
 
 
@@ -489,18 +491,18 @@ class Wire:
     #numbered sequentially.
     counter = 1
     connection = {}
-    colors = [ 0xdfc766FFL,   
-               0xdf9766FFL,   
-               0xdf667dFFL,   
-               0xdf66bcFFL,   
-               0xc466dfFFL,   
-               0x9c66dfFFL,   
-               0xA4FFB3FFL,   
-               0x6666dfFFL,   
-               0x669fdfFFL,   
+    colors = [ 0xdfc766FFL,
+               0xdf9766FFL,
+               0xdf667dFFL,
+               0xdf66bcFFL,
+               0xc466dfFFL,
+               0x9c66dfFFL,
+               0xA4FFB3FFL,
+               0x6666dfFFL,
+               0x669fdfFFL,
                0x66df6cFFL,
                0x66dfd8FFL ]
-               
+
     def __init__(self, electric, source_node, x1, y1, x2, y2):
       self.electric = electric
       self.rootitem = electric.rootitem
@@ -511,7 +513,7 @@ class Wire:
       self.x2 = x2
       self.y2 = y2
       self.wire_item = self.rootitem.add(
-        gnome.canvas.CanvasLine,
+        gnomecanvas.CanvasLine,
         points=( self.x1, self.y1, self.x2, self.y2),
         fill_color_rgba = 0xFF0000FFL,
         width_units=5.0
@@ -519,7 +521,7 @@ class Wire:
       self.wire_item.connect("event", self.delete_wire, self)
       self.wire_id = -1
       self._add_connection(source_node)
-      
+
     def _add_connection(self, node):
       # Is this node already connected
       if(node.get_wires()):
@@ -538,14 +540,14 @@ class Wire:
             Wire.counter += 1
           else:
             self.wire_id = wire_id
-           
+
       else:
         if self.wire_id == -1:
           self.wire_id = Wire.counter
           Wire.counter += 1
-          
+
         Wire.connection[node] = self
-        
+
       if debug: print "WIRE_ID = %d" %self.wire_id
 
     def set_wire_id(self, id):
@@ -557,10 +559,10 @@ class Wire:
 
       # Colorize the wire
       self.wire_item.set(fill_color_rgba = Wire.colors[id % len(Wire.colors)])
-    
+
     def get_wire_id(self):
       return self.wire_id
-    
+
     def destroy(self):
       self.wire_item.destroy()
       self.wire_id = -1
@@ -571,15 +573,15 @@ class Wire:
       self.source_node = None
       self.target_node = None
       self.electric.run_simulation()
-      
-      
+
+
     def set_target_node(self, node):
       self.target_node = node
       self._add_connection(node)
-      
+
       # Colorize the wire
       self.wire_item.set(fill_color_rgba = Wire.colors[self.wire_id % len(Wire.colors)])
-      
+
     # Move wire. In fact, the attached component are moved and THEY
     # move the wire
     def move_all_wire(self, x, y):
@@ -588,14 +590,14 @@ class Wire:
         target_component = self.target_node.get_component()
         # TBD Need to move the components but not loosing their distance.
         #     Don't know yet how
-        
+
     # Move one node of the wire at a time, depending on the given node
     def move(self, node, x, y):
       if(node == self.source_node):
         self.move_source_node(x, y)
       elif(node== self.target_node):
         self.move_target_node(x, y)
-        
+
     def move_source_node(self, x1, y1):
       self.x1 = x1
       self.y1 = y1
@@ -611,7 +613,7 @@ class Wire:
 
     # Callback event to delete a wire
     def delete_wire(self, widget, event, wire):
-      
+
       if event.type == gtk.gdk.BUTTON_PRESS:
         if event.button == 1:
           wire.destroy()
@@ -641,9 +643,9 @@ class Node:
       pixmap = gcompris.utils.load_pixmap(self.image)
       self.center_x =  pixmap.get_width()/2
       self.center_y =  pixmap.get_height()/2
-        
+
       self.item = self.rootitem.add(
-        gnome.canvas.CanvasPixbuf,
+        gnomecanvas.CanvasPixbuf,
         pixbuf = pixmap,
         x = x + self.center_x,
         y = y + self.center_y,
@@ -668,8 +670,8 @@ class Node:
           self.renumber_wire(wire, wire_id)
       except:
         pass
-        
-      
+
+
     # Renumber the wires
     def renumber_wire(self, wire, wire_id):
       for wire in self.wires:
@@ -691,7 +693,7 @@ class Node:
       except:
         pass
 
-      
+
     def move(self, x, y):
       if(self.item):
         self.item.set(x = x + self.x,
@@ -721,14 +723,14 @@ class Component(object):
         self.electric.components.append(self)
       else:
         self.gnucap_name = ""
-        
+
       Component.counter += 1
       self.gnucap_value = gnucap_value
       self.image = image
       self.nodes = nodes
       # Create a group for this component
       self.comp_rootitem = self.rootitem.add(
-        gnome.canvas.CanvasGroup,
+        gnomecanvas.CanvasGroup,
         x=0.0,
         y=0.0
         )
@@ -740,12 +742,14 @@ class Component(object):
       self.y = 0
       self.center_x =  pixmap.get_width()/2
       self.center_y =  pixmap.get_height()/2
-      
+
+      self.component_item_offset_x = 0
+      self.component_item_offset_y = 0
       self.component_item = self.comp_rootitem.add(
-        gnome.canvas.CanvasPixbuf,
+        gnomecanvas.CanvasPixbuf,
         pixbuf = pixmap,
-        x = self.x,
-        y = self.y,
+        x = self.x + self.component_item_offset_x,
+        y = self.y + self.component_item_offset_y,
         )
       self.component_item.connect("event", self.component_move, self)
 
@@ -758,7 +762,7 @@ class Component(object):
       self.item_values_x = 0
       self.item_values_y = 0
       self.item_values = self.comp_rootitem.add(
-        gnome.canvas.CanvasText,
+        gnomecanvas.CanvasText,
         x = self.item_values_x,
         y = self.item_values_y,
         font = "Sans 8",
@@ -780,23 +784,23 @@ class Component(object):
         self.item_values.hide()
       return True
 
-      
+
     def get_rootitem(self):
       return self.comp_rootitem
-    
+
     def move(self, x, y):
       self.x =  x - self.center_x
       self.y =  y - self.center_y
-      
+
       self.item_values.set(x =  self.item_values_x + self.x,
                            y =  self.item_values_y + self.y)
 
-      self.component_item.set(x =  self.x,
-                              y =  self.y)
+      self.component_item.set(x =  self.x + self.component_item_offset_x,
+                              y =  self.y + self.component_item_offset_y )
 
       for node in self.nodes:
         node.move( self.x,  self.y)
-        
+
     def show(self):
       self.comp_rootitem.show()
 
@@ -809,7 +813,7 @@ class Component(object):
         self.electric.components.remove(self)
       except:
         pass
-      
+
       for node in self.nodes:
         while node.get_wires():
           wire = node.get_wires()[0]
@@ -817,7 +821,7 @@ class Component(object):
           wire.destroy()
 
       self.comp_rootitem.destroy()
-        
+
     # Return the nodes
     def get_nodes(self):
       return self.nodes
@@ -832,9 +836,9 @@ class Component(object):
       for node in self.nodes:
         if not node.get_wires():
           return False
-        
+
       return True
-    
+
     # Return the gnucap definition for this component
     # model is optional
     #
@@ -857,27 +861,26 @@ class Component(object):
         gnucap += " "
         if(node.get_wires()):
           gnucap += str(node.get_wires()[0].get_wire_id())
-          
+
       gnucap += " "
       gnucap += str(self.gnucap_value)
       gnucap += "\n"
       gnucap += model
-      gnucap += ".print dc + v(%s) i(%s)\n" %(self.gnucap_name, self.gnucap_name)
 
-      return gnucap
-    
+      return [gnucap, ".print dc + v(%s) i(%s)\n" %(self.gnucap_name, self.gnucap_name)]
+
     # Callback event to move the component
     def component_move(self, widget, event, component):
-      
+
       if event.state & gtk.gdk.BUTTON1_MASK:
         if event.type == gtk.gdk.MOTION_NOTIFY:
           if(self.electric.get_current_tools()=="SELECT"):
             component.move(event.x, event.y)
-            
+
         else:
           if(self.electric.get_current_tools()=="DEL"):
             self.destroy()
-          
+
       return True
 
     # Callback event to create a wire
@@ -885,7 +888,7 @@ class Component(object):
 
       if(self.electric.get_current_tools()=="DEL"):
         return True
-      
+
       if event.type == gtk.gdk.BUTTON_PRESS:
         if event.button == 1:
           bounds = widget.get_bounds()
@@ -899,7 +902,7 @@ class Component(object):
       if event.type == gtk.gdk.MOTION_NOTIFY:
         if event.state & gtk.gdk.BUTTON1_MASK:
           self.wire.move_target_node(event.x, event.y)
-        
+
       if event.type == gtk.gdk.BUTTON_RELEASE:
         if event.button == 1:
           node_target = None
@@ -910,7 +913,7 @@ class Component(object):
               node_target = target_item.get_data('node')
               if(node_target):
                 break
-            
+
           # Take care not to wire the same component or 2 times the same node
           if(not node_target
              or node.get_component() == node_target.get_component()
@@ -921,7 +924,7 @@ class Component(object):
             self.wire.set_target_node(node_target)
             node_target.add_wire(self.wire)
             self.electric.run_simulation()
-            
+
           return True
 
       return False
@@ -936,7 +939,7 @@ class Component(object):
 
 # ----------------------------------------
 # RESISTOR
-# 
+#
 #
 class Resistor(Component):
   image = "electric/resistor.png"
@@ -959,7 +962,7 @@ class Resistor(Component):
 
 # ----------------------------------------
 # DIODE
-# 
+#
 #
 class Diode(Component):
   image = "electric/diode.png"
@@ -991,13 +994,13 @@ class Diode(Component):
     model = ".model  ddd  d  ( is= 50.u  rs= 0.  n= 0.072  tt= 0.  cjo= 1.p  vj= 1.  m= 0.5\n"
     model += "+ eg= 1.11  xti= 3.  kf= 0.  af= 1.  fc= 0.5  bv= 0.  ibv= 0.001 )\n"
 
-    gnucap = ""
-    gnucap += super(Diode, self).to_gnucap(model)
+    gnucap = []
+    gnucap = super(Diode, self).to_gnucap(model)
     return gnucap
-  
+
 # ----------------------------------------
 # SWITCH
-# 
+#
 #
 class Switch(Component):
   image = "electric/switch_off.png"
@@ -1008,7 +1011,7 @@ class Switch(Component):
     self.click_ofset_y = -28
     self.value_on  = "0"
     self.value_off = "10000k"
-    
+
     super(Switch, self).__init__(electric,
                                  "R",
                                  self.value_off,
@@ -1018,12 +1021,12 @@ class Switch(Component):
 
     # Overide some values
     self.item_values.hide()
-    
+
     self.move(x, y)
 
     pixmap = gcompris.utils.load_pixmap("electric/switch_click.png")
     self.click_item = self.comp_rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x = self.x + self.click_ofset_x,
       y = self.y + self.click_ofset_y,
@@ -1040,25 +1043,25 @@ class Switch(Component):
       else:
         self.gnucap_value = self.value_off
         pixmap = gcompris.utils.load_pixmap("electric/switch_off.png")
-        
+
       self.component_item.set(pixbuf = pixmap)
       self.electric.run_simulation()
-        
+
     return False
 
   # Callback event to move the component
   def component_move(self, widget, event, component):
      super(Switch, self).component_move(widget, event, component)
-     
+
      if(self.electric.get_current_tools()=="DEL"):
        return True
-     
+
      self.click_item.set(
        x = self.x + self.click_ofset_x,
        y = self.y + self.click_ofset_y)
 
      return True
-   
+
   # Return False if we need more value to complete our component
   # This is usefull in case where one Component is made of several gnucap component
   def set_voltage_intensity(self, valid_value, voltage, intensity):
@@ -1068,9 +1071,162 @@ class Switch(Component):
     self.item_values.hide()
     return True
 
+# ----------------------------------------
+# SWITCH2
+#
+#
+class Switch2(Component):
+  image = "electric/switch2_on.png"
+  icon  = "electric/switch2_icon.png"
+  def __init__(self, electric,
+               x, y, dummy):
+    self.click_ofset_x = 22
+    self.click_ofset_y = -28
+    self.gnucap_current_resistor = 1
+    self.gnucap_nb_resistor = 0
+    self.value_on  = "0"
+    self.value_off = "10000k"
+    self.value_top = self.value_on
+    self.value_bottom = self.value_off
+
+    super(Switch2, self).__init__(electric,
+                                   "R",
+                                   self.value_off,
+                                   self.image,
+                                   [Node("electric/connect.png", "C", -15, 0),
+                                    Node("electric/connect.png", "A", 80, -25),
+                                    Node("electric/connect.png", "B", 80, 25)])
+
+    # Overide some values
+    self.item_values.hide()
+
+    self.move(x, y)
+
+    pixmap = gcompris.utils.load_pixmap("electric/switch_click.png")
+    self.click_item = self.comp_rootitem.add(
+      gnomecanvas.CanvasPixbuf,
+      pixbuf = pixmap,
+      x = self.x + self.click_ofset_x,
+      y = self.y + self.click_ofset_y,
+      )
+    self.click_item.connect("event", self.component_click)
+    self.show()
+
+
+  # Callback event on the switch
+  def component_click(self, widget, event):
+    if event.state & gtk.gdk.BUTTON1_MASK:
+      if(self.value_top == self.value_off):
+        self.value_top = self.value_on
+        self.value_bottom = self.value_off
+        self.component_item_offset_y = - 6
+        pixmap = gcompris.utils.load_pixmap("electric/switch2_on.png")
+      else:
+        self.value_top = self.value_off
+        self.value_bottom = self.value_on
+        self.component_item_offset_y = 10
+        pixmap = gcompris.utils.load_pixmap("electric/switch2_off.png")
+
+      self.component_item.set(y = self.y + self.component_item_offset_y)
+      self.component_item.set(pixbuf = pixmap)
+      self.electric.run_simulation()
+
+    return False
+
+  # Callback event to move the component
+  def component_move(self, widget, event, component):
+    super(Switch2, self).component_move(widget, event, component)
+
+    if(self.electric.get_current_tools()=="DEL"):
+      return True
+
+    self.click_item.set(
+      x = self.x + self.click_ofset_x,
+      y = self.y + self.click_ofset_y)
+
+    return True
+
+  # Return True if this component is connected and can provides a gnucap
+  # description
+  #
+  # The switch2 needs at least 2 connected nodes
+  #
+  def is_connected(self):
+    count = 0
+    for node in self.nodes:
+      if node.get_wires():
+        count += 1
+
+    if count >= 2:
+      return True
+
+    return False
+
+  # Return the gnucap definition for a single resitor of the switch2
+  # node_id1 and node_id2 are the index in the list of nodes
+  def to_gnucap_res(self, gnucap_name, node_id1, node_id2, gnucap_value):
+    gnucap = gnucap_name
+    gnucap += " "
+
+    for i in (node_id1, node_id2):
+      node = self.nodes[i]
+      if node.get_wires():
+        gnucap += str(node.get_wires()[0].get_wire_id())
+
+      gnucap += " "
+
+    gnucap += " "
+    gnucap += str(gnucap_value)
+    gnucap += "\n"
+
+    return [gnucap, ".print dc + v(%s) i(%s)\n" %(gnucap_name, gnucap_name)]
+
+  # Return the gnucap definition for this component
+  # depending of the connected nodes, it create one or two resistor
+  def to_gnucap(self, model):
+
+    gnucap = ["", ""]
+
+    # reset set_voltage_intensity counter
+    self.gnucap_current_resistor = 0
+    self.gnucap_nb_resistor = 0
+
+    # top resistor
+    if self.nodes[0].get_wires() and \
+       self.nodes[1].get_wires():
+      gnucap_resp = self.to_gnucap_res(self.gnucap_name + "_top", 0, 1,
+                                        self.value_top)
+      gnucap[0] += gnucap_resp[0]
+      gnucap[1] += gnucap_resp[1]
+      self.gnucap_nb_resistor += 1
+
+    # bottom resistor
+    if self.nodes[0].get_wires() and \
+       self.nodes[2].get_wires():
+      gnucap_resp = self.to_gnucap_res(self.gnucap_name + "_bot", 0, 2,
+                                       self.value_bottom)
+      gnucap[0] += gnucap_resp[0]
+      gnucap[1] += gnucap_resp[1]
+      self.gnucap_nb_resistor += 1
+
+    return [gnucap[0], gnucap[1]]
+
+  # Return False if we need more value to complete our component
+  # This is usefull in case where one Component is made of several gnucap component
+  def set_voltage_intensity(self, valid_value, voltage, intensity):
+    # Never show values
+    self.item_values.hide()
+
+    self.gnucap_current_resistor += 1
+
+    if(self.gnucap_nb_resistor == self.gnucap_current_resistor):
+      return True
+    else:
+      return False
+
 # ----------------------------------------
 # RHEOSTAT
-# 
+#
 #
 class Rheostat(Component):
   image = "electric/resistor_track.png"
@@ -1091,26 +1247,26 @@ class Rheostat(Component):
                                    [Node("electric/connect.png", "A", 0, -25),
                                     Node("electric/connect.png", "B", 50, 50),
                                     Node("electric/connect.png", "C", 0, 125)])
-    
+
     # Overide some values
     self.item_values_x = 20
     self.item_values_y = 70
     self.item_values.set(fill_color="blue")
-  
+
     self.move(x, y)
 
     # The wiper wire
     self.wiper_wire_item = self.comp_rootitem.add(
-      gnome.canvas.CanvasLine,
+      gnomecanvas.CanvasLine,
       points = (0,0,0,0),
       fill_color_rgba = 0x5A5A5AFFL,
       width_units=5.0
       )
     self.update_wiper_wire()
-    
+
     pixmap = gcompris.utils.load_pixmap("electric/resistor_wiper.png")
     self.wiper_item = self.comp_rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x = self.x + self.wiper_ofset_x,
       y = self.y + self.wiper_ofset_y,
@@ -1118,7 +1274,7 @@ class Rheostat(Component):
     self.wiper_item.connect("event", self.component_click)
 
     self.show()
-    
+
   def update_wiper_wire(self):
     self.wiper_wire_item.set(
       points = (self.x + self.wiper_ofset_x + 35,
@@ -1148,14 +1304,14 @@ class Rheostat(Component):
       elif event.type == gtk.gdk.SCROLL_DOWN:
         self.move_wiper(self.y + 5)
     return True
-  
+
   # Callback event on the wiper
   def component_click(self, widget, event):
     # drag and drop
     if event.type == gtk.gdk.MOTION_NOTIFY:
       if event.state & gtk.gdk.BUTTON1_MASK:
         self.move_wiper(event.y)
-        
+
     return True
 
   # Callback event to move the component
@@ -1164,14 +1320,14 @@ class Rheostat(Component):
 
      if(self.electric.get_current_tools()=="DEL"):
        return True
-     
+
      self.wiper_item.set(
        x = self.x + self.wiper_ofset_x,
        y = self.y + self.wiper_ofset_y)
      self.update_wiper_wire()
 
      return True
-   
+
   # Return True if this component is connected and can provides a gnucap
   # description
   #
@@ -1187,7 +1343,7 @@ class Rheostat(Component):
       return True
 
     return False
-    
+
   # Return the gnucap definition for a single resitor of the rheostat
   # node_id1 and node_id2 are the index in the list of nodes
   def to_gnucap_res(self, gnucap_name, node_id1, node_id2, gnucap_value):
@@ -1196,31 +1352,30 @@ class Rheostat(Component):
       node = self.nodes[i]
       if not node.get_wires():
         gnucap = "* %s: component ignored: not connected\n" %(gnucap_name)
-        return gnucap
+        return [gnucap, ""]
 
     gnucap = gnucap_name
     gnucap += " "
-    
+
     for i in (node_id1, node_id2):
       node = self.nodes[i]
       if node.get_wires():
         gnucap += str(node.get_wires()[0].get_wire_id())
-        
+
       gnucap += " "
 
     gnucap += " "
     gnucap += str(gnucap_value)
     gnucap += "\n"
-    gnucap += ".print dc + v(%s) i(%s)\n" %(gnucap_name, gnucap_name)
 
-    return gnucap
-  
+    return [gnucap, ".print dc + v(%s) i(%s)\n" %(gnucap_name, gnucap_name)]
+
   # Return the gnucap definition for this component
   # depending of the connected nodes, it create one or two resistor
   def to_gnucap(self, model):
 
-    gnucap = ""
-    
+    gnucap = ["", ""]
+
     # reset set_voltage_intensity counter
     self.gnucap_current_resistor = 0
 
@@ -1233,9 +1388,11 @@ class Rheostat(Component):
        not self.nodes[1].get_wires() and \
        self.nodes[2].get_wires():
       self.gnucap_nb_resistor = 1
-      gnucap += self.to_gnucap_res(self.gnucap_name + "_all", 0, 2,
-                                   self.resitance)
-      return gnucap
+      gnucap_resp = self.to_gnucap_res(self.gnucap_name + "_all", 0, 2,
+                                       self.resitance)
+      gnucap[0] += gnucap_resp[0]
+      gnucap[1] += gnucap_resp[1]
+      return [gnucap[0], gnucap[1]]
 
 
     self.gnucap_nb_resistor = 0
@@ -1244,18 +1401,22 @@ class Rheostat(Component):
     if self.nodes[0].get_wires() and \
        self.nodes[1].get_wires():
       self.gnucap_nb_resistor += 1
-      gnucap  += self.to_gnucap_res(self.gnucap_name + "_top", 0, 1,
-                                    gnucap_value)
+      gnucap_resp  = self.to_gnucap_res(self.gnucap_name + "_top", 0, 1,
+                                        gnucap_value)
+      gnucap[0] += gnucap_resp[0]
+      gnucap[1] += gnucap_resp[1]
 
     # bottom resistor
     if self.nodes[1].get_wires() and \
        self.nodes[2].get_wires():
       self.gnucap_nb_resistor += 1
-      gnucap += self.to_gnucap_res(self.gnucap_name + "_bot", 1, 2,
-                                     self.resitance - gnucap_value)
-      
-    return gnucap
-    
+      gnucap_resp = self.to_gnucap_res(self.gnucap_name + "_bot", 1, 2,
+                                       self.resitance - gnucap_value)
+      gnucap[0] += gnucap_resp[0]
+      gnucap[1] += gnucap_resp[1]
+
+    return [gnucap[0], gnucap[1]]
+
   # Return False if we need more value to complete our component
   # This is usefull in case one Component is made of several gnucap component
   def set_voltage_intensity(self, valid_value, voltage, intensity):
@@ -1275,13 +1436,13 @@ class Rheostat(Component):
         self.gnucap_current_resistor = 0
         return True
     else:
-      self.gnucap_current_resistor = 0 
+      self.gnucap_current_resistor = 0
       return True
     return False
 
 # ----------------------------------------
 # BULB
-# 
+#
 #
 class Bulb(Component):
   image = "electric/bulb1.png"
@@ -1306,7 +1467,7 @@ class Bulb(Component):
     self.show()
     self.power_max = power_max
     self.resistor_blown = 100000000
-    
+
   # Change the pixmap depending on the real power in the Bulb
   # Return False if we need more value to complete our component
   # This is usefull in case where one Component is made of several gnucap component
@@ -1317,7 +1478,7 @@ class Bulb(Component):
     # If the Bulb is blown, do not update it anymore
     if self.is_blown:
       return True
-    
+
     power = abs(voltage * intensity)
     image_index = min((power * 10) /  self.power_max + 1, 11)
     pixmap = gcompris.utils.load_pixmap("electric/bulb%d.png" %(image_index,))
@@ -1330,7 +1491,7 @@ class Bulb(Component):
       self.gnucap_value = self.resistor_blown
       self.electric.run_simulation()
       self.is_blown = True
-      
+
     return True
 
   # Callback event to move the component
@@ -1343,19 +1504,19 @@ class Bulb(Component):
         self.is_blown = False
         self.gnucap_value = self.internal_resistor
         self.electric.run_simulation()
-        
+
     elif (event.state & gtk.gdk.BUTTON3_MASK) and self.electric.get_current_tools()=="SELECT":
       if not self.is_blown:
         # Blown us with arbitrate high value
         self.set_voltage_intensity(True, 100, 10)
-      
-    return super(Bulb, self).component_move(widget, event, component)
-        
 
-    
+    return super(Bulb, self).component_move(widget, event, component)
+
+
+
 # ----------------------------------------
 # BATTERY
-# 
+#
 #
 class Battery(Component):
   image = "electric/battery.png"
@@ -1371,7 +1532,7 @@ class Battery(Component):
     # Overide some values
     self.item_values_x = 23
     self.item_values_y = 70
-    
+
     self.move(x, y)
     self.show()
 
@@ -1385,7 +1546,7 @@ class Battery(Component):
       self.component_item.set(pixbuf = gcompris.utils.load_pixmap("electric/battery_dead.png"))
     else:
       self.component_item.set(pixbuf = gcompris.utils.load_pixmap("electric/battery.png"))
-      
+
     return True
 
 # ----------------------------------------
@@ -1419,7 +1580,7 @@ class Selector:
       self.rootitem = electric.rootitem
 
       self.rootitem.add(
-        gnome.canvas.CanvasPixbuf,
+        gnomecanvas.CanvasPixbuf,
         pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("draw/tool-selector.png")),
         x=5,
         y=5.0,
@@ -1436,11 +1597,11 @@ class Selector:
       gap     = 20
       self.init_coord = {}
       self.offset_x = self.offset_y = 0
-      
+
       for component_class in components_class:
         pixmap = gcompris.utils.load_pixmap(component_class[0].icon)
         item = self.rootitem.add(
-          gnome.canvas.CanvasPixbuf,
+          gnomecanvas.CanvasPixbuf,
           pixbuf = pixmap,
           x = self.x,
           y = self.y + index_y,
@@ -1459,7 +1620,7 @@ class Selector:
           and self.electric.get_current_tools()=="DEL"):
         # Switch to select mode
         self.electric.assign_tool(1)
-      
+
       if event.type == gtk.gdk.MOTION_NOTIFY:
         if event.state & gtk.gdk.BUTTON1_MASK:
           # Save the click to image offset
@@ -1470,7 +1631,7 @@ class Selector:
 
           widget.set(x = event.x - self.offset_x,
                      y = event.y - self.offset_y)
-          
+
       if event.type == gtk.gdk.BUTTON_RELEASE:
         if event.button == 1:
           bounds = widget.get_bounds()
@@ -1478,7 +1639,7 @@ class Selector:
                              event.x - self.offset_x + (bounds[2]-bounds[0])/2,
                              event.y - self.offset_y + (bounds[3]-bounds[1])/2,
                              component_class[1])
-          
+
           widget.set(x = self.init_coord[component_class[0]][0],
                      y = self.init_coord[component_class[0]][1])
 
@@ -1490,7 +1651,7 @@ class Selector:
     # ------------------------------------------------------------
     # ------------------------------------------------------------
     # ------------------------------------------------------------
-    
+
 def stop_board():
     gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
 
