@@ -1,25 +1,24 @@
 #  gcompris - searace
-# 
+#
 # Time-stamp: <2001/08/20 00:54:45 bruno>
-# 
+#
 # Copyright (C) 2004 Bruno Coudoin
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
-import gnome
-import gnome.canvas
+#
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -43,7 +42,7 @@ class Boat:
   arrived     = False
   won         = False
   finish_time = 0
-  
+
   # To move the ship
   dx          = 0.0
   dy          = 0.0
@@ -62,16 +61,16 @@ class Boat:
 
   # Display the speed here
   speeditem   = []
-  
+
 class Gcompris_searace:
   """The Boat Racing activity"""
-  
+
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
 
     self.board_paused = False
-    
+
     # Some constants
     self.border_x  = 30
     self.sea_area = (self.border_x , 30, gcompris.BOARD_WIDTH-self.border_x , 350)
@@ -79,13 +78,13 @@ class Gcompris_searace:
 
     self.left_boat  = Boat()
     self.left_boat.player = 0
-    
+
     self.right_boat = Boat()
     self.left_boat.player = 1
 
     self.left_initial_boat_y  = 150
     self.right_initial_boat_y = 150 + 28
-    
+
     # The basic tick for object moves
     self.timerinc = 40
     self.timer_turn = 15
@@ -97,14 +96,14 @@ class Gcompris_searace:
 
     # We display what's going on here
     self.statusitem = []
-    
-    #print("Gcompris_searace __init__.")
-  
 
-  def start(self):  
+    #print("Gcompris_searace __init__.")
+
+
+  def start(self):
     self.gcomprisBoard.level=1
     self.gcomprisBoard.maxlevel=4
-    self.gcomprisBoard.sublevel=1 
+    self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
 
     self.board_paused = False
@@ -115,21 +114,21 @@ class Gcompris_searace:
       gcompris.bar_set(gcompris.BAR_OK|gcompris.BAR_LEVEL|gcompris.BAR_REPEAT_ICON)
     else:
       gcompris.bar_set(gcompris.BAR_OK|gcompris.BAR_LEVEL|gcompris.BAR_REPEAT);
-    
-    
+
+
     gcompris.bar_set_level(self.gcomprisBoard)
 
     # Create our rootitem. We put each canvas item in it so at the end we
     # only have to kill it. The canvas deletes all the items it contains automaticaly.
     self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=0.0,
       y=0.0
       )
 
     pixmap = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("gcompris-bg.jpg"))
     item = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=0,
       y=0,
@@ -139,7 +138,7 @@ class Gcompris_searace:
     self.display_sea_area()
 
     self.root_weather_item = self.rootitem.add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=0.0,
       y=0.0
       )
@@ -149,7 +148,7 @@ class Gcompris_searace:
 
     # And finaly the players boats
     self.init_boats()
-    
+
     #print("Gcompris_searace start.")
 
 
@@ -157,26 +156,26 @@ class Gcompris_searace:
     # Remove all the timer first
     if self.timer1 :
       gtk.timeout_remove(self.timer1)
-    
+
     if self.timer2 :
       gtk.timeout_remove(self.timer2)
-    
+
     if self.left_boat.timer :
       gtk.timeout_remove(self.left_boat.timer)
-    
+
     if self.right_boat.timer :
       gtk.timeout_remove(self.right_boat.timer)
-    
+
     # Remove the root item removes all the others inside it
     self.rootitem.destroy()
 
     #print("Gcompris_searace end.")
-        
+
 
   def pause(self, pause):
-    
+
     self.board_paused = pause
-    
+
     # There is a problem with GTK widgets, they are not covered by the help
     # We hide/show them here
     if(pause):
@@ -188,7 +187,7 @@ class Gcompris_searace:
       self.repeat()
 
     return
-                  
+
   def ok(self):
     # This is a real go
     # We set a timer. At each tick an entry in each user box is read analysed and run
@@ -207,15 +206,15 @@ class Gcompris_searace:
     else:
       self.gcomprisBoard.level=level;
       self.gcomprisBoard.sublevel=1;
-      
+
       # Set the level in the control bar
       gcompris.bar_set_level(self.gcomprisBoard);
-      
+
       # Remove the root item removes all the others inside it
       self.root_weather_item.destroy()
 
       self.root_weather_item = self.rootitem.add(
-        gnome.canvas.CanvasGroup,
+        gnomecanvas.CanvasGroup,
         x=0.0,
         y=0.0
         )
@@ -224,20 +223,20 @@ class Gcompris_searace:
       self.display_weather()
 
       self.init_boats()
-      
-            
+
+
   def repeat(self):
     # Want to rerun it
     if(self.left_boat.timer or self.right_boat.timer):
       self.statusitem.set(text=_("The race is already being run"))
     else:
       self.init_boats()
-      
-            
+
+
   def config(self):
     #print("Gcompris_searace config.")
     return
-              
+
   def key_press(self, keyval, commit_str, preedit_str):
     #print("got key %i" % keyval)
     return False
@@ -255,14 +254,14 @@ class Gcompris_searace:
     self.right_boat.y     = self.right_initial_boat_y
     self.left_boat.angle  = 0
     self.right_boat.angle = 0
-    
+
     # Display the player boats
     if(self.left_boat.item):
       self.left_boat.item.destroy()
-      
+
     pixmap = gcompris.utils.load_pixmap("images/top_boat_red.png")
     self.left_boat.item = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=self.left_boat.x,
       y=self.left_boat.y,
@@ -270,13 +269,13 @@ class Gcompris_searace:
       )
     self.left_boat.item.raise_to_top()
     self.left_boat.item.connect("event", self.ruler_item_event)
-    
+
     if(self.right_boat.item):
       self.right_boat.item.destroy()
 
     pixmap = gcompris.utils.load_pixmap("images/top_boat_green.png")
     self.right_boat.item = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=self.right_boat.x,
       y=self.right_boat.y,
@@ -285,7 +284,7 @@ class Gcompris_searace:
     self.right_boat.item.raise_to_top()
     self.right_boat.item.connect("event", self.ruler_item_event)
 
-    
+
     # Reset command line processing as well.
     self.left_boat.line     = 0
     self.right_boat.line    = 0
@@ -313,7 +312,7 @@ class Gcompris_searace:
     step_x    = (self.sea_area[2]-self.sea_area[0])/20
     step_y    = (self.sea_area[3]-self.sea_area[1])/10
     self.sea_ratio = step_x
-    
+
     text_x    = self.sea_area[0] - 15
     text_y    = self.sea_area[1] - 15
 
@@ -331,7 +330,7 @@ class Gcompris_searace:
 
       # Shadow for text number
       item = self.rootitem.add (
-        gnome.canvas.CanvasText,
+        gnomecanvas.CanvasText,
         text=int(ci),
         font=gcompris.skin.get_font("gcompris/content"),
         x=text_x+1,
@@ -342,7 +341,7 @@ class Gcompris_searace:
 
       # Text number
       item = self.rootitem.add (
-        gnome.canvas.CanvasText,
+        gnomecanvas.CanvasText,
         text=int(ci),
         font=gcompris.skin.get_font("gcompris/content"),
         x=text_x,
@@ -352,7 +351,7 @@ class Gcompris_searace:
       item.connect("event", self.ruler_item_event)
 
       item = self.rootitem.add(
-        gnome.canvas.CanvasLine,
+        gnomecanvas.CanvasLine,
         points=(self.sea_area[0], y, self.sea_area[2], y),
         fill_color_rgba = color,
          width_units=1.0
@@ -370,7 +369,7 @@ class Gcompris_searace:
 
       # Shadow for text number
       item = self.rootitem.add (
-        gnome.canvas.CanvasText,
+        gnomecanvas.CanvasText,
         text=int(ci),
         font=gcompris.skin.get_font("gcompris/content"),
         x=x+1,
@@ -381,7 +380,7 @@ class Gcompris_searace:
 
       # Text number
       item = self.rootitem.add (
-        gnome.canvas.CanvasText,
+        gnomecanvas.CanvasText,
         text=int(ci),
         font=gcompris.skin.get_font("gcompris/content"),
         x=x,
@@ -391,7 +390,7 @@ class Gcompris_searace:
       item.connect("event", self.ruler_item_event)
 
       item = self.rootitem.add(
-        gnome.canvas.CanvasLine,
+        gnomecanvas.CanvasLine,
         points=(x, self.sea_area[1], x, self.sea_area[3]),
         fill_color_rgba = color,
          width_units=1.0
@@ -401,21 +400,21 @@ class Gcompris_searace:
 
     # The ARRIVAL LINE
     item = self.rootitem.add(
-      gnome.canvas.CanvasLine,
+      gnomecanvas.CanvasLine,
       points=(self.sea_area[2], self.sea_area[1]-5, self.sea_area[2], self.sea_area[3]+5),
       fill_color_rgba = 0xFF0000FFL,
       width_units=5.0
       )
     item.connect("event", self.ruler_item_event)
-    
+
     # The grid is done
     # ----------------
-    
+
     # The Programming input area LEFT
     self.left_boat.sw = gtk.ScrolledWindow()
     self.left_boat.sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
     self.left_boat.sw.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
-      
+
     w = 250.0
     h = 100.0
     y = 400.0 # The upper limit of the text boxes
@@ -428,10 +427,10 @@ class Gcompris_searace:
 
     command_example = _("right") + " 45\n" + _("forward") + " 5\n" + _("left") + " 45"
     self.left_boat.tb.set_text(command_example)
-    
+
     self.left_boat.tv.set_wrap_mode(gtk.WRAP_CHAR)
     self.rootitem.add(
-      gnome.canvas.CanvasWidget,
+      gnomecanvas.CanvasWidget,
       widget=self.left_boat.sw,
       x=x_left,
       y=y,
@@ -446,17 +445,17 @@ class Gcompris_searace:
     self.right_boat.sw = gtk.ScrolledWindow()
     self.right_boat.sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
     self.right_boat.sw.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
-      
+
     self.right_boat.tb = gtk.TextBuffer()
     self.right_boat.tv = gtk.TextView(self.right_boat.tb)
     self.right_boat.sw.add(self.right_boat.tv)
 
     command_example = _("left") + " 45\n" + _("forward") + " 5\n" + _("right") + " 45"
     self.right_boat.tb.set_text(command_example)
-    
+
     self.right_boat.tv.set_wrap_mode(gtk.WRAP_CHAR)
     self.rootitem.add(
-      gnome.canvas.CanvasWidget,
+      gnomecanvas.CanvasWidget,
       widget=self.right_boat.sw,
       x=x_right,
       y=y,
@@ -469,7 +468,7 @@ class Gcompris_searace:
 
     # Text Labels
     self.left_boat.speeditem = self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text="",
       font=gcompris.skin.get_font("gcompris/content"),
       x=x_left,
@@ -478,7 +477,7 @@ class Gcompris_searace:
       )
 
     self.right_boat.speeditem = self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text="",
       font=gcompris.skin.get_font("gcompris/content"),
       x=x_right,
@@ -488,7 +487,7 @@ class Gcompris_searace:
 
     # The status area
     self.statusitem = self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text="",
       font=gcompris.skin.get_font("gcompris/content"),
       x=gcompris.BOARD_WIDTH/2,
@@ -499,7 +498,7 @@ class Gcompris_searace:
     # The decoration boats
     pixmap = gcompris.utils.load_pixmap("images/top_boat_red.png")
     item = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=25,
       y=y+40,
@@ -509,7 +508,7 @@ class Gcompris_searace:
 
     pixmap = gcompris.utils.load_pixmap("images/top_boat_green.png")
     item = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=gcompris.BOARD_WIDTH-25,
       y=y+40,
@@ -522,41 +521,41 @@ class Gcompris_searace:
     y += 7
     text_color = 0x0000FFFFL
     self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=_("COMMANDS ARE"),
       font=gcompris.skin.get_font("gcompris/content"),
       x=gcompris.BOARD_WIDTH/2,
       y=y,
       fill_color_rgba=text_color
       )
-    
+
     self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=_("forward"),
       font=gcompris.skin.get_font("gcompris/content"),
       x=gcompris.BOARD_WIDTH/2,
       y=y+hl,
       fill_color_rgba=text_color
       )
-    
+
     self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=_("left"),
       font=gcompris.skin.get_font("gcompris/content"),
       x=gcompris.BOARD_WIDTH/2,
       y=y+hl*2,
       fill_color_rgba=text_color
       )
-    
+
     self.rootitem.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=_("right"),
       font=gcompris.skin.get_font("gcompris/content"),
       x=gcompris.BOARD_WIDTH/2,
       y=y+hl*3,
       fill_color_rgba=text_color
       )
-    
+
 
   # Weather condition is a 2 value pair (angle wind_speed)
   # Weather is a list of the form:
@@ -570,7 +569,7 @@ class Gcompris_searace:
     # The sea area is defined in the global self.sea_area
     slice_x = 5 + self.gcomprisBoard.level
     slice_y = 3 + self.gcomprisBoard.level
-    
+
     step_x  = (self.sea_area[2]-self.sea_area[0])/slice_x
     step_y  = (self.sea_area[3]-self.sea_area[1])/slice_y
 
@@ -604,8 +603,8 @@ class Gcompris_searace:
         condition = [ (x, y, x+step_x, y+step_y), (angle, speed) ]
         self.display_condition(condition)
         self.weather.append(condition)
-    
-    
+
+
     return
 
   # Display the given weather condition
@@ -615,10 +614,10 @@ class Gcompris_searace:
     # Calc the center
     cx = condition[0][0]+(condition[0][2]-condition[0][0])/2
     cy = condition[0][1]+(condition[0][3]-condition[0][1])/2
-    
+
     pixmap = gcompris.utils.load_pixmap("images/arrow.png")
     item = self.root_weather_item.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = pixmap,
       x=cx,
       y=cy,
@@ -629,7 +628,7 @@ class Gcompris_searace:
 
     # Text number Shadow
     item = self.root_weather_item.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=condition[1][1],
       font=gcompris.skin.get_font("gcompris/content"),
       x=cx+1+pixmap.get_width()/2,
@@ -640,7 +639,7 @@ class Gcompris_searace:
 
     # Text number
     item = self.root_weather_item.add (
-      gnome.canvas.CanvasText,
+      gnomecanvas.CanvasText,
       text=condition[1][1],
       font=gcompris.skin.get_font("gcompris/content"),
       x=cx+pixmap.get_width()/2,
@@ -661,7 +660,7 @@ class Gcompris_searace:
       condition = boat.condition[1]
       if(boat.x >= coord[0] and boat.x <= coord[2] and boat.y >= coord[1] and boat.y <= coord[3]):
         return(condition)
-    
+
     for conditions in self.weather:
       coord = conditions[0]
       condition = conditions[1]
@@ -706,7 +705,7 @@ class Gcompris_searace:
     penalty=3
     if(cx<0):
       penalty*=2
-      
+
     return(cx*condition[1]*-1*penalty)
 
   #
@@ -718,14 +717,14 @@ class Gcompris_searace:
     if(self.board_paused):
       boat.timer = 0
       return
-    
+
     value -= 1
     if value <= 0:
       # Process next command
       self.race_one_command(boat)
       boat.timer = 0
       return
-    
+
     # Move it
     boat.x += 1
     boat.y += 0
@@ -761,12 +760,12 @@ class Gcompris_searace:
       elif(self.right_boat.won):
         self.statusitem.set(text=_("The Green boat has won"))
         boat.speeditem.set(text="")
-           
+
       boat.timer = 0
       return
 
     condition = self.get_weather_condition(boat)
-    
+
     boat.item.set(x = boat.x,
                   y = boat.y)
 
@@ -780,7 +779,7 @@ class Gcompris_searace:
     boat.speeditem.set(text = _("Angle:") + str(angle) + " " + _("Wind:") + str(int(wind)*-1))
     boat.timer = gtk.timeout_add(int(self.timerinc+wind), self.cmd_forward, boat, value)
 
-    
+
 
 
   # Counter Clock wise rotation (use negative param to turn clock wise)
@@ -790,7 +789,7 @@ class Gcompris_searace:
     if(self.board_paused):
       boat.timer = 0
       return
-    
+
     if value == 0:
       # Process next command
       self.race_one_command(boat)
@@ -800,25 +799,25 @@ class Gcompris_searace:
     turn = 1
     if value > 0:
       turn = -1
-      
+
     boat.angle += turn
     if(boat.angle>360):
       boat.angle-=360
     elif(boat.angle<360):
       boat.angle+=360
-      
+
     value    += turn
 
     gcompris.utils.item_rotate_relative(boat.item, turn);
     boat.timer = gtk.timeout_add(self.timer_turn, self.cmd_turn_left, boat, value)
-  
+
   # Run the race
   def race_one_command(self, boat):
 
     if(self.board_paused):
       # Let the user enter commands
       boat.tv.set_editable(True)
-      
+
       boat.line = 0
       boat.timer = 0
       return
@@ -837,7 +836,7 @@ class Gcompris_searace:
       cmd   = cmd.strip("\n\t ")
       if(cmd != "" and cmd[0] != "#"):
         valid_cmd = True
-    
+
     # No more commands to process for this player
     if (boat.line > boat.tb.get_line_count() or not valid_cmd):
       # Let the user enter commands
@@ -846,7 +845,7 @@ class Gcompris_searace:
       boat.line = 0
       boat.timer = 0
       return
-    
+
     #print "boat.line=" + str(boat.line)
     #print "Parsing command = " + cmd + "<<"
     cmds  = cmd.split()
@@ -862,7 +861,7 @@ class Gcompris_searace:
 
       # Let the user enter commands
       boat.tv.set_editable(True)
-      
+
       boat.line = 0
       boat.timer = 0
       return
@@ -874,12 +873,12 @@ class Gcompris_searace:
       except ValueError:
         # Let the user enter commands
         boat.tv.set_editable(True)
-      
+
         boat.timer = 0
         boat.speeditem.set(text=_("The command") + " '" + cmd.split()[0] + "' " + "at line" + " " + str(boat.line) + "\n" + "requires a number parameter")
         boat.line = 0
         return
-      
+
     if( cmd.startswith(_("forward"))):
       # Transform the value from user visible sea size to pixels
       value *= self.sea_ratio
@@ -893,7 +892,7 @@ class Gcompris_searace:
     else:
       # Let the user enter commands
       boat.tv.set_editable(True)
-      
+
       boat.timer = 0
       boat.speeditem.set(text=_("Unknown command at line") + " " + str(boat.line) + "\n(" +  cmd.split()[0] + ")")
       boat.line = 0
@@ -904,7 +903,7 @@ class Gcompris_searace:
     # The sea area is defined in the global self.sea_area
     step_x    = (self.sea_area[2]-self.sea_area[0])/20*2
     step_y    = (self.sea_area[3]-self.sea_area[1])/10
-    
+
     # Original boat position
     bx     = self.right_boat.x
     by     = self.right_boat.y
@@ -932,23 +931,23 @@ class Gcompris_searace:
         elif(y>self.sea_area[3]):
           y = self.sea_area[1] + (y - self.sea_area[3])
           line_style = gtk.gdk.LINE_DOUBLE_DASH
-            
+
         # Find shortest path to previous calculated point
         condition = self.get_absolute_weather_condition(x, y)
         wind = self.get_wind_score(boat_angle, condition)
         if(wind<score):
           score = wind
           coord = (x, y, boat_angle, step_x, line_style) # x y angle distance line_style
-        
+
         self.root_weather_item.add(
-          gnome.canvas.CanvasText, text=int(wind),
+          gnomecanvas.CanvasText, text=int(wind),
           y=y, x=x,
           fill_color_rgba=0xFF0000FFL,
           )
 
       # ----------
       self.root_weather_item.add(
-        gnome.canvas.CanvasLine,
+        gnomecanvas.CanvasLine,
         points=(bx, by, coord[0], coord[1]),
         fill_color_rgba=0x00CC00FFL,
         width_units=2.0,
@@ -962,7 +961,7 @@ class Gcompris_searace:
     # --------------------------------------------------------------
     # Translate the previous calculation in a string for Tux program
     # --------------------------------------------------------------
-    
+
     ba = 0                              # Boat angle
     cumulative_distance = 0
     tux_move = ""
@@ -972,13 +971,13 @@ class Gcompris_searace:
       y=c[1]
       a=c[2]                            # angle
       d=c[3]                            # distance
-      
+
       if(ba-a<0):
         if(cumulative_distance):
           tux_move += _("forward") + " " + str(cumulative_distance) + "\n"
           cumulative_distance=0
         tux_move += _("right") + " " + str(abs(int(ba-a))) + "\n"
-        ba += abs(int(ba-a)) 
+        ba += abs(int(ba-a))
       elif(ba-a>0):
         if(cumulative_distance):
           tux_move += _("forward") + " " + str(cumulative_distance) + "\n"
@@ -993,7 +992,7 @@ class Gcompris_searace:
 
     self.right_boat.tb.set_text(tux_move)
     self.right_boat.tv.set_editable(False)
-    
+
 
   # ----------------------------------------
   # The RULER
@@ -1004,7 +1003,7 @@ class Gcompris_searace:
         self.pos_x = event.x
         self.pos_y = event.y
         self.ruleritem = self.rootitem.add(
-          gnome.canvas.CanvasLine,
+          gnomecanvas.CanvasLine,
           points=( self.pos_x, self.pos_y, event.x, event.y),
           fill_color_rgba=0xFF0000FFL,
           width_units=2.0
