@@ -1,25 +1,24 @@
 #  gcompris - watercycle
-# 
+#
 # Time-stamp: <2001/08/20 00:54:45 bruno>
-# 
+#
 # Copyright (C) 2003 Bruno Coudoin
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
-import gnome
-import gnome.canvas
+#
+import gnomecanvas
 import gcompris
 import gcompris.utils
 import gcompris.anim
@@ -29,18 +28,18 @@ import gtk.gdk
 
 class Gcompris_watercycle:
   """The Cycle Water activity"""
-  
+
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
-    
-    print("Gcompris_watercycle __init__.")
-  
 
-  def start(self):  
+    print("Gcompris_watercycle __init__.")
+
+
+  def start(self):
     self.gcomprisBoard.level=1
     self.gcomprisBoard.maxlevel=1
-    self.gcomprisBoard.sublevel=1 
+    self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
 
     # The basic tick for object moves
@@ -48,14 +47,14 @@ class Gcompris_watercycle:
 
     # The tick for the boat is variable
     self.boat_timerinc = self.timerinc
-    
+
     # Need to manage the timers to quit properly
     self.boat_timer = 0
     self.sun_timer = 0
     self.vapor_timer = 0
     self.cloud_timer = 0
     self.waterlevel_timer = 0
-    
+
     gcompris.bar_set(0)
     gcompris.set_background(self.gcomprisBoard.canvas.root(),
                             "watercycle/background.png")
@@ -64,7 +63,7 @@ class Gcompris_watercycle:
     # Create our rootitem. We put each canvas item in it so at the end we
     # only have to kill it. The canvas deletes all the items it contains automaticaly.
     self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnome.canvas.CanvasGroup,
+      gnomecanvas.CanvasGroup,
       x=0.0,
       y=0.0
       )
@@ -74,7 +73,7 @@ class Gcompris_watercycle:
 
     # The River
     self.riveritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/riverempty.png"),
       x=150.0,
       y=50.0
@@ -83,7 +82,7 @@ class Gcompris_watercycle:
 
     # The bad water
     self.badwateritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/badwater_off.png"),
       x=360.0,
       y=292.0
@@ -91,16 +90,16 @@ class Gcompris_watercycle:
 
     # The clean water
     self.cleanwateritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/cleanwater_off.png"),
       x=470.0,
       y=130.0
       )
     self.cleanwaterstatus = 0
-    
+
     # The Sun
     self.sunitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/sun.png"),
       x=10.0,
       y=70.0
@@ -113,7 +112,7 @@ class Gcompris_watercycle:
 
     # The sun mask object to simulate the see
     self.rootitem.add(
-      gnome.canvas.CanvasRect,
+      gnomecanvas.CanvasRect,
       x1=10.0,
       y1=89.0,
       x2=90.0,
@@ -124,7 +123,7 @@ class Gcompris_watercycle:
 
     # The Snow
     self.snowitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/snow.png"),
       x=180.0,
       y=3.0
@@ -133,17 +132,17 @@ class Gcompris_watercycle:
 
     # The rain
     self.rainitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/rain.png"),
       x=40.0,
       y=70.0
       )
     self.rainitem.hide()
     self.rain_on = 0
-    
+
     # The cloud
     self.clouditem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("gcompris/misc/cloud.png"),
       x=10.0,
       y=10.0
@@ -153,10 +152,10 @@ class Gcompris_watercycle:
     # This item is clickeable and it must be seen
     self.clouditem.connect("event", gcompris.utils.item_event_focus)
     self.cloud_on = 0
-    
+
     # The vapor
     self.vaporitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/vapor.png"),
       x=35.0,
       y=150.0
@@ -165,7 +164,7 @@ class Gcompris_watercycle:
 
     # The Waterpump
     self.waterpumpitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/waterpump.png"),
       x=165.0,
       y=120.0
@@ -174,10 +173,10 @@ class Gcompris_watercycle:
     # This item is clickeable and it must be seen
     self.waterpumpitem.connect("event", gcompris.utils.item_event_focus)
     self.waterpump_on = 0
-    
+
     # The pump water
     self.pumpwateritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/pumpwater_off.png"),
       x=270.0,
       y=133.0
@@ -185,7 +184,7 @@ class Gcompris_watercycle:
 
     # The WaterCleaning
     self.watercleaningitem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/watercleaning.png"),
       x=520.0,
       y=380.0
@@ -199,32 +198,32 @@ class Gcompris_watercycle:
     self.tuxboatitem = gcompris.anim.CanvasItem( gcompris.anim.Animation("watercycle/tuxboat.txt"),
                                                  self.rootitem );
     numstates = self.tuxboatitem.num_states
-    print "numstates: " + str(numstates)
-    self.tuxboatcanvas = self.tuxboatitem.gnome_canvas
+
+    self.tuxboatcanvas = self.tuxboatitem.gnomecanvas
     self.tuxboatcanvas.set( x=-100.0, y=430.0 )
-  
+
     # Tux in the shower (without water)
     self.tuxshoweritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("gcompris/misc/minitux.png"),
       x=569.0,
       y=239.0
       )
     self.tuxshoweritem.hide()
     self.tuxisinshower = 0
-    
+
     # Tux in the shower with the water
     self.tuxshowerwateritem = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/showerwater.png"),
       x=561.0,
       y=231.0
       )
     self.tuxshowerwateritem.hide()
-    
+
     # The shower itself
     self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/shower.png"),
       x=560.0,
       y=283.0
@@ -232,7 +231,7 @@ class Gcompris_watercycle:
 
     # The shower on/off button (I need to get the 2 buttons to manage the focus)
     self.showerbuttonitem_on = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/shower_on.png"),
       x=622.0,
       y=260.0
@@ -244,7 +243,7 @@ class Gcompris_watercycle:
     self.showerbutton = 0
 
     self.showerbuttonitem_off = self.rootitem.add(
-      gnome.canvas.CanvasPixbuf,
+      gnomecanvas.CanvasPixbuf,
       pixbuf = gcompris.utils.load_pixmap("watercycle/shower_off.png"),
       x=622.0,
       y=260.0
@@ -260,7 +259,7 @@ class Gcompris_watercycle:
     self.waterlevel_timer = gtk.timeout_add(1000, self.update_waterlevel)
 
     self.waterlevel_item = self.rootitem.add(
-          gnome.canvas.CanvasLine,
+          gnomecanvas.CanvasLine,
           points = (655 , self.waterlevel,
                     655 , self.waterlevel_min),
           fill_color_rgba = 0x0033FFFFL,
@@ -270,13 +269,13 @@ class Gcompris_watercycle:
     # Some item ordering
     self.rainitem.raise_to_top()
     self.clouditem.raise_to_top()
-    
+
     # Ready GO
     self.move_boat()
-    
+
     print("Gcompris_watercycle start.")
 
-    
+
   def end(self):
     # Remove all the timer first
     if self.boat_timer :
@@ -289,24 +288,24 @@ class Gcompris_watercycle:
       gtk.timeout_remove(self.cloud_timer)
     if self.waterlevel_timer :
       gtk.timeout_remove(self.waterlevel_timer)
-    
+
     # Remove the root item removes all the others inside it
     self.rootitem.destroy()
 
     print("Gcompris_watercycle end.")
-        
+
 
   def ok(self):
     print("Gcompris_watercycle ok.")
-          
+
 
   def repeat(self):
     print("Gcompris_watercycle repeat.")
-            
+
 
   def config(self):
     print("Gcompris_watercycle config.")
-              
+
   def key_press(self, keyval, commit_str, preedit_str):
     print("got key %i" % keyval)
     return False
@@ -314,7 +313,7 @@ class Gcompris_watercycle:
   # This is called each second to update to castle water level
   def update_waterlevel(self):
     old_waterlevel = self.waterlevel
-    
+
     if self.waterpump_on and self.waterlevel > self.waterlevel_max :
       self.waterlevel -= 1
 
@@ -347,21 +346,21 @@ class Gcompris_watercycle:
   def set_cleanwater(self, status):
     if(status == self.cleanwaterstatus):
       return
-    
+
     if status:
       self.cleanwateritem.set(pixbuf = gcompris.utils.load_pixmap("watercycle/cleanwater.png"));
     else:
       self.cleanwateritem.set(pixbuf = gcompris.utils.load_pixmap("watercycle/cleanwater_off.png"));
     self.cleanwaterstatus = status
-    
-    
+
+
   def move_boat(self):
     if( self.tuxboatcanvas.get_bounds()[2] < 770 ) :
-      
+
       # Make the boat slow down when arriving
       if(self.tuxboatcanvas.get_bounds()[2]==700 or self.tuxboatcanvas.get_bounds()[2]==701):
         self.boat_timerinc+=50
-        
+
       self.tuxboatcanvas.move(2, 0)
       self.boat_timer = gtk.timeout_add(self.boat_timerinc, self.move_boat)
     else:
@@ -376,7 +375,7 @@ class Gcompris_watercycle:
         #  pixbuf = gcompris.utils.load_pixmap("gcompris/misc/fishingboat.png"),
         #  width = 100.0,
         #  height = 48.0,
-        #  width_set = 1, 
+        #  width_set = 1,
         #  height_set = 1,
         #  )
         self.tuxboatitem.setState(2)
@@ -385,13 +384,13 @@ class Gcompris_watercycle:
         self.tuxshoweritem.show()
         self.tuxisinshower = 1
 
-        
+
   def move_cloud(self):
     if(self.cloud_on):
       self.clouditem.show()
     else:
       self.clouditem.hide()
-      
+
     if(self.rain_on):
       self.rainitem.show()
       # The snow appear if we are close to the left mountain
@@ -401,7 +400,7 @@ class Gcompris_watercycle:
       if(not self.riverfull):
         self.riveritem.set(pixbuf = gcompris.utils.load_pixmap("watercycle/riverfull.png"));
         self.riverfull = 1
-        
+
     else:
       self.rainitem.hide()
 
@@ -416,19 +415,19 @@ class Gcompris_watercycle:
       self.rainitem.hide()
     else:
       self.cloud_timer = gtk.timeout_add(self.timerinc, self.move_cloud)
-      
+
   def init_vapor(self):
     self.vapor_on = 1
     self.vaporitem.show()
     self.move_vapor()
-    
+
   def move_vapor(self):
     self.vaporitem.move(0, -1);
     if( self.vaporitem.get_bounds()[1] < 20 ) :
       self.vaporitem.move(0, +100);
 
     self.vapor_timer = gtk.timeout_add(self.timerinc, self.move_vapor)
-      
+
   def move_sun(self):
     self.sunitem.move(0, self.sun_direction);
     if( (self.sunitem.get_bounds()[1] > 0 and
@@ -457,11 +456,11 @@ class Gcompris_watercycle:
         self.sun_on = 0
 
       self.sun_direction = self.sun_direction * -1
-      
-  def pause(self, pause):  
+
+  def pause(self, pause):
     print("Gcompris_watercycle pause. %i" % pause)
-                  
-  def set_level(self, level):  
+
+  def set_level(self, level):
     print("Gcompris_watercycle set level. %i" % level)
 
   def sun_item_event(self, widget, event=None):
@@ -501,7 +500,7 @@ class Gcompris_watercycle:
 
   # If Tux is in the shower, we must display the water if needed
   def shower_water_update(self):
-    
+
     if not self.tuxisinshower:
       return
 
@@ -512,7 +511,7 @@ class Gcompris_watercycle:
       self.tuxshoweritem.show()
       self.tuxshowerwateritem.hide()
 
-  
+
   def showerbutton_item_event(self, widget, event=None):
 
     # Not active until tux is in the shower and the watercleaning station is running
@@ -521,7 +520,7 @@ class Gcompris_watercycle:
 
     if not self.watercleaning_on:
       return
-    
+
     if event.type == gtk.gdk.BUTTON_PRESS:
       if event.button == 1:
         if self.showerbutton:
@@ -530,7 +529,7 @@ class Gcompris_watercycle:
         else:
           self.showerbuttonitem_on.show()
           self.showerbuttonitem_off.hide()
-          
+
         self.showerbutton = not self.showerbutton
 
         self.shower_water_update()
