@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -147,19 +143,19 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      "railroad/railroad-bg.png");
 
       for (i=0; i<ENGINES; i++) {
       	str = g_strdup_printf("railroad/loco%d.png", i+1);
-	pixmap = gcompris_load_pixmap(str);
+	pixmap = gc_pixmap_load(str);
 	listPixmapEngines = g_list_append(listPixmapEngines, pixmap);
 	g_free(str);
       }
 
       for (i=0; i<WAGONS; i++) {
       	str = g_strdup_printf("railroad/wagon%d.png", i+1);
-	pixmap = gcompris_load_pixmap(str);
+	pixmap = gc_pixmap_load(str);
 	listPixmapWagons = g_list_append(listPixmapWagons, pixmap);
 	g_free(str);
       }
@@ -169,21 +165,21 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=NUMBER_OF_SUBLEVELS; /* Go to next level after this number of 'play' */
-      gcompris_score_start(SCORESTYLE_NOTE,
+      gc_score_start(SCORESTYLE_NOTE,
 			   gcomprisBoard->width - 220,
 			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
 
 
-      str = gcompris_image_to_skin("button_reload.png");
-      pixmap = gcompris_load_pixmap(str);
+      str = gc_skin_image_get("button_reload.png");
+      pixmap = gc_pixmap_load(str);
       g_free(str);
       if(pixmap) {
-	gcompris_bar_set_repeat_icon(pixmap);
+	gc_bar_set_repeat_icon(pixmap);
 	gdk_pixbuf_unref(pixmap);
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK|GCOMPRIS_BAR_REPEAT_ICON);
+	gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK|GC_BAR_REPEAT_ICON);
       } else {
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK|GCOMPRIS_BAR_REPEAT);
+	gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK|GC_BAR_REPEAT);
       }
 
       railroad_next_level();
@@ -205,7 +201,7 @@ static void end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       railroad_destroy_all_items();
 
       while(g_list_length(listPixmapEngines)>0) {
@@ -267,17 +263,17 @@ static void repeat ()
 /* set initial values for the next level */
 static void railroad_next_level()
 {
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   reset_all_lists();
   // I have big troubles with the GList API : the worst I have ever seen !
-  assert(g_list_length(item_answer_list) == 0 && g_list_length(int_answer_list) == 0 && g_list_length(int_model_list) == 0);
+  g_assert(g_list_length(item_answer_list) == 0 && g_list_length(int_answer_list) == 0 && g_list_length(int_model_list) == 0);
 
   model_size = 0;
 
   railroad_destroy_all_items();
   gamewon = FALSE;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   /* Try the next level */
   railroad_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -362,11 +358,11 @@ static GnomeCanvasItem *railroad_create_item(GnomeCanvasGroup *parent)
   // First the cars, depending of the level
   for (i=0; i<model_size-1; i++) {
     r = (int)(((float) WAGONS)*rand()/(RAND_MAX+1.0));
-    assert( r >=0 && r < WAGONS);
+    g_assert( r >=0 && r < WAGONS);
     // keep track of the answer
     int_model_list = g_list_append(int_model_list, GINT_TO_POINTER(r+ENGINES));
     pixmap = g_list_nth_data(listPixmapWagons, r);
-    assert(i >= 0 && i<MODEL_MAX_SIZE);
+    g_assert(i >= 0 && i<MODEL_MAX_SIZE);
     item_model[i] =gnome_canvas_item_new (modelRootItem,
 					  gnome_canvas_pixbuf_get_type (),
 					  "pixbuf",  pixmap,
@@ -378,7 +374,7 @@ static GnomeCanvasItem *railroad_create_item(GnomeCanvasGroup *parent)
 
   // Then the engine
   r = (int)(((float) ENGINES)*rand()/(RAND_MAX+1.0));
-  assert( r >=0 && r < ENGINES);
+  g_assert( r >=0 && r < ENGINES);
   // keep track of the answer
   int_model_list = g_list_append(int_model_list, GINT_TO_POINTER(r));
   pixmap = g_list_nth_data(listPixmapEngines, r);
@@ -403,10 +399,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   railroad_next_level();
 }
@@ -438,7 +434,7 @@ static void process_ok()
   for (i=0; i<g_list_length(int_model_list); i++)
     g_warning(" i = \t%d val = \t%d\n", i, GPOINTER_TO_INT(g_list_nth_data(int_model_list,i)) );
 
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
 }
 /* ==================================== */
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
@@ -619,7 +615,7 @@ static void animate_model() {
   animation_pending = TRUE;
   animation_count = 0;
 
-  gcompris_play_ogg( "train", NULL );
+  gc_sound_play_ogg( "sounds/train.ogg", NULL );
 
   // warning : if timeout is too low, the model will not be displayed
   timer_id = gtk_timeout_add (100, (GtkFunction) animate_step, NULL);
