@@ -1,6 +1,6 @@
 /* gcompris - reading.c
  *
- * Time-stamp: <2006/04/04 00:04:46 bruno>
+ * Time-stamp: <2006/08/21 23:34:48 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -21,8 +21,6 @@
 
 // FIXME: Cleanup of LettersItem created struct is not done
 
-#include <errno.h>
-#include <stdio.h>
 #include <string.h>
 
 #include "gcompris/gcompris.h"
@@ -33,7 +31,7 @@
 #define MAX_WORDS 100
 
 
-static GPtrArray *words=NULL;
+static GcomprisWordlist *gc_wordlist = NULL;
 
 static GcomprisBoard *gcomprisBoard = NULL;
 
@@ -97,8 +95,7 @@ static void		 reading_config_stop(void);
 
 static void		 player_win(void);
 static void		 player_loose(void);
-static gchar		*get_random_word(gboolean);
-static gboolean	 read_wordfile();
+static gchar		*get_random_word(const gchar *except);
 static GnomeCanvasItem	*display_what_to_do(GnomeCanvasGroup *parent);
 static void		 ask_ready(gboolean status);
 static void		 ask_yes_no(void);
@@ -172,9 +169,9 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
 
-  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   g_hash_table_destroy(config);
 
@@ -184,8 +181,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gcomprisBoard=agcomprisBoard;
 
-      img = gcompris_image_to_skin("reading-bg.jpg");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+      img = gc_skin_image_get("reading-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      img);
       g_free(img);
       wait_for_ready = TRUE;
@@ -193,16 +190,16 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
 
-      font_size = PANGO_PIXELS(pango_font_description_get_size (pango_font_description_from_string (gcompris_skin_font_board_medium)));
+      font_size = PANGO_PIXELS(pango_font_description_get_size (pango_font_description_from_string (gc_skin_font_board_medium)));
       interline = (int) (1.5*font_size);
 
       PangoContext *pango_context = gtk_widget_get_pango_context  (GTK_WIDGET(agcomprisBoard->canvas));
 
       PangoFontMetrics* pango_metrics =  pango_context_get_metrics (pango_context,
-								    pango_font_description_from_string (gcompris_skin_font_board_medium),
-								    pango_language_from_string   (gcompris_get_locale()));
+								    pango_font_description_from_string (gc_skin_font_board_medium),
+								    pango_language_from_string   (gc_locale_get()));
 
       int ascent = PANGO_PIXELS(pango_font_metrics_get_ascent (pango_metrics));
       int descent = PANGO_PIXELS(pango_font_metrics_get_descent (pango_metrics));
@@ -215,6 +212,21 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       if(gcomprisBoard->mode && g_strcasecmp(gcomprisBoard->mode, "horizontal")==0)
 	currentMode=MODE_HORIZONTAL;
 
+      gc_wordlist = gc_wordlist_get_from_file("wordsgame/default-$LOCALE.xml");
+
+      if(!gc_wordlist)
+	{
+	  /* Fallback to english */
+	  gc_wordlist = gc_wordlist_get_from_file("wordsgame/default-en.xml");
+
+	  if(!gc_wordlist)
+	    {
+	      gcomprisBoard = NULL;
+	      gc_dialog(_("Error: We can't find\na list of words to play this game.\n"), gc_board_end);
+	      return;
+	    }
+	}
+
       reading_next_level();
     }
 }
@@ -229,7 +241,12 @@ end_board ()
       reading_destroy_all_items();
     }
 
-  gcompris_reset_locale();
+  if (gc_wordlist != NULL){
+    gc_wordlist_free(gc_wordlist);
+    gc_wordlist = NULL;
+  }
+
+  gc_locale_reset();
 
   gcomprisBoard = NULL;
 }
@@ -271,7 +288,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 static gint reading_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   gamewon = FALSE;
 
@@ -303,7 +320,6 @@ static gint reading_next_level()
   gcomprisBoard->number_of_sublevel=1;
   gcomprisBoard->sublevel=1;
 
-  read_wordfile();
   display_what_to_do(boardRootItem);
   ask_ready(TRUE);
   return (FALSE);
@@ -318,7 +334,7 @@ static void reading_destroy_all_items()
     drop_items_id = 0;
   }
 
-  if (next_level_timer) { 
+  if (next_level_timer) {
     gtk_timeout_remove (next_level_timer);
     drop_items_id = 0;
   }
@@ -330,18 +346,11 @@ static void reading_destroy_all_items()
   previousFocus.rootItem = NULL;
   toDeleteFocus.rootItem = NULL;
 
-  if (textToFind!=NULL) 
+  if (textToFind!=NULL)
     {
     g_free(textToFind);
     textToFind=NULL;
     }
-
-  if (words!=NULL) 
-    {
-    g_ptr_array_free (words, TRUE);
-    words=NULL;
-    }
-
 }
 
 static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
@@ -352,10 +361,10 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
   gint i;
 
   /* Load the text to find */
-  
-  textToFind = get_random_word(TRUE);
 
-  assert(textToFind != NULL);
+  textToFind = get_random_word(NULL);
+
+  g_assert(textToFind != NULL);
 
   /* Decide now if this time we will display the text to find */
   /* Use this formula to have a better random number see 'man 3 rand' */
@@ -368,7 +377,7 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (parent,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Please, check if the word"),
-			 "font", gcompris_skin_font_board_big,
+			 "font", gc_skin_font_board_big,
 			 "x", (double) base_X,
 			 "y", (double) base_Y,
 			 "anchor", GTK_ANCHOR_CENTER,
@@ -378,7 +387,7 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (parent,
 			 gnome_canvas_text_get_type (),
 			 "text", textToFind,
-			 "font", gcompris_skin_font_board_big,
+			 "font", gc_skin_font_board_big,
 			 "x", (double) base_X,
 			 "y", (double) base_Y + 30,
 			 "anchor", GTK_ANCHOR_CENTER,
@@ -388,7 +397,7 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
   gnome_canvas_item_new (parent,
 			 gnome_canvas_text_get_type (),
 			 "text", _("is being displayed"),
-			 "font", gcompris_skin_font_board_big,
+			 "font", gc_skin_font_board_big,
 			 "x", (double) base_X,
 			 "y", (double) base_Y + 60,
 			 "anchor", GTK_ANCHOR_CENTER,
@@ -404,7 +413,7 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
   gint   anchor = GTK_ANCHOR_CENTER;
   gchar *word;
 
-  assert(textToFind!=NULL);
+  g_assert(textToFind!=NULL);
 
   if(toDeleteFocus.rootItem)
     {
@@ -427,17 +436,17 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
       return FALSE;
     }
 
-    
+
   if(textToFindIndex!=0)
     {
-      word = get_random_word(FALSE);
+      word = get_random_word(textToFind);
     }
   else
     {
-      word = textToFind;
+      word = g_strdup(textToFind);
     }
 
-  assert(word!=NULL);
+  g_assert(word!=NULL);
 
   if(textToFindIndex>=0)
     textToFindIndex--;
@@ -456,20 +465,23 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(previousFocus.rootItem),
 			   gnome_canvas_text_get_type (),
 			   "text", word,
-			   "font", gcompris_skin_font_board_medium,
+			   "font", gc_skin_font_board_medium,
 			   "x", (double) 0,
 			   "y", (double) 0,
 			   "anchor", anchor,
 			   "fill_color", "black",
 			   NULL);
 
+
   gchar *oldword = g_strdup_printf("<span foreground=\"black\" background=\"black\">%s</span>", word);
 
-  previousFocus.overwriteItem = \
+  g_free(word);
+
+  previousFocus.overwriteItem =						\
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(previousFocus.rootItem),
 			   gnome_canvas_text_get_type (),
 			   "markup", oldword,
-			   "font", gcompris_skin_font_board_medium,
+			   "font", gc_skin_font_board_medium,
 			   "x", (double) 0,
 			   "y", (double) 0,
 			   "anchor", anchor,
@@ -543,10 +555,10 @@ static void ask_ready(gboolean status)
     }
 
   /*----- READY -----*/
-  button_pixmap = gcompris_load_skin_pixmap("button_large2.png");
+  button_pixmap = gc_skin_pixmap_load("button_large2.png");
   item1 = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf",  button_pixmap, 
+				"pixbuf",  button_pixmap,
 				"x", x_offset,
 				"y", y_offset,
 				NULL);
@@ -559,7 +571,7 @@ static void ask_ready(gboolean status)
   item2 = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _("I am Ready"),
-				"font", gcompris_skin_font_board_big,
+				"font", gc_skin_font_board_big,
 				"x", (double) x_offset +
 				gdk_pixbuf_get_width(button_pixmap)/2,
 				"y", (double) y_offset + 40,
@@ -583,7 +595,7 @@ static void ask_yes_no()
     return;
 
   /*----- YES -----*/
-  button_pixmap = gcompris_load_skin_pixmap("button_large2.png");
+  button_pixmap = gc_skin_pixmap_load("button_large2.png");
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_pixbuf_get_type (),
 				"pixbuf",  button_pixmap,
@@ -599,7 +611,7 @@ static void ask_yes_no()
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _("Yes, I saw it"),
-				"font", gcompris_skin_font_board_big,
+				"font", gc_skin_font_board_big,
 				"x", (double) x_offset +
 				gdk_pixbuf_get_width(button_pixmap)/2,
 				"y", (double) y_offset + 40,
@@ -613,7 +625,7 @@ static void ask_yes_no()
 
   /*----- NO -----*/
   y_offset += 100;
-  button_pixmap = gcompris_load_skin_pixmap("button_large2.png");
+  button_pixmap = gc_skin_pixmap_load("button_large2.png");
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_pixbuf_get_type (),
 				"pixbuf",  button_pixmap,
@@ -629,7 +641,7 @@ static void ask_yes_no()
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _("No, it was not there"),
-				"font", gcompris_skin_font_board_big,
+				"font", gc_skin_font_board_big,
 				"x", (double) x_offset +
 				gdk_pixbuf_get_width(button_pixmap)/2,
 				"y", (double) y_offset + 40,
@@ -647,11 +659,11 @@ static void player_win()
 {
   gamewon = TRUE;
   wait_for_ready = TRUE;
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
   /* Try the next level */
   gcomprisBoard->level++;
   if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-    board_finished(BOARD_FINISHED_RANDOM);
+    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
     return;
   }
 
@@ -673,12 +685,12 @@ static void player_loose()
   else
     got    = g_strdup_printf(_("And it was displayed"));
 
-  gcompris_log_set_comment (gcomprisBoard, expected, got);
+  gc_log_set_comment (gcomprisBoard, expected, got);
 
   g_free(expected);
   g_free(got);
 
-  gcompris_display_bonus(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, BONUS_FLOWER);
 
   next_level_timer = g_timeout_add(3000, (GtkFunction)reading_next_level, NULL);
 }
@@ -724,88 +736,28 @@ item_event_valid(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 }
 
 
-
-
-static FILE *get_wordfile(const char *locale)
-{
-  gchar *filename;
-  FILE *wordsfd = NULL;
-                                                                                                                              
-  /* First Try to find a file matching the level and the locale */
-  filename = g_strdup_printf("%s%s%d.%.2s",
-                             PACKAGE_DATA_DIR, "/wordsgame/wordslevel",
-                             gcomprisBoard->level, locale);
-  //  g_message("Trying to open file %s ", filename);
-  wordsfd = fopen (filename, "r");
-                                                                                                                              
-  if(wordsfd==NULL)
-    {
-      g_free(filename);
-      /* Second Try to find a file matching the 'max' and the locale */
-      filename = g_strdup_printf("%s%s%.2s",
-				 PACKAGE_DATA_DIR, "/wordsgame/wordslevelmax.",
-				 locale);
-      //      g_message("Trying to open file %s ", filename);
-      
-      wordsfd = fopen (filename, "r");
-    }
-                                                                                                                              
-  g_free(filename);
-                                                                                                                              
-  return wordsfd;
-}
-
-
-
-
-static gboolean  read_wordfile()
-{
-
-  FILE *wordsfd;
-  gchar *buf;
-  int len;                                                                                                                                
-
-  wordsfd = get_wordfile(gcompris_get_locale());
-                                                                                                                              
-  if(wordsfd==NULL)
-    {
-      /* Try to open the english locale by default */
-      wordsfd = get_wordfile("en");
-                                                                                                                              
-      /* Too bad, even english is not there. Check your Install */
-      if(wordsfd==NULL) {
-        gcompris_dialog(_("Cannot open file of words for your locale"), gcompris_end_board);
-        return FALSE;
-      }
-    }
-                                                                                                                              
-   words=g_ptr_array_new ();
-   while (buf=fgets(g_new(gchar,MAXWORDSLENGTH), MAXWORDSLENGTH, wordsfd)) {
- 	assert(g_utf8_validate(buf,-1,NULL));
-
-	//remove \n from end of line
-        len = strlen(buf);
-        if((0 < len)&&('\n'==buf[len-1]))
-            buf[len-1] = '\0';
-	    
-	g_ptr_array_add(words,buf);
-	}
-   fclose(wordsfd);
-
-}
-/*
- * Return a random word from a set of text file depending on 
- * the current level and language
+/** Return a random word from a set of text file depending on
+ *  the current level and language
+ *
+ * \param except: if non NULL, never return this value
+ *
+ * \return a random word from. must be freed by the caller
  */
-
-
-static gchar *get_random_word(gboolean remove)
+static gchar *
+get_random_word(const gchar* except)
 {
-  int i=rand()%words->len;
-  if (remove) 
-    return g_ptr_array_remove_index(words,i);
-  else
-    return g_ptr_array_index(words,i);
+  gchar *word;
+
+  word = gc_wordlist_random_word_get(gc_wordlist, gcomprisBoard->level);
+
+  if(except)
+    while(strcmp(except, word)==0)
+      {
+	g_free(word);
+	word = gc_wordlist_random_word_get(gc_wordlist, gcomprisBoard->level);
+      }
+
+  return(word);
 }
 
 
@@ -821,17 +773,17 @@ static gchar *get_random_word(gboolean remove)
 static GcomprisProfile *profile_conf;
 static GcomprisBoard   *board_conf;
 
-static GHFunc save_table (gpointer key,
-		    gpointer value,
-		    gpointer user_data)
+static void save_table (gpointer key,
+			gpointer value,
+			gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
-			    (gchar *) key, 
+			    (gchar *) key,
 			    (gchar *) value);
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+static void conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
@@ -842,25 +794,25 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
 
   if (gcomprisBoard){
-    gcompris_reset_locale();
+    gc_locale_reset();
 
     GHashTable *config;
-    
+
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
-    
-    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
-  
+
+    gc_locale_set(g_hash_table_lookup( config, "locale"));
+
     if (profile_conf)
       g_hash_table_destroy(config);
 
     reading_next_level();
-  
+
     pause_board(FALSE);
   }
-  
+
   board_conf = NULL;
   profile_conf = NULL;
 
@@ -877,38 +829,28 @@ reading_config_start(GcomprisBoard *agcomprisBoard,
     pause_board(TRUE);
 
   gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-				 agcomprisBoard->name, 
+				 agcomprisBoard->name,
 				 aProfile? aProfile->name: "");
 
-  gcompris_configuration_window( label, 
+  gc_board_config_window_display( label,
 				 (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *locale = g_hash_table_lookup( config, "locale");
-  
-  gcompris_combo_locales( locale);
+
+  gc_board_config_combo_locales( locale);
 
 }
 
-  
+
 /* ======================= */
 /* = config_stop        = */
 /* ======================= */
-static void 
+static void
 reading_config_stop()
 {
 }
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
