@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -177,7 +173,7 @@ static void pause_board (gboolean pause)
     }
 
   if(leavenow == TRUE && pause == FALSE)
-    board_finished(BOARD_FINISHED_TOOMANYERRORS);
+    gc_bonus_end_display(BOARD_FINISHED_TOOMANYERRORS);
 
   board_paused = pause;
 }
@@ -198,7 +194,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=7;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
 
       reversecount_next_level();
 
@@ -273,7 +269,7 @@ gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     case GDK_Hyper_L:
     case GDK_Hyper_R:
     case GDK_Num_Lock:
-      return FALSE; 
+      return FALSE;
     case GDK_KP_Enter:
     case GDK_Return:
       process_ok();
@@ -286,14 +282,14 @@ gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 
 static void process_error()
 {
-  gcompris_play_ogg ("crash", NULL);
+  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
   errors--;
   if(errors==0)
     {
       gamewon = FALSE;
       leavenow = TRUE;
       reversecount_destroy_all_items();
-      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, BONUS_SMILEY);
     }
   else
     {
@@ -326,7 +322,7 @@ static void process_ok()
   if(!animate_id) {
     animate_id = gtk_timeout_add (animate_speed, (GtkFunction) animate_tux, NULL);
   }
-  
+
 }
 
 /*-------------------------------------------------------------------------------*/
@@ -336,10 +332,10 @@ static void process_ok()
 static void reversecount_next_level()
 {
 
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  imageList[gcomprisBoard->level-1]);
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   reversecount_destroy_all_items();
   gamewon = FALSE;
@@ -410,7 +406,7 @@ static void reversecount_next_level()
 static void reversecount_destroy_all_items()
 {
 
-  gcompris_timer_end();
+  gc_timer_end();
 
   if(boardRootItem!=NULL)
     gtk_object_destroy (GTK_OBJECT(boardRootItem));
@@ -426,7 +422,7 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
   double block_width, block_height;
   double dice_area_x;
   double xratio, yratio;
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -452,37 +448,37 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
     }
 
   /* Calc the tux best ratio to display it */
-  pixmap = gcompris_load_pixmap(TUX_IMG_EAST);
+  pixmap = gc_pixmap_load(TUX_IMG_EAST);
   xratio =  block_width  / (gdk_pixbuf_get_width (pixmap) + TUX_TO_BORDER_GAP);
   yratio =  block_height / (gdk_pixbuf_get_height(pixmap) + TUX_TO_BORDER_GAP);
   tux_ratio = yratio = MIN(xratio, yratio);
   gdk_pixbuf_unref(pixmap);
 
-  pixmap = gcompris_load_pixmap("reversecount/iceblock.png");
+  pixmap = gc_pixmap_load("reversecount/iceblock.png");
 
   for(i=0; i<BOARDWIDTH; i+=block_width)
     {
       j=0;
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) i,
 				    "y", (double) j,
 				    "width", (double) block_width,
 				    "height", (double)  block_height,
-				    "width_set", TRUE, 
+				    "width_set", TRUE,
 				    "height_set", TRUE,
 					NULL);
 
       j=BOARDHEIGHT-block_height;
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) i,
 				    "y", (double) j,
 				    "width", (double) block_width,
 				    "height", (double)  block_height,
-				    "width_set", TRUE, 
+				    "width_set", TRUE,
 				    "height_set", TRUE,
 					NULL);
     }
@@ -492,24 +488,24 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
       i = 0;
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) i,
 				    "y", (double) j,
 				    "width", (double) block_width,
 				    "height", (double)  block_height,
-				    "width_set", TRUE, 
+				    "width_set", TRUE,
 				    "height_set", TRUE,
 					NULL);
 
       i = BOARDWIDTH - block_width;
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) i,
 				    "y", (double) j,
 				    "width", (double) block_width,
 				    "height", (double)  block_height,
-				    "width_set", TRUE, 
+				    "width_set", TRUE,
 				    "height_set", TRUE,
 					NULL);
     }
@@ -519,13 +515,13 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
 
   //----------------------------------------
   // Create the dice area
-  pixmap = gcompris_load_pixmap("reversecount/dice_area.png");
+  pixmap = gc_pixmap_load("reversecount/dice_area.png");
 
   dice_area_x = BOARDWIDTH - block_width - gdk_pixbuf_get_width (pixmap) - 20;
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_pixbuf_get_type (),
-			 "pixbuf", pixmap, 
+			 "pixbuf", pixmap,
 			 "x", (double) dice_area_x,
 			 "y", (double) block_height + 20,
 			 NULL);
@@ -534,7 +530,7 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
 
   //----------------------------------------
   // Create the dices
-  pixmap = gcompris_load_pixmap("gcompris/dice/gnome-dice1.png");
+  pixmap = gc_pixmap_load("gcompris/dice/gnome-dice1.png");
 
   for(d=0; d<number_of_dices; d++)
     {
@@ -545,17 +541,17 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
 
       item = gnome_canvas_item_new (boardRootItem,
 				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
+				    "pixbuf", pixmap,
 				    "x", (double) i,
 				    "y", (double) j,
 				    NULL);
       dicevalue_array[d] = 1;
       val = g_new(gint, 1);
       *val = d;
-      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, 
+      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event,
 			 val);
       gtk_signal_connect(GTK_OBJECT(item), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
 
     }
@@ -573,7 +569,7 @@ static GnomeCanvasItem *reversecount_create_item(GnomeCanvasGroup *parent)
 static void display_random_fish()
 {
 
-  fish_index = tux_index + 
+  fish_index = tux_index +
     rand()%(max_dice_number*number_of_dices) + 1;
 
   // Wrapping
@@ -599,7 +595,7 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
   block_width  = BOARDWIDTH/number_of_item_x;
   block_height = BOARDHEIGHT/number_of_item_y;
 
-  pixmap = gcompris_load_pixmap(imagename);
+  pixmap = gc_pixmap_load(imagename);
 
   if(block < number_of_item_x)
     {
@@ -607,7 +603,7 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
       g_warning("      // Upper line\n");
       i = block_width * block;
       j = 0;
-    } 
+    }
   else if(block < number_of_item_x + number_of_item_y - 2)
     {
       // Right line
@@ -628,7 +624,7 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
       // Left line
       g_warning("      // Left line\n");
       i = 0;
-      j = block_height * (number_of_item_y - (block - (number_of_item_x*2 + 
+      j = block_height * (number_of_item_y - (block - (number_of_item_x*2 +
 						      number_of_item_y-4)));
     }
 
@@ -648,14 +644,14 @@ static GnomeCanvasItem *display_item_at(gchar *imagename, int block, double rati
 
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) i + (block_width -
 						   (gdk_pixbuf_get_width (pixmap) * xratio)) / 2,
 				"y", (double) j + (block_height -
 						   (gdk_pixbuf_get_height (pixmap) * yratio)) / 2,
 				"width", (double) gdk_pixbuf_get_width (pixmap) * xratio,
 				"height", (double)  gdk_pixbuf_get_height (pixmap) * yratio,
-				"width_set", TRUE, 
+				"width_set", TRUE,
 				"height_set", TRUE,
 				NULL);
 
@@ -674,10 +670,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   reversecount_next_level();
 }
@@ -697,10 +693,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gint *dice_index)
   if(board_paused)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_BUTTON_PRESS:
-      switch(event->button.button) 
+      switch(event->button.button)
 	{
 	case 1:
 	  if(dicevalue_array[i]++ >= max_dice_number)
@@ -716,11 +712,11 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gint *dice_index)
 	}
 
       str = g_strdup_printf("gcompris/dice/gnome-dice%d.png", dicevalue_array[i]);
-      
-      pixmap = gcompris_load_pixmap(str);
+
+      pixmap = gc_pixmap_load(str);
 
       /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-      g_object_set_data (G_OBJECT (item), "pixbuf_ref", pixmap);
+      gc_item_focus_free(item, NULL);
       gnome_canvas_item_set (item,
       			     "pixbuf", pixmap,
       			     NULL);
@@ -739,7 +735,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gint *dice_index)
 /*
  * Clock management
  */
-static void create_clock(double x, double y, int value) 
+static void create_clock(double x, double y, int value)
 {
   GdkPixbuf   *pixmap = NULL;
   char	      *str = NULL;
@@ -749,7 +745,7 @@ static void create_clock(double x, double y, int value)
 
   str = g_strdup_printf("%s%d.png", "gcompris/timers/clock",value);
 
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   clock_image_item = gnome_canvas_item_new (boardRootItem,
 					    gnome_canvas_pixbuf_get_type (),
@@ -757,12 +753,12 @@ static void create_clock(double x, double y, int value)
 					    "x", (double) x,
 					    "y", (double) y,
 					    NULL);
-  
+
   gdk_pixbuf_unref(pixmap);
   g_free(str);
 }
 
-static void update_clock(int value) 
+static void update_clock(int value)
 {
   GdkPixbuf   *pixmap = NULL;
   char        *str = NULL;
@@ -772,12 +768,12 @@ static void update_clock(int value)
 
   str = g_strdup_printf("%s%d.png", "gcompris/timers/clock",value);
 
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   gnome_canvas_item_set (clock_image_item,
 			 "pixbuf", pixmap,
 			 NULL);
-  
+
   gdk_pixbuf_unref(pixmap);
   g_free(str);
 }
@@ -825,14 +821,14 @@ static gint animate_tux()
 	  // Remove the fish
 	  if(fishItem!=NULL)
 	    gtk_object_destroy(GTK_OBJECT(fishItem));
-	  
-	  gcompris_play_ogg ("gobble", NULL);
-	  
+
+	  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+
 	  if(--number_of_fish == 0)
 	    {
 	      gamewon = TRUE;
 	      reversecount_destroy_all_items();
-	      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	      gc_bonus_display(gamewon, BONUS_SMILEY);
 	    }
 	  else
 	    {
