@@ -1,6 +1,6 @@
 /* gcompris - smallnumbers.c
  *
- * Time-stamp: <2006/03/27 00:54:18 bruno>
+ * Time-stamp: <2006/08/21 23:36:29 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -139,7 +139,7 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
-  GHashTable *config = gcompris_get_board_conf();
+  GHashTable *config = gc_db_get_board_conf();
 
   locale_sound = g_strdup(g_hash_table_lookup( config, "locale_sound"));
 
@@ -159,16 +159,16 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery7_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery7_background.png");
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
       gcomprisBoard->number_of_sublevel=10;
-      gcompris_score_start(SCORESTYLE_NOTE, 
+      gc_score_start(SCORESTYLE_NOTE, 
 			   gcomprisBoard->width - 220, 
 			   gcomprisBoard->height - 50, 
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
 
 
       number_of_dices=1;
@@ -192,7 +192,7 @@ end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       smallnumbers_destroy_all_items();
     }
   gcomprisBoard = NULL;
@@ -244,7 +244,8 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
   keyval = atoi(str);
 
   g_list_foreach(GNOME_CANVAS_GROUP(boardRootItem)->item_list, 
-		 (GFunc) smallnumbers_gotkey_item, (void *)keyval);
+		 (GFunc) smallnumbers_gotkey_item,
+		 GINT_TO_POINTER(keyval));
 
   return TRUE;
 }
@@ -276,7 +277,7 @@ static void smallnumbers_next_level()
 {
 
   gamewon = FALSE;
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   smallnumbers_destroy_all_items();
 
@@ -292,7 +293,7 @@ static void smallnumbers_next_level()
   fallSpeed=5000-gcomprisBoard->level*200;
   imageZoom=0.9+(0.5/gcomprisBoard->level);
   gcomprisBoard->sublevel=1;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 }
 
 
@@ -358,13 +359,9 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
   GnomeCanvasItem *item;
   GnomeCanvasGroup *group_item;
   guint i;
-  char *lettersItem;
-  gchar *str1 = NULL;
-  gchar *str2 = NULL;
   guint total_number = 0;
   double x = 0.0;
   guint number_of_dice = number_of_dices;
-  gchar *letter;
 
   group_item = GNOME_CANVAS_GROUP(
 				  gnome_canvas_item_new (parent,
@@ -374,8 +371,8 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
 							 NULL));
 
   while(number_of_dice-- > 0) {
-
-    lettersItem = g_malloc (2);
+    gchar *str1 = NULL;
+    gchar *str2 = NULL;
 
     /* Take care not to go above 9 anyway */
     if(total_number==0) {
@@ -386,43 +383,64 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
     }
 
     total_number += i + 1;
-    sprintf(lettersItem, "%c", numbers[i]);
 
-    lettersItem[1] = '\0';
-
-    gunichar *unichar_letterItem;
-
-    unichar_letterItem = g_new(gunichar,1);
-
-    *unichar_letterItem = g_utf8_get_char (lettersItem);
-
-    letter = g_new0(gchar, 6);
-    g_unichar_to_utf8 ( *unichar_letterItem, letter);
-
-    str1 = gcompris_alphabet_sound(letter);
-
-    str2 = gcompris_get_asset_file_locale("gcompris alphabet", NULL, "audio/x-ogg", str1, locale_sound);
+    /*
+     * Play the sound
+     */
 
     if (with_sound)
-      gcompris_play_ogg(str2, NULL);
+      {
+	gunichar *unichar_letterItem;
+	char *lettersItem;
+	gchar *letter;
 
-    g_free(str1);
-    g_free(str2);
+	lettersItem = g_malloc (2);
 
+	sprintf(lettersItem, "%c", numbers[i]);
+	lettersItem[1] = '\0';
+
+	unichar_letterItem = g_new(gunichar,1);
+
+	*unichar_letterItem = g_utf8_get_char (lettersItem);
+
+	letter = g_new0(gchar, 6);
+
+	g_unichar_to_utf8(*unichar_letterItem, letter);
+
+	str1 = gc_sound_alphabet(letter);
+
+	g_free(letter);
+	g_free(lettersItem);
+	g_free(unichar_letterItem);
+
+	str2 = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str1);
+
+	gc_sound_play_ogg(str2, NULL);
+
+	g_free(str1);
+	g_free(str2);
+      }
+
+    /*
+     * Now the images
+     */
     str1 = g_strdup_printf("level%c.png", numbers[i]);
-    str2 = gcompris_image_to_skin(str1);
+    str2 = gc_skin_image_get(str1);
 
-    smallnumbers_pixmap = gcompris_load_pixmap(str2);
+    smallnumbers_pixmap = gc_pixmap_load(str2);
 
     g_free(str1);
     g_free(str2);
 
-    if(x==0.0) {
-      x = (double)(rand()%(gcomprisBoard->width-
-			   (guint)(gdk_pixbuf_get_width(smallnumbers_pixmap)* imageZoom)*2));
-    } else {
-      x += ((gdk_pixbuf_get_width(smallnumbers_pixmap)-10)*imageZoom);
-    }
+    if(x==0.0)
+      {
+	x = (double)(rand()%(gcomprisBoard->width-
+			     (guint)(gdk_pixbuf_get_width(smallnumbers_pixmap)* imageZoom)*2));
+      }
+    else
+      {
+	x += ((gdk_pixbuf_get_width(smallnumbers_pixmap)-10)*imageZoom);
+      }
 
     item = gnome_canvas_item_new (group_item,
 				  gnome_canvas_pixbuf_get_type (),
@@ -456,33 +474,33 @@ static gint smallnumbers_drop_items (GtkWidget *widget, gpointer data)
 static void player_win(GnomeCanvasItem *item)
 {
   gtk_object_destroy (GTK_OBJECT(item));
-  gcompris_play_ogg ("gobble", NULL);
+  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
 
   gcomprisBoard->sublevel++;
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   if(gcomprisBoard->sublevel>gcomprisBoard->number_of_sublevel)
     {
       /* Try the next level */
       gcomprisBoard->level++;
       if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-	gcompris_score_end();
-	board_finished(BOARD_FINISHED_RANDOM);
+	gc_score_end();
+	gc_bonus_end_display(BOARD_FINISHED_RANDOM);
 	return;
       }
       gamewon = TRUE;
       smallnumbers_destroy_all_items();
-      gcompris_display_bonus(gamewon, BONUS_SMILEY);
+      gc_bonus_display(gamewon, BONUS_SMILEY);
     }
   else
     {
-      gcompris_score_set(gcomprisBoard->sublevel);
+      gc_score_set(gcomprisBoard->sublevel);
     }
 }
 
 static void player_loose()
 {
-  gcompris_play_ogg ("crash", NULL);
+  gc_sound_play_ogg ("crash", NULL);
 }
 
 
@@ -497,7 +515,7 @@ static GHFunc save_table (gpointer key,
 		    gpointer value,
 		    gpointer user_data)
 {
-  gcompris_set_board_conf ( profile_conf,
+  gc_db_set_board_conf ( profile_conf,
 			    board_conf,
 			    (gchar *) key, 
 			    (gchar *) value);
@@ -505,7 +523,7 @@ static GHFunc save_table (gpointer key,
   return NULL;
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+static void conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
@@ -519,7 +537,7 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
     GHashTable *config;
 
     if (profile_conf)
-      config = gcompris_get_board_conf();
+      config = gc_db_get_board_conf();
     else
       config = table;
     
@@ -549,12 +567,6 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   profile_conf = NULL;
 }
 
-static gboolean check_text(gchar *key, gchar *text, GtkLabel *label){
-  gtk_label_set_markup(label, text);
-
-  return TRUE;
-}
-
 static void sound_control_box_toggled(GtkToggleButton *togglebutton,
 				      gpointer combo)
 {
@@ -577,12 +589,12 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
 			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
-  gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
+  gc_board_config_window_display(label, (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
   /* init the combo to previously saved value */
-  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+  GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
 
@@ -592,9 +604,11 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   else
     with_sound = FALSE;
 
-  GtkCheckButton  *sound_control = gcompris_boolean_box("Enable sounds", "with_sound", with_sound);
+  GtkCheckButton  *sound_control = gc_board_config_boolean_box("Enable sounds", "with_sound", with_sound);
   
-  GtkComboBox *sound_box = gcompris_combo_locales_asset( "Select sound locale", saved_locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+  GtkComboBox *sound_box = gc_board_config_combo_locales_asset( "Select sound locale",
+							 saved_locale_sound,
+							 "sounds/$LOCALE/colors/purple.ogg");
 
   gtk_widget_set_sensitive(GTK_WIDGET(sound_box), with_sound);
 
@@ -612,14 +626,3 @@ static void
 smallnumber_config_stop()
 {
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
