@@ -17,10 +17,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
-
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
@@ -74,7 +70,7 @@ static void		animate_items(void);
 static void		launch_dart(double item_x, double item_y);
 
 /*
- * distance to target, min wind speed, max wind speed, target1 width(center), 
+ * distance to target, min wind speed, max wind speed, target1 width(center),
  * value1 (for target1), ... to target10, value10
  *
  * a target width of 0 means no such target
@@ -92,7 +88,7 @@ typedef struct {
 
 /*
  * Definition of targets one line by level based on TargetDefinition
- */ 
+ */
 static TargetDefinition targetDefinition[] =
 {
   { 3, 100, 2, 5,  { 40, 5 , 80, 3, 150, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 } },
@@ -195,7 +191,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=1; /* Go to next level after this number of 'play' */
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/target_background.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/target_background.jpg");
 
       target_next_level();
 
@@ -254,7 +250,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     case GDK_Hyper_L:
     case GDK_Hyper_R:
     case GDK_Num_Lock:
-      return FALSE; 
+      return FALSE;
     case GDK_KP_Enter:
     case GDK_Return:
       process_ok();
@@ -271,7 +267,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
       break;
     }
 
-  c = tolower(keyval); 
+  c = tolower(keyval);
 
   /* Limit the user entry to 5 digits */
   if(c>='0' && c<='9' && answer_string_index<5)
@@ -281,9 +277,13 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     }
 
   if(answer_item)
-    gnome_canvas_item_set(answer_item,
-			  "text", g_strdup_printf(_("Points = %s"), answer_string),
-			  NULL);
+    {
+      gchar *tmpstr = g_strdup_printf(_("Points = %s"), answer_string);
+      gnome_canvas_item_set(answer_item,
+			    "text", tmpstr,
+			    NULL);
+      g_free(tmpstr);
+    }
 
   return TRUE;
 }
@@ -311,8 +311,8 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void target_next_level()
 {
 
-  gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set(GC_BAR_LEVEL);
+  gc_bar_set_level(gcomprisBoard);
 
   target_destroy_all_items();
   gamewon = FALSE;
@@ -347,7 +347,7 @@ static void display_windspeed()
 {
   guint second = 0;
   guint needle_zoom = 15;
-
+  gchar *tmpstr;
   GnomeCanvasPoints *canvasPoints;
   canvasPoints = gnome_canvas_points_new (2);
 
@@ -400,15 +400,17 @@ static void display_windspeed()
 			 "width_units", (double)1,
 			 NULL);
 
+  tmpstr = g_strdup_printf(_("Wind speed = %d\nkilometers/hour"), (guint)wind_speed);
   gnome_canvas_item_new (speedRootItem,
 			 gnome_canvas_text_get_type (),
-			 "text", g_strdup_printf(_("Wind speed = %d\nkilometers/hour"), (guint)wind_speed),
-			 "font", gcompris_skin_font_board_medium,
+			 "text", tmpstr,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) SPEED_CENTER_X,
 			 "y", (double) SPEED_CENTER_Y + 110,
 			 "anchor", GTK_ANCHOR_CENTER,
 			 "fill_color", "white",
 			 NULL);
+  g_free(tmpstr);
 
 }
 
@@ -418,6 +420,7 @@ static void display_windspeed()
 static GnomeCanvasItem *target_create_item(GnomeCanvasGroup *parent)
 {
   int i;
+  gchar *tmpstr;
   GnomeCanvasItem *item = NULL;
 
   boardRootItem = GNOME_CANVAS_GROUP(
@@ -440,38 +443,42 @@ static GnomeCanvasItem *target_create_item(GnomeCanvasGroup *parent)
 					"outline_color", "black",
 					"width_units", (double)1,
 					NULL);
-	  
+
 	  gnome_canvas_item_lower_to_bottom(item);
 	  gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
-	  
+
 	  /* Display the value for this target */
+	  tmpstr = g_strdup_printf("%d",
+				   targetDefinition[gcomprisBoard->level-1].target_width_value[i*2+1]);
 	  item = gnome_canvas_item_new (boardRootItem,
 					gnome_canvas_text_get_type (),
-					"text", g_strdup_printf("%d", 
-								targetDefinition[gcomprisBoard->level-1].target_width_value[i*2+1]),
-					"font", gcompris_skin_font_board_medium,
+					"text", tmpstr,
+					"font", gc_skin_font_board_medium,
 					"x", (double) 0,
 					"y", (double) targetDefinition[gcomprisBoard->level-1].target_width_value[i*2] - 10,
 					"anchor", GTK_ANCHOR_CENTER,
 					"fill_color", "white",
 					NULL);
-	  
+	  g_free(tmpstr);
+
 	  gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
 	}
     }
 
   number_of_arrow = targetDefinition[gcomprisBoard->level-1].number_of_arrow;
 
+  tmpstr = g_strdup_printf(_("Distance to target = %d meters"),
+			   targetDefinition[gcomprisBoard->level-1].target_distance);
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
-			 "text", g_strdup_printf(_("Distance to target = %d meters"), 
-						 targetDefinition[gcomprisBoard->level-1].target_distance),
-			 "font", gcompris_skin_font_board_medium,
+			 "text", tmpstr,
+			 "font", gc_skin_font_board_medium,
 			 "x", (double) 0,
 			 "y", (double) BOARDHEIGHT-TARGET_CENTER_Y -45,
 			 "anchor", GTK_ANCHOR_CENTER,
 			 "fill_color", "white",
 			 NULL);
+  g_free(tmpstr);
 
   display_windspeed();
 
@@ -487,10 +494,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   target_next_level();
 }
@@ -500,17 +507,17 @@ static void process_ok()
   guint answer_points = atoi(answer_string);
 
   if(answer_item) {
-    
+
     if(answer_points == user_points)
       {
 	gamewon = TRUE;
 	target_destroy_all_items();
-	gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	gc_bonus_display(gamewon, BONUS_SMILEY);
       }
     else
       {
 	gamewon = FALSE;
-	gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	gc_bonus_display(gamewon, BONUS_SMILEY);
       }
   }
 
@@ -525,25 +532,28 @@ static void request_score()
   GdkPixbuf *button_pixmap = NULL;
   double y_offset = 160;
   double x_offset = 245;
+  gchar *tmpstr;
 
-  gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
-  button_pixmap = gcompris_load_skin_pixmap("button_large2.png");
+  gc_bar_set(GC_BAR_LEVEL|GC_BAR_OK);
+  button_pixmap = gc_skin_pixmap_load("button_large2.png");
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_pixbuf_get_type (),
-			 "pixbuf",  button_pixmap, 
+			 "pixbuf",  button_pixmap,
 			 "x", x_offset,
 			 "y", y_offset,
 			 NULL);
 
+  tmpstr =  g_strdup_printf(_("Points = %s"), "");
   answer_item = gnome_canvas_item_new (boardRootItem,
 				       gnome_canvas_text_get_type (),
-				       "text", g_strdup_printf(_("Points = %s"), ""),
-				       "font", gcompris_skin_font_board_title_bold,
+				       "text", tmpstr,
+				       "font", gc_skin_font_board_title_bold,
 				       "x", (double) x_offset + gdk_pixbuf_get_width(button_pixmap)/2,
 				       "y", (double) y_offset + gdk_pixbuf_get_height(button_pixmap)/2,
 				       "anchor", GTK_ANCHOR_CENTER,
 				       "fill_color", "white",
 				       NULL);
+  g_free(tmpstr);
 
   gdk_pixbuf_unref(button_pixmap);
 }
@@ -590,7 +600,7 @@ static void animate_items()
 			 "x2", (double)animate_item_x + animate_item_size,
 			 "y2", (double)animate_item_y + animate_item_size,
 			 NULL);
-  
+
   if(animate_item_size>MIN_DART_SIZE)
     animate_item_size--;
 
@@ -610,7 +620,7 @@ static void animate_items()
 }
 
 /*
- * 
+ *
  */
 static void launch_dart(double item_x, double item_y)
 {
@@ -637,7 +647,7 @@ static void launch_dart(double item_x, double item_y)
     {
       request_score();
     }
-  
+
 }
 
 /* ==================================== */
@@ -645,7 +655,7 @@ static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
   double item_x, item_y;
-  
+
   if(board_paused)
     return FALSE;
 
@@ -653,10 +663,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   if(number_of_arrow == 0 || animate_item)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_BUTTON_PRESS:
-      switch(event->button.button) 
+      switch(event->button.button)
 	{
 	case 1:
 	case 2:
