@@ -3,7 +3,7 @@
  * Copyright (C) 2002 Bruno Coudoin
  *
  * Based on the original code from Geoff Reedy <vader21@imsa.edu>
- * Copyright (C) 2000 Geoff Reedy 
+ * Copyright (C) 2000 Geoff Reedy
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
  */
 
 #include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <assert.h>
 
 #include "traffic.h"
 
@@ -84,7 +81,7 @@ struct _jam {
 static int	 car_cb(GnomeCanvasItem *item, GdkEvent *event, car *thiscar);
 gboolean	 load_level(guint level, guint card);
 
-static jam	 current_card  ={0,0,0,NULL};
+static jam	 current_card  ={0,0,0,{NULL}};
 
 static void	 draw_grid  (GnomeCanvasGroup *rootBorder);
 static gint	 cars_from_strv(char *strv);
@@ -155,24 +152,24 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=8;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=5; /* Go to next level after this number of 'play' */
-      gcompris_score_start(SCORESTYLE_NOTE, 
-			   gcomprisBoard->width - 220, 
-			   gcomprisBoard->height - 50, 
+      gc_score_start(SCORESTYLE_NOTE,
+			   gcomprisBoard->width - 220,
+			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
 
-      str = gcompris_image_to_skin("button_reload.png");
-      pixmap = gcompris_load_pixmap(str);
+      str = gc_skin_image_get("button_reload.png");
+      pixmap = gc_pixmap_load(str);
       g_free(str);
       if(pixmap) {
-	gcompris_bar_set_repeat_icon(pixmap);
+	gc_bar_set_repeat_icon(pixmap);
 	gdk_pixbuf_unref(pixmap);
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_REPEAT_ICON);
+	gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT_ICON);
       } else {
-	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_REPEAT);
+	gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT);
       }
 
-      img = gcompris_image_to_skin("traffic-bg.jpg");
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+      img = gc_skin_image_get("traffic-bg.jpg");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			      img);
       g_free(img);
 
@@ -188,7 +185,7 @@ static void end_board ()
   if(gcomprisBoard!=NULL)
     {
       pause_board(TRUE);
-      gcompris_score_end();
+      gc_score_end();
       traffic_destroy_all_items();
     }
   gcomprisBoard = NULL;
@@ -239,12 +236,12 @@ static void repeat (){
 static void traffic_next_level()
 {
 
-  gcompris_bar_set_level(gcomprisBoard);
+  gc_bar_set_level(gcomprisBoard);
 
   traffic_destroy_all_items();
   gamewon = FALSE;
 
-  gcompris_score_set(gcomprisBoard->sublevel);
+  gc_score_set(gcomprisBoard->sublevel);
 
   /* Try the next level */
   traffic_create_item(gnome_canvas_root(gcomprisBoard->canvas));
@@ -309,10 +306,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      board_finished(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
       return;
     }
-    gcompris_play_ogg ("bonus", NULL);
+    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
   }
   traffic_next_level();
 }
@@ -415,9 +412,9 @@ static int car_cb(GnomeCanvasItem *item, GdkEvent *event, car *thiscar)
 
     if (thiscar->orient==CAR_ORIENT_NS)
       cursor=gdk_cursor_new(GDK_SB_V_DOUBLE_ARROW);
-    else 
+    else
       cursor=gdk_cursor_new(GDK_SB_H_DOUBLE_ARROW);
-    gnome_canvas_item_grab(item,
+    gc_canvas_item_grab(item,
 			   GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 			   cursor,
 			   event->button.time);
@@ -494,13 +491,13 @@ static int car_cb(GnomeCanvasItem *item, GdkEvent *event, car *thiscar)
 	dy=CLAMP(item_y-start_y,-39,39);
 	dx=CLAMP(item_x-start_x,-39,39);
 
-	if (thiscar->goal && big_x==250+OFSET_X) { 
-	  gnome_canvas_item_ungrab(item,event->button.time);
+	if (thiscar->goal && big_x==250+OFSET_X) {
+	  gc_canvas_item_ungrab(item,event->button.time);
 	  gnome_canvas_item_hide(item);
 	  moving=FALSE;
 
 	  gamewon = TRUE;
-	  gcompris_display_bonus(gamewon, BONUS_SMILEY);
+	  gc_bonus_display(gamewon, BONUS_SMILEY);
 
 	}
 
@@ -573,7 +570,7 @@ static int car_cb(GnomeCanvasItem *item, GdkEvent *event, car *thiscar)
 	  dy=*ptr-y;
 
 	gnome_canvas_item_move(item,dx,dy);
-	gnome_canvas_item_ungrab(item,event->button.time);
+	gc_canvas_item_ungrab(item,event->button.time);
 	hit=0;
 	moving=FALSE;
       }
@@ -664,7 +661,7 @@ gint cars_from_strv(char *strv)
       else if (y == 'F') ccar->x = 5;
     }
 
-    if (id == 'X') 
+    if (id == 'X')
       {
 	ccar->color  = 0xFF0000FF;
 	ccar->goal   = 1;
@@ -684,7 +681,7 @@ gint cars_from_strv(char *strv)
     else if (id == 'P') ccar->color = 0xFF80FFFF;
     else if (id == 'Q') ccar->color = 0x0000FFFF;
     else if (id == 'R') ccar->color = 0x00FFFFFF;
-    
+
   }
   return number_of_cars;
 }
