@@ -1,6 +1,6 @@
 /* gcompris - bar.c
  *
- * Time-stamp: <2006/03/12 03:02:12 bruno>
+ * Time-stamp: <2006/08/21 23:27:39 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include "gcompris.h"
+#include "gc_core.h"
 #include "gcompris_config.h"
 #include "about.h"
 
@@ -57,7 +58,7 @@ static gint sound_play_id = 0;
 static void  confirm_quit(gboolean answer);
 
 /*
- * Main entry point 
+ * Main entry point
  * ----------------
  *
  */
@@ -66,9 +67,9 @@ static void  confirm_quit(gboolean answer);
 /*
  * Do all the bar display and register the events
  */
-void gcompris_bar_start (GnomeCanvas *theCanvas)
+void gc_bar_start (GnomeCanvas *theCanvas)
 {
-  GcomprisProperties *properties = gcompris_get_properties();
+  GcomprisProperties *properties = gc_prop_get();
   GdkPixbuf   *pixmap = NULL;
   GnomeCanvasItem *rootitem;
   gint16           width, height;
@@ -86,10 +87,10 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 			   "y", (double)0,
 			   NULL);
 
-  pixmap = gcompris_load_skin_pixmap("bar_bg.jpg");
+  pixmap = gc_skin_pixmap_load("bar_bg.jpg");
   bar_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) 0,
 				"y", (double) 0,
 				NULL);
@@ -98,11 +99,11 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
   // EXIT
   if(properties->disable_quit == 0)
     {
-      pixmap = gcompris_load_skin_pixmap("button_exit.png");
+      pixmap = gc_skin_pixmap_load("button_exit.png");
       zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
       exit_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					 gnome_canvas_pixbuf_get_type (),
-					 "pixbuf", pixmap, 
+					 "pixbuf", pixmap,
 					 "x", (double) (width/NUMBER_OF_ITEMS) * 1 -
 					 gdk_pixbuf_get_width(pixmap)/2,
 					 "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -114,17 +115,17 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 			 "quit");
 
       gtk_signal_connect(GTK_OBJECT(exit_item), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
     }
-  
+
   // HOME
-  pixmap = gcompris_load_skin_pixmap("home.png");
+  pixmap = gc_skin_pixmap_load("home.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   home_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
-				     "x", (double) (width/NUMBER_OF_ITEMS) * 9 - 
+				     "pixbuf", pixmap,
+				     "x", (double) (width/NUMBER_OF_ITEMS) * 9 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
 				     NULL);
@@ -135,16 +136,16 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     "back");
 
   gtk_signal_connect(GTK_OBJECT(home_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 
   // OK
-  pixmap = gcompris_load_skin_pixmap("ok.png");
+  pixmap = gc_skin_pixmap_load("ok.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   ok_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				   gnome_canvas_pixbuf_get_type (),
-				   "pixbuf", pixmap, 
+				   "pixbuf", pixmap,
 				   "x", (double) (width/NUMBER_OF_ITEMS) * 7 -
 				   gdk_pixbuf_get_width(pixmap)/2,
 				   "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -156,16 +157,16 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     "ok");
 
   gtk_signal_connect(GTK_OBJECT(ok_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 
   // LEVEL
-  pixmap = gcompris_load_skin_pixmap("level1.png");
+  pixmap = gc_skin_pixmap_load("level1.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   level_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				      gnome_canvas_pixbuf_get_type (),
-				      "pixbuf", pixmap, 
+				      "pixbuf", pixmap,
 				      "x", (double) (width/NUMBER_OF_ITEMS) * 5 -
 				      gdk_pixbuf_get_width(pixmap)/2,
 				      "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -178,35 +179,35 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     "level");
 
   level_handler_id =   gtk_signal_connect(GTK_OBJECT(level_item), "event",
-					  (GtkSignalFunc) gcompris_item_event_focus,
+					  (GtkSignalFunc) gc_item_focus_event,
 					  NULL);
 
   // REPEAT
-  pixmap = gcompris_load_skin_pixmap("repeat.png");
+  pixmap = gc_skin_pixmap_load("repeat.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   repeat_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				       gnome_canvas_pixbuf_get_type (),
-				       "pixbuf", pixmap, 
+				       "pixbuf", pixmap,
 				       "x", (double) (width/NUMBER_OF_ITEMS) * 6 -
 				       gdk_pixbuf_get_width(pixmap)/2,
 				       "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
 				       NULL);
   gdk_pixbuf_unref(pixmap);
-  
+
   gtk_signal_connect(GTK_OBJECT(repeat_item), "event",
 		     (GtkSignalFunc) item_event_bar,
 		     "repeat");
 
   gtk_signal_connect(GTK_OBJECT(repeat_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   // HELP
-  pixmap = gcompris_load_skin_pixmap("help.png");
+  pixmap = gc_skin_pixmap_load("help.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   help_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
+				     "pixbuf", pixmap,
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 4 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -218,17 +219,17 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     "help");
 
   gtk_signal_connect(GTK_OBJECT(help_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   // CONFIG
   if(properties->disable_config == 0)
     {
-      pixmap = gcompris_load_skin_pixmap("config.png");
+      pixmap = gc_skin_pixmap_load("config.png");
       zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
       config_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					   gnome_canvas_pixbuf_get_type (),
-					   "pixbuf", pixmap, 
+					   "pixbuf", pixmap,
 					   "x", (double) (width/NUMBER_OF_ITEMS) * 3 -
 					   gdk_pixbuf_get_width(pixmap)/2,
 					   "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -240,16 +241,16 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 			 "configuration");
 
       gtk_signal_connect(GTK_OBJECT(config_item), "event",
-			 (GtkSignalFunc) gcompris_item_event_focus,
+			 (GtkSignalFunc) gc_item_focus_event,
 			 NULL);
     }
 
   // ABOUT
-  pixmap = gcompris_load_skin_pixmap("about.png");
+  pixmap = gc_skin_pixmap_load("about.png");
   zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
   about_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
+				     "pixbuf", pixmap,
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 2 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
@@ -261,22 +262,22 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     "about");
 
   gtk_signal_connect(GTK_OBJECT(about_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   // Show them all
   update_exit_button();
-  gnome_canvas_item_show(level_item);
-  gnome_canvas_item_show(ok_item);
-  gnome_canvas_item_show(help_item);
-  gnome_canvas_item_show(repeat_item);
+  gnome_canvas_item_hide(level_item);
+  gnome_canvas_item_hide(ok_item);
+  gnome_canvas_item_hide(help_item);
+  gnome_canvas_item_hide(repeat_item);
   if(config_item)
-    gnome_canvas_item_show(config_item);
-  gnome_canvas_item_show(about_item);
+    gnome_canvas_item_hide(config_item);
+  gnome_canvas_item_hide(about_item);
 }
 
 
-void gcompris_bar_set_level(GcomprisBoard *gcomprisBoard)
+void gc_bar_set_level(GcomprisBoard *gcomprisBoard)
 {
   char *str = NULL;
   GdkPixbuf *pixmap = NULL;
@@ -292,36 +293,37 @@ void gcompris_bar_set_level(GcomprisBoard *gcomprisBoard)
     {
 
       str = g_strdup_printf("level%d.png", gcomprisBoard->level);
-      pixmap = gcompris_load_skin_pixmap(str);
-   
+      pixmap = gc_skin_pixmap_load(str);
+
       g_free(str);
-      /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-      g_object_set_data (G_OBJECT (level_item), "pixbuf_ref", pixmap);
+      /* Warning changing the image needs to free the focus first */
+      gc_item_focus_free(level_item, NULL);
+
       gnome_canvas_item_set (level_item,
       			     "pixbuf", pixmap,
       			     NULL);
       gdk_pixbuf_unref(pixmap);
     }
-  
+
   current_level=gcomprisBoard->level;
 }
 
 
 
-/* gcompris_bar_set_repeat_icon
+/* gc_bar_set_repeat_icon
  *
  * Override the repeat icon to a new one specific to your current board.
- * This must be called before calling gcompris_bar_set with GCOMPRIS_BAR_REPEAT_ICON
+ * This must be called before calling gc_bar_set with GC_BAR_REPEAT_ICON
  * the given pixmap is not freed.
  *
- * Next call to gcompris_bar_set with GCOMPRIS_BAR_REPEAT will restore the default icon.
+ * Next call to gc_bar_set with GC_BAR_REPEAT will restore the default icon.
  *
  */
 void
-gcompris_bar_set_repeat_icon (GdkPixbuf *pixmap)
+gc_bar_set_repeat_icon (GdkPixbuf *pixmap)
 {
   /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-  g_object_set_data (G_OBJECT (repeat_item), "pixbuf_ref", pixmap);
+  gc_item_focus_free(repeat_item, NULL);
   gnome_canvas_item_set (repeat_item,
 			 "pixbuf", pixmap,
 			 NULL);
@@ -329,33 +331,33 @@ gcompris_bar_set_repeat_icon (GdkPixbuf *pixmap)
 
 /* Setting list of available icons in the control bar */
 void
-gcompris_bar_set (const GComprisBarFlags flags)
+gc_bar_set (const GComprisBarFlags flags)
 {
 
   current_flags = flags;
 
   update_exit_button();
 
-  if(flags&GCOMPRIS_BAR_LEVEL)
+  if(flags&GC_BAR_LEVEL)
     gnome_canvas_item_show(level_item);
   else
     gnome_canvas_item_hide(level_item);
 
-  if(flags&GCOMPRIS_BAR_OK)
+  if(flags&GC_BAR_OK)
     gnome_canvas_item_show(ok_item);
   else
     gnome_canvas_item_hide(ok_item);
 
-  if(gcompris_board_has_help(get_current_gcompris_board()))
+  if(gc_help_has_board(gc_board_get_current()))
     gnome_canvas_item_show(help_item);
   else
     gnome_canvas_item_hide(help_item);
 
-  if(flags&GCOMPRIS_BAR_REPEAT) {
+  if(flags&GC_BAR_REPEAT) {
     GdkPixbuf *pixmap;
 
     /* Set the repeat icon to the original one */
-    pixmap = gcompris_load_skin_pixmap("repeat.png");
+    pixmap = gc_skin_pixmap_load("repeat.png");
     gnome_canvas_item_set (repeat_item,
 			   "pixbuf", pixmap,
 			   NULL);
@@ -364,32 +366,32 @@ gcompris_bar_set (const GComprisBarFlags flags)
     gnome_canvas_item_show(repeat_item);
   } else {
 
-    if(flags&GCOMPRIS_BAR_REPEAT_ICON)
+    if(flags&GC_BAR_REPEAT_ICON)
       gnome_canvas_item_show(repeat_item);
     else
       gnome_canvas_item_hide(repeat_item);
   }
 
-  if(flags&GCOMPRIS_BAR_CONFIG && config_item)
+  if(flags&GC_BAR_CONFIG && config_item)
     gnome_canvas_item_show(config_item);
   else
     gnome_canvas_item_hide(config_item);
 
-  if(flags&GCOMPRIS_BAR_ABOUT)
+  if(flags&GC_BAR_ABOUT)
     gnome_canvas_item_show(about_item);
   else
     gnome_canvas_item_hide(about_item);
 
   /* FIXME : Workaround for bugged canvas */
-  //  gnome_canvas_update_now(get_current_gcompris_board()->canvas);
+  //  gnome_canvas_update_now(gc_board_get_current()->canvas);
 
 }
 
-/* Hide all icons in the control bar 
+/* Hide all icons in the control bar
  * or retore the icons to the previous value
  */
 void
-gcompris_bar_hide (gboolean hide)
+gc_bar_hide (gboolean hide)
 {
   if(hide)
     {
@@ -407,7 +409,7 @@ gcompris_bar_hide (gboolean hide)
   else
     {
       gnome_canvas_item_show(home_item);
-      gcompris_bar_set(current_flags);
+      gc_bar_set(current_flags);
     }
 }
 
@@ -422,10 +424,10 @@ gcompris_bar_hide (gboolean hide)
 static void update_exit_button()
 {
 
-  if(get_current_gcompris_board() == NULL)
+  if(gc_board_get_current() == NULL)
     return;
 
-  if (get_current_gcompris_board()->previous_board == NULL)
+  if (gc_board_get_current()->previous_board == NULL)
     {
       /* We are in the upper menu: show it */
       if(exit_item)
@@ -446,20 +448,17 @@ static void update_exit_button()
  */
 static gint bar_play_sound (gchar *sound)
 {
-  int policy = getSoundPolicy();
-  gchar *str1;
-  gchar *str2;
-  setSoundPolicy(PLAY_ONLY_IF_IDLE);
+  int policy = gc_sound_policy_get();
+  gchar *str;
+  gc_sound_policy_set(PLAY_ONLY_IF_IDLE);
 
-  str1 = g_strdup_printf("%s%s", sound, ".ogg");
-  str2 = gcompris_get_asset_file("gcompris misc", NULL, "audio/x-ogg", str1);
+  str = g_strdup_printf("sounds/$LOCALE/misc/%s.ogg", sound);
 
-  gcompris_play_ogg( str2, NULL);
+  gc_sound_play_ogg(str, NULL);
 
-  g_free(str1);
-  g_free(str2);
+  g_free(str);
 
-  setSoundPolicy(policy);
+  gc_sound_policy_set(policy);
   sound_play_id = 0;
   return (FALSE);
 }
@@ -476,7 +475,7 @@ static void bar_reset_sound_id ()
 static gint
 item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+  GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
   switch (event->type)
     {
@@ -493,7 +492,7 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
       /* This is not perfect clean but it makes it easy to remove the help window
 	 by clicking on any button in the bar */
       if(strcmp((char *)data, "help"))
-	gcompris_help_stop ();
+	gc_help_stop ();
 
       if(!strcmp((char *)data, "ok"))
 	{
@@ -508,9 +507,6 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
       else if(!strcmp((char *)data, "level"))
 	{
 	  gint tmp = current_level;
-	  gchar *current_level_str;
-	  gchar *str_level;
-	  gchar *str_number;
 
 	  current_level++;
 	  if(current_level>gcomprisBoard->maxlevel)
@@ -518,16 +514,16 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 
 	  if(tmp!=current_level)
 	    {
-	      char *number_str = g_strdup_printf("%d", current_level);
-	      current_level_str = gcompris_alphabet_sound(number_str);
+	      gchar *str_number;
+
+	      gchar *number_str = g_strdup_printf("%d", current_level);
+	      gchar *current_level_str = gc_sound_alphabet(number_str);
 	      g_free(number_str);
 
-	      str_level  = gcompris_get_asset_file("gcompris misc",     NULL, "audio/x-ogg", "level.ogg");
-	      str_number = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", current_level_str);
+	      str_number = g_strdup_printf("sounds/$LOCALE/alphabet/%s", current_level_str);
 
-	      gcompris_play_ogg(str_level, str_number, NULL);
+	      gc_sound_play_ogg("sounds/$LOCALE/misc/level.ogg", str_number, NULL);
 
-	      g_free(str_level);
 	      g_free(str_number);
 	      g_free(current_level_str);
 	    }
@@ -539,13 +535,14 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 	}
       else if(!strcmp((char *)data, "back"))
 	{
-	  gcompris_play_ogg ("gobble", NULL);
-	  board_stop();
+	  gc_sound_play_ogg ("gobble", NULL);
+	  gc_bar_hide (TRUE);
+	  gc_board_stop();
 	}
       else if(!strcmp((char *)data, "help"))
 	{
-	  gcompris_play_ogg ("gobble", NULL);
-	  gcompris_help_start(gcomprisBoard);
+	  gc_sound_play_ogg ("gobble", NULL);
+	  gc_help_start(gcomprisBoard);
 	}
       else if(!strcmp((char *)data, "repeat"))
 	{
@@ -559,23 +556,23 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 	  if(gcomprisBoard->plugin->config_start != NULL)
 	    {
 	      gcomprisBoard->plugin->config_start(gcomprisBoard,
-						  gcompris_get_current_profile());
+						  gc_profile_get_current());
 	    }
 	}
       else if(!strcmp((char *)data, "about"))
 	{
-	  gcompris_about_start();
+	  gc_about_start();
 	}
       else if(!strcmp((char *)data, "quit"))
 	{
-	  gcompris_confirm( _("GCompris confirmation"),
-			    _("Sure you want to quit ?"),
-			    _("Yes, I am sure !"),
+	  gc_confirm_box( _("GCompris confirmation"),
+			    _("Are you sure you want to quit?"),
+			    _("Yes, I am sure!"),
 			    _("No, I want to keep going"),
 			    (ConfirmCallBack) confirm_quit);
 	}
       break;
-      
+
     default:
       break;
     }
@@ -587,14 +584,5 @@ static void
 confirm_quit(gboolean answer)
 {
   if (answer)
-    gcompris_exit();
+    gc_exit();
 }
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
