@@ -1,5 +1,5 @@
 /*  GCompris -- This files comes from XMMS
- * 
+ *
  *  XMMS - Cross-platform multimedia player
  *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
  *
@@ -21,17 +21,15 @@
 #include <string.h>
 
 #include "gcompris.h"
+#include "gc_core.h"
 
 
 static struct BoardPluginData *bp_data;
 
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
-
+static gboolean	 get_board_playing(void);
 
 #ifdef WIN32
+int gc_activation_check(char *code);
 extern BoardPlugin * get_advanced_colors_bplugin_info();
 extern BoardPlugin * get_algebra_bplugin_info();
 extern BoardPlugin * get_algebra_guesscount_bplugin_info();
@@ -42,6 +40,7 @@ extern BoardPlugin * get_clickgame_bplugin_info();
 extern BoardPlugin * get_click_on_letter_bplugin_info();
 extern BoardPlugin * get_clockgame_bplugin_info();
 extern BoardPlugin * get_colors_bplugin_info();
+extern BoardPlugin * get_crane_bplugin_info();
 extern BoardPlugin * get_draw_bplugin_info();
 extern BoardPlugin * get_enumerate_bplugin_info();
 extern BoardPlugin * get_erase_bplugin_info();
@@ -72,6 +71,7 @@ extern BoardPlugin * get_superbrain_bplugin_info();
 extern BoardPlugin * get_target_bplugin_info();
 extern BoardPlugin * get_traffic_bplugin_info();
 extern BoardPlugin * get_wordsgame_bplugin_info();
+extern BoardPlugin * get_python_bplugin_info();
 
 #define MAX_NUMBER_OF_BOARDS 200
 static BoardPlugin *static_boards_demo[MAX_NUMBER_OF_BOARDS];
@@ -79,42 +79,39 @@ static BoardPlugin *static_boards[MAX_NUMBER_OF_BOARDS];
 
 #endif
 
-/*
- * The directory in which we will search for plugins
- * (In that order)
- */
-static gchar *plugin_paths[] = {
-  "../boards/.libs/",		/* Usefull path to test plugins without re-installing them */
-  "./boards/.libs/",
-  PLUGIN_DIR,
-  NULL
-};
-
 #ifdef WIN32
-void init_plugins(void)
+int gc_board_number_in_demo;
+void gc_board_init(void)
 {
   guint i=0;
 
   bp_data = g_malloc0(sizeof (struct BoardPluginData));
 
   static_boards_demo[i++] = get_awele_bplugin_info();
+  static_boards_demo[i++] = get_canal_lock_bplugin_info();
   static_boards_demo[i++] = get_click_on_letter_bplugin_info();
   static_boards_demo[i++] = get_clickgame_bplugin_info();
+  static_boards_demo[i++] = get_clockgame_bplugin_info();
   static_boards_demo[i++] = get_colors_bplugin_info();
+  static_boards_demo[i++] = get_crane_bplugin_info();
   static_boards_demo[i++] = get_draw_bplugin_info();
   static_boards_demo[i++] = get_enumerate_bplugin_info();
   static_boards_demo[i++] = get_erase_bplugin_info();
   static_boards_demo[i++] = get_gletters_bplugin_info();
   static_boards_demo[i++] = get_gtans_bplugin_info();
   static_boards_demo[i++] = get_hanoi_bplugin_info();
+  static_boards_demo[i++] = get_leftright_bplugin_info();
   static_boards_demo[i++] = get_magic_hat_bplugin_info();
   static_boards_demo[i++] = get_menu_bplugin_info();
+  static_boards_demo[i++] = get_money_bplugin_info();
   static_boards_demo[i++] = get_reading_bplugin_info();
   static_boards_demo[i++] = get_submarine_bplugin_info();
   static_boards_demo[i++] = get_superbrain_bplugin_info();
   static_boards_demo[i++] = get_target_bplugin_info();
   static_boards_demo[i++] = NULL;
 
+  gc_board_number_in_demo = i - 2;
+
   i=0;
 
   static_boards[i++] = get_awele_bplugin_info();
@@ -128,6 +125,7 @@ void init_plugins(void)
   static_boards[i++] = get_clickgame_bplugin_info();
   static_boards[i++] = get_clockgame_bplugin_info();
   static_boards[i++] = get_colors_bplugin_info();
+  static_boards[i++] = get_crane_bplugin_info();
   static_boards[i++] = get_draw_bplugin_info();
   static_boards[i++] = get_enumerate_bplugin_info();
   static_boards[i++] = get_erase_bplugin_info();
@@ -158,26 +156,27 @@ void init_plugins(void)
   static_boards[i++] = get_target_bplugin_info();
   static_boards[i++] = get_traffic_bplugin_info();
   static_boards[i++] = get_wordsgame_bplugin_info();
+  static_boards[i++] = get_python_bplugin_info();
   static_boards[i++] = NULL;
 
   i=0;
   while(static_boards[i] != NULL) {
     /* If this plugin defines an initialisation entry point, call it */
     BoardPlugin *bp;
-      
+
     /* Get the BoardPlugin Info */
     bp = (BoardPlugin *) static_boards[i++];
-      
+
     if(bp->init != NULL) {
       bp->init(NULL);
     }
   }
 }
 #else
-void init_plugins(void)
+void gc_board_init(void)
 {
 
-  /* Fist make sure the module loading is supported on this platform */
+  /* First make sure the module loading is supported on this platform */
   if (!g_module_supported())
     g_error( _("Dynamic module loading is not supported. gcompris cannot load.\n") );
 
@@ -186,7 +185,7 @@ void init_plugins(void)
 }
 #endif
 
-BoardPlugin *get_current_board_plugin(void)
+BoardPlugin *gc_board_get_current_board_plugin(void)
 {
   if(bp_data->current_gcompris_board)
     return bp_data->current_gcompris_board->plugin;
@@ -194,106 +193,112 @@ BoardPlugin *get_current_board_plugin(void)
   return NULL;
 }
 
-GcomprisBoard *get_current_gcompris_board(void)
+GcomprisBoard *gc_board_get_current(void)
 {
   return bp_data->current_gcompris_board;
 }
 
-void set_current_gcompris_board(GcomprisBoard * gcomprisBoard)
+void gc_board_set_current(GcomprisBoard * gcomprisBoard)
 {
   bp_data->current_gcompris_board = gcomprisBoard;
 }
 
 #ifdef WIN32
-gboolean board_check_file(GcomprisBoard *gcomprisBoard)
+gboolean
+gc_board_check_file(GcomprisBoard *gcomprisBoard)
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
   BoardPlugin *bp;
   guint        i=0;
+  guint        key_is_valid = 0;
 
   g_assert(gcomprisBoard!=NULL);
   g_assert(properties->key!=NULL);
 
-  /* Check Already loaded */  
+  /* Check Already loaded */
   if(gcomprisBoard->plugin!=NULL) {
     return TRUE;
   }
 
-  if(strncmp(properties->key, "thanks_for_your_help", 20)==0) {
-    while(static_boards[i++] != NULL) {
-      BoardPlugin *bp;
+  key_is_valid = gc_activation_check(properties->key);
 
-      /* Get the BoardPlugin Info */
-      bp = (BoardPlugin *) static_boards[i-1];
+  i = 0;
+  if(key_is_valid == 1)
+    {
+      while(static_boards[i++] != NULL) {
 
-      if(bp->is_our_board(gcomprisBoard)) {
-	/* Great, we found our plugin */
-	g_warning("We found the correct plugin for board %s (type=%s)\n", 
-		  gcomprisBoard->name, gcomprisBoard->type);
+	/* Get the BoardPlugin Info */
+	bp = (BoardPlugin *) static_boards[i-1];
 
-	gcomprisBoard->plugin = bp;
+	if(bp->is_our_board(gcomprisBoard)) {
+	  /* Great, we found our plugin */
+	  g_warning("We found the correct plugin for board %s (type=%s)\n",
+		    gcomprisBoard->name, gcomprisBoard->type);
 
-	return TRUE;
+	  gcomprisBoard->plugin = bp;
+
+	  return TRUE;
+	}
       }
     }
-  } else {
-    while(static_boards_demo[i++] != NULL) {
-      BoardPlugin *bp;
+  else
+    {
+      while(static_boards_demo[i++] != NULL) {
 
-      /* Get the BoardPlugin Info */
-      bp = (BoardPlugin *) static_boards_demo[i-1];
+	/* Get the BoardPlugin Info */
+	bp = (BoardPlugin *) static_boards_demo[i-1];
 
-      if(bp->is_our_board(gcomprisBoard)) {
-	/* Great, we found our plugin */
-	g_warning("We found the correct plugin for board %s (type=%s)\n", 
+	if(bp->is_our_board(gcomprisBoard)) {
+	  /* Great, we found our plugin */
+	  g_warning("We found the correct plugin for board %s (type=%s)\n",
 		  gcomprisBoard->name, gcomprisBoard->type);
 
-	gcomprisBoard->plugin = bp;
+	  gcomprisBoard->plugin = bp;
 
-	return TRUE;
+	  return TRUE;
+	}
       }
     }
-  }
 
-  g_warning("No plugin library found for board type '%s', requested by '%s'", 
+  g_warning("No plugin library found for board type '%s', requested by '%s'",
 	    gcomprisBoard->type,  gcomprisBoard->filename);
 
   return FALSE;
 }
 #else
-gboolean board_check_file(GcomprisBoard *gcomprisBoard)
+gboolean
+gc_board_check_file(GcomprisBoard *gcomprisBoard)
 {
-  BoardPlugin *bp;
   GModule     *gmodule = NULL;
   gchar       *gmodule_file = NULL;
   BoardPlugin *(*plugin_get_bplugin_info) (void) = NULL;
-  guint        i=0;
+  GcomprisProperties *properties = gc_prop_get();
+  gchar *sep;
+  gchar *type;
 
   g_assert(gcomprisBoard!=NULL);
-  
-  /* Check Already loaded */  
+
+  /* Check Already loaded */
   if(gcomprisBoard->plugin!=NULL) {
     return TRUE;
   }
 
-  while(plugin_paths[i] != NULL && gmodule == NULL) {
-    gchar *sep;
-    gchar *type = g_strdup(gcomprisBoard->type);
+  type = g_strdup(gcomprisBoard->type);
 
-    /* Manage the python case where : is use to separate python plugin and boards */
-    if(sep = strchr(type, ':'))
-      *sep ='\0';
+  /* Manage the python case where : is use to separate python plugin and boards */
+  if((sep = strchr(type, ':')))
+    *sep ='\0';
 
-    gmodule_file = g_module_build_path (plugin_paths[i++], type);
+  gmodule_file = g_module_build_path (properties->package_plugin_dir, type);
 
-    gmodule = g_module_open (gmodule_file, 0);
-    if(gmodule) {
-      g_warning("opened module %s with name %s\n",gmodule_file , type);
-    } else {
-      g_warning("Failed to open module %s with name %s (error=%s)\n",gmodule_file , type, g_module_error());
-    }
-    g_free(type);
+  gmodule = g_module_open (gmodule_file, 0);
+  if(gmodule) {
+    g_warning("opened module %s with name %s\n", gmodule_file, type);
+  } else {
+    g_warning("Failed to open module %s with name %s (error=%s)\n", gmodule_file,
+	      type, g_module_error());
   }
+  g_free(type);
 
   if(gmodule != NULL) {
 
@@ -323,39 +328,39 @@ gboolean board_check_file(GcomprisBoard *gcomprisBoard)
 
 	return TRUE;
       } else {
-	g_warning("We found a plugin with the name %s but is_our_board() returned FALSE (type=%s)\n", 
+	g_warning("We found a plugin with the name %s but is_our_board() returned FALSE (type=%s)\n",
 		  gcomprisBoard->name,
 		  gcomprisBoard->type);
       }
     } else {
-      g_warning("plugin_get_bplugin_info entry point not found for %s\n", 
+      g_warning("plugin_get_bplugin_info entry point not found for %s\n",
 		gcomprisBoard->filename);
     }
   }
-  g_warning("No plugin library found for board type '%s', requested by '%s'", 
+  g_warning("No plugin library found for board type '%s', requested by '%s'",
 	    gcomprisBoard->type,  gcomprisBoard->filename);
 
   return FALSE;
 }
 #endif
 
-void board_play(GcomprisBoard *gcomprisBoard)
+void
+gc_board_play(GcomprisBoard *gcomprisBoard)
 {
   BoardPlugin *bp;
-  GModule     *gmodule = NULL;
 
   g_assert(gcomprisBoard!=NULL);
 
-  board_check_file(gcomprisBoard);
+  gc_board_check_file(gcomprisBoard);
 
   if(gcomprisBoard->plugin!=NULL)
     {
       /* Log the board start */
-      gcompris_log_start(gcomprisBoard);
+      gc_log_start(gcomprisBoard);
 
       bp = gcomprisBoard->plugin;
-      set_current_gcompris_board(gcomprisBoard);
-      
+      gc_board_set_current(gcomprisBoard);
+
       bp->start_board(gcomprisBoard);
       bp_data->playing = TRUE;
 
@@ -367,51 +372,39 @@ void board_play(GcomprisBoard *gcomprisBoard)
   bp_data->playing = TRUE;
 }
 
-void board_pause(void)
+void
+gc_board_pause(int pause)
 {
-  if (get_board_playing() && get_current_board_plugin())
+  if (get_board_playing() && gc_board_get_current_board_plugin())
     {
-      bp_data->paused = !bp_data->paused;
-      get_current_board_plugin()->pause_board(bp_data->paused);
+      if(gc_board_get_current_board_plugin()->pause_board)
+	gc_board_get_current_board_plugin()->pause_board(pause);
     }
 }
 
-void board_stop(void)
+void
+gc_board_stop(void)
 {
-
-  /* If we are in the upper menu, no need to stop and restart it */
-  if (get_current_gcompris_board()->previous_board == NULL){
-    return;
-  }
-
-  if (bp_data->playing && get_current_board_plugin())
+  if (bp_data->playing && gc_board_get_current_board_plugin())
     {
       bp_data->playing = FALSE;
-      
-      if (bp_data->paused)
-	board_pause();
-      if (get_current_board_plugin()->end_board)
-	get_current_board_plugin()->end_board();
 
-      bp_data->paused = FALSE;
-      
-      gcompris_end_board();
-      
+      if (gc_board_get_current_board_plugin()->end_board)
+	gc_board_get_current_board_plugin()->end_board();
+
+      gc_board_end();
+
       return;
     }
   bp_data->playing = FALSE;
 }
 
-gboolean get_board_playing(void)
+static gboolean
+get_board_playing(void)
 {
   return bp_data->playing;
 }
 
-gboolean get_board_paused(void)
-{
-  return bp_data->paused;
-}
-
 static GcomprisBoard *next_board = NULL;
 static gint next_board_callback_id = 0;
 #define NEXT_TIME_DELAY 10
@@ -421,35 +414,26 @@ void board_run_next_end()
   gtk_timeout_remove(next_board_callback_id);
   next_board_callback_id = 0;
 
-  if (next_board && 
+  if (next_board &&
       next_board->previous_board &&
       next_board->previous_board->plugin->end_board)
     next_board->previous_board->plugin->end_board();
 
   /* reset the im context */
-  gcompris_im_reset();
+  gc_im_reset();
 
   /*run the board */
-  board_play(next_board);
+  gc_board_play(next_board);
 }
 
-void board_run_next(GcomprisBoard *board)
+void gc_board_run_next(GcomprisBoard *board)
 {
-  board->previous_board = get_current_gcompris_board();
+  board->previous_board = gc_board_get_current();
 
   next_board = board;
 
   next_board_callback_id = gtk_timeout_add (NEXT_TIME_DELAY,
 					    (GtkFunction) board_run_next_end,
 					    NULL);
-	
-}
 
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
+}
