@@ -46,24 +46,17 @@ struct BoardPluginData
 {
   GcomprisBoard	*current_gcompris_board;
   gboolean	 playing;
-  gboolean	 paused;
 };
 
-void		 init_plugins(void);
-BoardPlugin	*get_current_board_plugin(void);
-void		 set_current_board_plugin(BoardPlugin * ip);
-GcomprisBoard	*get_current_gcompris_board(void);
-void		 set_current_gcompris_board(GcomprisBoard * gcomprisBoard);
-gboolean	 board_check_file(GcomprisBoard *gcomprisBoard);
-void		 board_play(GcomprisBoard *gcomprisBoard);
-void		 board_stop(void);
-void		 board_pause(void);
-gboolean	 get_board_playing(void);
-gboolean	 get_board_paused(void);
-gchar		*board_get_info_text(void);
+void		 gc_board_init(void);
+BoardPlugin	*gc_board_get_current_board_plugin(void);
+GcomprisBoard	*gc_board_get_current(void);
+void		 gc_board_set_current(GcomprisBoard * gcomprisBoard);
+gboolean	 gc_board_check_file(GcomprisBoard *gcomprisBoard);
+void		 gc_board_play(GcomprisBoard *gcomprisBoard);
+void		 gc_board_stop(void);
+void		 gc_board_pause(int pause);
 
-void		 board_set_info_text(gchar * text);
-void		 board_file_info_box(gchar * filename);
-void             board_run_next(GcomprisBoard *board);
+void             gc_board_run_next(GcomprisBoard *board);
 
 #endif
