@@ -1,6 +1,6 @@
 /* gcompris - board_config.c
  *
- * Time-stamp: <2006/01/30 08:57:29 yves>
+ * Time-stamp: <2006/08/21 23:27:57 bruno>
  *
  * Copyright (C) 2001 Pascal Georges
  *
@@ -22,22 +22,17 @@
 #include <string.h>
 
 #include "gcompris.h"
-#include "assetml.h"
 
 #define COMBOBOX_COL_MAX 15
 
 static GcomprisBoard *config_board;
 
-void	 board_config_start(GcomprisBoard *aBoard, GcomprisProfile *aProfile)
+void
+gc_board_config_start(GcomprisBoard *aBoard, GcomprisProfile *aProfile)
 {
 
-/*   if (config_board){ */
-/*     g_warning("board_config_start Cannot configure two boards at same time !\n Call config_end on previous board before !"); */
-/*     return; */
-/*   } */
-
   if (aBoard->plugin == NULL){
-    g_warning("board_config_start: board %s/%s is not initialised ? Hummmm...", aBoard->section,aBoard->name);
+    g_warning("gc_board_config_start: board %s/%s is not initialised ? Hummmm...", aBoard->section,aBoard->name);
     return;
   }
 
@@ -54,7 +49,8 @@ void	 board_config_start(GcomprisBoard *aBoard, GcomprisProfile *aProfile)
 
 
   
-void	 board_config_stop()
+void
+gc_board_config_stop()
 {
   if (!config_board)
     return;
@@ -72,7 +68,8 @@ static GcomprisConfCallback Confcallback = NULL;
 static gchar *label_markup = NULL;
 
 
-static void check_key(gchar *key)
+static void
+check_key(gchar *key)
 {
   if ((strcmp(key, "locale") == 0) ||
       (strcmp(key, "locale_sound") == 0) ||
@@ -80,10 +77,11 @@ static void check_key(gchar *key)
     g_error(" Key %s forbiden ! Change !", key);
 }
 
-void gcompris_close_board_conf (GtkDialog *dialog,
-				gpointer   user_data)
+void
+gc_board_conf_close (GtkDialog *dialog,
+		     gpointer   user_data)
 {
-  gtk_object_destroy              (GTK_OBJECT(dialog));
+  gtk_object_destroy(GTK_OBJECT(dialog));
   g_hash_table_destroy (hash_conf);
   hash_conf = NULL;
 
@@ -96,9 +94,10 @@ void gcompris_close_board_conf (GtkDialog *dialog,
   g_free(label_markup);
 }
 
-void gcompris_response_board_conf (GtkButton *button,
-				   gint arg1,
-				   gpointer user_data)
+void
+_response_board_conf (GtkButton *button,
+		      gint arg1,
+		      gpointer user_data)
 {
 
   if (Confcallback){
@@ -121,46 +120,100 @@ void gcompris_response_board_conf (GtkButton *button,
     Confcallback = NULL;
   }
 
-  gcompris_close_board_conf (GTK_DIALOG(conf_window), NULL);
+  gc_board_conf_close (GTK_DIALOG(conf_window), NULL);
 
 }
 
-GtkVBox *gcompris_configuration_window(gchar *label, GcomprisConfCallback callback)
+#ifdef XF86_VIDMODE
+static GdkEventConfigure last_configure_event;
+
+static gint
+_conf_window_configured(GtkWindow *window,
+			GdkEventConfigure *event, gpointer param)
+{
+  gint new_x, new_y;
+  double screen_width, screen_height;
+  /* Because we call gtk_window_move, we cause a configure event. Filter out
+     identical events to avoid looping. */
+  if (memcmp(&last_configure_event, event, sizeof(GdkEventConfigure)))
+  {
+    gnome_canvas_get_scroll_region( GNOME_CANVAS( gtk_bin_get_child( GTK_BIN(
+      gc_get_window()))), NULL, NULL, &screen_width, &screen_height);
+    /* strange but gcompris.c sets the scrollheight to screen_height + 30 */
+    screen_height -= 30;
+    new_x = ((gint)screen_width - event->width) / 2;
+    new_y = ((gint)screen_height - event->height) / 2;
+    /* printf("screen %dx%d, window %dx%d, place %dx%d\n", (int)screen_width, (int)screen_height, event->width, event->height, new_x, new_y); */
+    gtk_window_move (conf_window, new_x, new_y);
+    memcpy(&last_configure_event, event, sizeof(GdkEventConfigure));
+  }
+
+  /* Act as if we aren't there / aren't hooked up */
+  return FALSE;
+}
+#endif
+
+GtkVBox *
+gc_board_config_window_display(gchar *label, GcomprisConfCallback callback)
 {
   GtkWidget *header;
  
   /* init static values or callbacks */
   Confcallback = callback;
   hash_conf = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
+  
+  /* Creating a config window will cause our main window to loose focus,
+     this tells the main window to ignore the next focus out event (and thus
+     stay in fullscreen mode if we're fullscreen). */
+  gc_ignore_next_focus_out();
 
   /* main configuration window */
-  conf_window = GTK_WINDOW(gtk_dialog_new_with_buttons ("GCompris",
-							GTK_WINDOW(gtk_widget_get_toplevel (GTK_WIDGET(get_current_gcompris_board()->canvas))),
-							GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-							GTK_STOCK_CANCEL,
-							GTK_RESPONSE_CANCEL,
-							GTK_STOCK_APPLY,
-							GTK_RESPONSE_APPLY,
-                                         NULL));
+  conf_window = \
+    GTK_WINDOW(gtk_dialog_new_with_buttons ("GCompris",
+					    GTK_WINDOW(gtk_widget_get_toplevel (GTK_WIDGET(gc_board_get_current()->canvas))),
+					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					    GTK_STOCK_CANCEL,
+					    GTK_RESPONSE_CANCEL,
+					    GTK_STOCK_APPLY,
+					    GTK_RESPONSE_APPLY,
+					    NULL));
   
 
   /* parameters */
-  gtk_window_set_position         (conf_window,
+#ifdef XF86_VIDMODE
+  if (gc_prop_get()->fullscreen &&
+      !gc_prop_get()->noxf86vm)   
+    {
+      memset(&last_configure_event, 0, sizeof(GdkEventConfigure));
+      gtk_widget_add_events(GTK_WIDGET(conf_window), GDK_STRUCTURE_MASK);
+      gtk_signal_connect (GTK_OBJECT (conf_window), "configure_event",
+        GTK_SIGNAL_FUNC (_conf_window_configured), 0);
+    }
+  else
+#endif
+      gtk_window_set_position (conf_window,
 				   GTK_WIN_POS_CENTER_ALWAYS);
 
   gtk_widget_show(GTK_WIDGET(conf_window));
 
+  GcomprisProperties *properties = gc_prop_get();
+  if (properties->fullscreen && !properties->noxf86vm)
+    if (gdk_pointer_grab(gc_get_window()->window, TRUE, 0,
+			 gc_get_window()->window, NULL, GDK_CURRENT_TIME) !=
+	GDK_GRAB_SUCCESS)
+      g_warning("Pointer grab failed");
+
   /* main vbox in window */
   main_conf_box = GTK_VBOX(GTK_DIALOG(conf_window)->vbox);
 
   g_signal_connect(G_OBJECT(conf_window), 
 		   "response",
-		   G_CALLBACK(gcompris_response_board_conf),
+		   G_CALLBACK(_response_board_conf),
 		   NULL);
 
   g_signal_connect (G_OBJECT(conf_window),
 		    "close",
-		    G_CALLBACK(gcompris_close_board_conf),
+		    G_CALLBACK(gc_board_conf_close),
 		    NULL);
 
   
@@ -181,13 +234,14 @@ GtkVBox *gcompris_configuration_window(gchar *label, GcomprisConfCallback callba
   gtk_label_set_markup (GTK_LABEL(header),
                         (const gchar *)label_markup);
 
-  gcompris_separator();
+  gc_board_conf_separator();
   
   return main_conf_box;
 }
 
-void gcompris_boolean_box_toggled (GtkToggleButton *togglebutton,
-				   gpointer key)
+void 
+gc_board_conf_boolean_box_toggled (GtkToggleButton *togglebutton,
+			      gpointer key)
 {
   gchar *the_key = g_strdup((gchar *)key);
   gchar *value;
@@ -200,7 +254,8 @@ void gcompris_boolean_box_toggled (GtkToggleButton *togglebutton,
   g_hash_table_replace(hash_conf, (gpointer) the_key, (gpointer) value);
 }
 
-GtkCheckButton *gcompris_boolean_box(const gchar *label, gchar *key, gboolean initial_value)
+GtkCheckButton *
+gc_board_config_boolean_box(const gchar *label, gchar *key, gboolean initial_value)
 {
   check_key( key);
 
@@ -219,7 +274,7 @@ GtkCheckButton *gcompris_boolean_box(const gchar *label, gchar *key, gboolean in
 
   g_signal_connect   (G_OBJECT(CheckBox),
 		      "toggled",
-		      G_CALLBACK(gcompris_boolean_box_toggled),
+		      G_CALLBACK(gc_board_conf_boolean_box_toggled),
 		      key);
 
   return GTK_CHECK_BUTTON(CheckBox);
@@ -229,7 +284,7 @@ GtkCheckButton *gcompris_boolean_box(const gchar *label, gchar *key, gboolean in
 /* included here to not depend on gtk 2.6 */
 
 static gchar *
-gcompris_get_active_text (GtkComboBox *combo_box)
+_get_active_text (GtkComboBox *combo_box)
 {
   GtkTreeIter iter;
   gchar *text = NULL;
@@ -243,20 +298,21 @@ gcompris_get_active_text (GtkComboBox *combo_box)
   return text;
 }
 
-void gcompris_combo_box_changed(GtkComboBox *combobox,
-				gpointer key)
+static void
+_combo_box_changed(GtkComboBox *combobox,
+		   gpointer key)
 {
   gchar *the_key = g_strdup((gchar *)key);
 
-  gchar *value = g_strdup_printf("%s", gcompris_get_active_text (combobox));
+  gchar *value = g_strdup_printf("%s", _get_active_text (combobox));
   
   g_hash_table_replace(hash_conf, (gpointer) the_key, (gpointer) value);
 }
 
-inline int my_strcmp(gchar *a, gchar *b) { return strcmp( a, b); }
+static inline int my_strcmp(gchar *a, gchar *b) { return strcmp( a, b); }
 
 
-GtkComboBox *gcompris_combo_box(const gchar *label, GList *strings, gchar *key, gchar *init)
+GtkComboBox *gc_board_config_combo_box(const gchar *label, GList *strings, gchar *key, gchar *init)
 {
   check_key( key);
 
@@ -320,7 +376,7 @@ GtkComboBox *gcompris_combo_box(const gchar *label, GList *strings, gchar *key,
   
   g_signal_connect(G_OBJECT(combobox),
 		   "changed",
-		   G_CALLBACK(gcompris_combo_box_changed),
+		   G_CALLBACK(_combo_box_changed),
 		   key);
 
   return GTK_COMBO_BOX(combobox);
@@ -332,8 +388,8 @@ static gchar *radio_key = NULL;
 static gchar *radio_text = NULL;
 static gchar *radio_init = NULL;
 
-void radio_changed(GtkToggleButton *togglebutton,
-		   gpointer key)
+static void radio_changed(GtkToggleButton *togglebutton,
+			  gpointer key)
 {
   gboolean state = gtk_toggle_button_get_active (togglebutton);
   gchar *h_key;
@@ -346,9 +402,10 @@ void radio_changed(GtkToggleButton *togglebutton,
   }
 }
 
-void create_radio_buttons(gpointer key,
-			  gpointer value,
-			  gpointer hash_radio)
+static void
+create_radio_buttons(gpointer key,
+		     gpointer value,
+		     gpointer hash_radio)
 {
   GtkWidget *radio_button;
   gchar *key_copy;
@@ -375,8 +432,9 @@ void create_radio_buttons(gpointer key,
   g_hash_table_replace ( hash_radio, (gpointer) key_copy, (gpointer) radio_button);
 }
 
-void destroy_hash (GtkObject *object,
-                   gpointer hash_table)
+static void
+destroy_hash (GtkObject *object,
+	      gpointer hash_table)
 {
   g_hash_table_destroy((GHashTable *)hash_table);
   radio_group = NULL;
@@ -385,10 +443,11 @@ void destroy_hash (GtkObject *object,
   g_free(radio_init);
 }
 
-GHashTable *gcompris_radio_buttons(const gchar *label,
-				   gchar *key,
-				   GHashTable *buttons_label,
-				   gchar *init)
+GHashTable *
+gc_board_config_radio_buttons(const gchar *label,
+		       gchar *key,
+		       GHashTable *buttons_label,
+		       gchar *init)
 {
   check_key( key);
 
@@ -436,8 +495,9 @@ GHashTable *gcompris_radio_buttons(const gchar *label,
   return buttons;
 }
 
-void spin_changed (GtkSpinButton *spinbutton,
-		    gpointer key)
+static void
+spin_changed (GtkSpinButton *spinbutton,
+	      gpointer key)
 {
   gchar *h_key = g_strdup((gchar *) key);
   gchar *h_value = g_strdup_printf("%d",gtk_spin_button_get_value_as_int (spinbutton));
@@ -445,7 +505,8 @@ void spin_changed (GtkSpinButton *spinbutton,
   g_hash_table_replace (hash_conf, h_key, h_value);
 }
 
-GtkSpinButton *gcompris_spin_int(const gchar *label, gchar *key, gint min, gint max, gint step, gint init)
+GtkSpinButton *
+gc_board_config_spin_int(const gchar *label, gchar *key, gint min, gint max, gint step, gint init)
 {
   check_key( key);
 
@@ -501,7 +562,8 @@ GtkSpinButton *gcompris_spin_int(const gchar *label, gchar *key, gint min, gint
 
 }
 
-GtkHSeparator *gcompris_separator()
+GtkHSeparator *
+gc_board_conf_separator()
 {
   GtkWidget *separator = gtk_hseparator_new ();
 
@@ -521,30 +583,44 @@ GtkHSeparator *gcompris_separator()
 /* L10n                                        */
 /***********************************************/
 
-GList *gcompris_get_locales_list(){
-  gchar *textdomain;
-  GDir *textdomain_dir;
+/** \brief return the list of locales in which GCompris has been translated
+ *         even partialy.
+ *
+ * \note The list is calculated at the first call and must not be freed.
+ *       Uppon next call, the same list is returned.
+ *
+ * \return a list containing the locales we suport
+ */
+GList*
+gc_locale_gets_list(){
+
+  static GList *gcompris_locales_list = NULL;
+
+  GcomprisProperties *properties = gc_prop_get();
+  GDir   *textdomain_dir;
   GError **error = NULL;
+  GList  *locales = NULL;
 
-  //textdomain = bindtextdomain ("gcompris", NULL);
-  textdomain = PACKAGE_LOCALE_DIR;
-  
-  GList *locales = NULL;
+  if(gcompris_locales_list)
+    return(gcompris_locales_list);
 
-  textdomain_dir = g_dir_open (textdomain, 0, error);
+  /* There is no english locale but it exists anyway */
+  locales = g_list_append(locales, g_strdup("en"));
+
+  textdomain_dir = g_dir_open (properties->package_locale_dir, 0, error);
   const gchar *fname;
   gchar *fname_abs;
   gchar *catalog;
   
-  while (fname = g_dir_read_name(textdomain_dir)) {
-    fname_abs = g_strdup_printf("%s/%s",textdomain, fname);
+  while ((fname = g_dir_read_name(textdomain_dir))) {
+    fname_abs = g_strdup_printf("%s/%s", properties->package_locale_dir, fname);
     if (!g_file_test(fname_abs, G_FILE_TEST_IS_DIR))
       continue;
 
     catalog = g_strdup_printf("%s/LC_MESSAGES/gcompris.mo", fname_abs);
 
     if (g_file_test(catalog, G_FILE_TEST_EXISTS)){
-      locales = g_list_append( locales, g_strdup(fname));
+      locales = g_list_append(locales, g_strdup(fname));
     }
     g_free (fname_abs);
     g_free(catalog);
@@ -552,12 +628,16 @@ GList *gcompris_get_locales_list(){
 
   g_dir_close (textdomain_dir);
 
+  /* Save it for next call */
+  gcompris_locales_list = locales;
+
   return locales;
 }
 
 
-void gcompris_combo_locales_changed(GtkComboBox *combobox,
-			    gpointer key)
+void 
+gc_board_config_combo_locales_changed(GtkComboBox *combobox,
+			       gpointer key)
 {
   gchar *the_key = g_strdup((gchar *)key);
   gchar *value;
@@ -567,13 +647,14 @@ void gcompris_combo_locales_changed(GtkComboBox *combobox,
     /* Default value of gcompris selected */
     value = g_strdup ("NULL");
   else
-    value = gcompris_get_active_text (combobox);
+    value = _get_active_text (combobox);
 
   g_hash_table_replace(hash_conf, (gpointer) the_key, (gpointer) value);
 }
 
 /* key = "locale" */
-GtkComboBox *gcompris_combo_locales(gchar *init)
+GtkComboBox*
+gc_board_config_combo_locales(gchar *init)
 {
 
   GtkWidget *combobox;
@@ -582,13 +663,15 @@ GtkComboBox *gcompris_combo_locales(gchar *init)
   GtkWidget *label_combo;
   gint init_index = 0;
 
-  strings = gcompris_get_locales_list();
+  strings = gc_locale_gets_list();
 
   strings = g_list_prepend( strings, _("Default"));
 
-  if (init){
-    init_index =  g_list_position ( strings, g_list_find_custom ( strings,(gconstpointer)  init, (GCompareFunc) my_strcmp));
-  }
+  if (init)
+    init_index = g_list_position(strings,
+				 g_list_find_custom(strings,
+						    (gconstpointer) init,
+						    (GCompareFunc) my_strcmp));
 
   if (init_index < 0)
     init_index=0;
@@ -640,7 +723,7 @@ GtkComboBox *gcompris_combo_locales(gchar *init)
   
   g_signal_connect(G_OBJECT(combobox),
 		   "changed",
-		   G_CALLBACK(gcompris_combo_locales_changed),
+		   G_CALLBACK(gc_board_config_combo_locales_changed),
 		   "locale");
 
   return GTK_COMBO_BOX(combobox);
@@ -648,62 +731,94 @@ GtkComboBox *gcompris_combo_locales(gchar *init)
 }
 
 static gchar *current_locale = NULL;
-void gcompris_change_locale(gchar *locale)
+void
+gc_locale_change(gchar *locale)
 {
   if (!locale)
     return;
 
   if (strcmp(locale, "NULL") == 0){
-    gcompris_reset_locale();
+    gc_locale_reset();
     return;
   }
 
-  current_locale = g_strdup(gcompris_get_locale());
+  current_locale = g_strdup(gc_locale_get());
 
-  gcompris_set_locale(locale);
+  gc_locale_set(locale);
 }
 
-void gcompris_reset_locale(){
+void
+gc_locale_reset()
+{
   if (current_locale == NULL)
     return;
 
-  gcompris_set_locale(current_locale);
+  gc_locale_change(current_locale);
 
   g_free(current_locale);
   current_locale = NULL;
 }
 
 
-GList *gcompris_get_locales_asset_list(gchar *dataset, gchar* categories, 
-				       gchar* mimetype, gchar* file){
+/** \brief Search the given file for each locale and returns the locale list
+ *
+ * \param file: the file to search. In order to work, you need to provide a
+ *              filename that includes a $LOCALE in it like:
+ *              sounds/$LOCALE/colors/blue.ogg
+ *
+ * \return a list of locale
+ */
+GList*
+gc_locale_gets_asset_list(const gchar *filename)
+{
   GList *locales, *list, *locales_asset = NULL;
+  gchar *abs_filename;
 
-  GList *gl_result;
-  AssetML *assetml;
+  locales = gc_locale_gets_list();
 
-  locales = gcompris_get_locales_list();
+  for (list = locales; list != NULL; list = list->next)
+    { 
+      gchar **tmp;
 
-  for (list = locales; list != NULL; list = list->next){ 
-    gl_result = assetml_get_asset(dataset, categories, mimetype, list->data, file);
+      /* Check there is a $LOCALE to replace */
+      if((tmp = g_strsplit(filename, "$LOCALE", -1)))
+	{
+	  gchar locale[6];
+	  gchar *filename2;
 
-    if(gl_result && g_list_length(gl_result)>0)
-      {
+	  /* try with the locale */
+	  g_strlcpy(locale, list->data, sizeof(locale));
+	  filename2 = g_strjoinv(locale, tmp);
+	  g_warning("trying locale file '%s'\n", filename2);
+	  abs_filename = gc_file_find_absolute(filename2);
+	  g_free(filename2);
 
-	/* Always get the first item */
-	assetml = (AssetML *)g_list_nth_data(gl_result, 0);
+	  g_strfreev(tmp);
+	}
+      else
+	{
+	  abs_filename = gc_file_find_absolute(filename);
+	}
 
-	if(assetml->file)
-	  locales_asset = g_list_append ( locales_asset, list->data);
+      if(abs_filename)
+	/* It would be cleaner to provide the real locale name but then we need a way
+	 * to get back the locale code from it's name and from the boards
+	 *
+	 * locales_asset = g_list_append(locales_asset, gc_locale_get_name(list->data));
+	 *
+	 */
+	locales_asset = g_list_append(locales_asset, list->data);
 
-	assetml_free_assetlist(gl_result);
-      }
-  }
+    }
   
+
   return locales_asset;
 }
 
 /* key = "locale_sound" */
-GtkComboBox *gcompris_combo_locales_asset(const gchar *label, gchar *init, gchar *dataset, gchar* categories, gchar* mimetype, gchar *file)
+GtkComboBox *gc_board_config_combo_locales_asset(const gchar *label,
+					  gchar *init,
+					  const gchar *file)
 {
 
   GtkWidget *combobox;
@@ -712,13 +827,17 @@ GtkComboBox *gcompris_combo_locales_asset(const gchar *label, gchar *init, gchar
   GtkWidget *label_combo;
   gint init_index = 0;
 
-  strings = gcompris_get_locales_asset_list(dataset, categories, mimetype, file);
+  strings = gc_locale_gets_asset_list(file);
 
   strings = g_list_prepend( strings, _("Default"));
 
-  if (init){
-    init_index =  g_list_position ( strings, g_list_find_custom ( strings,(gconstpointer)  init, (GCompareFunc) my_strcmp));
-  }
+  if (init)
+    {
+      init_index =  g_list_position(strings,
+				    g_list_find_custom(strings,
+						       (gconstpointer)init,
+						       (GCompareFunc) my_strcmp));
+    }
 
   if (init_index < 0)
     init_index=0;
@@ -758,19 +877,19 @@ GtkComboBox *gcompris_combo_locales_asset(const gchar *label, gchar *init, gchar
 
 
   for (list = strings; list != NULL; list = list->next)
-    gtk_combo_box_append_text       (GTK_COMBO_BOX(combobox),
-				     list->data);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(combobox),
+			      list->data);
 
   if (g_list_length(strings) > COMBOBOX_COL_MAX)
-    gtk_combo_box_set_wrap_width    (GTK_COMBO_BOX(combobox),
-  	     g_list_length(strings) / COMBOBOX_COL_MAX +1 );
+    gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(combobox),
+				 g_list_length(strings) / COMBOBOX_COL_MAX +1 );
   
   gtk_combo_box_set_active (GTK_COMBO_BOX(combobox),
 			    init_index);
   
   g_signal_connect(G_OBJECT(combobox),
 		   "changed",
-		   G_CALLBACK(gcompris_combo_locales_changed),
+		   G_CALLBACK(gc_board_config_combo_locales_changed),
 		   "locale_sound");
 
   return GTK_COMBO_BOX(combobox);
@@ -787,8 +906,10 @@ typedef struct {
   GtkTextBuffer *TextBuffer;
 } user_param_type;
 
-void *gcompris_textview_destroy (GtkButton *button,
-				gpointer user_data){
+static void *
+_textview_destroy (GtkButton *button,
+		   gpointer user_data)
+{
   g_free(((user_param_type *)user_data)->key);
   g_free(user_data);
 
@@ -796,17 +917,20 @@ void *gcompris_textview_destroy (GtkButton *button,
 }
 
 
-void *gcompris_textbuffer_changed (GtkTextBuffer *buffer,
-				gpointer user_data){
-
+static void *
+_textbuffer_changed (GtkTextBuffer *buffer,
+		     gpointer user_data)
+{
   gtk_widget_set_sensitive        (GTK_WIDGET(user_data),
 				   TRUE);
 
   return NULL;
 }
 
-void *gcompris_textview_yes (GtkButton *button,
-			      gpointer user_data){
+static void *
+_textview_yes (GtkButton *button,
+	       gpointer user_data)
+{
 
   user_param_type *params= (user_param_type *) user_data;
 
@@ -849,13 +973,13 @@ void *gcompris_textview_yes (GtkButton *button,
   return NULL;
 }
 
-GtkTextView *gcompris_textview(const gchar *label, 
-			       gchar *key,
-			       const gchar*description, 
-			       gchar *init_text, 
-			       GcomprisTextCallback validate){
-
-
+GtkTextView *
+gc_board_config_textview(const gchar *label, 
+		  gchar *key,
+		  const gchar*description, 
+		  gchar *init_text, 
+		  GcomprisTextCallback validate)
+{
   GtkWidget*frame =  gtk_frame_new ("GCompris text tool");
   gtk_widget_show(frame);
 
@@ -1008,18 +1132,18 @@ GtkTextView *gcompris_textview(const gchar *label,
 
   g_signal_connect(G_OBJECT(button), 
 		   "clicked",
-		   G_CALLBACK(gcompris_textview_yes),
+		   G_CALLBACK(_textview_yes),
 		   (gpointer) user_param);
 
 
   g_signal_connect(G_OBJECT(button), 
 		   "destroy",
-		   G_CALLBACK(gcompris_textview_destroy),
+		   G_CALLBACK(_textview_destroy),
 		   (gpointer) user_param);
 
   g_signal_connect(G_OBJECT(user_param->TextBuffer), 
 		   "changed",
-		   G_CALLBACK(gcompris_textbuffer_changed),
+		   G_CALLBACK(_textbuffer_changed),
 		   (gpointer) button);
 
   gtk_widget_set_sensitive (button,
@@ -1027,12 +1151,3 @@ GtkTextView *gcompris_textview(const gchar *label,
 
   return GTK_TEXT_VIEW(textView);
 }
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
