@@ -19,7 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "bonus.h"
+#include "gcompris.h"
+#include "gc_core.h"
+
+#include <ctype.h>
+#include <math.h>
 
 #define SOUNDLISTFILE PACKAGE
 #define BONUS_DURATION 2000
@@ -30,10 +34,10 @@ static GnomeCanvasItem  *door1_item    = NULL;
 static GnomeCanvasItem  *door2_item    = NULL;
 static GnomeCanvasItem  *tuxplane_item = NULL;
 
-static gboolean board_finished_running = FALSE;
+static gboolean gc_bonus_end_display_running = FALSE;
 static gboolean bonus_display_running = FALSE;
 
-static gint end_bonus_id = 0, board_finished_id = 0;
+static gint end_bonus_id = 0, gc_bonus_end_display_id = 0;
 
 //static gint end_board_count = 0;
 static int left_door_limit = 0;
@@ -41,27 +45,35 @@ static int left_door_limit = 0;
 // List of sounds to use for greetings
 static gchar *greetingsList[] =
 {
-  "congratulation.ogg",
-  "great.ogg",
-  "good.ogg",
-  "awesome.ogg",
-  "fantastic.ogg",
-  "waytogo.ogg",
-  "super.ogg",
-  "perfect.ogg"
+  "sounds/$LOCALE/misc/congratulation.ogg",
+  "sounds/$LOCALE/misc/great.ogg",
+  "sounds/$LOCALE/misc/good.ogg",
+  "sounds/$LOCALE/misc/awesome.ogg",
+  "sounds/$LOCALE/misc/fantastic.ogg",
+  "sounds/$LOCALE/misc/waytogo.ogg",
+  "sounds/$LOCALE/misc/super.ogg",
+  "sounds/$LOCALE/misc/perfect.ogg"
 };
-#define NUMBER_OF_GREETINGS 8
+#define NUMBER_OF_GREETINGS G_N_ELEMENTS(greetingsList)
+
+// List of sounds to use for loosing
+static gchar *loosingList[] =
+{
+  "sounds/$LOCALE/misc/check_answer.ogg",
+};
+#define NUMBER_OF_LOOSING 1
 
 /*
  * Function definition
  * -------------------
  */
-void	 bonus_image(char *,BonusStatusList);
-void	 end_bonus(void);
+static void	 bonus_image(char *,BonusStatusList);
+static void	 end_bonus(void);
 
 
 /* ==================================== */
-void end_board_finished() {
+static void
+end_gc_bonus_end_display() {
   double dx1, dy1, dx2, dy2;
   //end_board_count++;
   gnome_canvas_item_get_bounds(tuxplane_item,  &dx1, &dy1, &dx2, &dy2);
@@ -71,9 +83,9 @@ void end_board_finished() {
     return;
   }
 
-  if (board_finished_id) {
-    gtk_timeout_remove(board_finished_id);
-    board_finished_id = 0;
+  if (gc_bonus_end_display_id) {
+    gtk_timeout_remove(gc_bonus_end_display_id);
+    gc_bonus_end_display_id = 0;
   }
 
   if(door1_item)
@@ -87,41 +99,43 @@ void end_board_finished() {
   door2_item = NULL;
   tuxplane_item = NULL;
 
-  board_finished_running = FALSE;
+  gc_bonus_end_display_running = FALSE;
   
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
 
   // go back to previous board layout
-  if (get_current_board_plugin()->end_board)
-    get_current_board_plugin()->end_board();
-  gcompris_end_board();
+  if (gc_board_get_current_board_plugin()->end_board)
+    gc_board_get_current_board_plugin()->end_board();
+  gc_board_end();
 }
 /* ==================================== */
 #define OFFSET 100
-void board_finished(BoardFinishedList type) {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+void
+gc_bonus_end_display(BoardFinishedList type) {
+  GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
   int x,y;
   GdkPixbuf *pixmap_door1 = NULL,*pixmap_door2 = NULL,*pixmap_tuxplane = NULL;
   char * str = NULL;
 
-  gcompris_bar_hide(TRUE);
+  g_assert(type < BOARD_FINISHED_LAST);
 
-  if (board_finished_running)
+  gc_bar_hide(TRUE);
+
+  if (gc_bonus_end_display_running)
     return;
   else
-    board_finished_running = TRUE;
+    gc_bonus_end_display_running = TRUE;
 
   /* First pause the board */
-  if(gcomprisBoard->plugin->pause_board != NULL)
-      gcomprisBoard->plugin->pause_board(TRUE);
+  gc_board_pause(TRUE);
 
   /* WARNING: I remove 1 to the BOARD_FINISHED_LAST because RANDOM is for GOOD end only */
   if(type==BOARD_FINISHED_RANDOM)
-    type = RAND(1,BOARD_FINISHED_LAST-1);
+    type = RAND(1,BOARD_FINISHED_LAST-2);
 
   /* Record the end of board */
-  gcompris_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_COMPLETED);
+  gc_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_COMPLETED);
 
   switch (type) {
 	case BOARD_FINISHED_TUXPLANE :
@@ -138,9 +152,9 @@ void board_finished(BoardFinishedList type) {
 		break;
   }
 
-  pixmap_door1 = gcompris_load_pixmap("gcompris/misc/door1.png");
-  pixmap_door2 = gcompris_load_pixmap("gcompris/misc/door2.png");
-  pixmap_tuxplane = gcompris_load_pixmap(str);
+  pixmap_door1 = gc_pixmap_load("gcompris/misc/door1.png");
+  pixmap_door2 = gc_pixmap_load("gcompris/misc/door2.png");
+  pixmap_tuxplane = gc_pixmap_load(str);
   g_free(str);
 
   g_assert(gcomprisBoard != NULL);
@@ -190,16 +204,19 @@ void board_finished(BoardFinishedList type) {
   gdk_pixbuf_unref(pixmap_door2);
   gdk_pixbuf_unref(pixmap_tuxplane);
 
-  board_finished_id = gtk_timeout_add (TUX_TIME_STEP, (GtkFunction) end_board_finished, NULL);
+  gc_bonus_end_display_id = gtk_timeout_add (TUX_TIME_STEP, (GtkFunction) end_gc_bonus_end_display, NULL);
 
 }
 
 /* ==================================== */
-void gcompris_display_bonus(BonusStatusList gamewon, BonusList bonus_id)
+void
+gc_bonus_display(BonusStatusList gamewon, BonusList bonus_id)
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+  gchar *absolute_file;
 
-  gcompris_bar_hide(TRUE);
+  g_assert(bonus_id < BONUS_LAST);
+
+  gc_bar_hide(TRUE);
 
   if (bonus_display_running)
     return;
@@ -207,21 +224,33 @@ void gcompris_display_bonus(BonusStatusList gamewon, BonusList bonus_id)
     bonus_display_running = TRUE;
   
   if(gamewon == BOARD_WIN || gamewon == BOARD_DRAW) {
-    gchar *str = gcompris_get_asset_file("gcompris misc", NULL, 
-					 "audio/x-ogg", 
-					 greetingsList[RAND(0, NUMBER_OF_GREETINGS-1)]);
-    gcompris_play_ogg(str, NULL);
-    g_free(str);
+    absolute_file = gc_file_find_absolute(greetingsList[RAND(0, NUMBER_OF_GREETINGS-1)]);
+
+    if (absolute_file)
+      {
+	gc_sound_play_ogg(absolute_file, NULL);
+	g_free(absolute_file);
+      }
+    else
+      gc_sound_play_ogg("sounds/wahoo.ogg", NULL);
+
   } else {
-    gcompris_play_ogg ("crash", NULL);
+    absolute_file = gc_file_find_absolute(loosingList[RAND(0, NUMBER_OF_LOOSING-1)]);
+
+    if (absolute_file)
+      {
+	gc_sound_play_ogg(absolute_file, NULL);
+	g_free(absolute_file);
+      }
+    else
+      gc_sound_play_ogg("sounds/crash.ogg", NULL);
   }
 
   /* First pause the board */
-  if(gcomprisBoard->plugin->pause_board != NULL)
-      gcomprisBoard->plugin->pause_board(TRUE);
+  gc_board_pause(TRUE);
 
   if(bonus_id==BONUS_RANDOM)
-    bonus_id = RAND(1, BONUS_LAST);
+    bonus_id = RAND(1, BONUS_LAST-2);
 
   switch(bonus_id) {
   case BONUS_SMILEY :
@@ -243,12 +272,13 @@ void gcompris_display_bonus(BonusStatusList gamewon, BonusList bonus_id)
 }
 
 /* ==================================== */
-void bonus_image(char *image, BonusStatusList gamewon)
+static void
+bonus_image(char *image, BonusStatusList gamewon)
 {
   char *str= NULL;
   int x,y;
   GdkPixbuf *pixmap = NULL;
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+  GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
   /* check that bonus_group is a singleton */
   if (bonus_group != NULL) {
@@ -261,12 +291,12 @@ void bonus_image(char *image, BonusStatusList gamewon)
   case BOARD_WIN :
     str = g_strdup_printf("%s%s%s", "gcompris/bonus/",image,"_good.png");
     /* Record the end of board */
-    gcompris_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_PASSED);
+    gc_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_PASSED);
     break;
   case BOARD_LOOSE :
     str = g_strdup_printf("%s%s%s", "gcompris/bonus/",image,"_bad.png");
     /* Record the end of board */
-    gcompris_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_FAILED);
+    gc_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_FAILED);
     break;
   case BOARD_DRAW :
     /* We do not have draw image so a text message is displayed bellow under the
@@ -274,16 +304,16 @@ void bonus_image(char *image, BonusStatusList gamewon)
      */
     str = g_strdup_printf("%s%s%s", "gcompris/bonus/",image,"_good.png");
     /* Record the end of board */
-    gcompris_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_DRAW);
+    gc_log_end (gcomprisBoard, GCOMPRIS_LOG_STATUS_DRAW);
     break;
   }
 
   /* Log the board start again*/
-  gcompris_log_start(gcomprisBoard);
+  gc_log_start(gcomprisBoard);
 
   g_assert(gcomprisBoard != NULL);
 
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gc_pixmap_load(str);
 
   bonus_group = (GnomeCanvasGroup *) \
     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -310,7 +340,7 @@ void bonus_image(char *image, BonusStatusList gamewon)
     gnome_canvas_item_new (bonus_group,
 			   gnome_canvas_text_get_type (),
 			   "text", _("Drawn game"),
-			   "font", gcompris_skin_font_title,
+			   "font", gc_skin_font_title,
 			   "x", (double) BOARDWIDTH/2 + 1.0,
 			   "y", (double) gdk_pixbuf_get_height(pixmap) + 1.0,
 			   "anchor", GTK_ANCHOR_CENTER,
@@ -319,11 +349,11 @@ void bonus_image(char *image, BonusStatusList gamewon)
     gnome_canvas_item_new (bonus_group,
 			   gnome_canvas_text_get_type (),
 			   "text", _("Drawn game"),
-			   "font", gcompris_skin_font_title,
+			   "font", gc_skin_font_title,
 			   "x", (double) BOARDWIDTH/2,
 			   "y", (double) gdk_pixbuf_get_height(pixmap),
 			   "anchor", GTK_ANCHOR_CENTER,
-			   "fill_color_rgba", gcompris_skin_color_title,
+			   "fill_color_rgba", gc_skin_color_title,
 			   NULL);
   }
 
@@ -334,10 +364,9 @@ void bonus_image(char *image, BonusStatusList gamewon)
 }
 
 /* ==================================== */
-void end_bonus()
+static void
+end_bonus()
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
-
   if (end_bonus_id) {
     gtk_timeout_remove (end_bonus_id);
     end_bonus_id = 0;
@@ -349,9 +378,8 @@ void end_bonus()
   bonus_group = NULL;
   bonus_display_running = FALSE;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
 
   /* Re-Start the board */
-  if(gcomprisBoard->plugin->pause_board != NULL)
-      gcomprisBoard->plugin->pause_board(FALSE);
+  gc_board_pause(FALSE);
 }
