@@ -1,6 +1,6 @@
 /* gcompris - config.c
  *
- * Time-stamp: <2006/01/09 23:59:33 bruno>
+ * Time-stamp: <2006/08/21 23:28:06 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -26,14 +26,10 @@
 #include <string.h>
 
 #include "gcompris.h"
+#include "gc_core.h"
 #include "gcompris_config.h"
 #include "locale.h"
 
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
-
 static GnomeCanvasItem	*rootitem		= NULL;
 static GnomeCanvasItem	*item_locale_text	= NULL;
 static GnomeCanvasItem	*item_locale_flag	= NULL;
@@ -88,6 +84,7 @@ static gchar *linguas[] = {
   "lt_LT.UTF-8",	N_("Lithuanian"),
   "mk_MK.UTF-8",	N_("Macedonian"),
   "ml_IN.UTF-8",	N_("Malayalam"),
+  "mr_IN.UTF-8",	N_("Marathi"),
   "ms_MY.UTF-8",	N_("Malay"),
   "ne_NP.UTF-8",	N_("Nepal"),
   "nl_NL.UTF-8",	N_("Dutch"),
@@ -101,10 +98,13 @@ static gchar *linguas[] = {
   "rw_RW.UTF-8",	N_("Kinyarwanda"),
   "sk_SK.UTF-8",	N_("Slovak"),
   "sl_SI.UTF-8",	N_("Slovenian"),
+  "so_SO.UTF-8",	N_("Somali"),
   "sq_AL.UTF-8",	N_("Albanian"),
   "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
   "sr_YU.UTF-8",	N_("Serbian"),
   "sv_FI.UTF-8",	N_("Swedish"),
+  /*  "ta_IN.UTF-8",	N_("Tamil"), */
+  "th_TH.UTF-8",	N_("Thai"),
   "tr_TR.UTF-8",	N_("Turkish"),
   "vi_VN.UTF-8",	N_("Vietnamese"),
   "wa_BE.UTF-8",	N_("Walloon"),
@@ -131,21 +131,20 @@ static gchar *filtername[] = {
 };
 
 static void set_locale_flag(gchar *locale);
-static gchar *get_locale_name(gchar *locale);
 static gchar *get_next_locale(gchar *locale);
 static gchar *get_previous_locale(gchar *locale);
 static gint   item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
-static void   display_previous_next(guint x_start, guint y_start, 
+static void   display_previous_next(guint x_start, guint y_start,
 				    gchar *eventname_previous, gchar *eventname_next);
 
 
 /*
  * Do all the bar display and register the events
  */
-void gcompris_config_start ()
+void
+gc_config_start ()
 {
-  GcomprisBoard		*gcomprisBoard = get_current_gcompris_board();
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
   GdkPixbuf   *pixmap = NULL;
   gint y_start = 0;
   gint x_start = 0;
@@ -155,27 +154,26 @@ void gcompris_config_start ()
   GnomeCanvasItem *item, *item2;
 
   /* Pause the board */
-  if(gcomprisBoard->plugin->pause_board != NULL)
-    gcomprisBoard->plugin->pause_board(TRUE);
+  gc_board_pause(TRUE);
 
   if(rootitem)
     return;
 
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
 
   rootitem = \
-    gnome_canvas_item_new (gnome_canvas_root(gcompris_get_canvas()),
+    gnome_canvas_item_new (gnome_canvas_root(gc_get_canvas()),
 			   gnome_canvas_group_get_type (),
 			   "x", (double)0,
 			   "y", (double)0,
 			   NULL);
 
-  pixmap = gcompris_load_skin_pixmap("help_bg.png");
+  pixmap = gc_skin_pixmap_load("help_bg.png");
   y_start = (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   x_start = (BOARDWIDTH - gdk_pixbuf_get_width(pixmap))/2;
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) x_start,
 				"y", (double) y_start,
 				NULL);
@@ -185,67 +183,26 @@ void gcompris_config_start ()
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
 			 "text", _("GCompris Configuration"),
-			 "font", gcompris_skin_font_title,
+			 "font", gc_skin_font_title,
 			 "x", (double) BOARDWIDTH/2 + 1.0,
 			 "y", (double) y_start + 40 + 1.0,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 "weight", PANGO_WEIGHT_HEAVY,
 			 NULL);
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
 			 "text", _("GCompris Configuration"),
-			 "font", gcompris_skin_font_title,
+			 "font", gc_skin_font_title,
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) y_start + 40,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_title,
+			 "fill_color_rgba", gc_skin_color_title,
+			 "weight", PANGO_WEIGHT_HEAVY,
 			 NULL);
 
-  // OK
-  pixmap = gcompris_load_skin_pixmap("button_large.png");
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
-				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
-				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 5,
-				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "ok");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
-
-  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			 gnome_canvas_text_get_type (),
-			 "text", _("OK"),
-			 "font", gcompris_skin_font_title,
-			 "x", (double)  BOARDWIDTH*0.5 + 1.0,
-			 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20 + 1.0,
-			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
-			 NULL);
-  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("OK"),
-				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.5,
-				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_text_button,
-				NULL);
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "ok");
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     item);
-  gdk_pixbuf_unref(pixmap);
-
-
-  pixmap_checked   = gcompris_load_skin_pixmap("button_checked.png");
-  pixmap_unchecked = gcompris_load_skin_pixmap("button_unchecked.png");
+  pixmap_checked   = gc_skin_pixmap_load("button_checked.png");
+  pixmap_unchecked = gc_skin_pixmap_load("button_unchecked.png");
 
 
   x_start += 150;
@@ -260,19 +217,19 @@ void gcompris_config_start ()
 
   item_locale_flag = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					    gnome_canvas_pixbuf_get_type (),
-					    "pixbuf", NULL, 
+					    "pixbuf", NULL,
 					    "x", (double) x_flag_start,
 					    "y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
 					    NULL);
 
   /* Display a bad icon if this locale is not available */
-  pixmap   = gcompris_load_skin_pixmap("mini_bad.png");
+  pixmap   = gc_skin_pixmap_load("mini_bad.png");
   item_bad_flag = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-					    gnome_canvas_pixbuf_get_type (),
-					    "pixbuf", pixmap,
-					    "x", (double) x_flag_start - 20,
-					    "y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
-					    NULL);
+					 gnome_canvas_pixbuf_get_type (),
+					 "pixbuf", pixmap,
+					 "x", (double) x_flag_start - 20,
+					 "y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
+					 NULL);
   gdk_pixbuf_unref(pixmap);
 
   /*
@@ -280,15 +237,15 @@ void gcompris_config_start ()
    */
   current_locale = properties->locale;
   set_locale_flag(current_locale);
- 
+
   item_locale_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					    gnome_canvas_text_get_type (),
-					    "text", get_locale_name(current_locale), 
-					    "font", gcompris_skin_font_subtitle,
+					    "text", gc_locale_get_name(current_locale),
+					    "font", gc_skin_font_subtitle,
 					    "x", (double) x_text_start,
 					    "y", (double) y_start,
 					    "anchor", GTK_ANCHOR_WEST,
-					    "fill_color_rgba", gcompris_skin_color_content,
+					    "fill_color_rgba", gc_skin_color_content,
 					    NULL);
 
   // Fullscreen / Window
@@ -296,7 +253,7 @@ void gcompris_config_start ()
 
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", (properties->fullscreen ? pixmap_checked : pixmap_unchecked), 
+				"pixbuf", (properties->fullscreen ? pixmap_checked : pixmap_unchecked),
 				"x", (double) x_start,
 				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
 				NULL);
@@ -305,18 +262,18 @@ void gcompris_config_start ()
 		     (GtkSignalFunc) item_event_ok,
 		     "fullscreen");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
-			 "text", _("Fullscreen"), 
-			 "font", gcompris_skin_font_subtitle,
+			 "text", _("Fullscreen"),
+			 "font", gc_skin_font_subtitle,
 			 "x", (double) x_text_start,
 			 "y", (double) y_start,
 			 "anchor", GTK_ANCHOR_WEST,
-			 "fill_color_rgba", gcompris_skin_color_content,
+			 "fill_color_rgba", gc_skin_color_content,
 			 NULL);
 
   // Screen size
@@ -326,12 +283,12 @@ void gcompris_config_start ()
 
   item_screen_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					    gnome_canvas_text_get_type (),
-					    "text", gettext(screenname[properties->screensize]), 
-					    "font", gcompris_skin_font_subtitle,
+					    "text", gettext(screenname[properties->screensize]),
+					    "font", gc_skin_font_subtitle,
 					    "x", (double) x_text_start,
 					    "y", (double) y_start,
 					    "anchor", GTK_ANCHOR_WEST,
-					    "fill_color_rgba", gcompris_skin_color_content,
+					    "fill_color_rgba", gc_skin_color_content,
 					    NULL);
 
   // Music
@@ -339,7 +296,7 @@ void gcompris_config_start ()
 
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", (properties->music ? pixmap_checked : pixmap_unchecked), 
+				"pixbuf", (properties->music ? pixmap_checked : pixmap_unchecked),
 				"x", (double) x_start,
 				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
 				NULL);
@@ -348,18 +305,18 @@ void gcompris_config_start ()
 		     (GtkSignalFunc) item_event_ok,
 		     "music");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
-			 "text", _("Music"), 
-			 "font", gcompris_skin_font_subtitle,
+			 "text", _("Music"),
+			 "font", gc_skin_font_subtitle,
 			 "x", (double) x_text_start,
 			 "y", (double) y_start,
 			 "anchor", GTK_ANCHOR_WEST,
-			 "fill_color_rgba", gcompris_skin_color_content,
+			 "fill_color_rgba", gc_skin_color_content,
 			 NULL);
 
   // Effect
@@ -367,7 +324,7 @@ void gcompris_config_start ()
 
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", (properties->fx ? pixmap_checked : pixmap_unchecked), 
+				"pixbuf", (properties->fx ? pixmap_checked : pixmap_unchecked),
 				"x", (double) x_start,
 				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
 				NULL);
@@ -376,18 +333,18 @@ void gcompris_config_start ()
 		     (GtkSignalFunc) item_event_ok,
 		     "effect");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
 
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
-			 "text", _("Effect"), 
-			 "font", gcompris_skin_font_subtitle,
+			 "text", _("Effect"),
+			 "font", gc_skin_font_subtitle,
 			 "x", (double) x_text_start,
 			 "y", (double) y_start,
 			 "anchor", GTK_ANCHOR_WEST,
-			 "fill_color_rgba", gcompris_skin_color_content,
+			 "fill_color_rgba", gc_skin_color_content,
 			 NULL);
 
   // Timer
@@ -398,32 +355,35 @@ void gcompris_config_start ()
   item_timer_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					   gnome_canvas_text_get_type (),
 					   "text", gettext(timername[properties->timer]),
-					   "font", gcompris_skin_font_subtitle,
+					   "font", gc_skin_font_subtitle,
 					   "x", (double) x_text_start,
 					   "y", (double) y_start,
 					   "anchor", GTK_ANCHOR_WEST,
-					   "fill_color_rgba", gcompris_skin_color_content,
+					   "fill_color_rgba", gc_skin_color_content,
 					   NULL);
 
   // Skin
   {
-    gchar *one_dirent;
+    const gchar *one_dirent;
     guint  i;
     GDir  *dir;
-    
+    gchar *skin_dir;
+    gchar *first_skin_name;
+
     /* Load the Pixpmaps directory file names */
-    dir = g_dir_open(PACKAGE_DATA_DIR"/skins", 0, NULL);
+    skin_dir = g_strconcat(properties->package_data_dir, "/skins", NULL);
+    dir = g_dir_open(skin_dir, 0, NULL);
 
     if (!dir)
-      g_error (_("Couldn't open skin dir: %s"), PACKAGE_DATA_DIR"/skins");
-    
+      g_warning (_("Couldn't open skin dir: %s"), skin_dir);
+
     /* Fill up the skin list */
     while((one_dirent = g_dir_read_name(dir)) != NULL) {
 
       if (one_dirent[0] != '.') {
 	gchar *filename;
 	/* Only directory here are skins */
-	filename = g_strdup_printf("%s/skins/%s", PACKAGE_DATA_DIR, one_dirent);
+	filename = g_strdup_printf("%s/skins/%s", properties->package_data_dir, one_dirent);
 
 	if (g_file_test ((filename), G_FILE_TEST_IS_DIR)) {
 	  gchar *skin_name = g_strdup_printf("%s", one_dirent);
@@ -434,11 +394,6 @@ void gcompris_config_start ()
     }
     g_dir_close(dir);
 
-    /* Should not happen. It the user found the config, there should be a skin */
-    if(g_list_length(skinlist) == 0) {
-      g_warning( "No skin found in %s\n", PACKAGE_DATA_DIR"/skins");
-    }
-
     /* Find the current skin index */
     skin_index = 0;
     for(i=0; i<g_list_length(skinlist);  i++)
@@ -447,18 +402,27 @@ void gcompris_config_start ()
 
     y_start += Y_GAP;
 
-    display_previous_next(x_start, y_start, "skin_previous", "skin_next");
+    /* Should not happen. It the user found the config, there should be a skin */
+    if(g_list_length(skinlist) > 0) {
+      g_warning("No skin found in %s\n", skin_dir);
+      display_previous_next(x_start, y_start, "skin_previous", "skin_next");
+      first_skin_name = g_strdup_printf(_("Skin : %s"), (char *)g_list_nth_data(skinlist, skin_index));
+    } else {
+      first_skin_name = g_strdup(_("SKINS NOT FOUND"));
+    }
 
     item_skin_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					    gnome_canvas_text_get_type (),
-					    "text", g_strdup_printf(_("Skin : %s"), 
-								    (char *)g_list_nth_data(skinlist, skin_index)),
-					    "font", gcompris_skin_font_subtitle,
+					    "text", first_skin_name,
+					    "font", gc_skin_font_subtitle,
 					    "x", (double) x_text_start,
 					    "y", (double) y_start,
 					    "anchor", GTK_ANCHOR_WEST,
-					    "fill_color_rgba", gcompris_skin_color_content,
+					    "fill_color_rgba", gc_skin_color_content,
 					    NULL);
+    g_free(first_skin_name);
+    g_free(skin_dir);
+
   }
 
   // Difficulty Filter
@@ -470,30 +434,73 @@ void gcompris_config_start ()
   stars_group_y = y_start - 25;
 
   item_filter_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-						gnome_canvas_text_get_type (),
-						"markup", gettext(filtername[0]), 
-						"font", gcompris_skin_font_subtitle,
-						"x", (double) x_text_start,
-						"y", (double) y_start,
-						"anchor", GTK_ANCHOR_WEST,
-						"fill_color_rgba", gcompris_skin_color_content,
-						NULL);
+					    gnome_canvas_text_get_type (),
+					    "markup", gettext(filtername[0]),
+					    "font", gc_skin_font_subtitle,
+					    "x", (double) x_text_start,
+					    "y", (double) y_start,
+					    "anchor", GTK_ANCHOR_WEST,
+					    "fill_color_rgba", gc_skin_color_content,
+					    NULL);
+
+
+  // OK
+  pixmap = gc_skin_pixmap_load("button_large.png");
+  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				gnome_canvas_pixbuf_get_type (),
+				"pixbuf", pixmap,
+				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
+				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 5,
+				NULL);
+
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) item_event_ok,
+		     "ok");
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     NULL);
+
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("OK"),
+			 "font", gc_skin_font_title,
+			 "x", (double)  BOARDWIDTH*0.5 + 1.0,
+			 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 "weight", PANGO_WEIGHT_HEAVY,
+			 NULL);
+  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				 gnome_canvas_text_get_type (),
+				 "text", _("OK"),
+				 "font", gc_skin_font_title,
+				 "x", (double)  BOARDWIDTH*0.5,
+				 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
+				 "anchor", GTK_ANCHOR_CENTER,
+				 "fill_color_rgba", gc_skin_color_text_button,
+				 "weight", PANGO_WEIGHT_HEAVY,
+				 NULL);
+  gtk_signal_connect(GTK_OBJECT(item2), "event",
+		     (GtkSignalFunc) item_event_ok,
+		     "ok");
+  gtk_signal_connect(GTK_OBJECT(item2), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     item);
+  gdk_pixbuf_unref(pixmap);
 
 
   is_displayed = TRUE;
 }
 
-void gcompris_config_stop ()
+void gc_config_stop ()
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
-
   // Destroy the help box
   if(rootitem!=NULL)
     {
       gtk_object_destroy(GTK_OBJECT(rootitem));
-      gcomprisBoard->plugin->pause_board(FALSE);
+      gc_board_pause(FALSE);
     }
-  rootitem = NULL;	  
+  rootitem = NULL;
 
   stars_group = NULL;
 
@@ -506,117 +513,28 @@ void gcompris_config_stop ()
   pixmap_checked = NULL;
 
   /* UnPause the board */
-  if((gcomprisBoard->plugin->pause_board != NULL) && is_displayed)
-    {
-      gcomprisBoard->plugin->pause_board(FALSE);
-    }
+  if(is_displayed)
+    gc_board_pause(FALSE);
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
 
   is_displayed = FALSE;
 }
 
 
-/*-------------------------------------------------------------------------------*/
-/*-------------------------------------------------------------------------------*/
-/*-------------------------------------------------------------------------------*/
-/*-------------------------------------------------------------------------------*/
-static void
-display_previous_next(guint x_start, guint y_start, 
-		      gchar *eventname_previous, gchar *eventname_next)
-{
-  GdkPixbuf   *pixmap = NULL;
-  GnomeCanvasItem *item;
-
-  pixmap = gcompris_load_skin_pixmap("button_backward.png");
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
-				"x", (double) x_start - gdk_pixbuf_get_width(pixmap) - 10,
-				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
-				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     eventname_previous);
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
-  gdk_pixbuf_unref(pixmap);
-
-
-  pixmap = gcompris_load_skin_pixmap("button_forward.png");
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
-				"x", (double) x_start,
-				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
-				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     eventname_next);
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
-  gdk_pixbuf_unref(pixmap);
-}
-  
-static void set_locale_flag(gchar *locale)
-{
-  char *str = NULL;
-  GdkPixbuf *pixmap = NULL;
-
-  if(locale == NULL)
-    return;
-
-  if(locale[0] == '\0') {
-    /* Set the flag to the default user's locale */
-    locale = gcompris_get_user_default_locale();
-    g_message("gcompris_get_user_default_locale = %s\n", locale);
-  }
-
-  /* First try to find a flag for the long locale name */
-  str = g_strdup_printf("%.5s.png", locale);
-  pixmap = gcompris_load_pixmap_asset("gcompris flags", "flags", "image/png", str);
-
-  /* Not found, Try now with the short locale name */
-  if(!pixmap) {
-    g_free(str);
-    str = g_strdup_printf("%.2s.png", locale);
-    pixmap = gcompris_load_pixmap_asset("gcompris flags", "flags", "image/png", str);
-  }
-
-  gnome_canvas_item_set (item_locale_flag,
-			 "pixbuf", pixmap,
-			 NULL);
-
-  /* Check wether or not the locale is available */
-#ifdef WIN32
-  /* On win32, it's always available, do not try to check */
-  gnome_canvas_item_hide (item_bad_flag);
-#else
-  if(setlocale(LC_MESSAGES, locale)==NULL)
-    gnome_canvas_item_show (item_bad_flag);
-  else
-    gnome_canvas_item_hide (item_bad_flag);
-#endif
-
-  g_free(str);
-
-  if(pixmap)
-    gdk_pixbuf_unref(pixmap);
-}
-
-
 /**
  * Given the locale name, return the full translated name
  * If not found, simply return the name
  */
-static gchar *get_locale_name(gchar *locale)
+gchar*
+gc_locale_get_name(gchar *locale)
 {
   guint i = 0;
 
+  /* en (US) is not in the Linguas table */
+  if(locale[0] != '\0' && !strncmp(locale, "en", strlen(locale)))
+    return(_("English (United State)"));
+
   while(linguas[i] != NULL)
     {
 
@@ -629,10 +547,112 @@ static gchar *get_locale_name(gchar *locale)
   return(linguas[1]);
 }
 
+/*-------------------------------------------------------------------------------*/
+/*-------------------------------------------------------------------------------*/
+/*-------------------------------------------------------------------------------*/
+/*-------------------------------------------------------------------------------*/
+static void
+display_previous_next(guint x_start, guint y_start,
+		      gchar *eventname_previous, gchar *eventname_next)
+{
+  GdkPixbuf   *pixmap = NULL;
+  GnomeCanvasItem *item;
+
+  pixmap = gc_skin_pixmap_load("button_backward.png");
+  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				gnome_canvas_pixbuf_get_type (),
+				"pixbuf", pixmap,
+				"x", (double) x_start - gdk_pixbuf_get_width(pixmap) - 10,
+				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
+				NULL);
+
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) item_event_ok,
+		     eventname_previous);
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     NULL);
+  gdk_pixbuf_unref(pixmap);
+
+
+  pixmap = gc_skin_pixmap_load("button_forward.png");
+  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				gnome_canvas_pixbuf_get_type (),
+				"pixbuf", pixmap,
+				"x", (double) x_start,
+				"y", (double) y_start - gdk_pixbuf_get_width(pixmap_checked)/2,
+				NULL);
+
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) item_event_ok,
+		     eventname_next);
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     NULL);
+  gdk_pixbuf_unref(pixmap);
+}
+
+static void
+set_locale_flag(gchar *locale)
+{
+  gchar *filename;
+  GdkPixbuf *pixmap = NULL;
+
+  if(locale == NULL)
+    return;
+
+  if(locale[0] == '\0') {
+    /* Set the flag to the default user's locale */
+    locale = gc_locale_get_user_default();
+    g_message("gc_locale_get_user_default = %s\n", locale);
+  }
+
+  /* First try to find a flag for the long locale name */
+  filename = gc_file_find_absolute("flags/%.5s.png", locale);
+
+  /* Not found, Try now with the short locale name */
+  if(!filename) {
+    filename = gc_file_find_absolute("flags/%.2s.png", locale);
+  }
+
+  if(filename)
+    {
+      pixmap = gc_net_load_pixmap(filename);
+
+      gnome_canvas_item_set (item_locale_flag,
+			     "pixbuf", pixmap,
+			     NULL);
+
+      gdk_pixbuf_unref(pixmap);
+      g_free(filename);
+    }
+  else
+    {
+      /* No flags */
+      gnome_canvas_item_set (item_locale_flag,
+			     "pixbuf", NULL,
+			     NULL);
+    }
+
+  /* Check wether or not the locale is available */
+#ifdef WIN32
+  /* On win32, it's always available, do not try to check */
+  gnome_canvas_item_hide (item_bad_flag);
+#else
+  if(setlocale(LC_MESSAGES, locale)==NULL)
+    gnome_canvas_item_show (item_bad_flag);
+  else
+    gnome_canvas_item_hide (item_bad_flag);
+#endif
+
+}
+
+
 /**
  * Given the short locale name, return the next one in our linguas table
  */
-static gchar *get_next_locale(gchar *locale)
+static gchar *
+get_next_locale(gchar *locale)
 {
   guint i = 0;
 
@@ -645,7 +665,7 @@ static gchar *get_next_locale(gchar *locale)
 	    return(linguas[i+2]);
 	  else
 	    return(linguas[0]);
-	  
+
 	}
       i=i+2;
     }
@@ -656,7 +676,8 @@ static gchar *get_next_locale(gchar *locale)
 /**
  * Given the short locale name, return the previous one in our linguas table
  */
-static gchar *get_previous_locale(gchar *locale)
+static gchar *
+get_previous_locale(gchar *locale)
 {
   guint i = 0;
 
@@ -672,7 +693,7 @@ static gchar *get_previous_locale(gchar *locale)
 	      // Go to the end of the list
 	      while(linguas[i]!=NULL) { i=i+2; };
 	      return(linguas[i-2]);
-	    }	  
+	    }
 	}
       i=i+2;
     }
@@ -683,12 +704,12 @@ static gchar *get_previous_locale(gchar *locale)
 static gint
 item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   if(data==NULL)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -697,35 +718,56 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     case GDK_BUTTON_PRESS:
       if(!strcmp((char *)data, "ok"))
 	{
+	  /* Set the new locale in the properties */
+	  if (properties->locale != current_locale)
+	    {
+	      g_free(properties->locale);
+	      properties->locale = strdup(current_locale);
+	    }
+
 	  if(current_locale[0] == '\0') {
 	    /* Set the locale to the default user's locale */
-	    gcompris_set_locale(gcompris_get_user_default_locale());
+	    gc_locale_set(gc_locale_get_user_default());
 	  } else {
-	    gcompris_set_locale(current_locale);
+	    gc_locale_set(current_locale);
 	  }
+	  g_free(properties->skin);
 	  properties->skin = g_strdup((char *)g_list_nth_data(skinlist, skin_index));
-	  gcompris_skin_load(properties->skin);
-	  gcompris_config_stop();
-	  gcompris_properties_save(properties);
+	  gc_skin_load(properties->skin);
+	  gc_config_stop();
 
-	  if(properties->music || properties->fx) {
-	    initSound();
-	  }
+	  if(properties->music || properties->fx)
+	    gc_sound_init();
+
+	  if(!properties->music && !properties->fx)
+	    gc_sound_close();
+	  else
+	    {
+	      if(!properties->music)
+		sdlplayer_halt_music();
+	      else
+		sdlplayer_resume_music();
+
+	      if(!properties->fx)
+		sdlplayer_halt_fx();
+	      else
+		sdlplayer_resume_fx();
+	    }
+	  gc_prop_save(properties);
 	}
       else if(!strcmp((char *)data, "fullscreen"))
 	{
 	  properties->fullscreen = (properties->fullscreen ? 0 : 1);
 
-#ifdef XRANDR
+#ifdef XF86_VIDMODE
 	  /* Changing screen without xrandr is more complex, it requires to remove the
 	     black border we created manually.
 	  */
-	  if(!properties->noxrandr)
-	    gcompris_set_fullscreen(properties->fullscreen);
+	  if(!properties->noxf86vm)
+	    gc_fullscreen_set(properties->fullscreen);
 #endif
 	  /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-	  g_object_set_data (G_OBJECT (item), "pixbuf_ref",  
-			     (properties->fullscreen ? pixmap_checked : pixmap_unchecked));
+	  gc_item_focus_free(item, NULL);
 	  gnome_canvas_item_set (item,
 				 "pixbuf", (properties->fullscreen ? pixmap_checked : pixmap_unchecked),
 				 NULL);
@@ -735,19 +777,25 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	{
 	  properties->music = (properties->music ? 0 : 1);
 	  /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-	  g_object_set_data (G_OBJECT (item), "pixbuf_ref",  
-			     (properties->music ? pixmap_checked : pixmap_unchecked));
+	  gc_item_focus_free(item, NULL);
 	  gnome_canvas_item_set (item,
 				 "pixbuf", (properties->music ? pixmap_checked : pixmap_unchecked),
 				 NULL);
-
+	  if(!properties->music)
+	    {
+	      sdlplayer_halt_music();
+	    }
+	  else
+	    {
+	      gc_sound_init();
+	      sdlplayer_resume_music();
+	    }
 	}
       else if(!strcmp((char *)data, "effect"))
 	{
 	  properties->fx = (properties->fx ? 0 : 1);
 	  /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-	  g_object_set_data (G_OBJECT (item), "pixbuf_ref",  
-			     (properties->fx ? pixmap_checked : pixmap_unchecked));
+	  gc_item_focus_free(item, NULL);
 	  gnome_canvas_item_set (item,
 				 "pixbuf", (properties->fx ? pixmap_checked : pixmap_unchecked),
 				 NULL);
@@ -758,20 +806,18 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	{
 	  current_locale = get_previous_locale(current_locale);
 	  gnome_canvas_item_set (item_locale_text,
-				 "text", get_locale_name(current_locale),
+				 "text", gc_locale_get_name(current_locale),
 				 NULL);
 	  set_locale_flag(current_locale);
-	  properties->locale = current_locale;
 	}
       else if(!strcmp((char *)data, "locale_next"))
 	{
 	  current_locale = get_next_locale(current_locale);
 	  gnome_canvas_item_set (item_locale_text,
-				 "text", get_locale_name(current_locale),
+				 "text", gc_locale_get_name(current_locale),
 				 NULL);
 
 	  set_locale_flag(current_locale);
-	  properties->locale = current_locale;
 	}
       else if(!strcmp((char *)data, "screen_previous"))
 	{
@@ -779,7 +825,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    properties->screensize--;
 
 	  gnome_canvas_item_set (item_screen_text,
-				 "text", gettext(screenname[properties->screensize]), 
+				 "text", gettext(screenname[properties->screensize]),
 				 NULL);
 	}
       else if(!strcmp((char *)data, "screen_next"))
@@ -788,7 +834,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    properties->screensize++;
 
 	  gnome_canvas_item_set (item_screen_text,
-				 "text", gettext(screenname[properties->screensize]), 
+				 "text", gettext(screenname[properties->screensize]),
 				 NULL);
 	}
       else if(!strcmp((char *)data, "timer_previous"))
@@ -797,7 +843,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    properties->timer--;
 
 	  gnome_canvas_item_set (item_timer_text,
-				 "text", gettext(timername[properties->timer]), 
+				 "text", gettext(timername[properties->timer]),
 				 NULL);
 	}
       else if(!strcmp((char *)data, "timer_next"))
@@ -806,29 +852,35 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    properties->timer++;
 
 	  gnome_canvas_item_set (item_timer_text,
-				 "text", gettext(timername[properties->timer]), 
+				 "text", gettext(timername[properties->timer]),
 				 NULL);
 	}
       else if(!strcmp((char *)data, "skin_previous"))
 	{
+	  gchar *skin_str;
 	  if(skin_index-- < 1)
 	    skin_index = g_list_length(skinlist)-1;
 
-	  gnome_canvas_item_set (item_skin_text,
-				 "text", g_strdup_printf(_("Skin : %s"), 
-							 (char *)g_list_nth_data(skinlist, skin_index)),
-				 NULL);
+	  skin_str = g_strdup_printf(_("Skin : %s"),
+				     (char *)g_list_nth_data(skinlist, skin_index));
 
+	  gnome_canvas_item_set (item_skin_text,
+				 "text", skin_str,
+				 NULL);
+	  g_free(skin_str);
 	}
       else if(!strcmp((char *)data, "skin_next"))
 	{
+	  gchar *skin_str;
 	  if(skin_index++ >= g_list_length(skinlist)-1)
 	    skin_index = 0;
 
+	  skin_str = g_strdup_printf(_("Skin : %s"),
+				     (char *)g_list_nth_data(skinlist, skin_index));
 	  gnome_canvas_item_set (item_skin_text,
-				 "text", g_strdup_printf(_("Skin : %s"), 
-							 (char *)g_list_nth_data(skinlist, skin_index)),
+				 "text", skin_str,
 				 NULL);
+	  g_free(skin_str);
 	}
     default:
       break;
@@ -836,14 +888,3 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   return FALSE;
 
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
