@@ -1,6 +1,6 @@
 /* gcompris - file_selector.c
  *
- * Time-stamp: <2005/11/12 19:00:49 bruno>
+ * Time-stamp: <2006/08/20 10:29:31 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -33,6 +33,7 @@
 #include <libxml/parser.h>
 
 #include "gcompris.h"
+#include "gc_core.h"
 
 #define SOUNDLISTFILE PACKAGE
 
@@ -40,17 +41,17 @@
 #define MODE_SAVE 2
 static gint mode;
 
-static gint		 item_event_file_selector(GnomeCanvasItem *item, 
-						  GdkEvent *event, 
+static gint		 item_event_file_selector(GnomeCanvasItem *item,
+						  GdkEvent *event,
 						  gpointer data);
 static gint		 item_event_scroll(GnomeCanvasItem *item,
 					   GdkEvent *event,
 					   GnomeCanvas *canvas);
-static gint		 item_event_directory(GnomeCanvasItem *item, 
-					      GdkEvent *event, 
+static gint		 item_event_directory(GnomeCanvasItem *item,
+					      GdkEvent *event,
 					      char *dir);
 static void		 display_files(GnomeCanvasItem *rootitem, gchar *rootdir);
-static int		 display_file_selector(int mode, 
+static int		 display_file_selector(int mode,
 					       GcomprisBoard *gcomprisBoard,
 					       gchar *rootdir,
 					       gchar *file_types,
@@ -106,7 +107,7 @@ static GHashTable* mimetypes_ext_hash  = NULL; /* Mime type with the key being t
 static GHashTable* mimetypes_desc_hash = NULL; /* Mime type with the key being the description */
 
 /*
- * Main entry point 
+ * Main entry point
  * ----------------
  *
  */
@@ -116,7 +117,7 @@ static GHashTable* mimetypes_desc_hash = NULL; /* Mime type with the key being t
  * file_types is A Comma separated text explaining the different file types
  */
 
-void gcompris_file_selector_save (GcomprisBoard *gcomprisBoard, gchar *rootdir,
+void gc_selector_file_save (GcomprisBoard *gcomprisBoard, gchar *rootdir,
 				  gchar *file_types,
 				  FileSelectorCallBack iscb)
 {
@@ -124,7 +125,7 @@ void gcompris_file_selector_save (GcomprisBoard *gcomprisBoard, gchar *rootdir,
 			iscb);
 }
 
-void gcompris_file_selector_load (GcomprisBoard *gcomprisBoard, gchar *rootdir,
+void gc_selector_file_load (GcomprisBoard *gcomprisBoard, gchar *rootdir,
 				  gchar *file_types,
 				  FileSelectorCallBack iscb)
 {
@@ -136,24 +137,19 @@ void gcompris_file_selector_load (GcomprisBoard *gcomprisBoard, gchar *rootdir,
  * Remove the displayed file_selector.
  * Do nothing if none is currently being dislayed
  */
-void gcompris_file_selector_stop ()
+void gc_selector_file_stop ()
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+  GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
   if(gcomprisBoard!=NULL && file_selector_displayed)
-    {
-      if(gcomprisBoard->plugin->pause_board != NULL)
-	{
-	  gcomprisBoard->plugin->pause_board(FALSE);
-	}
-    }
+    gc_board_pause(FALSE);
 
   // Destroy the file_selector box
   /* FIXME: Crashes randomly */
   if(rootitem!=NULL)
     gtk_object_destroy(GTK_OBJECT(rootitem));
 
-  rootitem = NULL;	  
+  rootitem = NULL;
 
   /* No need to destroy it since it's in rootitem but just clear it */
   file_root_item = NULL;
@@ -165,7 +161,7 @@ void gcompris_file_selector_stop ()
   }
   file_list = NULL;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
   file_selector_displayed = FALSE;
 }
 
@@ -177,8 +173,8 @@ void gcompris_file_selector_stop ()
 /*-------------------------------------------------------------------------------*/
 
 
-static int 
-display_file_selector(int the_mode, 
+static int
+display_file_selector(int the_mode,
 		      GcomprisBoard *gcomprisBoard,
 		      gchar *rootdir,
 		      gchar *file_types,
@@ -198,9 +194,9 @@ display_file_selector(int the_mode,
   mode = the_mode;
 
   /* Get the coordinate x y of the control area from the skin */
-  control_area_x1   = gcompris_skin_get_number_default("gcompris/fileselectx", 85);
-  control_area_y1   = gcompris_skin_get_number_default("gcompris/fileselecty", 80);
-  directory_label_y = gcompris_skin_get_number_default("gcompris/fileselectdiry", 180);
+  control_area_x1   = gc_skin_get_number_default("gcompris/fileselectx", 85);
+  control_area_y1   = gc_skin_get_number_default("gcompris/fileselecty", 80);
+  directory_label_y = gc_skin_get_number_default("gcompris/fileselectdiry", 180);
 
   if(file_types) {
     file_types_string = g_strdup(file_types);
@@ -209,30 +205,26 @@ display_file_selector(int the_mode,
   if(rootitem)
     return 0;
 
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
 
-  if(gcomprisBoard!=NULL)
-    {
-      if(gcomprisBoard->plugin->pause_board != NULL)
-	gcomprisBoard->plugin->pause_board(TRUE);
-    }
+  gc_board_pause(TRUE);
 
   name = gcomprisBoard->name;
   fileSelectorCallBack=iscb;
 
   rootitem = \
-    gnome_canvas_item_new (gnome_canvas_root(gcompris_get_canvas()),
+    gnome_canvas_item_new (gnome_canvas_root(gc_get_canvas()),
 			   gnome_canvas_group_get_type (),
 			   "x", (double)0,
 			   "y", (double)0,
 			   NULL);
 
-  pixmap = gcompris_load_skin_pixmap("file_selector_bg.png");
+  pixmap = gc_skin_pixmap_load("file_selector_bg.png");
   y_start = (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   x_start = (BOARDWIDTH - gdk_pixbuf_get_width(pixmap))/2;
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) x_start,
 				"y", (double) y_start,
 				NULL);
@@ -240,7 +232,8 @@ display_file_selector(int the_mode,
   gdk_pixbuf_unref(pixmap);
 
   /* Entry area */
-  widget_entry = (GtkEntry *)gtk_entry_new_with_max_length (30);
+  widget_entry = (GtkEntry *)gtk_entry_new ();
+  gtk_entry_set_max_length(widget_entry, 30);
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_widget_get_type (),
 				"widget", GTK_WIDGET(widget_entry),
@@ -258,7 +251,7 @@ display_file_selector(int the_mode,
   gtk_widget_show(GTK_WIDGET(widget_entry));
 
   /*
-   * Create the combo with the file types 
+   * Create the combo with the file types
    * ------------------------------------
    */
   if(mode==MODE_SAVE && file_types_string && *file_types_string!='\0') {
@@ -273,7 +266,7 @@ display_file_selector(int the_mode,
     /* Extract the mime type */
     mimeType = (GcomprisMimeType *)(g_hash_table_lookup(mimetypes_hash, str));
     if(mimeType) {
-      result = strdup(mimeType->description);
+      result = strdup(gettext(mimeType->description));
     } else {
       result = str;
     }
@@ -286,7 +279,7 @@ display_file_selector(int the_mode,
 	/* Extract the mime type */
 	mimeType = (GcomprisMimeType *)(g_hash_table_lookup(mimetypes_hash, sub_string));
 	if(mimeType) {
-	  result = strdup(mimeType->description);
+	  result = strdup(gettext(mimeType->description));
 	} else {
 	  result = str;
 	}
@@ -319,12 +312,12 @@ display_file_selector(int the_mode,
    * -------
    */
 
-  pixmap = gcompris_load_skin_pixmap("button_large.png");
+  pixmap = gc_skin_pixmap_load("button_large.png");
 
   // CANCEL
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) (BOARDWIDTH*0.33) - gdk_pixbuf_get_width(pixmap)/2,
 				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 25,
 				NULL);
@@ -333,29 +326,29 @@ display_file_selector(int the_mode,
 		     (GtkSignalFunc) item_event_file_selector,
 		     "/cancel/");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				 gnome_canvas_text_get_type (),
 				 "text", _("CANCEL"),
-				 "font", gcompris_skin_font_title,
+				 "font", gc_skin_font_title,
 				 "x", (double)  BOARDWIDTH*0.33,
 				 "y", (double)  y - gdk_pixbuf_get_height(pixmap),
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_text_button,
+				 "fill_color_rgba", gc_skin_color_text_button,
 				 NULL);
   gtk_signal_connect(GTK_OBJECT(item2), "event",
 		     (GtkSignalFunc) item_event_file_selector,
 		     "/cancel/");
   gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     item);
 
   // OK
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) (BOARDWIDTH*0.66) - gdk_pixbuf_get_width(pixmap)/2,
 				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 25,
 				NULL);
@@ -364,23 +357,23 @@ display_file_selector(int the_mode,
 		     (GtkSignalFunc) item_event_file_selector,
 		     "/ok/");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				 gnome_canvas_text_get_type (),
 				 "text", (mode==MODE_LOAD ? _("LOAD") : _("SAVE")),
-				 "font", gcompris_skin_font_title,
+				 "font", gc_skin_font_title,
 				 "x", (double)  BOARDWIDTH*0.66,
 				 "y", (double)  y - gdk_pixbuf_get_height(pixmap),
 				 "anchor", GTK_ANCHOR_CENTER,
-				 "fill_color_rgba", gcompris_skin_color_text_button,
+				 "fill_color_rgba", gc_skin_color_text_button,
 				 NULL);
   gtk_signal_connect(GTK_OBJECT(item2), "event",
 		     (GtkSignalFunc) item_event_file_selector,
 		     "/ok/");
   gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     item);
   gdk_pixbuf_unref(pixmap);
 
@@ -388,8 +381,8 @@ display_file_selector(int the_mode,
 
   file_selector_displayed = TRUE;
 
-  full_rootdir = g_strconcat(gcompris_get_current_user_dirname(), "/", rootdir, NULL);
-  create_rootdir(full_rootdir);
+  full_rootdir = g_strconcat(gc_prop_current_user_dirname_get(), "/", rootdir, NULL);
+  gc_util_create_rootdir(full_rootdir);
 
   current_rootdir = full_rootdir;
 
@@ -447,7 +440,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
     g_list_free(file_list);
   }
   file_list = NULL;
-  
+
   /* Create a root item to put the image list in it */
   file_root_item = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(root_item),
@@ -480,7 +473,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 			 "y1", (double) 0,
 			 "x2", (double) DRAWING_AREA_X2- DRAWING_AREA_X1,
 			 "y2", (double) DRAWING_AREA_Y2-DRAWING_AREA_Y1,
-			 "fill_color_rgba", gcompris_skin_get_color("gcompris/fileselectbg"),
+			 "fill_color_rgba", gc_skin_get_color("gcompris/fileselectbg"),
 			 NULL);
 
 
@@ -511,7 +504,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 				"text", rootdir,
 				"x", (double)control_area_x1,
 				"y", (double)directory_label_y,
-				"fill_color_rgba", gcompris_skin_get_color("gcompris/fileselectcol"),
+				"fill_color_rgba", gc_skin_get_color("gcompris/fileselectcol"),
 				"anchor", GTK_ANCHOR_NW,
 				NULL);
 
@@ -552,7 +545,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 
 
     if(g_file_test(allfilename, G_FILE_TEST_IS_DIR)) {
-      pixmap_current  = gcompris_load_pixmap(gcompris_image_to_skin("directory.png"));
+      pixmap_current  = gc_pixmap_load(gc_skin_image_get("directory.png"));
     } else if(ext) {
       /* Need to find an icon for this extension */
       GcomprisMimeType *mimeType = NULL;
@@ -561,22 +554,22 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
       mimeType = (GcomprisMimeType *)(g_hash_table_lookup(mimetypes_ext_hash, ext));
       if(mimeType) {
 	if(mimeType->icon) {
-	  pixmap_current  = gcompris_load_pixmap(mimeType->icon);
+	  pixmap_current  = gc_pixmap_load(mimeType->icon);
 	  if(pixmap_current==NULL) {
 	    g_warning("Cannot find icon %s for mimetype %s", mimeType->icon, mimeType->description);
-	    pixmap_current  = gcompris_load_pixmap(gcompris_image_to_skin("file.png"));
+	    pixmap_current  = gc_pixmap_load(gc_skin_image_get("file.png"));
 	  } else {
 	    /* We can remove the extension now that we have an icon */
 	    *ext='\0';
 	  }
 	} else {
-	  pixmap_current  = gcompris_load_pixmap(gcompris_image_to_skin("file.png"));
+	  pixmap_current  = gc_pixmap_load(gc_skin_image_get("file.png"));
 	}
       } else {
-	pixmap_current  = gcompris_load_pixmap(gcompris_image_to_skin("file.png"));
+	pixmap_current  = gc_pixmap_load(gc_skin_image_get("file.png"));
       }
     } else {
-      pixmap_current  = gcompris_load_pixmap(gcompris_image_to_skin("file.png"));
+      pixmap_current  = gc_pixmap_load(gc_skin_image_get("file.png"));
     }
 
     item = gnome_canvas_item_new (gnome_canvas_root(canvas),
@@ -599,7 +592,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 			 allfilename);
     }
     gtk_signal_connect(GTK_OBJECT(item), "event",
-		       (GtkSignalFunc) gcompris_item_event_focus,
+		       (GtkSignalFunc) gc_item_focus_event,
 		       NULL);
 
     g_signal_connect (item, "destroy",
@@ -612,7 +605,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 				  "x", (double)ix + (IMAGE_WIDTH + IMAGE_GAP)/2,
 				  "y", (double)iy + IMAGE_HEIGHT - 5,
 				  "anchor", GTK_ANCHOR_CENTER,
-				  "fill_color_rgba", gcompris_skin_get_color("gcompris/fileselectcol"),
+				  "fill_color_rgba", gc_skin_get_color("gcompris/fileselectcol"),
 				  NULL);
 
     if(g_file_test(allfilename, G_FILE_TEST_IS_DIR)) {
@@ -624,7 +617,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 			 (GtkSignalFunc) item_event_file_selector,
 			 allfilename);
     }
-      
+
     ix+=IMAGE_WIDTH + IMAGE_GAP;
     if(ix>=DRAWING_AREA_X2 - DRAWING_AREA_X1 -IMAGE_GAP)
       {
@@ -632,8 +625,8 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 
 	iy+=IMAGE_HEIGHT + IMAGE_GAP;
 
-	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), 0, 0, 
-					DRAWING_AREA_X2- DRAWING_AREA_X1, 
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), 0, 0,
+					DRAWING_AREA_X2- DRAWING_AREA_X1,
 					iy + IMAGE_HEIGHT + IMAGE_GAP);
 
 	if(iy>=DRAWING_AREA_Y2-DRAWING_AREA_Y1) {
@@ -657,7 +650,7 @@ item_event_directory(GnomeCanvasItem *item, GdkEvent *event, gchar *dir)
   if(!rootitem)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -687,7 +680,7 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
   if(!rootitem)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_SCROLL:
       gnome_canvas_get_scroll_offsets (canvas, &x, &y);
@@ -711,7 +704,7 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   if(!rootitem)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -730,7 +723,7 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  gchar *file_type=NULL;
 
 	  result = g_strdup_printf("%s/%s", current_rootdir, gtk_entry_get_text(widget_entry));
-	  
+
 	  if(mode==MODE_SAVE) {
 	    GcomprisMimeType *mimeType = NULL;
 	    GtkTreeModel *model;
@@ -743,11 +736,14 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
 	    /* Extract the mime type */
 	    mimeType = (GcomprisMimeType *)(g_hash_table_lookup(mimetypes_desc_hash, file_type));
-	    file_type = strdup(mimeType->mimetype);
-	    if(!g_str_has_suffix(result,mimeType->extension)) {
-	      gchar *old_result = result;
-	      result = g_strconcat(result, mimeType->extension, NULL);
-	      g_free(old_result);
+	    g_free(file_type);
+	    if(mimeType && mimeType->mimetype) {
+	      file_type = strdup(mimeType->mimetype);
+	      if(!g_str_has_suffix(result,mimeType->extension)) {
+		gchar *old_result = result;
+		result = g_strconcat(result, mimeType->extension, NULL);
+		g_free(old_result);
+	      }
 	    }
 	  } else {
 	    /* LOAD Mode, get the file_type from the extension in the mimetype */
@@ -779,9 +775,9 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  //	    g_free(result);
 	  //	  }
 	}
-	gcompris_file_selector_stop();
+	gc_selector_file_stop();
       } else if(!strcmp((char *)data, "/cancel/")) {
-	gcompris_file_selector_stop();
+	gc_selector_file_stop();
       } else {
 	gtk_entry_set_text(widget_entry, g_path_get_basename((gchar *)data));
       }
@@ -813,27 +809,18 @@ void parseMime (xmlDocPtr doc, xmlNodePtr xmlnode) {
 
   GcomprisMimeType *gcomprisMime = g_malloc0 (sizeof (GcomprisMimeType));
 
-  gcomprisMime->mimetype    = xmlGetProp(xmlnode,"mimetype");
-  gcomprisMime->extension   = xmlGetProp(xmlnode,"extension");
-  gcomprisMime->icon        = xmlGetProp(xmlnode,"icon");
-  gcomprisMime->description = NULL;
+  gcomprisMime->mimetype    = (gchar *)xmlGetProp(xmlnode, BAD_CAST "mimetype");
+  gcomprisMime->extension   = (gchar *)xmlGetProp(xmlnode, BAD_CAST "extension");
+  gcomprisMime->icon        = (gchar *)xmlGetProp(xmlnode, BAD_CAST "icon");
 
-  /* get the help user credit of the board */
-  xmlnode = xmlnode->xmlChildrenNode;
-  while (xmlnode != NULL) {
-    gchar *lang = xmlGetProp(xmlnode,"lang");
-    if (!strcmp(xmlnode->name, "description")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
-      {
-	if(gcomprisMime->description)
-	  g_free(gcomprisMime->description);
-	
-	gcomprisMime->description = xmlNodeListGetString(doc, 
-							 xmlnode->xmlChildrenNode, 1);
-      }
-    xmlnode = xmlnode->next;
+  for (xmlnode = xmlnode->xmlChildrenNode; xmlnode != NULL; xmlnode = xmlnode->next) {
+    if (xmlHasProp(xmlnode, BAD_CAST "lang"))
+      continue;
+
+    /* get the title of the board */
+    if (!strcmp((char *)xmlnode->name, "description"))
+      gcomprisMime->description = (gchar *)xmlNodeListGetString(doc,
+								xmlnode->xmlChildrenNode, 0);
   }
 
   if(!gcomprisMime->mimetype || !gcomprisMime->extension || !gcomprisMime->description ) {
@@ -850,7 +837,7 @@ void parseMime (xmlDocPtr doc, xmlNodePtr xmlnode) {
 
   g_hash_table_insert(mimetypes_hash,      gcomprisMime->mimetype,    gcomprisMime);
   g_hash_table_insert(mimetypes_ext_hash,  gcomprisMime->extension,   gcomprisMime);
-  g_hash_table_insert(mimetypes_desc_hash, gcomprisMime->description, gcomprisMime);
+  g_hash_table_insert(mimetypes_desc_hash, gettext(gcomprisMime->description), gcomprisMime);
 
   return;
 }
@@ -858,7 +845,7 @@ void parseMime (xmlDocPtr doc, xmlNodePtr xmlnode) {
 static void parse_doc(xmlDocPtr doc) {
   xmlNodePtr cur;
 
-  cur = xmlDocGetRootElement(doc);	
+  cur = xmlDocGetRootElement(doc);
   if (cur == NULL) {
     fprintf(stderr,"empty document\n");
     xmlFreeDoc(doc);
@@ -870,10 +857,10 @@ static void parse_doc(xmlDocPtr doc) {
     if ((!xmlStrcmp(cur->name, (const xmlChar *)"MimeType"))){
       parseMime (doc, cur);
     }
-    
+
     cur = cur->next;
   }
-	
+
   return;
 }
 
@@ -888,7 +875,7 @@ gboolean load_mime_type_from_file(gchar *fname)
   g_return_val_if_fail(fname!=NULL,FALSE);
 
   /* if the file doesn't exist */
-  if(!g_file_test ((fname), G_FILE_TEST_EXISTS)) 
+  if(!g_file_test ((fname), G_FILE_TEST_EXISTS))
     {
       g_warning("Couldn't find file %s !", fname);
       return FALSE;
@@ -900,79 +887,73 @@ gboolean load_mime_type_from_file(gchar *fname)
   /* in case something went wrong */
   if(!doc)
     return FALSE;
-  
+
   if(/* if there is no root element */
      !doc->children ||
      /* if it doesn't have a name */
      !doc->children->name ||
      /* if it isn't the good node */
-     g_strcasecmp(doc->children->name,"MimeTypeRoot")!=0) {
+     g_strcasecmp((gchar *)doc->children->name,"MimeTypeRoot")!=0) {
     xmlFreeDoc(doc);
     return FALSE;
   }
-  
+
   /* parse our document and replace old data */
   parse_doc(doc);
-  
+
   xmlFreeDoc(doc);
-  
+
   return TRUE;
 }
 
 /**
- * gcompris_load_mime_types
+ * gc_mime_type_load
  * Load all the mime type in PACKAGE_DATA_DIR"/gcompris/mimetypes/ *.xml"
  *
  * Must be called once at GCompris startup.
  *
  */
-void gcompris_load_mime_types() 
+void gc_mime_type_load()
 {
   const gchar  *one_dirent;
+  GcomprisProperties *properties = gc_prop_get();
   GDir   *dir;
+  gchar  *mime_dir;
 
   if(mimetypes_hash) {
     return;
   }
 
+  mime_dir = g_strconcat(properties->package_data_dir, "/gcompris/mimetypes/", NULL);
+
   mimetypes_hash      = g_hash_table_new (g_str_hash, g_str_equal);
   mimetypes_ext_hash  = g_hash_table_new (g_str_hash, g_str_equal);
   mimetypes_desc_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
   /* Load the Pixpmaps directory file names */
-  dir = g_dir_open(PACKAGE_DATA_DIR"/gcompris/mimetypes/", 0, NULL);
+  dir = g_dir_open(mime_dir, 0, NULL);
 
   if (!dir) {
-    g_warning("gcompris_load_mime_types : no mime types found in %s", 
-	      PACKAGE_DATA_DIR"/gcompris/mimetypes/");
+    g_warning("gc_mime_type_load : no mime types found in %s", mime_dir);
   } else {
 
     while((one_dirent = g_dir_read_name(dir)) != NULL) {
       /* add the board to the list */
       gchar *filename;
-      
-      filename = g_strdup_printf("%s/%s",
-				 PACKAGE_DATA_DIR"/gcompris/mimetypes/", one_dirent);
+
+      filename = g_strdup_printf("%s/%s", mime_dir, one_dirent);
 
       if(!g_file_test(filename, G_FILE_TEST_IS_REGULAR)) {
 	g_free(filename);
 	continue;
       }
 
-      if(selectMenuXML(one_dirent)) {
+      if(file_end_with_xml(one_dirent)) {
 	load_mime_type_from_file(filename);
       }
       g_free(filename);
     }
   }
+  g_free(mime_dir);
   g_dir_close(dir);
 }
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
