@@ -1,6 +1,6 @@
 /* gcompris - help.c
  *
- * Time-stamp: <2006/04/09 23:28:08 bruno>
+ * Time-stamp: <2006/08/21 23:26:30 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -26,11 +26,7 @@
 #include <string.h>
 
 #include "gcompris.h"
-
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
+#include "gc_core.h"
 
 #define SOUNDLISTFILE PACKAGE
 
@@ -64,7 +60,7 @@ static GnomeCanvasItem *item_selected_text	= NULL;
 
 static GtkTextBuffer   *buffer_content;
 /*
- * Main entry point 
+ * Main entry point
  * ----------------
  *
  */
@@ -73,7 +69,7 @@ static GtkTextBuffer   *buffer_content;
  * Return true wether the given board has at least one help field defined
  *
  */
-gboolean gcompris_board_has_help (GcomprisBoard *gcomprisBoard)
+gboolean gc_help_has_board (GcomprisBoard *gcomprisBoard)
 {
 
   prerequisite	= gcomprisBoard->prerequisite;
@@ -87,7 +83,7 @@ gboolean gcompris_board_has_help (GcomprisBoard *gcomprisBoard)
  * Do all the help display and register the events
  */
 
-void gcompris_help_start (GcomprisBoard *gcomprisBoard)
+void gc_help_start (GcomprisBoard *gcomprisBoard)
 {
 
   GdkPixbuf   *pixmap = NULL;
@@ -101,31 +97,27 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
   if(rootitem)
     return;
 
-  if(gcomprisBoard!=NULL)
-    {
-      if(gcomprisBoard->plugin->pause_board != NULL)
-	  gcomprisBoard->plugin->pause_board(TRUE);
-    }
+  gc_board_pause(TRUE);
 
   item_selected = NULL;
   item_selected_text = NULL;
 
   name = gcomprisBoard->title;
-  gcompris_board_has_help(gcomprisBoard);
+  gc_help_has_board(gcomprisBoard);
 
   rootitem = \
-    gnome_canvas_item_new (gnome_canvas_root(gcompris_get_canvas()),
+    gnome_canvas_item_new (gnome_canvas_root(gc_get_canvas()),
 			   gnome_canvas_group_get_type (),
 			   "x", (double)0,
 			   "y", (double)0,
 			   NULL);
 
-  pixmap = gcompris_load_skin_pixmap("help_bg.png");
+  pixmap = gc_skin_pixmap_load("help_bg.png");
   y_start = (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   x_start = (BOARDWIDTH - gdk_pixbuf_get_width(pixmap))/2;
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) x_start,
 				"y", (double) y_start,
 				NULL);
@@ -138,20 +130,20 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
      gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			    gnome_canvas_text_get_type (),
 			    "text", text_to_display,
-			    "font", gcompris_skin_font_board_tiny,
+			    "font", gc_skin_font_board_tiny,
 			    "x", (double) BOARDWIDTH*0.10 + 1.0,
 			    "y", (double) y_start + 1.0,
 			    "anchor", GTK_ANCHOR_NW,
-			    "fill_color_rgba", gcompris_skin_color_shadow,
+			    "fill_color_rgba", gc_skin_color_shadow,
 			    NULL);
      gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			    gnome_canvas_text_get_type (),
 			    "text", text_to_display,
-			    "font", gcompris_skin_font_board_tiny,
+			    "font", gc_skin_font_board_tiny,
 			    "x", (double) BOARDWIDTH*0.10,
 			    "y", (double) y_start,
 			    "anchor", GTK_ANCHOR_NW,
-			    "fill_color_rgba", gcompris_skin_color_title,
+			    "fill_color_rgba", gc_skin_color_title,
 			    NULL);
     g_free(text_to_display);
   }
@@ -159,50 +151,52 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
   y_start += 35;
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
-			 "text", name, 
-			 "font", gcompris_skin_font_title,
+			 "text", name,
+			 "font", gc_skin_font_title,
 			 "x", (double) BOARDWIDTH/2 + 1.0,
 			 "y", (double) y_start + 1.0,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 "weight", PANGO_WEIGHT_HEAVY,
 			 NULL);
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
-			 "text", name, 
-			 "font", gcompris_skin_font_title,
+			 "text", name,
+			 "font", gc_skin_font_title,
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) y_start,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_title,
+			 "fill_color_rgba", gc_skin_color_title,
+			 "weight", PANGO_WEIGHT_HEAVY,
 			 NULL);
 
 
   y_start += 120;
 
-  pixmap = gcompris_load_skin_pixmap("button_up.png");
+  pixmap = gc_skin_pixmap_load("button_up.png");
 
   // Prerequisite Button
   if(prerequisite)
     {
       item_prerequisite = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 						 gnome_canvas_pixbuf_get_type (),
-						 "pixbuf", pixmap, 
+						 "pixbuf", pixmap,
 						 "x", (double) (BOARDWIDTH*0.2) - gdk_pixbuf_get_width(pixmap)/2,
 						 "y", (double) y_start - gdk_pixbuf_get_height(pixmap) - 10,
 						 NULL);
-      
+
       gtk_signal_connect(GTK_OBJECT(item_prerequisite), "event",
 			 (GtkSignalFunc) item_event_help,
 			 "prerequisite");
-      
+
       item_prerequisite_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				    gnome_canvas_text_get_type (),
 				    "text", _("Prerequisite"),
-				    "font", gcompris_skin_font_content,
+				    "font", gc_skin_font_content,
 				    "x", (double)  BOARDWIDTH*0.20,
 				    "y", (double)  y_start - gdk_pixbuf_get_height(pixmap)  + GAP_TO_BUTTON,
 				    "anchor", GTK_ANCHOR_CENTER,
-				    "fill_color_rgba", gcompris_skin_get_color("gcompris/helpunselect"),
+				    "fill_color_rgba", gc_skin_get_color("gcompris/helpunselect"),
 				    NULL);
       gtk_signal_connect(GTK_OBJECT(item_prerequisite_text), "event",
 			 (GtkSignalFunc) item_event_help,
@@ -214,23 +208,23 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
     {
       item_goal = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					 gnome_canvas_pixbuf_get_type (),
-					 "pixbuf", pixmap, 
+					 "pixbuf", pixmap,
 					 "x", (double) (BOARDWIDTH*0.4) - gdk_pixbuf_get_width(pixmap)/2,
 					 "y", (double) y_start - gdk_pixbuf_get_height(pixmap) - 10,
 					 NULL);
-      
+
       gtk_signal_connect(GTK_OBJECT(item_goal), "event",
 			 (GtkSignalFunc) item_event_help,
 			 "goal");
-      
+
       item_goal_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				    gnome_canvas_text_get_type (),
 				    "text", _("Goal"),
-				    "font", gcompris_skin_font_content,
+				    "font", gc_skin_font_content,
 				    "x", (double)  BOARDWIDTH*0.4,
 				    "y", (double)  y_start - gdk_pixbuf_get_height(pixmap)  + GAP_TO_BUTTON,
 				    "anchor", GTK_ANCHOR_CENTER,
-				    "fill_color_rgba", gcompris_skin_get_color("gcompris/helpunselect"),
+				    "fill_color_rgba", gc_skin_get_color("gcompris/helpunselect"),
 				    NULL);
       gtk_signal_connect(GTK_OBJECT(item_goal_text), "event",
 			 (GtkSignalFunc) item_event_help,
@@ -242,23 +236,23 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
     {
       item_manual = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					   gnome_canvas_pixbuf_get_type (),
-					   "pixbuf", pixmap, 
+					   "pixbuf", pixmap,
 					   "x", (double) (BOARDWIDTH*0.6) - gdk_pixbuf_get_width(pixmap)/2,
 					   "y", (double) y_start - gdk_pixbuf_get_height(pixmap) - 10,
 					   NULL);
-      
+
       gtk_signal_connect(GTK_OBJECT(item_manual), "event",
 			 (GtkSignalFunc) item_event_help,
 			 "manual");
-      
+
       item_manual_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				    gnome_canvas_text_get_type (),
 				    "text", _("Manual"),
-				    "font", gcompris_skin_font_content,
+				    "font", gc_skin_font_content,
 				    "x", (double)  BOARDWIDTH*0.6,
 				    "y", (double)  y_start - gdk_pixbuf_get_height(pixmap)  + GAP_TO_BUTTON,
 				    "anchor", GTK_ANCHOR_CENTER,
-				    "fill_color_rgba", gcompris_skin_get_color("gcompris/helpunselect"),
+				    "fill_color_rgba", gc_skin_get_color("gcompris/helpunselect"),
 				    NULL);
       gtk_signal_connect(GTK_OBJECT(item_manual_text), "event",
 			 (GtkSignalFunc) item_event_help,
@@ -270,23 +264,23 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
     {
       item_credit = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 					   gnome_canvas_pixbuf_get_type (),
-					   "pixbuf", pixmap, 
+					   "pixbuf", pixmap,
 					   "x", (double) (BOARDWIDTH*0.8) - gdk_pixbuf_get_width(pixmap)/2,
 					   "y", (double) y_start - gdk_pixbuf_get_height(pixmap) - 10,
 					   NULL);
-      
+
       gtk_signal_connect(GTK_OBJECT(item_credit), "event",
 			 (GtkSignalFunc) item_event_help,
 			 "credit");
-      
+
       item_credit_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				    gnome_canvas_text_get_type (),
 				    "text", _("Credit"),
-				    "font", gcompris_skin_font_content,
+				    "font", gc_skin_font_content,
 				    "x", (double)  BOARDWIDTH*0.8,
 				    "y", (double)  y_start - gdk_pixbuf_get_height(pixmap)  + GAP_TO_BUTTON,
 				    "anchor", GTK_ANCHOR_CENTER,
-				    "fill_color_rgba", gcompris_skin_get_color("gcompris/helpunselect"),
+				    "fill_color_rgba", gc_skin_get_color("gcompris/helpunselect"),
 				    NULL);
       gtk_signal_connect(GTK_OBJECT(item_credit_text), "event",
 			 (GtkSignalFunc) item_event_help,
@@ -331,14 +325,14 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
   gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW (view), FALSE);
 
   PangoFontDescription *font_desc;
-  font_desc = pango_font_description_from_string (gcompris_skin_font_content);
+  font_desc = pango_font_description_from_string (gc_skin_font_content);
   gtk_widget_modify_font (view, font_desc);
   pango_font_description_free (font_desc);
 
   GdkColor fg_color;
   GdkColor bg_color;
-  gcompris_skin_get_gdkcolor("gcompris/helpfg", &fg_color);
-  gcompris_skin_get_gdkcolor("gcompris/helpbg", &bg_color);
+  gc_skin_get_gdkcolor("gcompris/helpfg", &fg_color);
+  gc_skin_get_gdkcolor("gcompris/helpbg", &bg_color);
   gtk_widget_modify_base(view, GTK_STATE_NORMAL, &bg_color);
   gtk_widget_modify_text(view, GTK_STATE_NORMAL, &fg_color);
 
@@ -361,11 +355,11 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
 
   set_content(text_to_display);
   // OK
-  pixmap = gcompris_load_skin_pixmap("button_large.png");
+  pixmap = gc_skin_pixmap_load("button_large.png");
 
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
 				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 5,
 				NULL);
@@ -374,36 +368,38 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
 		     (GtkSignalFunc) item_event_help,
 		     "ok");
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
 			 "text", _("OK"),
-			 "font", gcompris_skin_font_title,
+			 "font", gc_skin_font_title,
 			 "x", (double)  BOARDWIDTH*0.5 + 1.0,
 			 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20 + 1.0,
 			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 "fill_color_rgba", gc_skin_color_shadow,
+			 "weight", PANGO_WEIGHT_HEAVY,
 			 NULL);
   item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("OK"),
-				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.5,
-				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_text_button,
+				 gnome_canvas_text_get_type (),
+				 "text", _("OK"),
+				 "font", gc_skin_font_title,
+				 "x", (double)  BOARDWIDTH*0.5,
+				 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
+				 "anchor", GTK_ANCHOR_CENTER,
+				 "fill_color_rgba", gc_skin_color_text_button,
+				 "weight", PANGO_WEIGHT_HEAVY,
 				NULL);
   gtk_signal_connect(GTK_OBJECT(item2), "event",
 		     (GtkSignalFunc) item_event_help,
 		     "ok");
   gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     item);
   gdk_pixbuf_unref(pixmap);
 
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
 
   help_displayed = TRUE;
 }
@@ -412,25 +408,20 @@ void gcompris_help_start (GcomprisBoard *gcomprisBoard)
  * Remove the displayed help.
  * Do nothing if none is currently being dislayed
  */
-void gcompris_help_stop ()
+void gc_help_stop ()
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
-
-  if(gcomprisBoard!=NULL && help_displayed)
+  if(help_displayed)
     {
-      if(gcomprisBoard->plugin->pause_board != NULL)
+      // Destroy the help box
+      if(rootitem!=NULL)
 	{
-	  // Destroy the help box
-	  if(rootitem!=NULL)
-	    {
-	      gtk_object_destroy(GTK_OBJECT(rootitem));
-	      gcomprisBoard->plugin->pause_board(FALSE);
-	    }
-	  rootitem = NULL;	  
+	  gtk_object_destroy(GTK_OBJECT(rootitem));
+	  rootitem = NULL;
 	}
+      gc_board_pause(FALSE);
     }
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
   help_displayed = FALSE;
 }
 
@@ -444,31 +435,31 @@ void gcompris_help_stop ()
 static void select_item(GnomeCanvasItem *item, GnomeCanvasItem *item_text)
 {
   GdkPixbuf   *pixmap = NULL;
-  
+
   if(item_selected)
     {
-      pixmap = gcompris_load_skin_pixmap("button_up.png");
+      pixmap = gc_skin_pixmap_load("button_up.png");
       /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-      g_object_set_data (G_OBJECT (item_selected), "pixbuf_ref", pixmap);
-      gnome_canvas_item_set(item_selected, 
+      gc_item_focus_free(item_selected, NULL);
+      gnome_canvas_item_set(item_selected,
 			    "pixbuf", pixmap,
 			    NULL);
-      gnome_canvas_item_set(item_selected_text, 
-			    "fill_color_rgba", gcompris_skin_get_color("gcompris/helpunselect"),
+      gnome_canvas_item_set(item_selected_text,
+			    "fill_color_rgba", gc_skin_get_color("gcompris/helpunselect"),
 			    NULL);
 
       gdk_pixbuf_unref(pixmap);
     }
 
-  pixmap = gcompris_load_skin_pixmap("button_up_selected.png");
+  pixmap = gc_skin_pixmap_load("button_up_selected.png");
   /* Warning changing the image needs to update pixbuf_ref for the focus usage */
-  g_object_set_data (G_OBJECT (item), "pixbuf_ref", pixmap);
-  gnome_canvas_item_set(item, 
+  gc_item_focus_free(item, NULL);
+  gnome_canvas_item_set(item,
 			"pixbuf", pixmap,
 			NULL);
   gdk_pixbuf_unref(pixmap);
-  gnome_canvas_item_set(item_text, 
-			"fill_color_rgba", gcompris_skin_get_color("gcompris/helpselect"),
+  gnome_canvas_item_set(item_text,
+			"fill_color_rgba", gc_skin_get_color("gcompris/helpselect"),
 			NULL);
   item_selected = item;
   item_selected_text = item_text;
@@ -486,7 +477,7 @@ static gint
 item_event_help(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -495,42 +486,31 @@ item_event_help(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
     case GDK_BUTTON_PRESS:
       if(!strcmp((char *)data, "ok"))
 	{
-	  gcompris_help_stop();
-	}      
+	  gc_help_stop();
+	}
       else if(!strcmp((char *)data, "prerequisite"))
 	{
 	  select_item(item_prerequisite, item_prerequisite_text);
 	  set_content(prerequisite);
-	}      
+	}
       else if(!strcmp((char *)data, "goal"))
 	{
 	  select_item(item_goal, item_goal_text);
 	  set_content(goal);
-	}      
+	}
       else if(!strcmp((char *)data, "manual"))
 	{
 	  select_item(item_manual, item_manual_text);
 	  set_content(manual);
-	}      
+	}
       else if(!strcmp((char *)data, "credit"))
 	{
 	  select_item(item_credit, item_credit_text);
 	  set_content(credit);
-	}      
+	}
     default:
       break;
     }
   return FALSE;
 
 }
-
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
