@@ -1,6 +1,6 @@
 /* gcompris - images_selector.c
  *
- * Time-stamp: <2006/03/02 00:57:15 bruno>
+ * Time-stamp: <2006/08/21 23:26:43 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -34,11 +34,11 @@
 
 #define SOUNDLISTFILE PACKAGE
 
-static gint		 item_event_images_selector(GnomeCanvasItem *item, 
-						    GdkEvent *event, 
+static gint		 item_event_images_selector(GnomeCanvasItem *item,
+						    GdkEvent *event,
 						    gpointer data);
-static gint		 item_event_imageset_selector(GnomeCanvasItem *item, 
-						      GdkEvent *event, 
+static gint		 item_event_imageset_selector(GnomeCanvasItem *item,
+						      GdkEvent *event,
 						      gpointer data);
 static gint		 item_event_scroll(GnomeCanvasItem *item,
 					   GdkEvent *event,
@@ -46,7 +46,7 @@ static gint		 item_event_scroll(GnomeCanvasItem *item,
 static gboolean		 read_xml_file(gchar *fname);
 static gboolean		 read_dataset_directory(gchar *dataset_dir);
 static void		 display_image(gchar *imagename, GnomeCanvasItem *rootitem);
-static void		 free_stuff (GtkObject *obj, GList *data);
+static void		 free_stuff (GtkObject *obj, GSList *data);
 
 static gboolean		 images_selector_displayed = FALSE;
 
@@ -61,6 +61,8 @@ static GnomeCanvasItem  *image_bg_item;
 
 static ImageSelectorCallBack imageSelectorCallBack = NULL;
 
+static gboolean		 display_in_progress;
+
 /* Represent the limits of the image area */
 #define	DRAWING_AREA_X1	111.0
 #define DRAWING_AREA_Y1	14.0
@@ -89,7 +91,7 @@ static guint		 iy;
 static guint		 isy;
 
 /*
- * Main entry point 
+ * Main entry point
  * ----------------
  *
  */
@@ -98,8 +100,9 @@ static guint		 isy;
  * Do all the images_selector display and register the events
  */
 
-void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
-				     ImageSelectorCallBack iscb)
+void
+gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
+				ImageSelectorCallBack iscb)
 {
 
   GnomeCanvasItem *item, *item2;
@@ -107,37 +110,34 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
   gint		 y = 0;
   gint		 y_start = 0;
   gint		 x_start = 0;
-  gchar		*name = NULL;
+  gchar		*dataseturl = NULL;
 
   GtkWidget	  *w;
 
   if(rootitem)
     return;
 
-  gcompris_bar_hide(TRUE);
+  gc_bar_hide(TRUE);
 
-  if(gcomprisBoard!=NULL)
-    {
-      if(gcomprisBoard->plugin->pause_board != NULL)
-	  gcomprisBoard->plugin->pause_board(TRUE);
-    }
+  gc_board_pause(TRUE);
 
-  name = gcomprisBoard->name;
   imageSelectorCallBack=iscb;
 
   rootitem = \
-    gnome_canvas_item_new (gnome_canvas_root(gcompris_get_canvas()),
+    gnome_canvas_item_new (gnome_canvas_root(gc_get_canvas()),
 			   gnome_canvas_group_get_type (),
 			   "x", (double)0,
 			   "y", (double)0,
 			   NULL);
 
-  pixmap = gcompris_load_skin_pixmap("images_selector_bg.png");
+  images_selector_displayed = TRUE;
+
+  pixmap = gc_skin_pixmap_load("images_selector_bg.png");
   y_start = (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   x_start = (BOARDWIDTH - gdk_pixbuf_get_width(pixmap))/2;
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
+				"pixbuf", pixmap,
 				"x", (double) x_start,
 				"y", (double) y_start,
 				NULL);
@@ -146,7 +146,7 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
 
   y_start += 110;
 
-  pixmap = gcompris_load_skin_pixmap("button_large.png");
+  pixmap = gc_skin_pixmap_load("button_large.png");
 
   /*
    * Create the list scrollbar
@@ -172,7 +172,7 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
 					"y1", (double) 0,
 					"x2", (double) LIST_AREA_X2 - LIST_AREA_X1,
 					"y2", (double) LIST_AREA_Y2 - LIST_AREA_Y1,
-					"fill_color_rgba", gcompris_skin_get_color("gcompris/imageselectbg"),
+					"fill_color_rgba", gc_skin_get_color("gcompris/imageselectbg"),
 					NULL);
 
 
@@ -218,7 +218,7 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
 					"y1", (double) 0,
 					"x2", (double) DRAWING_AREA_X2 - DRAWING_AREA_X1,
 					"y2", (double) DRAWING_AREA_Y2 - DRAWING_AREA_Y1,
-					 "fill_color_rgba", gcompris_skin_get_color("gcompris/imageselectbg"),
+					 "fill_color_rgba", gc_skin_get_color("gcompris/imageselectbg"),
 					NULL);
 
 
@@ -241,41 +241,8 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
 		     GNOME_CANVAS(canvas_image_selector));
 
   /*
-   * OK Button
-   * ---------
+   * DISPLAY IMAGES
    */
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
-				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
-				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 10,
-				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_images_selector,
-		     "/ok/");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
-
-  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("OK"),
-				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.5,
-				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 15,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_text_button,
-				NULL);
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) item_event_images_selector,
-		     "/ok/");
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     item);
-  gdk_pixbuf_unref(pixmap);
-
-  images_selector_displayed = TRUE;
 
   /* Initial image position */
   ix  = 0;
@@ -286,17 +253,81 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
      -> if dataset is a file read it.
      -> if dataset is a directory, read all xml file in it.
   */
+  dataseturl = \
+    gc_file_find_absolute(dataset,
+				    NULL);
 
   /* if the file doesn't exist */
-  if(g_file_test ((dataset), G_FILE_TEST_IS_DIR) )
+  if(g_file_test ((dataseturl), G_FILE_TEST_IS_DIR) )
     {
-      g_warning("dataset %s is a directory. Trying to read xml", dataset);
+      g_warning("dataset %s is a directory. Trying to read xml", dataseturl);
 
-      read_dataset_directory(dataset);
+      read_dataset_directory(dataseturl);
     }
-  else 
-    /* Read the given data set */
-    read_xml_file(dataset);
+  else if(dataseturl)
+    {
+      /* Read the given data set file, local or net */
+      read_xml_file(dataseturl);
+    }
+  else
+    {
+      /* Network code for dataset directory */
+      GSList *filelist = NULL;
+      GSList *i = NULL;
+
+      g_free(dataseturl);
+      dataseturl = g_strconcat("boards/", dataset, NULL);
+
+      filelist = gc_net_dir_read_name(dataseturl, ".xml");
+
+      for (i = filelist; i != NULL; i = g_slist_next (i))
+	{
+	  gchar *url = gc_file_find_absolute(i->data,
+					     NULL);
+	  g_warning("processing dataset=%s\n", (char *)i->data);
+	  read_xml_file(url);
+	  g_free(url);
+	}
+
+      g_slist_free(filelist);
+
+    }
+  g_free(dataseturl);
+
+  /*
+   * OK Button
+   * ---------
+   */
+  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				gnome_canvas_pixbuf_get_type (),
+				"pixbuf", pixmap,
+				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
+				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 10,
+				NULL);
+
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) item_event_images_selector,
+		     "/ok/");
+  gtk_signal_connect(GTK_OBJECT(item), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     NULL);
+
+  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				gnome_canvas_text_get_type (),
+				"text", _("OK"),
+				"font", gc_skin_font_title,
+				"x", (double)  BOARDWIDTH*0.5,
+				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 15,
+				"anchor", GTK_ANCHOR_CENTER,
+				"fill_color_rgba", gc_skin_color_text_button,
+				NULL);
+  gtk_signal_connect(GTK_OBJECT(item2), "event",
+		     (GtkSignalFunc) item_event_images_selector,
+		     "/ok/");
+  gtk_signal_connect(GTK_OBJECT(item2), "event",
+		     (GtkSignalFunc) gc_item_focus_event,
+		     item);
+  gdk_pixbuf_unref(pixmap);
 
 }
 
@@ -304,16 +335,13 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
  * Remove the displayed images_selector.
  * Do nothing if none is currently being dislayed
  */
-void gcompris_images_selector_stop ()
+void gc_selector_images_stop ()
 {
-  GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
+  GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
   if(gcomprisBoard!=NULL && images_selector_displayed)
     {
-      if(gcomprisBoard->plugin->pause_board != NULL)
-	{
-	  gcomprisBoard->plugin->pause_board(FALSE);
-	}
+      gc_board_pause(FALSE);
     }
 
   // Destroy the images_selector box
@@ -321,10 +349,10 @@ void gcompris_images_selector_stop ()
     {
       gtk_object_destroy(GTK_OBJECT(rootitem));
     }
-  rootitem = NULL;	  
+  rootitem = NULL;
   current_root_set = NULL;
 
-  gcompris_bar_hide(FALSE);
+  gc_bar_hide(FALSE);
   images_selector_displayed = FALSE;
 }
 
@@ -335,7 +363,8 @@ void gcompris_images_selector_stop ()
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
 
-static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
+static void
+display_image(gchar *imagename, GnomeCanvasItem *root_item)
 {
 
   GdkPixbuf *pixmap = NULL;
@@ -343,10 +372,10 @@ static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
   double xratio, yratio;
   double iw, ih;
 
-  if (imagename==NULL)
+  if (imagename==NULL || !images_selector_displayed)
     return;
 
-  pixmap = gcompris_load_pixmap(imagename);
+  pixmap = gc_pixmap_load(imagename);
 
   /* Sad, the image is not found */
   if(!pixmap)
@@ -367,7 +396,7 @@ static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
 				"y", (double)iy,
 				"width", (double) gdk_pixbuf_get_width(pixmap)/xratio,
 				"height", (double) gdk_pixbuf_get_height(pixmap)/xratio,
-				"width_set", TRUE, 
+				"width_set", TRUE,
 				"height_set", TRUE,
 				NULL);
   gdk_pixbuf_unref(pixmap);
@@ -376,7 +405,7 @@ static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
 		     (GtkSignalFunc) item_event_images_selector,
 		     imagename);
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   ix+=IMAGE_WIDTH + IMAGE_GAP;
@@ -402,19 +431,19 @@ static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
  * Same as display_image but for the dataset
  * The imagelist contains the list of images to be displayed when this dataset is selected
  */
-static void display_image_set(gchar *imagename, GList *imagelist)
+static void
+display_image_set(gchar *imagename, GSList *imagelist)
 {
-
   GdkPixbuf *pixmap = NULL;
   GnomeCanvasItem *item;
   GnomeCanvasItem *rootitem_set;
   double xratio, yratio;
   double iw, ih;
 
-  if (imagename==NULL)
+  if (imagename==NULL || !images_selector_displayed)
     return;
 
-  pixmap = gcompris_load_pixmap(imagename);
+  pixmap = gc_pixmap_load(imagename);
 
   iw = LIST_IMAGE_WIDTH;
   ih = LIST_IMAGE_HEIGHT;
@@ -431,7 +460,7 @@ static void display_image_set(gchar *imagename, GList *imagelist)
 				"y", (double)isy,
 				"width", (double) gdk_pixbuf_get_width(pixmap)/xratio,
 				"height", (double) gdk_pixbuf_get_height(pixmap)/xratio,
-				"width_set", TRUE, 
+				"width_set", TRUE,
 				"height_set", TRUE,
 				NULL);
   gdk_pixbuf_unref(pixmap);
@@ -441,13 +470,13 @@ static void display_image_set(gchar *imagename, GList *imagelist)
 		     (GtkSignalFunc) item_event_imageset_selector,
 		     imagename);
   gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
+		     (GtkSignalFunc) gc_item_focus_event,
 		     NULL);
 
   isy+=LIST_IMAGE_HEIGHT + IMAGE_GAP;
 
-  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_list_selector), 0, 0, 
-				  LIST_AREA_X2- LIST_AREA_X1, 
+  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_list_selector), 0, 0,
+				  LIST_AREA_X2- LIST_AREA_X1,
 				  isy - IMAGE_GAP);
 
   if(isy>=LIST_AREA_Y2-LIST_AREA_Y1) {
@@ -473,13 +502,13 @@ static void display_image_set(gchar *imagename, GList *imagelist)
 }
 
 static void
-free_stuff (GtkObject *obj, GList *list)
+free_stuff (GtkObject *obj, GSList *list)
 {
-  while (g_list_length(list) > 0) {
-    g_free(g_list_nth_data(list,0));
-    list = g_list_remove(list, g_list_nth_data(list,0));
+  while (g_slist_length(list) > 0) {
+    g_free(g_slist_nth_data(list,0));
+    list = g_slist_remove(list, g_slist_nth_data(list,0));
   }
-  g_list_free(list);
+  g_slist_free(list);
 }
 
 
@@ -487,11 +516,14 @@ free_stuff (GtkObject *obj, GList *list)
 static gint
 item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
-  GList *image_list;
+  GSList *image_list;
   GnomeCanvasItem *rootitem_set;
   guint imageset_done;
 
-  switch (event->type) 
+  if(display_in_progress)
+    return TRUE;
+
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -501,8 +533,10 @@ item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer da
 	{
 	  guint last_iy;
 
+	  display_in_progress = TRUE;
+
 	  /* We must display the list of images for this set */
-	  image_list = (GList *)g_object_get_data (G_OBJECT (item), "imagelist");
+	  image_list = (GSList *)g_object_get_data (G_OBJECT (item), "imagelist");
 	  g_return_val_if_fail (image_list != NULL, FALSE);
 
 	  /* We must display the list of images for this set */
@@ -523,14 +557,14 @@ item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer da
 	    iy_calc = IMAGE_HEIGHT + IMAGE_GAP;
 	    g_object_set_data (G_OBJECT (rootitem_set), "iy", GINT_TO_POINTER (iy_calc));
 
-	    g_list_foreach (image_list, (GFunc) display_image, rootitem_set);
+	    g_slist_foreach (image_list, (GFunc) display_image, rootitem_set);
 	    g_object_set_data (G_OBJECT (item), "imageset_done", GINT_TO_POINTER (1));
 	  }
 
 	  /* Set the image scrollbar back to its max position */
 	  last_iy = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (rootitem_set), "iy"));
-	  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_image_selector), 0, 0, 
-					  DRAWING_AREA_X2- DRAWING_AREA_X1, 
+	  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_image_selector), 0, 0,
+					  DRAWING_AREA_X2- DRAWING_AREA_X1,
 					  last_iy - IMAGE_GAP);
 	  if(last_iy>=DRAWING_AREA_Y2-DRAWING_AREA_Y1) {
 	    gnome_canvas_item_set(image_bg_item,
@@ -544,6 +578,8 @@ item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer da
 	  /* Back to the initial image position */
 	  ix  = 0;
 	  iy  = 0;
+
+	  display_in_progress = FALSE;
 	}
     default:
       break;
@@ -557,7 +593,10 @@ static gint
 item_event_images_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
 
-  switch (event->type) 
+  if(display_in_progress)
+    return TRUE;
+
+  switch (event->type)
     {
     case GDK_ENTER_NOTIFY:
       break;
@@ -566,14 +605,14 @@ item_event_images_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data
     case GDK_BUTTON_PRESS:
       if(!strcmp((char *)data, "/ok/"))
 	{
-	  gcompris_images_selector_stop();
+	  gc_selector_images_stop();
 	}
       else
 	{
 	  if(imageSelectorCallBack!=NULL)
 	    imageSelectorCallBack(data);
 
-	  gcompris_images_selector_stop();
+	  gc_selector_images_stop();
 	}
     default:
       break;
@@ -590,7 +629,7 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
   if(!rootitem)
     return FALSE;
 
-  switch (event->type) 
+  switch (event->type)
     {
     case GDK_SCROLL:
       gnome_canvas_get_scroll_offsets (canvas, &x, &y);
@@ -611,17 +650,17 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
  * --------------
  */
 
-void
+static void
 parseImage (xmlDocPtr doc, xmlNodePtr cur) {
-  gchar *imageSetName = NULL;
-  gchar *filename;
-  gchar	*pathname = NULL;
-  gchar *absolutepath;
-  GList	*imageList = NULL;	/* List of Images */
+  GcomprisProperties *properties = gc_prop_get();
+  gchar  *imageSetName = NULL;
+  gchar  *filename;
+  gchar	 *pathname = NULL;
+  gchar  *absolutepath;
+  GSList *imageList = NULL;	/* List of Images */
   gboolean havePathName = FALSE;
-  gchar *type = NULL;
-  GDir *imageset_directory;
-  GError **error = NULL;
+  gchar  *type = NULL;
+  GDir   *imageset_directory;
 
   /* get the filename of this ImageSet */
   imageSetName = (gchar *)xmlGetProp(cur, BAD_CAST "filename");
@@ -652,23 +691,17 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
   /*               -> and else for PACKAGE_DATA_DIR/imagesetname */
   if (havePathName) {
     if (!g_path_is_absolute (imageSetName)){
-      absolutepath = g_strdup_printf("%s/%s",pathname,imageSetName);
-      if(!g_file_test ((absolutepath), G_FILE_TEST_EXISTS) ){
-	g_free(absolutepath);
-	absolutepath = g_strdup_printf("%s/%s",PACKAGE_DATA_DIR,imageSetName);
-      }
-      else 
-	imageSetName = g_strdup(absolutepath);
+      absolutepath = gc_file_find_absolute(imageSetName, NULL);
     }
     else
       absolutepath = g_strdup(imageSetName);
   }
   else
-    absolutepath = g_strdup_printf("%s/%s",PACKAGE_DATA_DIR,imageSetName);
-  
-  if(!g_file_test ((absolutepath), G_FILE_TEST_EXISTS) )
+    absolutepath = gc_file_find_absolute(imageSetName, NULL);
+
+  if(!absolutepath)
     {
-      g_warning("In ImageSet %s, an image is not found. Skipping ImageSet...", absolutepath);
+      g_warning("In ImageSet %s, an image is not found. Skipping ImageSet...", imageSetName);
       return;
     }
 
@@ -683,7 +716,7 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
 	if (havePathName){
 	  filename = g_strdup_printf("%s/%s",pathname,filename);
 	}
-	imageList = g_list_append (imageList, filename);
+	imageList = g_slist_prepend (imageList, filename);
       }
       cur = cur->next;
     }
@@ -695,7 +728,7 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
 
     if (!g_file_test ((pathname), G_FILE_TEST_IS_DIR)){
       char *tmpdir;
-      tmpdir = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, pathname);
+      tmpdir = g_strdup_printf("%s/%s", properties->package_data_dir, pathname);
       g_free(pathname);
       pathname = tmpdir;
       if (!g_file_test ((pathname), G_FILE_TEST_IS_DIR)){
@@ -703,10 +736,10 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
         return;
       }
     }
-    imageset_directory = g_dir_open (pathname, 0, error);    
+    imageset_directory = g_dir_open (pathname, 0, NULL);
     const gchar * onefile;
     while ((onefile = g_dir_read_name(imageset_directory))){
-      if ((g_ascii_strcasecmp (type,"lsdir") != 0) && 
+      if ((g_ascii_strcasecmp (type,"lsdir") != 0) &&
 	  (!g_str_has_suffix (onefile, type))){
 	continue;
       }
@@ -714,15 +747,28 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
       if (!g_file_test ((filename), G_FILE_TEST_IS_REGULAR)){
 	continue;
       }
-      imageList = g_list_append (imageList, filename);
+
+      {
+	/* Add a % before a % to avoid it being used as a format arg */
+	gchar **tmp;
+	gchar *filename2;
+	if((tmp = g_strsplit(filename, "%", -1)))
+	  {
+	    filename2 = g_strjoinv("%%", tmp);
+	    g_strfreev(tmp);
+	    g_free(filename);
+	    filename = filename2;
+	  }
+      }
+      imageList = g_slist_prepend (imageList, filename);
     }
     g_dir_close(imageset_directory);
   }
 
   /* do not display if there is nothing to display */
-  if (imageList != NULL) /* g_list is not empty */
+  if (imageList != NULL) /* g_slist is not empty */
     display_image_set(imageSetName, imageList);
-  
+
   g_free(absolutepath);
   if(pathname)
     g_free(pathname);
@@ -736,7 +782,7 @@ static void
 parse_doc(xmlDocPtr doc) {
   xmlNodePtr cur;
 
-  cur = xmlDocGetRootElement(doc);	
+  cur = xmlDocGetRootElement(doc);
   if (cur == NULL) {
     fprintf(stderr,"empty document\n");
     xmlFreeDoc(doc);
@@ -748,38 +794,34 @@ parse_doc(xmlDocPtr doc) {
     if ((!xmlStrcmp(cur->name, (const xmlChar *)"ImageSet"))){
       parseImage (doc, cur);
     }
-    
+
     cur = cur->next;
   }
-	
+
   return;
 }
 
 
 /* read an xml file into our memory structures and update our view,
-   dump any old data we have in memory if we can load a new set */
+ * dump any old data we have in memory if we can load a new set
+ *
+ * \param fname is an absolute file name
+ *
+ */
 static gboolean
 read_xml_file(gchar *fname)
 {
   /* pointer to the new doc */
   xmlDocPtr doc;
 
-  g_return_val_if_fail(fname!=NULL,FALSE);
+  g_return_val_if_fail(fname!=NULL, FALSE);
 
-  /* if the file doesn't exist */
-  if(!g_file_test ((fname), G_FILE_TEST_EXISTS)) 
-    {
-      g_warning("Couldn't find file %s !", fname);
-      return FALSE;
-    }
-
-  /* parse the new file and put the result into newdoc */
-  doc = xmlParseFile(fname);
+  doc = gc_net_load_xml(fname);
 
   /* in case something went wrong */
   if(!doc)
     return FALSE;
-  
+
   if(/* if there is no root element */
      !doc->children ||
      /* if it doesn't have a name */
@@ -789,40 +831,47 @@ read_xml_file(gchar *fname)
     xmlFreeDoc(doc);
     return FALSE;
   }
-  
+
   /* parse our document and replace old data */
   parse_doc(doc);
-  
+
   xmlFreeDoc(doc);
-  
+
   return TRUE;
 }
 
 
-/* read an xml file into our memory structures and update our view,
-   dump any old data we have in memory if we can load a new set */
+/** read an xml file into our memory structures and update our view,
+ *   dump any old data we have in memory if we can load a new set
+ *
+ * \return TRUE is the parsing occurs, FALSE instead
+ *
+ */
 static gboolean
 read_dataset_directory(gchar *dataset_dir)
 {
-
-
-  GError **error = NULL;
-  GDir *dataset_directory = g_dir_open (dataset_dir, 0, error);
+  GDir *dataset_directory = g_dir_open (dataset_dir, 0, NULL);
   const gchar *fname;
   gchar *absolute_fname;
 
+  if(!dataset_directory)
+    return FALSE;
+
   while ((fname = g_dir_read_name(dataset_directory))) {
     /* skip files without ".xml" */
     if (!g_str_has_suffix (fname,".xml")){
-      printf("skipping file not in .xml : %s\n", fname);
+      g_warning("skipping file not in .xml : %s", fname);
       continue;
     }
 
-    absolute_fname = g_strdup_printf("%s/%s",dataset_dir,fname);
-    printf("Reading dataset file %s\n",absolute_fname);
-   
-    if (!g_file_test ((absolute_fname), G_FILE_TEST_IS_REGULAR))
+    absolute_fname = g_strdup_printf("%s/%s", dataset_dir, fname);
+    g_warning("Reading dataset file %s", absolute_fname);
+
+    if (!g_file_test ((absolute_fname), G_FILE_TEST_EXISTS))
+    {
+      g_free(absolute_fname);
       continue;
+    }
 
     /* parse the new file and put the result into newdoc */
 
@@ -833,8 +882,11 @@ read_dataset_directory(gchar *dataset_dir)
 
     /* in case something went wrong */
     if(!doc)
+    {
+      g_free(absolute_fname);
       continue;
-  
+    }
+    
     if(/* if there is no root element */
        !doc->children ||
        /* if it doesn't have a name */
@@ -842,13 +894,15 @@ read_dataset_directory(gchar *dataset_dir)
        /* if it isn't the good node */
        g_strcasecmp((gchar *)doc->children->name, "ImageSetRoot")!=0) {
       xmlFreeDoc(doc);
+      g_free(absolute_fname);
       continue;
     }
-  
+
     /* parse our document and replace old data */
-    printf("Parsing dataset : %s \n",absolute_fname);
+    g_warning("Parsing dataset : %s \n", absolute_fname);
+    g_free(absolute_fname);
     parse_doc(doc);
-    
+
     xmlFreeDoc(doc);
   }
 
@@ -856,13 +910,3 @@ read_dataset_directory(gchar *dataset_dir)
 
   return TRUE;
 }
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
