@@ -1,4 +1,4 @@
-/* gcompris - reporting.c
+/* gcompris - log.c
  *
  * Time-stamp: <2003/10/29 18:55:55 bcoudoin>
  *
@@ -32,19 +32,14 @@
  */
 
 #include <unistd.h>
-#include <stdio.h>
+#include <glib/gstdio.h>
 #include <time.h>
 #include <string.h>
 
 #include <gcompris.h>
 #include "profile.h"
- 
-#define KEYLOG_MAX 256
 
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
+#define KEYLOG_MAX 256
 
 #ifdef WIN32
 static gchar hostname[256]="unknown";
@@ -61,11 +56,11 @@ static time_t		 start_time_key;
 /* By default, we use local time, not UTC */
 #define USE_UTC 0
 
-/** gcompris_log_start 
+/** gc_log_start
  * \param GcomprisBoard *gcomprisBoard: the board for which the event happen
  *
  */
-void gcompris_log_start (GcomprisBoard *gcomprisBoard) {
+void gc_log_start (GcomprisBoard *gcomprisBoard) {
 
   gcomprisBoard_set = gcomprisBoard;
   start_time     = time(NULL);
@@ -79,7 +74,7 @@ void gcompris_log_start (GcomprisBoard *gcomprisBoard) {
   keylog[0]   = '\0';
 }
 
-/** gcompris_log_set_comment
+/** gc_log_set_comment
  * \param GcomprisBoard *gcomprisBoard: the board for which the event happen
  * \param expected: string describing what was expected. This string is copied.
  * \param got: string describing what we got from the user. This string is copied.
@@ -87,9 +82,9 @@ void gcompris_log_start (GcomprisBoard *gcomprisBoard) {
  * Note: Do not include the charater ';' in expected or got
  *
  */
-void gcompris_log_set_comment (GcomprisBoard *gcomprisBoard, gchar *expected, gchar *got) {
+void gc_log_set_comment (GcomprisBoard *gcomprisBoard, gchar *expected, gchar *got) {
 
-  printf("gcompris_log_set_comment %s %s\n", expected, got);
+  printf("gc_log_set_comment %s %s\n", expected, got);
   if(gcomprisBoard_set != gcomprisBoard) {
     return;
   }
@@ -102,18 +97,18 @@ void gcompris_log_set_comment (GcomprisBoard *gcomprisBoard, gchar *expected, gc
 
   /* If We already had a comment, log the previous one */
   if(comment_set[0] != '\0') {
-    gcompris_log_end(gcomprisBoard, GCOMPRIS_LOG_STATUS_FAILED);
+    gc_log_end(gcomprisBoard, GCOMPRIS_LOG_STATUS_FAILED);
   }
 
   comment_set = g_strdup_printf("%s;%s", expected, got);
 }
 
-/** gcompris_log_key
+/** gc_log_key
  * \param GcomprisBoard *gcomprisBoard: the board for which the event happen
  * \param key: a keyval as defined by gtk
  *
  */
-void gcompris_log_set_key (GcomprisBoard *gcomprisBoard, guint keyval) {
+void gc_log_set_key (GcomprisBoard *gcomprisBoard, guint keyval) {
   char utf8char[6];
   int i;
   /* get the current time from the Unix kernel */
@@ -137,19 +132,19 @@ void gcompris_log_set_key (GcomprisBoard *gcomprisBoard, guint keyval) {
 
   if(strlen(keylog)<(KEYLOG_MAX-10)) {
     strcat(keylog, utf8char);
-    printf(" 1 gcompris_log_set_key %s\n", keylog);
+    printf(" 1 gc_log_set_key %s\n", keylog);
     sprintf(keylog+strlen(keylog), "/%d:", (guint)duration);
-    printf(" 2 gcompris_log_set_key %s\n", keylog);
+    printf(" 2 gc_log_set_key %s\n", keylog);
   }
 
 }
 
-/** gcompris_log_end
+/** gc_log_end
  * \param GcomprisBoard *gcomprisBoard: the board for which the event happen
  * \param status: a string representing the status like PASSED, FAILED.
  *
  */
-void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status) {
+void gc_log_end (GcomprisBoard *gcomprisBoard, gchar *status) {
   FILE *flog;
   gchar *file;
 
@@ -159,15 +154,15 @@ void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status) {
   char *fmt = "%F %T";
 
   char buf[256];
-   
+
   /* get the current time from the Unix kernel */
   time_t end_time = time(NULL);
   double duration = difftime(end_time,start_time);
 
   struct tm *tp;
 
-  GcomprisUser *gcomprisUser = gcompris_get_current_user();
-  char *username = g_get_user_name();
+  GcomprisUser *gcomprisUser = gc_profile_get_current_user();
+  const char *username = g_get_user_name();
 
   if(gcomprisBoard_set != gcomprisBoard)
     return;
@@ -189,28 +184,33 @@ void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status) {
     file = g_strconcat(g_get_home_dir(), "/.gcompris/gcompris.log", NULL);
   } else {
     /* On WIN98, No home dir */
-    file = g_strdup("gcompris/gcompris.log");
+    file = g_strdup("gcompris.log");
   }
 
-  flog = fopen(file,"a");
+  flog = g_fopen(file,"a");
 
   /* date,computer,user,board,level,sublevel,status, duration,comment */
-  fprintf(flog, "%s;%s;%s;gcompris;%s;%d;%d;%s;%d;%s;%s\n", buf, hostname, username,
-	  gcomprisBoard->name, 
-	  gcomprisBoard->level, gcomprisBoard->sublevel,
-	  status,
-	  (guint)duration,
-	  comment_set,
-	  keylog);
-  printf("%s;%s;%s;gcompris;%s;%d;%d;%s;%d;%s;%s\n", buf, hostname, username,
-	 gcomprisBoard->name, 
-	 gcomprisBoard->level, gcomprisBoard->sublevel,
-	 status,
-	 (guint)duration,
-	 comment_set,
-	 keylog);
+  if(flog)
+    fprintf(flog, "%s;%s;%s;gcompris;%s;%d;%d;%s;%d;%s;%s\n", buf, hostname, username,
+	    gcomprisBoard->name,
+	    gcomprisBoard->level, gcomprisBoard->sublevel,
+	    status,
+	    (guint)duration,
+	    comment_set,
+	    keylog);
+  else
+    g_warning("Failed to save the log in file '%s'", file);
 
-  fclose(flog);
+  g_warning("%s;%s;%s;gcompris;%s;%d;%d;%s;%d;%s;%s\n", buf, hostname, username,
+	    gcomprisBoard->name,
+	    gcomprisBoard->level, gcomprisBoard->sublevel,
+	    status,
+	    (guint)duration,
+	    comment_set,
+	    keylog);
+
+  if(flog)
+    fclose(flog);
 
   g_free(file);
 }
