@@ -1,6 +1,6 @@
 /* gcompris - profile.c
  *
- * Time-stamp: <2006/03/29 01:33:14 bruno>
+ * Time-stamp: <2006/08/21 23:26:49 bruno>
  *
  * Copyright (C) 2005 Bruno Coudoin
  *
@@ -26,15 +26,15 @@
 /** Return the current profile or NULL if sqlite not activated
  *
  */
-GcomprisProfile
-*gcompris_get_current_profile()
+GcomprisProfile*
+gc_profile_get_current()
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   if (properties->profile)
     return properties->profile;
 
-  properties->profile = gcompris_db_get_profile();
+  properties->profile = gc_db_get_profile();
 
   return properties->profile;
 
@@ -42,9 +42,9 @@ GcomprisProfile
 
 
 void
-*gcompris_set_current_user(GcomprisUser *user)
+gc_profile_set_current_user(GcomprisUser *user)
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisProperties	*properties = gc_prop_get();
 
   if (user)
     properties->logged_user = user;
@@ -52,13 +52,13 @@ void
     g_warning("No user, getting one from system.");
     GcomprisUser *sys_user = g_malloc0(sizeof(GcomprisUser));
 
-    gchar *user_name = g_get_user_name ();
+    const gchar *user_name = g_get_user_name ();
     if (user_name)
       sys_user->login = g_strdup(user_name);
     else
       sys_user->login = g_strdup("nobody");
 
-    gchar *last_name = g_get_real_name ();
+    const gchar *last_name = g_get_real_name ();
     if (last_name)
       sys_user->lastname = g_strdup(last_name);
     else
@@ -76,23 +76,37 @@ void
   gchar *session_id_str = g_strdup_printf("%s%ld%ld", (properties->logged_user)->login, now.tv_sec, now.tv_usec);
 
   (properties->logged_user)->session_id = g_str_hash((gconstpointer) session_id_str);
-   
+  g_free(session_id_str);
+
 }
 
-
-GcomprisUser            *gcompris_get_current_user()
+void gc_profile_destroy(GcomprisProfile*prof)
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
+  if(!prof)
+    return;
+
+  g_free(prof->name);
+  g_free(prof->directory);
+  g_free(prof->description);
+  g_free(prof);
+}
+
+void gc_user_destroy(GcomprisUser*user)
+{
+  if(!user)
+    return;
+
+  g_free(user->login);
+  g_free(user->lastname);
+  g_free(user->firstname);
+  g_free(user->birthdate);
+  g_free(user);
+}
+
+GcomprisUser*
+gc_profile_get_current_user()
+{
+  GcomprisProperties	*properties = gc_prop_get();
   return properties->logged_user;
 }
 
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
-
