@@ -1,6 +1,6 @@
 /* gcompris - properties.c
  *
- * Time-stamp: <2006/03/02 01:08:31 bruno>
+ * Time-stamp: <2006/08/21 23:26:56 bruno>
  *
  * Copyright (C) 2000,2003 Bruno Coudoin
  *
@@ -19,11 +19,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <glib/gstdio.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <string.h>
 
 #include "gcompris.h"
@@ -31,11 +28,6 @@
 /* This should be detected in the configure for good portability */
 #define HAVE_SETENV 1
 
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
-
 #ifdef WIN32
 # define WIN32_LEAN_AND_MEAN
 # include <windows.h>
@@ -47,7 +39,8 @@ static gchar *config_file = NULL;
  * return 1 if parsing OK, 0 otherwise
  * the return value is returned in retval
  */
-guint scan_get_int(GScanner *scanner, int *retval) {
+static guint
+scan_get_int(GScanner *scanner, int *retval) {
   GTokenType token = g_scanner_get_next_token (scanner);
   token = g_scanner_get_next_token (scanner);
   if(token == G_TOKEN_INT) {
@@ -62,7 +55,8 @@ guint scan_get_int(GScanner *scanner, int *retval) {
 /*
  * return String if parsing OK, NULL otherwise
  */
-gchar *scan_get_string(GScanner *scanner) {
+static gchar *
+scan_get_string(GScanner *scanner) {
   GTokenType token = g_scanner_get_next_token (scanner);
   token = g_scanner_get_next_token (scanner);
   if(token == G_TOKEN_STRING) {
@@ -73,36 +67,13 @@ gchar *scan_get_string(GScanner *scanner) {
   return NULL;
 }
 
-/*
- * create the root dir if needed
- *
- * return 0 if OK, -1 if ERROR
- */
-int
-create_rootdir (gchar *rootdir)
-{
-
-  /* Case where ~/.gcompris already exist as a file. We remove it */
-  if(g_file_test(rootdir, G_FILE_TEST_IS_REGULAR)) {
-    unlink(rootdir);
-  }
-
-  if(g_file_test(rootdir, G_FILE_TEST_IS_DIR)) {
-    return 0;
-  }
-
-#if defined WIN32
-  return(mkdir(rootdir));
-#else
-  return(mkdir(rootdir, 0755));
-#endif
-}
 
 /* get the gcompris user directory name */
 /* Architecture dependant: "gcompris" in Win9x, */
 /* "/.gcompris" in POSIX compliant systems */
 
-gchar *get_gcompris_user_root_directory ()
+gchar *
+gc_prop_user_root_directory_get ()
 {
   G_CONST_RETURN gchar *home_dir = g_get_home_dir();
 
@@ -112,23 +83,25 @@ gchar *get_gcompris_user_root_directory ()
     return g_strconcat(home_dir, "/.gcompris", NULL);
 }
 
-/** return the name of the configuration file used
+/** return the name of the configuration file used.
  *  the name has the full path and is platform dependant
  *  must not be freed by the caller.
- * 
+ *
  */
-gchar *get_gcompris_conf_name()
+gchar *
+gc_prop_config_file_get()
 {
+  gchar *dir;
   if(config_file)
     return(config_file);
-
-  /* Was never called, mus calculate it */
+  dir = gc_prop_user_root_directory_get();
+  /* Was never called, must calculate it */
   if (g_get_home_dir()==NULL) {
-    config_file = g_strconcat(get_gcompris_user_root_directory(), "/gcompris.cfg", NULL);
+    config_file = g_strconcat(dir, "/gcompris.cfg", NULL);
   } else {
-    config_file = g_strconcat(get_gcompris_user_root_directory(), "/gcompris.conf", NULL);
+    config_file = g_strconcat(dir, "/gcompris.conf", NULL);
   }
-
+  g_free(dir);
    return(config_file);
 }
 
@@ -136,43 +109,46 @@ gchar *get_gcompris_conf_name()
 #define DEFAULT_DATABASE "gcompris_sqlite.db"
 #define PROFILES_ROOT "profiles"
 
-gchar *get_default_database_name (gchar *shared_dir)
+gchar *
+gc_prop_default_database_name_get (gchar *shared_dir)
 {
   gchar *dir_base = g_strconcat( shared_dir, "/",  PROFILES_ROOT, NULL);
-  create_rootdir(dir_base);
+  gc_util_create_rootdir(dir_base);
   g_free(dir_base);
   return g_strconcat( shared_dir, "/",  PROFILES_ROOT, "/",  DEFAULT_DATABASE, NULL);
-  
+
 }
 
-GcomprisProperties *gcompris_properties_new ()
+GcomprisProperties *
+gc_prop_new ()
 {
   GcomprisProperties *tmp;
-  char          *config_file = get_gcompris_conf_name();
+  char          *config_file = gc_prop_config_file_get();
   GScanner      *scanner;
-  int		 filefd;
+  gchar		*content;
+  gsize		length;
   gchar         *full_rootdir;
   const gchar   *locale;
-  gchar         *gcompris_user_dir;
+  gchar         *user_dir;
 
   tmp = (GcomprisProperties *) malloc (sizeof (GcomprisProperties));
   tmp->music		 = 1;
   tmp->fx		 = 1;
   tmp->screensize	 = 1;
   tmp->fullscreen	 = 1;
-  tmp->noxrandr		 = FALSE;
+  tmp->noxf86vm		 = FALSE;
   tmp->timer		 = 1;
-  tmp->skin		 = "babytoy";
-  tmp->key		 = "default";
+  tmp->skin		 = g_strdup("babytoy");
+  tmp->key		 = g_strdup("default");
   tmp->locale            = NULL;
   tmp->difficulty_max    = 0;
   tmp->filter_style      = GCOMPRIS_FILTER_NONE;	/* No difficulty filter by default */
   tmp->difficulty_filter = 1;				/* No difficulty filter by default */
   tmp->disable_quit      = 0;				/* Used to remove the quit button from the bar. Use it for kiosk mode */
   tmp->disable_config    = 0;				/* Used to remove the config button from the bar. Use it for kiosk mode */
+  tmp->display_resource  = 0;
   tmp->root_menu         = "/";
   tmp->local_directory   = NULL;
-  tmp->package_data_dir  = PACKAGE_DATA_DIR;
   tmp->profile           = NULL;
   tmp->logged_user       = NULL;
 
@@ -181,51 +157,63 @@ GcomprisProperties *gcompris_properties_new ()
   tmp->experimental      = FALSE;
   tmp->menu_position     = NULL;
 
-  gcompris_user_dir = get_gcompris_user_root_directory() ;
-  create_rootdir( gcompris_user_dir );
+  tmp->server            = NULL;
 
-  tmp->shared_dir        = g_strconcat(gcompris_user_dir, "/shared", NULL);
-  create_rootdir( tmp->shared_dir );
+  tmp->package_data_dir           = NULL;
+  tmp->package_locale_dir         = NULL;
+  tmp->package_plugin_dir         = NULL;
+  tmp->package_python_plugin_dir  = NULL;
+  tmp->system_icon_dir            = NULL;
+  tmp->cache_dir                  = NULL;
 
-  tmp->users_dir        = g_strconcat(gcompris_user_dir, "/users", NULL);
-  create_rootdir( tmp->users_dir );
+  user_dir = gc_prop_user_root_directory_get() ;
+  gc_util_create_rootdir( user_dir );
 
-  tmp->user_data_dir	= g_strconcat(gcompris_user_dir, "/Plugins/boards", NULL);
-  create_rootdir( tmp->user_data_dir );
+  tmp->shared_dir        = g_strconcat(user_dir, "/shared", NULL);
+  gc_util_create_rootdir( tmp->shared_dir );
+
+  tmp->users_dir        = g_strconcat(user_dir, "/users", NULL);
+  gc_util_create_rootdir( tmp->users_dir );
+
+  tmp->user_data_dir	= g_strconcat(user_dir, "/Plugins/boards", NULL);
+  gc_util_create_rootdir( tmp->user_data_dir );
 
   /* Needs to be set after command line parsing */
   tmp->database          = NULL;
 
-  full_rootdir = g_strconcat(gcompris_user_dir, "/user_data", NULL);
-  create_rootdir(full_rootdir);
+  full_rootdir = g_strconcat(user_dir, "/user_data", NULL);
+  gc_util_create_rootdir(full_rootdir);
   g_free(full_rootdir);
 
-  full_rootdir = g_strconcat(gcompris_user_dir, "/user_data/images", NULL);
-  create_rootdir(full_rootdir);
+  full_rootdir = g_strconcat(user_dir, "/user_data/images", NULL);
+  gc_util_create_rootdir(full_rootdir);
   g_free(full_rootdir);
 
-  full_rootdir = g_strconcat(gcompris_user_dir, "/", PROFILES_ROOT, NULL);
-  create_rootdir(full_rootdir);
+  full_rootdir = g_strconcat(user_dir, "/", PROFILES_ROOT, NULL);
+  gc_util_create_rootdir(full_rootdir);
   g_free(full_rootdir);
 
+  g_free(user_dir);
+
   g_warning("config_file %s", config_file);
 
-  filefd = open(config_file, O_RDONLY);
-
-  if(filefd > 0) {
+  if(g_file_get_contents(config_file,
+			 &content,
+			 &length,
+			 NULL)) {
 
     /* create a new scanner */
     scanner = g_scanner_new(NULL);
 
     /* set up the scanner to read from the file */
-    g_scanner_input_file(scanner, filefd);
+    g_scanner_input_text(scanner, content, length);
 
     /* while the next token is something else other than end of file */
     while(g_scanner_peek_next_token(scanner) != G_TOKEN_EOF) {
 
       /* get the next token */
-      GTokenType token = g_scanner_get_next_token(scanner);
-      switch(token) {
+      GTokenType tokent = g_scanner_get_next_token(scanner);
+      switch(tokent) {
       case G_TOKEN_IDENTIFIER: {
 	gchar *token;
 	/* if we have a symbol, check it's ours */
@@ -244,8 +232,8 @@ GcomprisProperties *gcompris_properties_new ()
 	} else if(!strcmp(value.v_identifier, "fullscreen")) {
 	  if(!scan_get_int(scanner, &tmp->fullscreen))
 	    g_warning("Config file parsing error on token %s", token);
-	} else if(!strcmp(value.v_identifier, "noxrandr")) {
-	  if(!scan_get_int(scanner, &tmp->noxrandr))
+	} else if(!strcmp(value.v_identifier, "noxf86vm")) {
+	  if(!scan_get_int(scanner, &tmp->noxf86vm))
 	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "timer")) {
 	  if(!scan_get_int(scanner, &tmp->timer))
@@ -263,6 +251,7 @@ GcomprisProperties *gcompris_properties_new ()
 	  if(!scan_get_int(scanner, &tmp->filter_style))
 	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "skin")) {
+        g_free(tmp->skin);
 	  tmp->skin = scan_get_string(scanner);
 	  if(!tmp->skin)
 	    g_warning("Config file parsing error on token %s", token);
@@ -271,6 +260,7 @@ GcomprisProperties *gcompris_properties_new ()
 	  if(!tmp->locale)
 	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "key")) {
+      g_free(tmp->key);
 	  tmp->key = scan_get_string(scanner);
 	  if(!tmp->key)
 	    g_warning("Config file parsing error on token %s", token);
@@ -280,6 +270,7 @@ GcomprisProperties *gcompris_properties_new ()
 	  if(!tmp->database)
 	    g_warning("Config file parsing error on token %s", token);
 	}
+	g_free(token);
 	break;
       }
       default:
@@ -289,14 +280,9 @@ GcomprisProperties *gcompris_properties_new ()
 
     /* destroy the scanner */
     g_scanner_destroy(scanner);
-
-    close(filefd);
-
+    g_free(content);
   }
 
-  /* By default audio is said to work until libao fails to load it */
-  tmp->audio_works	= TRUE;
-
   /*
    * Warning, gcompris need a proper locale prefix to find suitable dataset
    * Some system use LOCALE 'C' for english. We have to set it explicitly
@@ -315,32 +301,51 @@ GcomprisProperties *gcompris_properties_new ()
     if (locale != NULL && !strcmp(locale, "C"))
       {
 	tmp->locale		= "en_US.UTF-8";
-      } 
+      }
 #endif
   }
 
   if(!tmp->locale) {
     /* No user specified locale = '' */
-    tmp->locale		= "";
+    tmp->locale		= strdup("");
   }
 
   return (tmp);
 }
 
-void gcompris_properties_destroy (GcomprisProperties *props)
+void
+gc_prop_destroy (GcomprisProperties *props)
 {
-  if(props->locale!=NULL)
-    g_free(props->locale);
-
-  free (props);
+  if(!props)
+    return;
+  g_free(props->user_data_dir);
+  g_free(props->package_data_dir);
+  g_free(props->package_locale_dir);
+  g_free(props->package_plugin_dir);
+  g_free(props->package_python_plugin_dir);
+  g_free(props->system_icon_dir);
+  g_free(props->cache_dir);
+  g_free(props->locale);
+  g_free(props->skin);
+  g_free(props->key);
+  gc_profile_destroy(props->profile);
+  gc_user_destroy(props->logged_user);
+  g_free(props->database);
+  g_free(props->shared_dir);
+  g_free(props->users_dir);
+  g_free(props->menu_position);
+  g_free(props->server);
+  g_free (props);
+  g_warning("properties free");
 }
 
-void gcompris_properties_save (GcomprisProperties *props)
+void
+gc_prop_save (GcomprisProperties *props)
 {
-  char *config_file = get_gcompris_conf_name();
+  char *config_file = gc_prop_config_file_get();
   FILE *filefd;
 
-  filefd = fopen(config_file, "w+");
+  filefd = g_fopen(config_file, "w+");
 
   if(!filefd) {
       g_warning("cannot open '%s', configuration file not saved\n",(char *) config_file);
@@ -362,10 +367,51 @@ void gcompris_properties_save (GcomprisProperties *props)
   fclose(filefd);
 }
 
+gchar*
+gc_prop_user_dirname_get(GcomprisUser *user)
+{
+  GcomprisProperties	*properties = gc_prop_get ();
+
+  gchar *user_dirname = g_strconcat (properties->users_dir,
+				     "/",
+				     user->login,
+				     NULL);
+
+  gc_util_create_rootdir(user_dirname);
+
+  return user_dirname;
+}
+
+gchar*
+gc_prop_current_user_dirname_get()
+{
+  return gc_prop_user_dirname_get(gc_profile_get_current_user());
+}
+
+gchar*
+gc_prop_board_dirname_get(GcomprisBoard *board)
+{
+  GcomprisProperties	*properties = gc_prop_get ();
+
+  gchar *board_main = g_strconcat (properties->shared_dir, "/boards", NULL);
+  gc_util_create_rootdir(board_main);
+
+  gchar *board_dirname = g_strconcat (board_main, "/", board->name, NULL);
+  gc_util_create_rootdir(board_dirname);
+
+  g_free(board_main);
+  return board_dirname;
+}
+
+gchar*
+gc_prop_current_board_dirname_get()
+{
+  return gc_prop_board_dirname_get(gc_board_get_current());
+}
 
 
 int
-my_setenv (const char * name, const char * value) {
+gc_setenv (const char * name, const char * value) {
 #if defined WIN32
   size_t namelen = strlen(name);
   size_t valuelen = (value==NULL ? 0 : strlen(value));
@@ -399,12 +445,3 @@ my_setenv (const char * name, const char * value) {
   return -1;
 #endif
 }
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
