@@ -1,6 +1,6 @@
 /* gcompris - properties.h
  *
- * Time-stamp: <2006/03/02 00:48:25 bruno>
+ * Time-stamp: <2006/08/28 23:54:33 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -27,9 +27,8 @@
 typedef struct {
   gint		music;
   gint		fx;
-  gint		audio_works;
   gint		fullscreen;
-  gint		noxrandr;
+  gint		noxf86vm;
   gint		screensize;
   gint		defaultcursor;
   gint		timer;
@@ -38,10 +37,16 @@ typedef struct {
   gint		difficulty_max;
   gint		disable_quit;
   gint		disable_config;
+  gint		display_resource;
   gchar        *root_menu;
   gchar        *local_directory;
   gchar        *user_data_dir;
   gchar        *package_data_dir;
+  gchar        *package_locale_dir;
+  gchar        *package_plugin_dir;
+  gchar        *package_python_plugin_dir;
+  gchar        *system_icon_dir;
+  gchar        *cache_dir;
   gchar	       *locale;
   gchar	       *skin;
   gchar	       *key;
@@ -53,28 +58,27 @@ typedef struct {
   gint          reread_menu;
   gchar        *shared_dir;
   gchar        *users_dir;
-  /* this are set by gcompris_im_init() */
+  /* this are set by gc_im_init() */
   GtkIMContext *context;
   gchar        *default_context;
   gint         experimental;
   gchar        *menu_position;
+  gchar        *server;
 } GcomprisProperties;
 
-GcomprisProperties	*gcompris_get_properties (void);
-GcomprisProperties	*gcompris_properties_new (void);
-void			 gcompris_properties_destroy (GcomprisProperties *props);
-void			 gcompris_properties_save (GcomprisProperties *props);
+GcomprisProperties	*gc_prop_get (void);
+GcomprisProperties	*gc_prop_new (void);
+void			 gc_prop_destroy (GcomprisProperties *props);
+void			 gc_prop_save (GcomprisProperties *props);
+
+gchar                   *gc_prop_default_database_name_get (gchar *shared_dir);
+int			 gc_setenv (const char * name, const char * value);
+
+/* Directories */
+gchar			*gc_prop_user_dirname_get(GcomprisUser *user);
+gchar			*gc_prop_current_user_dirname_get();
+gchar			*gc_prop_board_dirname_get(GcomprisBoard *board);
+gchar			*gc_prop_current_board_dirname_get();
 
-gchar                   *get_default_database_name (gchar *shared_dir);
-int                      create_rootdir (gchar *rootdir);
-int			 my_setenv (const char * name, const char * value);
 
 #endif
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
