@@ -39,7 +39,6 @@ int len=4096, bits=0, which=0;
 int audio_buffers=2048;
 
 static gboolean sound_closed = FALSE;
-static gboolean sound_paused = FALSE;
 
 /******************************************************************************/
 /* some simple exit and error routines                                        */
@@ -79,7 +78,7 @@ int sdlplayer_init()
   // initialize SDL for audio
   if(SDL_Init(SDL_INIT_AUDIO)<0)
     return(cleanExit("SDL_Init"));
-	
+
   // initialize sdl mixer, open up the audio device
   if(Mix_OpenAudio(44100,MIX_DEFAULT_FORMAT,2,audio_buffers)<0)
     return(cleanExit("Mix_OpenAudio"));
@@ -87,9 +86,8 @@ int sdlplayer_init()
   // print out some info on the audio device and stream
   Mix_QuerySpec(&audio_rate, &audio_format, &audio_channels);
   bits=audio_format&0xFF;
-  printf("Opened audio at %d Hz %d bit %s, %d bytes audio buffer\n", audio_rate,
-	 bits, audio_channels>1?"stereo":"mono", audio_buffers );
-  sound_paused = FALSE;
+  g_warning("Opened audio at %d Hz %d bit %s, %d bytes audio buffer\n", audio_rate,
+	    bits, audio_channels>1?"stereo":"mono", audio_buffers );
 
   return(0);
 }
@@ -97,27 +95,24 @@ int sdlplayer_init()
 int sdlplayer_quit(Mix_Music *music)
 {
   // free & close
-  Mix_FreeMusic(music); 
-  Mix_CloseAudio(); 
-  printf("SDL PLAYER SDL_Quit\n"); 
-  SDL_Quit(); 
+  Mix_FreeMusic(music);
+  Mix_CloseAudio();
+  g_warning("SDL PLAYER SDL_Quit\n");
+  SDL_Quit();
 
   return 0;
 }
 
-int sdlplayer_bg(char *filename, int volume)
+int sdlplayer_music(char *filename, int volume)
 {
   Mix_Music *music;
 
-  while (sound_paused)
-    SDL_Delay(50);
-
-  printf("sdlplayer_bg %s\n", filename);
+  g_warning("sdlplayer_bg %s\n", filename);
 
   // load the song
   if(!(music=Mix_LoadMUS(filename)))
     return(cleanExit("Mix_LoadMUS(\"%s\")",filename));
-	
+
   if(Mix_PlayMusic(music, 1)==-1) {
     return(cleanExit("Mix_LoadMUS(0x%p,1)",music));
   }
@@ -125,23 +120,21 @@ int sdlplayer_bg(char *filename, int volume)
   Mix_VolumeMusic(volume);
 
   // wait for the music to complete
-  while((Mix_PlayingMusic() || Mix_PausedMusic()))
+  while(Mix_PlayingMusic() || Mix_PausedMusic())
     {
       SDL_Delay(50);
     }
-	
+
   return(0);
 }
 
-int sdlplayer(char *filename, int volume)
+int sdlplayer_fx(char *filename, int volume)
 {
   Mix_Chunk *sample;
   static int channel;
 
   g_warning("sdlplayer %s\n", filename);
 
-  Mix_PauseMusic();
-
   sample=Mix_LoadWAV_RW(SDL_RWFromFile(filename, "rb"), 1);
   if(!sample) {
     return(cleanExit("Mix_LoadWAV_RW"));
@@ -158,16 +151,6 @@ int sdlplayer(char *filename, int volume)
     {
       SDL_Delay(50);
     }
-	
-  // fade in music. Removed, eats too much CPU on low end PCs
-  /*   for(i=32; i<=128; i+=10) { */
-  /*     Mix_VolumeMusic(i); */
-  /*     SDL_Delay(20); */
-  /*   } */
-  
-  // resume music playback
-  if ((!sound_closed) && (!sound_paused))
-    Mix_ResumeMusic();
 
   // free the sample
   // Mix_Chunk *sample;
@@ -177,30 +160,48 @@ int sdlplayer(char *filename, int volume)
 
   return(0);
 }
+
+void sdlplayer_pause_music()
+{
+  if(!sound_closed && Mix_PlayingMusic())
+    Mix_PauseMusic();
+}
+
+void sdlplayer_halt_music()
+{
+  if(!sound_closed)
+    Mix_HaltMusic();
+}
+
+void sdlplayer_halt_fx()
+{
+  if(!sound_closed)
+    Mix_HaltChannel(-1);
+}
+
+void sdlplayer_resume_music()
+{
+  if(!sound_closed)
+    Mix_ResumeMusic();
+}
+
+void sdlplayer_resume_fx()
+{
+  if(!sound_closed)
+    Mix_Resume(-1);
+}
+
 void sdlplayer_close()
 {
-  Mix_HaltMusic();
-  SDL_PauseAudio(1);
-  Mix_CloseAudio();
   sound_closed = TRUE;
+  Mix_HaltMusic();
+  Mix_HaltChannel(-1);
+  Mix_CloseAudio();
 }
 void sdlplayer_reopen()
 {
   Mix_OpenAudio(44100,MIX_DEFAULT_FORMAT,2,audio_buffers);
-  SDL_PauseAudio(0);
   sound_closed = FALSE;
-  sound_paused = FALSE;
-}
-
-void sdlplayer_pause(){
-  Mix_PauseMusic();
-  sound_paused = TRUE;
-}
-
-void sdlplayer_resume(){
-  // resume music playback
-  if (!sound_closed){
-    Mix_ResumeMusic();
-    sound_paused = FALSE;
-  }
+  Mix_ResumeMusic();
+  Mix_Resume(-1);
 }
