@@ -18,7 +18,6 @@
  */
 
 #include "string.h"
-#include <unistd.h>		/* sleep */
 
 #ifdef __APPLE__
 #   include <sys/types.h>
@@ -29,129 +28,146 @@
 
 static GList	*pending_queue = NULL;
 static int	 sound_policy;
-static gboolean	 is_playing;
+static gboolean	 music_paused = FALSE;
 static gboolean	 sound_closed = FALSE;
 
-#if defined _WIN32 || defined __WIN32__
-# undef WIN32   /* avoid warning on mingw32 */
-# define WIN32
-#endif
-
 /* mutex */
 GMutex		*lock = NULL;
-GMutex		*lock_bg = NULL;
+GMutex		*lock_music = NULL;
+GMutex		*lock_fx = NULL;
 GCond		*cond = NULL;
 
 /* Singleton */
 static guint	 sound_init = 0;
 
 /* Forward function declarations */
-GThread		*thread_scheduler, *thread_scheduler_bgnd;
+GThread		*thread_scheduler_fx, *thread_scheduler_music;
 
-static void	*thread_play_ogg (char *file);
+static void	*thread_play_ogg (gchar *file);
 static char	*get_next_sound_to_play( );
 
-static gpointer  scheduler (gpointer user_data);
-static gpointer  scheduler_bgnd (gpointer user_data);
-
-extern int	 ogg123(char * sound);
+static gpointer  scheduler_fx (gpointer user_data);
+static gpointer  scheduler_music (gpointer user_data);
 
 /* sound control */
-GObject *gcompris_sound_controller = NULL;
-void gcompris_sound_callback(GcomprisSound *ctl, gchar *file, gpointer user_data);
+GObject *gc_sound_controller = NULL;
+void gc_sound_callback(GcomprisSound *ctl, gchar *file, gpointer user_data);
 GHashTable *sound_callbacks = NULL;
 
 /* =====================================================================
  *
  * =====================================================================*/
-void initSound()
+void
+gc_sound_init()
 {
 
-  gcompris_sound_controller = g_object_new (GCOMPRIS_SOUND_TYPE, NULL);
+  /* Check to run the init once only */
+  if(sound_init == 1)
+    {
+      if(sound_closed == TRUE)
+	gc_sound_reopen();
 
-  g_signal_connect( gcompris_sound_controller, 
+	  return;
+    }
+  sound_init = 1;
+
+  gc_sound_controller = g_object_new (GCOMPRIS_SOUND_TYPE, NULL);
+
+  g_signal_connect( gc_sound_controller,
 		    "sound-played",
-		    (GCallback) gcompris_sound_callback,
+		    (GCallback) gc_sound_callback,
 		    NULL);
 
-  g_assert( gcompris_sound_controller != NULL );
-
-  /* Check to run the init once only */
-  if(sound_init == 1) {
-    return;
-  }
-  sound_init = 1;
+  g_assert( gc_sound_controller != NULL );
 
   /* Initialize the thread system */
   if (!g_thread_supported ()) g_thread_init (NULL);
 
   lock = g_mutex_new ();
-  lock_bg = g_mutex_new ();
+  lock_music = g_mutex_new ();
+  lock_fx = g_mutex_new ();
   cond = g_cond_new ();
 
   sound_policy = PLAY_AFTER_CURRENT;
-  is_playing = FALSE;
 
   if(sdlplayer_init()!=0) {
     /* Sound init failed. Desactivate the sound */
-    gcompris_get_properties()->music = 0;
-    gcompris_get_properties()->fx    = 0;
+    gc_prop_get()->music = 0;
+    gc_prop_get()->fx    = 0;
     return;
   }
 
-  thread_scheduler = g_thread_create((GThreadFunc)scheduler, NULL, FALSE, NULL);
-  if (thread_scheduler == NULL)
-    perror("create failed for scheduler");
+  thread_scheduler_fx = g_thread_create((GThreadFunc)scheduler_fx, NULL, FALSE, NULL);
+  if (thread_scheduler_fx == NULL)
+    perror("create failed for fx scheduler");
 
-  thread_scheduler_bgnd = g_thread_create((GThreadFunc)scheduler_bgnd, NULL, FALSE, NULL);
-  if (thread_scheduler_bgnd == NULL)
-    perror("create failed for scheduler background");
+  thread_scheduler_music = g_thread_create((GThreadFunc)scheduler_music, NULL, FALSE, NULL);
+  if (thread_scheduler_music == NULL)
+    perror("create failed for music scheduler");
 
 }
-void gcompris_close_sound()
+
+void
+gc_sound_close()
 {
-  if ( ! ( sound_closed || ( ( gcompris_get_properties()->music ==  0 )
-			     && ( gcompris_get_properties()->fx   == 0) ) ) ){
-    g_mutex_lock(lock);
-    g_mutex_lock(lock_bg);
-    sdlplayer_close();
-    sound_closed = TRUE;
-  }
+  if ( !sound_closed )
+    {
+      sdlplayer_halt_music();
+      sdlplayer_halt_fx();
+      g_mutex_lock(lock_fx);
+      g_mutex_lock(lock_music);
+      sdlplayer_close();
+      sound_closed = TRUE;
+      music_paused = FALSE;
+    }
 }
-void gcompris_reopen_sound()
+
+void
+gc_sound_reopen()
 {
-  if (sound_closed){
-    sdlplayer_reopen();
-    g_mutex_unlock(lock);
-    g_mutex_unlock(lock_bg);
-    sound_closed = FALSE;
-  }
+  if (sound_closed)
+    {
+      sdlplayer_reopen();
+      g_mutex_unlock(lock_fx);
+      g_mutex_unlock(lock_music);
+      sound_closed = FALSE;
+      music_paused = FALSE;
+    }
 }
 
-void gcompris_pause_sound(){
-  sdlplayer_pause();
+void
+gc_sound_pause()
+{
+  sdlplayer_pause_music();
+  music_paused = TRUE;
 }
 
-void gcompris_resume_sound(){
-  sdlplayer_resume();
+void
+gc_sound_resume()
+{
+  sdlplayer_resume_music();
+  music_paused = FALSE;
 }
 
 /* =====================================================================
  *
  * =====================================================================*/
-void setSoundPolicy(int policy)
+void
+gc_sound_policy_set(int policy)
 {
   switch (policy)
     {
     case PLAY_ONLY_IF_IDLE : sound_policy = PLAY_ONLY_IF_IDLE; break;
     case PLAY_AFTER_CURRENT : sound_policy = PLAY_AFTER_CURRENT; break;
+    case PLAY_AND_INTERRUPT : sound_policy = PLAY_AND_INTERRUPT; break;
     default : sound_policy = PLAY_AFTER_CURRENT;
     }
 }
 /* =====================================================================
  *
  * =====================================================================*/
-int getSoundPolicy()
+int
+gc_sound_policy_get()
 {
   return sound_policy;
 }
@@ -161,75 +177,77 @@ int getSoundPolicy()
  *	- launches a single thread for playing and play any file found
  *        in the gcompris music directory
  ======================================================================*/
-static gpointer scheduler_bgnd (gpointer user_data)
+static gpointer
+scheduler_music (gpointer user_data)
 {
+  GcomprisProperties *properties = gc_prop_get();
   gint i;
   gchar *str;
-  gchar *filename;
-  GList *musiclist = NULL;
+  gchar *music_dir;
+  GSList *musiclist = NULL;
   GDir *dir;
   const gchar *one_dirent;
 
   /* Sleep to let gcompris intialisation and intro music to complete */
-#if defined WIN32
-  sleep(20000);
-#else
-  sleep(20);
-#endif
+  g_usleep(25000000);
 
   /* Load the Music directory file names */
-  filename = g_strdup_printf("%s", PACKAGE_DATA_DIR "/music/background");
+  music_dir = g_strconcat(properties->package_data_dir, "/music/background", NULL);
+
+  dir = g_dir_open(music_dir, 0, NULL);
 
-  dir = g_dir_open(filename, 0, NULL);
-      
   if (!dir) {
-    g_warning ("Couldn't open music dir: %s", filename);
-    g_free(filename);
+    g_warning ("Couldn't open music dir: %s", music_dir);
+    g_free(music_dir);
     return NULL;
   }
-  
-  g_free(filename);
-  
+
   /* Fill up the music list */
-  while((one_dirent = g_dir_read_name(dir)) != NULL) {
-
-    if (strcmp(one_dirent, "COPYRIGHT")) {
-      str = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR "/music/background", one_dirent);
-
-      musiclist = g_list_append (musiclist, str);
+  while((one_dirent = g_dir_read_name(dir)) != NULL)
+    {
+      if (g_str_has_suffix(one_dirent, ".ogg"))
+	{
+	  str = g_strdup_printf("%s/%s", music_dir, one_dirent);
+	  musiclist = g_slist_insert (musiclist, str, RAND(0, g_slist_length(musiclist)));
+	}
     }
-  }
   g_dir_close(dir);
 
   /* No music no play */
-  if(g_list_length(musiclist)==0)
-    return NULL;
+  if(g_slist_length(musiclist)==0)
+    {
+      g_free(music_dir);
+      return NULL;
+    }
 
   /* Now loop over all our music files */
   while (TRUE)
     {
-      /* Music can be disabled at any time */
-      if ( !gcompris_get_properties()->music )
-	return NULL;
-
-      for(i=0; i<g_list_length(musiclist); i++)
+      for(i=0; i<g_slist_length(musiclist); i++)
 	{
+	  /* Music can be disabled at any time */
+	  while(!gc_prop_get()->music || music_paused)
+	    g_usleep(1000000);
+
 	  /* WARNING Displaying stuff in a thread seems to make gcompris unstable */
 	  /*	  display_ogg_file_credits((char *)g_list_nth_data(musiclist, i)); */
 	  //	  if(decode_ogg_file((char *)g_list_nth_data(musiclist, i))!=0)
-	  if(sdlplayer_bg((char *)g_list_nth_data(musiclist, i), 128)!=0){
-	    printf("vire de sound_ng\n");
-	    goto exit;
+	  g_mutex_lock(lock_music);
+	  if(sdlplayer_music((char *)g_slist_nth_data(musiclist, i), 128)!=0){
+	    g_warning("sdlplayer_music failed, try again in 5 seconds");
+	    g_usleep(5000000);
 	  }
-	  g_mutex_lock( lock_bg );
-	  g_mutex_unlock( lock_bg );
+	  g_mutex_unlock(lock_music);
+
 	}
     }
 
-
- exit:
-  g_list_free(musiclist);
-  g_warning( "The background thread music is stopped now. The files in %s are not ogg vorbis OR the sound output failed", PACKAGE_DATA_DIR "/music/background");
+  /* Never happen */
+  g_slist_free(musiclist);
+  g_warning( "The background thread music is stopped now. "\
+	     "The files in %s are not ogg vorbis OR the sound output failed",
+	     music_dir);
+  g_free(music_dir);
   return NULL;
 }
 /* =====================================================================
@@ -239,7 +257,8 @@ static gpointer scheduler_bgnd (gpointer user_data)
  *	-	then launches another thread if some sounds are pending
  *	-	the thread never ends
  ======================================================================*/
-static gpointer scheduler (gpointer user_data)
+static gpointer
+scheduler_fx (gpointer user_data)
 {
   char *sound = NULL;
 
@@ -248,7 +267,7 @@ static gpointer scheduler (gpointer user_data)
       if ( ( sound = get_next_sound_to_play( ) ) != NULL )
 	{
 	  thread_play_ogg(sound);
-	  is_playing = FALSE;
+	  g_free(sound);
 	}
       else
 	{
@@ -262,65 +281,38 @@ static gpointer scheduler (gpointer user_data)
 /* =====================================================================
  * Thread function for playing a single file
  ======================================================================*/
-static void* thread_play_ogg (char *file)
+static void*
+thread_play_ogg (gchar *file)
 {
-  gchar *tmpstr;
-  gchar *file_arg = g_strdup(file);
+  gchar *absolute_file;
 
-  g_warning(" thread_play_ogg %s \n", file);
+  g_warning("  Thread_play_ogg %s", file);
 
-  if (!g_file_test (file, G_FILE_TEST_IS_REGULAR)) {
-    gchar *relative_filename;
-    char   locale[3];
-    strncpy( locale, gcompris_get_locale(), 2 );
-    locale[2] = 0; // because strncpy does not put a '\0' at the end of the string
-    relative_filename = g_strdup_printf("sounds/%s/%s.ogg", locale, file);
-    tmpstr = gcompris_find_absolute_filename(relative_filename);
-    g_free(relative_filename);
-    if (!tmpstr){
-      relative_filename = g_strdup_printf("music/%s.ogg", file);
-      tmpstr = gcompris_find_absolute_filename(relative_filename);
-      g_free(relative_filename);
-      if (!tmpstr){
-	/* Try to find a sound file that does not need to be localized 
-	   (ie directly in root /sounds directory) */
-	relative_filename = g_strdup_printf("sounds/%s.ogg", file);
-	tmpstr = gcompris_find_absolute_filename(relative_filename);
-	g_free(relative_filename);
-	if (!tmpstr){
-	  tmpstr = gcompris_find_absolute_filename(file);
-	  if (!tmpstr){
-	  g_warning("Can't find sound %s", file);
-	  if (sound_callbacks)
-	    g_hash_table_remove (sound_callbacks, file);
-	  return NULL;
-	  }
-	}
-      }
-    }
-    g_free( file );
-    file = tmpstr;
-  }
+  absolute_file = gc_file_find_absolute(file);
+
+  if (!absolute_file)
+    return NULL;
+
+  g_warning("   Calling gcompris internal sdlplayer_file (%s)", absolute_file);
+  g_mutex_lock(lock_fx);
+  sdlplayer_fx(absolute_file, 128);
+  g_mutex_unlock(lock_fx);
+  g_signal_emit (gc_sound_controller,
+		 GCOMPRIS_SOUND_GET_CLASS (gc_sound_controller)->sound_played_signal_id,
+		 0 /* details */,
+		 g_strdup(file));
+  g_warning("  sdlplayer_fx(%s) ended.", absolute_file);
+
+  g_free(absolute_file);
 
-  if ( file )
-    {
-      g_warning("Calling gcompris internal sdlplayer_file(%s)\n", file);
-      sdlplayer(file, 128);
-      g_signal_emit (gcompris_sound_controller,
-		     GCOMPRIS_SOUND_GET_CLASS (gcompris_sound_controller)->sound_played_signal_id,
-		     0 /* details */,
-		     file_arg);
-      g_warning("sdlplayer_file(%s) ended.\n", file);
-      g_free( file );
-    }
-  
   return NULL;
 }
 
 /* =====================================================================
  * Returns the next sound play, or NULL if there is no
  ======================================================================*/
-char* get_next_sound_to_play( )
+static char*
+get_next_sound_to_play( )
 {
   char* tmpSound = NULL;
 
@@ -340,10 +332,10 @@ char* get_next_sound_to_play( )
 
 /* =====================================================================
  * Play a OGG sound file.
- * gcompris_play_ogg function to process the sounds.
+ * gc_sound_play_ogg function to process the sounds.
  ======================================================================*/
-
-void	 gcompris_play_ogg_cb(gchar *file, GcomprisSoundCallback cb)
+void
+gc_sound_play_ogg_cb(const gchar *file, GcomprisSoundCallback cb)
 {
 
   g_assert ( cb != NULL);
@@ -359,59 +351,77 @@ void	 gcompris_play_ogg_cb(gchar *file, GcomprisSoundCallback cb)
 
   /* i suppose there will not be two call of that function with same sound file before sound is played */
   g_hash_table_replace (sound_callbacks,
-			intern_file,
+			(gpointer)intern_file,
 			cb);
-  gcompris_play_ogg(intern_file, NULL);
+  gc_sound_play_ogg(intern_file, NULL);
 }
 
 /* =====================================================================
  * Play a list of OGG sound files. The list must be NULL terminated
- * This function wraps the var args into a GList and call the 
- * gcompris_play_ogg_list function to process the sounds.
+ * This function wraps the var args into a GList and call the
+ * gc_sound_play_ogg_list function to process the sounds.
  ======================================================================*/
-void gcompris_play_ogg(char *sound, ...)
+void
+gc_sound_play_ogg(const gchar *sound, ...)
 {
   va_list ap;
   char* tmp = NULL;
   GList* list = NULL;
 
-  if(!sound)
+  if(!sound || !gc_prop_get()->fx)
     return;
 
-  list = g_list_append(list, sound);
+  list = g_list_append(list, (gpointer)sound);
 
   g_warning("Adding %s in the play list queue\n", sound);
 
   va_start( ap, sound);
   while( (tmp = va_arg (ap, char *)))
     {
-      list = g_list_append(list, tmp);
+      list = g_list_append(list, (gpointer)tmp);
     }
   va_end(ap);
 
-  gcompris_play_ogg_list( list );
-  
-  g_list_free(list);  
+  gc_sound_play_ogg_list( list );
+
+  g_list_free(list);
 }
 
 /* =====================================================================
- * Play a list of OGG sound files. 
+ * Play a list of OGG sound files.
  * The given ogg files will be first tested as a locale dependant sound file:
  * sounds/<current gcompris locale>/<sound>
  * If it doesn't exists, then the test is done with a music file:
  * music/<sound>
  =====================================================================*/
-void gcompris_play_ogg_list( GList* files )
+void free_string(gpointer data,  gpointer user_data)
+{
+  g_free(data);
+}
+void
+gc_sound_play_ogg_list( GList* files )
 {
   GList* list;
+  char* tmpSound = NULL;
 
-  if ( !gcompris_get_properties()->fx )
+  if ( !gc_prop_get()->fx )
     return;
 
   if ( 	sound_policy == PLAY_ONLY_IF_IDLE &&
-	( is_playing == TRUE || g_list_length( pending_queue ) > 0 ) )
+        g_list_length( pending_queue ) > 0 )
     return;
 
+  if ( sound_policy == PLAY_AND_INTERRUPT ) {
+    g_warning("halt music");
+    while ( g_list_length(pending_queue) > 0 )
+    {
+      tmpSound = g_list_nth_data( pending_queue, 0 );
+      pending_queue = g_list_remove( pending_queue, tmpSound );
+      g_free(tmpSound);
+    }
+    sdlplayer_halt_fx();
+  }
+
   g_mutex_lock (lock);
 
   list = g_list_first( files );
@@ -423,7 +433,7 @@ void gcompris_play_ogg_list( GList* files )
 	}
       list = g_list_next(list);
     }
-  
+
   g_mutex_unlock (lock);
 
   // Tell the scheduler to check for new sounds to play
@@ -432,9 +442,16 @@ void gcompris_play_ogg_list( GList* files )
 
 }
 
-/* get alphabet sound file name from gunichar */
+/** return a string representing a letter or number audio file
+ *  get alphabet sound file name from gunichar
+ *
+ * the returned sound has the suffix .ogg
+ *
+ * \return a newly allocated string of the form U0033.ogg
+ */
 
-gchar *gcompris_alphabet_sound(gchar *chars)
+gchar *
+gc_sound_alphabet(gchar *chars)
 {
   gchar *next, *str, *prev, *result;
   gint i;
@@ -445,7 +462,6 @@ gchar *gcompris_alphabet_sound(gchar *chars)
 
   next = chars;
   result = NULL;
-  str = g_new0(gchar, 6);
 
   for (i=0; i < length; i++) {
     next_unichar = g_utf8_get_char(next);
@@ -468,13 +484,13 @@ gchar *gcompris_alphabet_sound(gchar *chars)
 }
 
 
-void gcompris_sound_callback(GcomprisSound *ctl, gchar *file, gpointer user_data)
+void gc_sound_callback(GcomprisSound *ctl, gchar *file, gpointer user_data)
 {
   GcomprisSoundCallback cb;
 
   if (!sound_callbacks)
     return;
-  
+
   cb = g_hash_table_lookup (sound_callbacks, file);
 
   if (cb){
@@ -496,8 +512,8 @@ struct _GcomprisSoundPrivate
 #include "gcompris-marshal.h"
 
 static void
-gcompris_sound_instance_init (GTypeInstance   *instance,
-                         gpointer         g_class)
+gc_sound_instance_init (GTypeInstance   *instance,
+			      gpointer         g_class)
 {
         GcomprisSound *self = (GcomprisSound *)instance;
         self->private = g_new (GcomprisSoundPrivate, 1);
@@ -511,15 +527,14 @@ default_sound_played_signal_handler (GcomprisSound *obj, gchar *file, gpointer u
 }
 
 static void
-gcompris_sound_class_init (gpointer g_class,
-                      gpointer g_class_data)
+gc_sound_class_init (gpointer g_class,
+			   gpointer g_class_data)
 {
-        GObjectClass *gobject_class = G_OBJECT_CLASS (g_class);
         GcomprisSoundClass *klass = GCOMPRIS_SOUND_CLASS (g_class);
 
 	klass->sound_played = default_sound_played_signal_handler;
 
-        klass->sound_played_signal_id = 
+        klass->sound_played_signal_id =
                 g_signal_new ("sound-played",
 			      G_TYPE_FROM_CLASS (g_class),
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
@@ -533,7 +548,7 @@ gcompris_sound_class_init (gpointer g_class,
 
 }
 
-GType gcompris_sound_get_type (void)
+GType gc_sound_get_type (void)
 {
         static GType type = 0;
         if (type == 0) {
@@ -541,12 +556,12 @@ GType gcompris_sound_get_type (void)
                         sizeof (GcomprisSoundClass),
                         NULL,   /* base_init */
                         NULL,   /* base_finalize */
-                        gcompris_sound_class_init,   /* class_init */
+                        gc_sound_class_init,   /* class_init */
                         NULL,   /* class_finalize */
                         NULL,   /* class_data */
                         sizeof (GcomprisSound),
                         0,      /* n_preallocs */
-                        gcompris_sound_instance_init    /* instance_init */
+                        gc_sound_instance_init    /* instance_init */
                 };
                 type = g_type_register_static (G_TYPE_OBJECT,
                                                "GcomprisSoundType",
@@ -554,13 +569,3 @@ GType gcompris_sound_get_type (void)
         }
         return type;
 }
-
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
