@@ -31,20 +31,21 @@ typedef enum
 {
   PLAY_ONLY_IF_IDLE		= 0,
   PLAY_AFTER_CURRENT		= 1,
+  PLAY_AND_INTERRUPT		= 2,
 } SoundPolicy;
 
 typedef void (*GcomprisSoundCallback) (gchar *);
 
-void	 gcompris_play_ogg(char *, ...);
-void	 gcompris_play_ogg_cb(char *, GcomprisSoundCallback);
-void	 gcompris_play_ogg_list( GList* files );
-void	 setSoundPolicy(int);
-int	 getSoundPolicy(void);
-void	 initSound(void);
-void	 gcompris_reopen_sound(void);
-void	 gcompris_close_sound(void);
-void	 gcompris_pause_sound(void);
-void	 gcompris_resume_sound(void);
+void	 gc_sound_play_ogg(const gchar *, ...);
+void	 gc_sound_play_ogg_cb(const gchar *, GcomprisSoundCallback);
+void	 gc_sound_play_ogg_list( GList* files );
+void	 gc_sound_policy_set(int);
+int	 gc_sound_policy_get(void);
+void	 gc_sound_init(void);
+void	 gc_sound_reopen(void);
+void	 gc_sound_close(void);
+void	 gc_sound_pause(void);
+void	 gc_sound_resume(void);
 
 int	 decode_ogg_file(char *infile);
 void	 display_ao_devices();
@@ -53,14 +54,19 @@ void	 display_ao_devices();
  * SDL PLAYER
  */
 int	 sdlplayer_init();
-int	 sdlplayer_bg();
 void	 sdlplayer_close();
 void	 sdlplayer_reopen();
-void	 sdlplayer_pause();
-void	 sdlplayer_resume();
-int	 sdlplayer(char *filename, int volume);
 
-gchar *gcompris_alphabet_sound(gchar *chars);
+int	 sdlplayer_music(char *filename, int volume);
+void	 sdlplayer_halt_music();
+void	 sdlplayer_pause_music();
+void	 sdlplayer_resume_music();
+
+void	 sdlplayer_halt_fx();
+void	 sdlplayer_resume_fx();
+int	 sdlplayer_fx(char *filename, int volume);
+
+gchar *gc_sound_alphabet(gchar *chars);
 
 
 /*************************************************************/
@@ -71,7 +77,7 @@ gchar *gcompris_alphabet_sound(gchar *chars);
  */
 #include <glib-object.h>
 
-#define GCOMPRIS_SOUND_TYPE 	  (gcompris_sound_get_type ())
+#define GCOMPRIS_SOUND_TYPE 	  (gc_sound_get_type ())
 #define GCOMPRIS_SOUND(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCOMPRIS_SOUND_TYPE, GcomprisSound))
 #define GCOMPRIS_SOUND_CLASS(klass)	  (G_TYPE_CHECK_CLASS_CAST ((klass), GCOMPRIS_SOUND_TYPE, GcomprisSoundClass))
 #define GCOMPRIS_SOUND_IS(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj),  GCOMPRIS_SOUND_TYPE))
@@ -90,13 +96,13 @@ struct _GcomprisSound {
 
 struct _GcomprisSoundClass {
 	GObjectClass parent;
-        
+
         guint sound_played_signal_id;
-        void (*sound_played) (GcomprisSound *self, gchar *file);
+        void (*sound_played) (GcomprisSound *self, gchar *file, gpointer user_data);
 };
 
 /* used by MAMAN_TYPE_FILE */
-GType gcompris_sound_get_type (void);
+GType gc_sound_get_type (void);
 
 /* API. */
 
@@ -104,6 +110,6 @@ GType gcompris_sound_get_type (void);
 
 
 /* Declaration of GCompris Sound Controller */
-extern GObject *gcompris_sound_controller;
+extern GObject *gc_sound_controller;
 
 #endif
